#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 1873
#define LARGE_STATE_COUNT 516
#define SYMBOL_COUNT 381
#define ALIAS_COUNT 0
#define TOKEN_COUNT 237
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 0
#define MAX_ALIAS_SEQUENCE_LENGTH 17
#define PRODUCTION_ID_COUNT 1

enum ts_symbol_identifiers {
  sym_comment = 1,
  sym_semi_colon = 2,
  sym_keyword_on = 3,
  sym_keyword_let = 4,
  sym_keyword_return = 5,
  sym_keyword_else = 6,
  sym_keyword_end = 7,
  sym_keyword_select = 8,
  sym_keyword_from = 9,
  sym_keyword_only = 10,
  sym_keyword_value = 11,
  sym_keyword_as = 12,
  sym_keyword_omit = 13,
  sym_keyword_explain = 14,
  sym_keyword_full = 15,
  sym_keyword_parallel = 16,
  sym_keyword_timeout = 17,
  sym_keyword_fetch = 18,
  sym_keyword_start_at = 19,
  sym_keyword_limit = 20,
  sym_keyword_by = 21,
  sym_keyword_rand = 22,
  sym_keyword_collate = 23,
  sym_keyword_numeric = 24,
  sym_keyword_asc = 25,
  sym_keyword_desc = 26,
  sym_keyword_order = 27,
  sym_keyword_with = 28,
  sym_keyword_index = 29,
  sym_keyword_no_index = 30,
  sym_keyword_where = 31,
  sym_keyword_split = 32,
  sym_keyword_at = 33,
  sym_keyword_group = 34,
  sym_keyword_all = 35,
  sym_keyword_true = 36,
  sym_keyword_false = 37,
  sym_keyword_begin = 38,
  sym_keyword_cancel = 39,
  sym_keyword_commit = 40,
  sym_keyword_transaction = 41,
  sym_keyword_none = 42,
  sym_keyword_null = 43,
  sym_keyword_and = 44,
  sym_keyword_or = 45,
  sym_keyword_is = 46,
  sym_keyword_not = 47,
  sym_keyword_contains = 48,
  sym_keyword_contains_not = 49,
  sym_keyword_contains_all = 50,
  sym_keyword_contains_any = 51,
  sym_keyword_contains_none = 52,
  sym_keyword_inside = 53,
  sym_keyword_in = 54,
  sym_keyword_not_inside = 55,
  sym_keyword_all_inside = 56,
  sym_keyword_any_inside = 57,
  sym_keyword_none_inside = 58,
  sym_keyword_outside = 59,
  sym_keyword_intersects = 60,
  sym_keyword_chebyshev = 61,
  sym_keyword_cosine = 62,
  sym_keyword_euclidean = 63,
  sym_keyword_hamming = 64,
  sym_keyword_jaccard = 65,
  sym_keyword_manhattan = 66,
  sym_keyword_minkowski = 67,
  sym_keyword_pearson = 68,
  sym_keyword_define = 69,
  sym_keyword_analyzer = 70,
  sym_keyword_event = 71,
  sym_keyword_field = 72,
  sym_keyword_function = 73,
  sym_keyword_namespace = 74,
  sym_keyword_param = 75,
  sym_keyword_scope = 76,
  sym_keyword_drop = 77,
  sym_keyword_schemafull = 78,
  sym_keyword_schemaless = 79,
  sym_keyword_live = 80,
  sym_keyword_diff = 81,
  sym_keyword_flexible = 82,
  sym_keyword_readonly = 83,
  sym_keyword_jwks = 84,
  sym_keyword_eddsa = 85,
  sym_keyword_es256 = 86,
  sym_keyword_es384 = 87,
  sym_keyword_es512 = 88,
  sym_keyword_ps256 = 89,
  sym_keyword_ps384 = 90,
  sym_keyword_ps512 = 91,
  sym_keyword_rs256 = 92,
  sym_keyword_rs384 = 93,
  sym_keyword_rs512 = 94,
  sym_keyword_bm25 = 95,
  sym_keyword_doc_ids_cache = 96,
  sym_keyword_doc_ids_order = 97,
  sym_keyword_doc_lengths_cache = 98,
  sym_keyword_doc_lengths_order = 99,
  sym_keyword_postings_cache = 100,
  sym_keyword_postings_order = 101,
  sym_keyword_terms_cache = 102,
  sym_keyword_terms_order = 103,
  sym_keyword_highlights = 104,
  sym_keyword_any = 105,
  sym_keyword_normal = 106,
  sym_keyword_relation = 107,
  sym_keyword_out = 108,
  sym_keyword_to = 109,
  sym_keyword_changefeed = 110,
  sym_keyword_content = 111,
  sym_keyword_merge = 112,
  sym_keyword_patch = 113,
  sym_keyword_before = 114,
  sym_keyword_after = 115,
  sym_keyword_table = 116,
  sym_keyword_root = 117,
  sym_keyword_token = 118,
  sym_keyword_use = 119,
  sym_keyword_ns = 120,
  sym_keyword_db = 121,
  sym_keyword_user = 122,
  sym_keyword_roles = 123,
  sym_keyword_remove = 124,
  sym_keyword_create = 125,
  sym_keyword_delete = 126,
  sym_keyword_update = 127,
  sym_keyword_insert = 128,
  sym_keyword_into = 129,
  sym_keyword_tokenizers = 130,
  sym_keyword_filters = 131,
  sym_keyword_when = 132,
  sym_keyword_then = 133,
  sym_keyword_type = 134,
  sym_keyword_default = 135,
  sym_keyword_assert = 136,
  sym_keyword_permissions = 137,
  sym_keyword_relate = 138,
  sym_keyword_ignore = 139,
  sym_keyword_values = 140,
  sym_keyword_for = 141,
  sym_keyword_comment = 142,
  sym_keyword_fields = 143,
  sym_keyword_columns = 144,
  sym_keyword_unique = 145,
  sym_keyword_search = 146,
  sym_keyword_session = 147,
  sym_keyword_signin = 148,
  sym_keyword_signup = 149,
  sym_keyword_if = 150,
  sym_keyword_exists = 151,
  sym_keyword_database = 152,
  sym_keyword_password = 153,
  sym_keyword_password_hash = 154,
  sym_keyword_on_duplicate_key_update = 155,
  sym_keyword_count = 156,
  sym_keyword_set = 157,
  sym_keyword_unset = 158,
  sym_keyword_dimension = 159,
  sym_keyword_mtree = 160,
  sym_keyword_dist = 161,
  anon_sym_COMMA = 162,
  anon_sym_DASH_GT = 163,
  anon_sym_LBRACK = 164,
  anon_sym_RBRACK = 165,
  anon_sym_LPAREN = 166,
  anon_sym_RPAREN = 167,
  anon_sym_QMARK = 168,
  anon_sym_COLON = 169,
  anon_sym_LBRACE = 170,
  anon_sym_RBRACE = 171,
  anon_sym_LT_DASH = 172,
  anon_sym_LT_DASH_GT = 173,
  anon_sym_STAR = 174,
  anon_sym_DOT = 175,
  anon_sym_LT = 176,
  anon_sym_GT = 177,
  aux_sym_type_name_token1 = 178,
  anon_sym_blank = 179,
  anon_sym_camel = 180,
  anon_sym_class = 181,
  anon_sym_punct = 182,
  anon_sym_ascii = 183,
  anon_sym_lowercase = 184,
  anon_sym_uppercase = 185,
  anon_sym_edgengram = 186,
  anon_sym_ngram = 187,
  anon_sym_snowball = 188,
  sym_string = 189,
  sym_prefixed_string = 190,
  sym_int = 191,
  sym_float = 192,
  sym_decimal = 193,
  sym_variable_name = 194,
  sym_custom_function_name = 195,
  sym_function_name = 196,
  sym_version_number = 197,
  sym_record_id_ident = 198,
  anon_sym_DOT_DOT = 199,
  anon_sym_EQ = 200,
  sym_duration_part = 201,
  anon_sym_DASH = 202,
  anon_sym_AT = 203,
  anon_sym_LT_PIPE = 204,
  anon_sym_PIPE_GT = 205,
  anon_sym_AMP_AMP = 206,
  anon_sym_PIPE_PIPE = 207,
  anon_sym_QMARK_QMARK = 208,
  anon_sym_QMARK_COLON = 209,
  anon_sym_BANG_EQ = 210,
  anon_sym_EQ_EQ = 211,
  anon_sym_QMARK_EQ = 212,
  anon_sym_STAR_EQ = 213,
  anon_sym_TILDE = 214,
  anon_sym_BANG_TILDE = 215,
  anon_sym_STAR_TILDE = 216,
  anon_sym_LT_EQ = 217,
  anon_sym_GT_EQ = 218,
  anon_sym_PLUS = 219,
  anon_sym_PLUS_EQ = 220,
  anon_sym_DASH_EQ = 221,
  anon_sym_u00d7 = 222,
  anon_sym_SLASH = 223,
  anon_sym_u00f7 = 224,
  anon_sym_STAR_STAR = 225,
  anon_sym_u220b = 226,
  anon_sym_u220c = 227,
  anon_sym_u2287 = 228,
  anon_sym_u2283 = 229,
  anon_sym_u2285 = 230,
  anon_sym_u2208 = 231,
  anon_sym_u2209 = 232,
  anon_sym_u2286 = 233,
  anon_sym_u2282 = 234,
  anon_sym_u2284 = 235,
  anon_sym_AT_AT = 236,
  sym_source_file = 237,
  sym_expressions = 238,
  sym_expression = 239,
  sym_statement = 240,
  sym_begin_statement = 241,
  sym_cancel_statement = 242,
  sym_commit_statement = 243,
  sym_define_analyzer_statement = 244,
  sym_define_event_statement = 245,
  sym_define_field_statement = 246,
  sym_define_function_statement = 247,
  sym_define_function = 248,
  sym_define_index_statement = 249,
  sym_define_namespace_statement = 250,
  sym_define_param_statement = 251,
  sym_define_param = 252,
  sym_define_scope_statement = 253,
  sym_define_table_statement = 254,
  sym_define_token_statement = 255,
  sym_define_user_statement = 256,
  sym_remove_statement = 257,
  sym_create_statement = 258,
  sym_update_statement = 259,
  sym_relate_statement = 260,
  sym_delete_statement = 261,
  sym_insert_statement = 262,
  sym_select_statement = 263,
  sym_with_clause = 264,
  sym_where_clause = 265,
  sym_split_clause = 266,
  sym_group_clause = 267,
  sym_order_clause = 268,
  sym_order_criteria = 269,
  sym_limit_clause = 270,
  sym_fetch_clause = 271,
  sym_timeout_clause = 272,
  sym_parallel_clause = 273,
  sym_explain_clause = 274,
  sym_filter = 275,
  sym_tokenizers_clause = 276,
  sym_filters_clause = 277,
  sym_function_clause = 278,
  sym_on_table_clause = 279,
  sym_when_then_clause = 280,
  sym_type_clause = 281,
  sym_default_clause = 282,
  sym_readonly_clause = 283,
  sym_value_clause = 284,
  sym_assert_clause = 285,
  sym_permissions_for_clause = 286,
  sym_permissions_basic_clause = 287,
  sym_comment_clause = 288,
  sym_param_list = 289,
  sym_block = 290,
  sym_fields_columns_clause = 291,
  sym_unique_clause = 292,
  sym_search_analyzer_clause = 293,
  sym_bm25_clause = 294,
  sym_doc_ids_cache_clause = 295,
  sym_doc_ids_order_clause = 296,
  sym_doc_lengths_cache_clause = 297,
  sym_doc_lengths_order_clause = 298,
  sym_postings_cache_clause = 299,
  sym_postings_order_clause = 300,
  sym_terms_cache_clause = 301,
  sym_terms_order_clause = 302,
  sym_session_clause = 303,
  sym_signin_clause = 304,
  sym_signup_clause = 305,
  sym_table_type_clause = 306,
  sym_table_view_clause = 307,
  sym_changefeed_clause = 308,
  sym_token_type_clause = 309,
  sym_if_not_exists_clause = 310,
  sym_if_exists_clause = 311,
  sym_create_target = 312,
  sym_content_clause = 313,
  sym_set_clause = 314,
  sym_unset_clause = 315,
  sym_return_clause = 316,
  sym_relate_subject = 317,
  sym_merge_clause = 318,
  sym_patch_clause = 319,
  sym_field_assignment = 320,
  sym_value = 321,
  sym_function_call = 322,
  sym_base_value = 323,
  sym_binary_expression = 324,
  sym_path = 325,
  sym_path_element = 326,
  sym_graph_path = 327,
  sym_predicate = 328,
  sym_inclusive_predicate = 329,
  sym_graph_predicate = 330,
  sym_subscript = 331,
  sym_version = 332,
  sym_argument_list = 333,
  sym_argument_list_count = 334,
  sym_type = 335,
  sym_type_name = 336,
  sym_parameterized_type = 337,
  sym_analyzer_tokenizers = 338,
  sym_analyzer_filters = 339,
  sym_number = 340,
  sym_identifier = 341,
  sym_array = 342,
  sym_object = 343,
  sym_object_content = 344,
  sym_object_property = 345,
  sym_object_key = 346,
  sym_record_id = 347,
  sym_record_id_value = 348,
  sym_record_id_range = 349,
  sym_sub_query = 350,
  sym_duration = 351,
  sym_point = 352,
  sym_operator = 353,
  sym_binary_operator = 354,
  sym_assignment_operator = 355,
  aux_sym_expressions_repeat1 = 356,
  aux_sym_define_analyzer_statement_repeat1 = 357,
  aux_sym_define_field_statement_repeat1 = 358,
  aux_sym_define_function_statement_repeat1 = 359,
  aux_sym_define_index_statement_repeat1 = 360,
  aux_sym_define_scope_statement_repeat1 = 361,
  aux_sym_define_table_statement_repeat1 = 362,
  aux_sym_define_user_statement_repeat1 = 363,
  aux_sym_update_statement_repeat1 = 364,
  aux_sym_insert_statement_repeat1 = 365,
  aux_sym_insert_statement_repeat2 = 366,
  aux_sym_insert_statement_repeat3 = 367,
  aux_sym_select_statement_repeat1 = 368,
  aux_sym_order_clause_repeat1 = 369,
  aux_sym_tokenizers_clause_repeat1 = 370,
  aux_sym_filters_clause_repeat1 = 371,
  aux_sym_when_then_clause_repeat1 = 372,
  aux_sym_permissions_for_clause_repeat1 = 373,
  aux_sym_permissions_for_clause_repeat2 = 374,
  aux_sym_param_list_repeat1 = 375,
  aux_sym_search_analyzer_clause_repeat1 = 376,
  aux_sym_path_repeat1 = 377,
  aux_sym_graph_path_repeat1 = 378,
  aux_sym_object_content_repeat1 = 379,
  aux_sym_duration_repeat1 = 380,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_comment] = "comment",
  [sym_semi_colon] = "semi_colon",
  [sym_keyword_on] = "keyword_on",
  [sym_keyword_let] = "keyword_let",
  [sym_keyword_return] = "keyword_return",
  [sym_keyword_else] = "keyword_else",
  [sym_keyword_end] = "keyword_end",
  [sym_keyword_select] = "keyword_select",
  [sym_keyword_from] = "keyword_from",
  [sym_keyword_only] = "keyword_only",
  [sym_keyword_value] = "keyword_value",
  [sym_keyword_as] = "keyword_as",
  [sym_keyword_omit] = "keyword_omit",
  [sym_keyword_explain] = "keyword_explain",
  [sym_keyword_full] = "keyword_full",
  [sym_keyword_parallel] = "keyword_parallel",
  [sym_keyword_timeout] = "keyword_timeout",
  [sym_keyword_fetch] = "keyword_fetch",
  [sym_keyword_start_at] = "keyword_start_at",
  [sym_keyword_limit] = "keyword_limit",
  [sym_keyword_by] = "keyword_by",
  [sym_keyword_rand] = "keyword_rand",
  [sym_keyword_collate] = "keyword_collate",
  [sym_keyword_numeric] = "keyword_numeric",
  [sym_keyword_asc] = "keyword_asc",
  [sym_keyword_desc] = "keyword_desc",
  [sym_keyword_order] = "keyword_order",
  [sym_keyword_with] = "keyword_with",
  [sym_keyword_index] = "keyword_index",
  [sym_keyword_no_index] = "keyword_no_index",
  [sym_keyword_where] = "keyword_where",
  [sym_keyword_split] = "keyword_split",
  [sym_keyword_at] = "keyword_at",
  [sym_keyword_group] = "keyword_group",
  [sym_keyword_all] = "keyword_all",
  [sym_keyword_true] = "keyword_true",
  [sym_keyword_false] = "keyword_false",
  [sym_keyword_begin] = "keyword_begin",
  [sym_keyword_cancel] = "keyword_cancel",
  [sym_keyword_commit] = "keyword_commit",
  [sym_keyword_transaction] = "keyword_transaction",
  [sym_keyword_none] = "keyword_none",
  [sym_keyword_null] = "keyword_null",
  [sym_keyword_and] = "keyword_and",
  [sym_keyword_or] = "keyword_or",
  [sym_keyword_is] = "keyword_is",
  [sym_keyword_not] = "keyword_not",
  [sym_keyword_contains] = "keyword_contains",
  [sym_keyword_contains_not] = "keyword_contains_not",
  [sym_keyword_contains_all] = "keyword_contains_all",
  [sym_keyword_contains_any] = "keyword_contains_any",
  [sym_keyword_contains_none] = "keyword_contains_none",
  [sym_keyword_inside] = "keyword_inside",
  [sym_keyword_in] = "keyword_in",
  [sym_keyword_not_inside] = "keyword_not_inside",
  [sym_keyword_all_inside] = "keyword_all_inside",
  [sym_keyword_any_inside] = "keyword_any_inside",
  [sym_keyword_none_inside] = "keyword_none_inside",
  [sym_keyword_outside] = "keyword_outside",
  [sym_keyword_intersects] = "keyword_intersects",
  [sym_keyword_chebyshev] = "keyword_chebyshev",
  [sym_keyword_cosine] = "keyword_cosine",
  [sym_keyword_euclidean] = "keyword_euclidean",
  [sym_keyword_hamming] = "keyword_hamming",
  [sym_keyword_jaccard] = "keyword_jaccard",
  [sym_keyword_manhattan] = "keyword_manhattan",
  [sym_keyword_minkowski] = "keyword_minkowski",
  [sym_keyword_pearson] = "keyword_pearson",
  [sym_keyword_define] = "keyword_define",
  [sym_keyword_analyzer] = "keyword_analyzer",
  [sym_keyword_event] = "keyword_event",
  [sym_keyword_field] = "keyword_field",
  [sym_keyword_function] = "keyword_function",
  [sym_keyword_namespace] = "keyword_namespace",
  [sym_keyword_param] = "keyword_param",
  [sym_keyword_scope] = "keyword_scope",
  [sym_keyword_drop] = "keyword_drop",
  [sym_keyword_schemafull] = "keyword_schemafull",
  [sym_keyword_schemaless] = "keyword_schemaless",
  [sym_keyword_live] = "keyword_live",
  [sym_keyword_diff] = "keyword_diff",
  [sym_keyword_flexible] = "keyword_flexible",
  [sym_keyword_readonly] = "keyword_readonly",
  [sym_keyword_jwks] = "keyword_jwks",
  [sym_keyword_eddsa] = "keyword_eddsa",
  [sym_keyword_es256] = "keyword_es256",
  [sym_keyword_es384] = "keyword_es384",
  [sym_keyword_es512] = "keyword_es512",
  [sym_keyword_ps256] = "keyword_ps256",
  [sym_keyword_ps384] = "keyword_ps384",
  [sym_keyword_ps512] = "keyword_ps512",
  [sym_keyword_rs256] = "keyword_rs256",
  [sym_keyword_rs384] = "keyword_rs384",
  [sym_keyword_rs512] = "keyword_rs512",
  [sym_keyword_bm25] = "keyword_bm25",
  [sym_keyword_doc_ids_cache] = "keyword_doc_ids_cache",
  [sym_keyword_doc_ids_order] = "keyword_doc_ids_order",
  [sym_keyword_doc_lengths_cache] = "keyword_doc_lengths_cache",
  [sym_keyword_doc_lengths_order] = "keyword_doc_lengths_order",
  [sym_keyword_postings_cache] = "keyword_postings_cache",
  [sym_keyword_postings_order] = "keyword_postings_order",
  [sym_keyword_terms_cache] = "keyword_terms_cache",
  [sym_keyword_terms_order] = "keyword_terms_order",
  [sym_keyword_highlights] = "keyword_highlights",
  [sym_keyword_any] = "keyword_any",
  [sym_keyword_normal] = "keyword_normal",
  [sym_keyword_relation] = "keyword_relation",
  [sym_keyword_out] = "keyword_out",
  [sym_keyword_to] = "keyword_to",
  [sym_keyword_changefeed] = "keyword_changefeed",
  [sym_keyword_content] = "keyword_content",
  [sym_keyword_merge] = "keyword_merge",
  [sym_keyword_patch] = "keyword_patch",
  [sym_keyword_before] = "keyword_before",
  [sym_keyword_after] = "keyword_after",
  [sym_keyword_table] = "keyword_table",
  [sym_keyword_root] = "keyword_root",
  [sym_keyword_token] = "keyword_token",
  [sym_keyword_use] = "keyword_use",
  [sym_keyword_ns] = "keyword_ns",
  [sym_keyword_db] = "keyword_db",
  [sym_keyword_user] = "keyword_user",
  [sym_keyword_roles] = "keyword_roles",
  [sym_keyword_remove] = "keyword_remove",
  [sym_keyword_create] = "keyword_create",
  [sym_keyword_delete] = "keyword_delete",
  [sym_keyword_update] = "keyword_update",
  [sym_keyword_insert] = "keyword_insert",
  [sym_keyword_into] = "keyword_into",
  [sym_keyword_tokenizers] = "keyword_tokenizers",
  [sym_keyword_filters] = "keyword_filters",
  [sym_keyword_when] = "keyword_when",
  [sym_keyword_then] = "keyword_then",
  [sym_keyword_type] = "keyword_type",
  [sym_keyword_default] = "keyword_default",
  [sym_keyword_assert] = "keyword_assert",
  [sym_keyword_permissions] = "keyword_permissions",
  [sym_keyword_relate] = "keyword_relate",
  [sym_keyword_ignore] = "keyword_ignore",
  [sym_keyword_values] = "keyword_values",
  [sym_keyword_for] = "keyword_for",
  [sym_keyword_comment] = "keyword_comment",
  [sym_keyword_fields] = "keyword_fields",
  [sym_keyword_columns] = "keyword_columns",
  [sym_keyword_unique] = "keyword_unique",
  [sym_keyword_search] = "keyword_search",
  [sym_keyword_session] = "keyword_session",
  [sym_keyword_signin] = "keyword_signin",
  [sym_keyword_signup] = "keyword_signup",
  [sym_keyword_if] = "keyword_if",
  [sym_keyword_exists] = "keyword_exists",
  [sym_keyword_database] = "keyword_database",
  [sym_keyword_password] = "keyword_password",
  [sym_keyword_password_hash] = "keyword_password_hash",
  [sym_keyword_on_duplicate_key_update] = "keyword_on_duplicate_key_update",
  [sym_keyword_count] = "keyword_count",
  [sym_keyword_set] = "keyword_set",
  [sym_keyword_unset] = "keyword_unset",
  [sym_keyword_dimension] = "keyword_dimension",
  [sym_keyword_mtree] = "keyword_mtree",
  [sym_keyword_dist] = "keyword_dist",
  [anon_sym_COMMA] = ",",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_QMARK] = "\?",
  [anon_sym_COLON] = ":",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_LT_DASH] = "<-",
  [anon_sym_LT_DASH_GT] = "<->",
  [anon_sym_STAR] = "*",
  [anon_sym_DOT] = ".",
  [anon_sym_LT] = "<",
  [anon_sym_GT] = ">",
  [aux_sym_type_name_token1] = "type_name_token1",
  [anon_sym_blank] = "blank",
  [anon_sym_camel] = "camel",
  [anon_sym_class] = "class",
  [anon_sym_punct] = "punct",
  [anon_sym_ascii] = "ascii",
  [anon_sym_lowercase] = "lowercase",
  [anon_sym_uppercase] = "uppercase",
  [anon_sym_edgengram] = "edgengram",
  [anon_sym_ngram] = "ngram",
  [anon_sym_snowball] = "snowball",
  [sym_string] = "string",
  [sym_prefixed_string] = "prefixed_string",
  [sym_int] = "int",
  [sym_float] = "float",
  [sym_decimal] = "decimal",
  [sym_variable_name] = "variable_name",
  [sym_custom_function_name] = "custom_function_name",
  [sym_function_name] = "function_name",
  [sym_version_number] = "version_number",
  [sym_record_id_ident] = "record_id_ident",
  [anon_sym_DOT_DOT] = "..",
  [anon_sym_EQ] = "=",
  [sym_duration_part] = "duration_part",
  [anon_sym_DASH] = "-",
  [anon_sym_AT] = "@",
  [anon_sym_LT_PIPE] = "<|",
  [anon_sym_PIPE_GT] = "|>",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_QMARK_QMARK] = "\?\?",
  [anon_sym_QMARK_COLON] = "\?:",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_QMARK_EQ] = "\?=",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_TILDE] = "~",
  [anon_sym_BANG_TILDE] = "!~",
  [anon_sym_STAR_TILDE] = "*~",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_PLUS] = "+",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_u00d7] = "\u00d7",
  [anon_sym_SLASH] = "/",
  [anon_sym_u00f7] = "\u00f7",
  [anon_sym_STAR_STAR] = "**",
  [anon_sym_u220b] = "\u220b",
  [anon_sym_u220c] = "\u220c",
  [anon_sym_u2287] = "\u2287",
  [anon_sym_u2283] = "\u2283",
  [anon_sym_u2285] = "\u2285",
  [anon_sym_u2208] = "\u2208",
  [anon_sym_u2209] = "\u2209",
  [anon_sym_u2286] = "\u2286",
  [anon_sym_u2282] = "\u2282",
  [anon_sym_u2284] = "\u2284",
  [anon_sym_AT_AT] = "@@",
  [sym_source_file] = "source_file",
  [sym_expressions] = "expressions",
  [sym_expression] = "expression",
  [sym_statement] = "statement",
  [sym_begin_statement] = "begin_statement",
  [sym_cancel_statement] = "cancel_statement",
  [sym_commit_statement] = "commit_statement",
  [sym_define_analyzer_statement] = "define_analyzer_statement",
  [sym_define_event_statement] = "define_event_statement",
  [sym_define_field_statement] = "define_field_statement",
  [sym_define_function_statement] = "define_function_statement",
  [sym_define_function] = "define_function",
  [sym_define_index_statement] = "define_index_statement",
  [sym_define_namespace_statement] = "define_namespace_statement",
  [sym_define_param_statement] = "define_param_statement",
  [sym_define_param] = "define_param",
  [sym_define_scope_statement] = "define_scope_statement",
  [sym_define_table_statement] = "define_table_statement",
  [sym_define_token_statement] = "define_token_statement",
  [sym_define_user_statement] = "define_user_statement",
  [sym_remove_statement] = "remove_statement",
  [sym_create_statement] = "create_statement",
  [sym_update_statement] = "update_statement",
  [sym_relate_statement] = "relate_statement",
  [sym_delete_statement] = "delete_statement",
  [sym_insert_statement] = "insert_statement",
  [sym_select_statement] = "select_statement",
  [sym_with_clause] = "with_clause",
  [sym_where_clause] = "where_clause",
  [sym_split_clause] = "split_clause",
  [sym_group_clause] = "group_clause",
  [sym_order_clause] = "order_clause",
  [sym_order_criteria] = "order_criteria",
  [sym_limit_clause] = "limit_clause",
  [sym_fetch_clause] = "fetch_clause",
  [sym_timeout_clause] = "timeout_clause",
  [sym_parallel_clause] = "parallel_clause",
  [sym_explain_clause] = "explain_clause",
  [sym_filter] = "filter",
  [sym_tokenizers_clause] = "tokenizers_clause",
  [sym_filters_clause] = "filters_clause",
  [sym_function_clause] = "function_clause",
  [sym_on_table_clause] = "on_table_clause",
  [sym_when_then_clause] = "when_then_clause",
  [sym_type_clause] = "type_clause",
  [sym_default_clause] = "default_clause",
  [sym_readonly_clause] = "readonly_clause",
  [sym_value_clause] = "value_clause",
  [sym_assert_clause] = "assert_clause",
  [sym_permissions_for_clause] = "permissions_for_clause",
  [sym_permissions_basic_clause] = "permissions_basic_clause",
  [sym_comment_clause] = "comment_clause",
  [sym_param_list] = "param_list",
  [sym_block] = "block",
  [sym_fields_columns_clause] = "fields_columns_clause",
  [sym_unique_clause] = "unique_clause",
  [sym_search_analyzer_clause] = "search_analyzer_clause",
  [sym_bm25_clause] = "bm25_clause",
  [sym_doc_ids_cache_clause] = "doc_ids_cache_clause",
  [sym_doc_ids_order_clause] = "doc_ids_order_clause",
  [sym_doc_lengths_cache_clause] = "doc_lengths_cache_clause",
  [sym_doc_lengths_order_clause] = "doc_lengths_order_clause",
  [sym_postings_cache_clause] = "postings_cache_clause",
  [sym_postings_order_clause] = "postings_order_clause",
  [sym_terms_cache_clause] = "terms_cache_clause",
  [sym_terms_order_clause] = "terms_order_clause",
  [sym_session_clause] = "session_clause",
  [sym_signin_clause] = "signin_clause",
  [sym_signup_clause] = "signup_clause",
  [sym_table_type_clause] = "table_type_clause",
  [sym_table_view_clause] = "table_view_clause",
  [sym_changefeed_clause] = "changefeed_clause",
  [sym_token_type_clause] = "token_type_clause",
  [sym_if_not_exists_clause] = "if_not_exists_clause",
  [sym_if_exists_clause] = "if_exists_clause",
  [sym_create_target] = "create_target",
  [sym_content_clause] = "content_clause",
  [sym_set_clause] = "set_clause",
  [sym_unset_clause] = "unset_clause",
  [sym_return_clause] = "return_clause",
  [sym_relate_subject] = "relate_subject",
  [sym_merge_clause] = "merge_clause",
  [sym_patch_clause] = "patch_clause",
  [sym_field_assignment] = "field_assignment",
  [sym_value] = "value",
  [sym_function_call] = "function_call",
  [sym_base_value] = "base_value",
  [sym_binary_expression] = "binary_expression",
  [sym_path] = "path",
  [sym_path_element] = "path_element",
  [sym_graph_path] = "graph_path",
  [sym_predicate] = "predicate",
  [sym_inclusive_predicate] = "inclusive_predicate",
  [sym_graph_predicate] = "graph_predicate",
  [sym_subscript] = "subscript",
  [sym_version] = "version",
  [sym_argument_list] = "argument_list",
  [sym_argument_list_count] = "argument_list_count",
  [sym_type] = "type",
  [sym_type_name] = "type_name",
  [sym_parameterized_type] = "parameterized_type",
  [sym_analyzer_tokenizers] = "analyzer_tokenizers",
  [sym_analyzer_filters] = "analyzer_filters",
  [sym_number] = "number",
  [sym_identifier] = "identifier",
  [sym_array] = "array",
  [sym_object] = "object",
  [sym_object_content] = "object_content",
  [sym_object_property] = "object_property",
  [sym_object_key] = "object_key",
  [sym_record_id] = "record_id",
  [sym_record_id_value] = "record_id_value",
  [sym_record_id_range] = "record_id_range",
  [sym_sub_query] = "sub_query",
  [sym_duration] = "duration",
  [sym_point] = "point",
  [sym_operator] = "operator",
  [sym_binary_operator] = "binary_operator",
  [sym_assignment_operator] = "assignment_operator",
  [aux_sym_expressions_repeat1] = "expressions_repeat1",
  [aux_sym_define_analyzer_statement_repeat1] = "define_analyzer_statement_repeat1",
  [aux_sym_define_field_statement_repeat1] = "define_field_statement_repeat1",
  [aux_sym_define_function_statement_repeat1] = "define_function_statement_repeat1",
  [aux_sym_define_index_statement_repeat1] = "define_index_statement_repeat1",
  [aux_sym_define_scope_statement_repeat1] = "define_scope_statement_repeat1",
  [aux_sym_define_table_statement_repeat1] = "define_table_statement_repeat1",
  [aux_sym_define_user_statement_repeat1] = "define_user_statement_repeat1",
  [aux_sym_update_statement_repeat1] = "update_statement_repeat1",
  [aux_sym_insert_statement_repeat1] = "insert_statement_repeat1",
  [aux_sym_insert_statement_repeat2] = "insert_statement_repeat2",
  [aux_sym_insert_statement_repeat3] = "insert_statement_repeat3",
  [aux_sym_select_statement_repeat1] = "select_statement_repeat1",
  [aux_sym_order_clause_repeat1] = "order_clause_repeat1",
  [aux_sym_tokenizers_clause_repeat1] = "tokenizers_clause_repeat1",
  [aux_sym_filters_clause_repeat1] = "filters_clause_repeat1",
  [aux_sym_when_then_clause_repeat1] = "when_then_clause_repeat1",
  [aux_sym_permissions_for_clause_repeat1] = "permissions_for_clause_repeat1",
  [aux_sym_permissions_for_clause_repeat2] = "permissions_for_clause_repeat2",
  [aux_sym_param_list_repeat1] = "param_list_repeat1",
  [aux_sym_search_analyzer_clause_repeat1] = "search_analyzer_clause_repeat1",
  [aux_sym_path_repeat1] = "path_repeat1",
  [aux_sym_graph_path_repeat1] = "graph_path_repeat1",
  [aux_sym_object_content_repeat1] = "object_content_repeat1",
  [aux_sym_duration_repeat1] = "duration_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_comment] = sym_comment,
  [sym_semi_colon] = sym_semi_colon,
  [sym_keyword_on] = sym_keyword_on,
  [sym_keyword_let] = sym_keyword_let,
  [sym_keyword_return] = sym_keyword_return,
  [sym_keyword_else] = sym_keyword_else,
  [sym_keyword_end] = sym_keyword_end,
  [sym_keyword_select] = sym_keyword_select,
  [sym_keyword_from] = sym_keyword_from,
  [sym_keyword_only] = sym_keyword_only,
  [sym_keyword_value] = sym_keyword_value,
  [sym_keyword_as] = sym_keyword_as,
  [sym_keyword_omit] = sym_keyword_omit,
  [sym_keyword_explain] = sym_keyword_explain,
  [sym_keyword_full] = sym_keyword_full,
  [sym_keyword_parallel] = sym_keyword_parallel,
  [sym_keyword_timeout] = sym_keyword_timeout,
  [sym_keyword_fetch] = sym_keyword_fetch,
  [sym_keyword_start_at] = sym_keyword_start_at,
  [sym_keyword_limit] = sym_keyword_limit,
  [sym_keyword_by] = sym_keyword_by,
  [sym_keyword_rand] = sym_keyword_rand,
  [sym_keyword_collate] = sym_keyword_collate,
  [sym_keyword_numeric] = sym_keyword_numeric,
  [sym_keyword_asc] = sym_keyword_asc,
  [sym_keyword_desc] = sym_keyword_desc,
  [sym_keyword_order] = sym_keyword_order,
  [sym_keyword_with] = sym_keyword_with,
  [sym_keyword_index] = sym_keyword_index,
  [sym_keyword_no_index] = sym_keyword_no_index,
  [sym_keyword_where] = sym_keyword_where,
  [sym_keyword_split] = sym_keyword_split,
  [sym_keyword_at] = sym_keyword_at,
  [sym_keyword_group] = sym_keyword_group,
  [sym_keyword_all] = sym_keyword_all,
  [sym_keyword_true] = sym_keyword_true,
  [sym_keyword_false] = sym_keyword_false,
  [sym_keyword_begin] = sym_keyword_begin,
  [sym_keyword_cancel] = sym_keyword_cancel,
  [sym_keyword_commit] = sym_keyword_commit,
  [sym_keyword_transaction] = sym_keyword_transaction,
  [sym_keyword_none] = sym_keyword_none,
  [sym_keyword_null] = sym_keyword_null,
  [sym_keyword_and] = sym_keyword_and,
  [sym_keyword_or] = sym_keyword_or,
  [sym_keyword_is] = sym_keyword_is,
  [sym_keyword_not] = sym_keyword_not,
  [sym_keyword_contains] = sym_keyword_contains,
  [sym_keyword_contains_not] = sym_keyword_contains_not,
  [sym_keyword_contains_all] = sym_keyword_contains_all,
  [sym_keyword_contains_any] = sym_keyword_contains_any,
  [sym_keyword_contains_none] = sym_keyword_contains_none,
  [sym_keyword_inside] = sym_keyword_inside,
  [sym_keyword_in] = sym_keyword_in,
  [sym_keyword_not_inside] = sym_keyword_not_inside,
  [sym_keyword_all_inside] = sym_keyword_all_inside,
  [sym_keyword_any_inside] = sym_keyword_any_inside,
  [sym_keyword_none_inside] = sym_keyword_none_inside,
  [sym_keyword_outside] = sym_keyword_outside,
  [sym_keyword_intersects] = sym_keyword_intersects,
  [sym_keyword_chebyshev] = sym_keyword_chebyshev,
  [sym_keyword_cosine] = sym_keyword_cosine,
  [sym_keyword_euclidean] = sym_keyword_euclidean,
  [sym_keyword_hamming] = sym_keyword_hamming,
  [sym_keyword_jaccard] = sym_keyword_jaccard,
  [sym_keyword_manhattan] = sym_keyword_manhattan,
  [sym_keyword_minkowski] = sym_keyword_minkowski,
  [sym_keyword_pearson] = sym_keyword_pearson,
  [sym_keyword_define] = sym_keyword_define,
  [sym_keyword_analyzer] = sym_keyword_analyzer,
  [sym_keyword_event] = sym_keyword_event,
  [sym_keyword_field] = sym_keyword_field,
  [sym_keyword_function] = sym_keyword_function,
  [sym_keyword_namespace] = sym_keyword_namespace,
  [sym_keyword_param] = sym_keyword_param,
  [sym_keyword_scope] = sym_keyword_scope,
  [sym_keyword_drop] = sym_keyword_drop,
  [sym_keyword_schemafull] = sym_keyword_schemafull,
  [sym_keyword_schemaless] = sym_keyword_schemaless,
  [sym_keyword_live] = sym_keyword_live,
  [sym_keyword_diff] = sym_keyword_diff,
  [sym_keyword_flexible] = sym_keyword_flexible,
  [sym_keyword_readonly] = sym_keyword_readonly,
  [sym_keyword_jwks] = sym_keyword_jwks,
  [sym_keyword_eddsa] = sym_keyword_eddsa,
  [sym_keyword_es256] = sym_keyword_es256,
  [sym_keyword_es384] = sym_keyword_es384,
  [sym_keyword_es512] = sym_keyword_es512,
  [sym_keyword_ps256] = sym_keyword_ps256,
  [sym_keyword_ps384] = sym_keyword_ps384,
  [sym_keyword_ps512] = sym_keyword_ps512,
  [sym_keyword_rs256] = sym_keyword_rs256,
  [sym_keyword_rs384] = sym_keyword_rs384,
  [sym_keyword_rs512] = sym_keyword_rs512,
  [sym_keyword_bm25] = sym_keyword_bm25,
  [sym_keyword_doc_ids_cache] = sym_keyword_doc_ids_cache,
  [sym_keyword_doc_ids_order] = sym_keyword_doc_ids_order,
  [sym_keyword_doc_lengths_cache] = sym_keyword_doc_lengths_cache,
  [sym_keyword_doc_lengths_order] = sym_keyword_doc_lengths_order,
  [sym_keyword_postings_cache] = sym_keyword_postings_cache,
  [sym_keyword_postings_order] = sym_keyword_postings_order,
  [sym_keyword_terms_cache] = sym_keyword_terms_cache,
  [sym_keyword_terms_order] = sym_keyword_terms_order,
  [sym_keyword_highlights] = sym_keyword_highlights,
  [sym_keyword_any] = sym_keyword_any,
  [sym_keyword_normal] = sym_keyword_normal,
  [sym_keyword_relation] = sym_keyword_relation,
  [sym_keyword_out] = sym_keyword_out,
  [sym_keyword_to] = sym_keyword_to,
  [sym_keyword_changefeed] = sym_keyword_changefeed,
  [sym_keyword_content] = sym_keyword_content,
  [sym_keyword_merge] = sym_keyword_merge,
  [sym_keyword_patch] = sym_keyword_patch,
  [sym_keyword_before] = sym_keyword_before,
  [sym_keyword_after] = sym_keyword_after,
  [sym_keyword_table] = sym_keyword_table,
  [sym_keyword_root] = sym_keyword_root,
  [sym_keyword_token] = sym_keyword_token,
  [sym_keyword_use] = sym_keyword_use,
  [sym_keyword_ns] = sym_keyword_ns,
  [sym_keyword_db] = sym_keyword_db,
  [sym_keyword_user] = sym_keyword_user,
  [sym_keyword_roles] = sym_keyword_roles,
  [sym_keyword_remove] = sym_keyword_remove,
  [sym_keyword_create] = sym_keyword_create,
  [sym_keyword_delete] = sym_keyword_delete,
  [sym_keyword_update] = sym_keyword_update,
  [sym_keyword_insert] = sym_keyword_insert,
  [sym_keyword_into] = sym_keyword_into,
  [sym_keyword_tokenizers] = sym_keyword_tokenizers,
  [sym_keyword_filters] = sym_keyword_filters,
  [sym_keyword_when] = sym_keyword_when,
  [sym_keyword_then] = sym_keyword_then,
  [sym_keyword_type] = sym_keyword_type,
  [sym_keyword_default] = sym_keyword_default,
  [sym_keyword_assert] = sym_keyword_assert,
  [sym_keyword_permissions] = sym_keyword_permissions,
  [sym_keyword_relate] = sym_keyword_relate,
  [sym_keyword_ignore] = sym_keyword_ignore,
  [sym_keyword_values] = sym_keyword_values,
  [sym_keyword_for] = sym_keyword_for,
  [sym_keyword_comment] = sym_keyword_comment,
  [sym_keyword_fields] = sym_keyword_fields,
  [sym_keyword_columns] = sym_keyword_columns,
  [sym_keyword_unique] = sym_keyword_unique,
  [sym_keyword_search] = sym_keyword_search,
  [sym_keyword_session] = sym_keyword_session,
  [sym_keyword_signin] = sym_keyword_signin,
  [sym_keyword_signup] = sym_keyword_signup,
  [sym_keyword_if] = sym_keyword_if,
  [sym_keyword_exists] = sym_keyword_exists,
  [sym_keyword_database] = sym_keyword_database,
  [sym_keyword_password] = sym_keyword_password,
  [sym_keyword_password_hash] = sym_keyword_password_hash,
  [sym_keyword_on_duplicate_key_update] = sym_keyword_on_duplicate_key_update,
  [sym_keyword_count] = sym_keyword_count,
  [sym_keyword_set] = sym_keyword_set,
  [sym_keyword_unset] = sym_keyword_unset,
  [sym_keyword_dimension] = sym_keyword_dimension,
  [sym_keyword_mtree] = sym_keyword_mtree,
  [sym_keyword_dist] = sym_keyword_dist,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_LT_DASH] = anon_sym_LT_DASH,
  [anon_sym_LT_DASH_GT] = anon_sym_LT_DASH_GT,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_GT] = anon_sym_GT,
  [aux_sym_type_name_token1] = aux_sym_type_name_token1,
  [anon_sym_blank] = anon_sym_blank,
  [anon_sym_camel] = anon_sym_camel,
  [anon_sym_class] = anon_sym_class,
  [anon_sym_punct] = anon_sym_punct,
  [anon_sym_ascii] = anon_sym_ascii,
  [anon_sym_lowercase] = anon_sym_lowercase,
  [anon_sym_uppercase] = anon_sym_uppercase,
  [anon_sym_edgengram] = anon_sym_edgengram,
  [anon_sym_ngram] = anon_sym_ngram,
  [anon_sym_snowball] = anon_sym_snowball,
  [sym_string] = sym_string,
  [sym_prefixed_string] = sym_prefixed_string,
  [sym_int] = sym_int,
  [sym_float] = sym_float,
  [sym_decimal] = sym_decimal,
  [sym_variable_name] = sym_variable_name,
  [sym_custom_function_name] = sym_custom_function_name,
  [sym_function_name] = sym_function_name,
  [sym_version_number] = sym_version_number,
  [sym_record_id_ident] = sym_record_id_ident,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [anon_sym_EQ] = anon_sym_EQ,
  [sym_duration_part] = sym_duration_part,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_LT_PIPE] = anon_sym_LT_PIPE,
  [anon_sym_PIPE_GT] = anon_sym_PIPE_GT,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_QMARK_QMARK] = anon_sym_QMARK_QMARK,
  [anon_sym_QMARK_COLON] = anon_sym_QMARK_COLON,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_QMARK_EQ] = anon_sym_QMARK_EQ,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_BANG_TILDE] = anon_sym_BANG_TILDE,
  [anon_sym_STAR_TILDE] = anon_sym_STAR_TILDE,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_u00d7] = anon_sym_u00d7,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_u00f7] = anon_sym_u00f7,
  [anon_sym_STAR_STAR] = anon_sym_STAR_STAR,
  [anon_sym_u220b] = anon_sym_u220b,
  [anon_sym_u220c] = anon_sym_u220c,
  [anon_sym_u2287] = anon_sym_u2287,
  [anon_sym_u2283] = anon_sym_u2283,
  [anon_sym_u2285] = anon_sym_u2285,
  [anon_sym_u2208] = anon_sym_u2208,
  [anon_sym_u2209] = anon_sym_u2209,
  [anon_sym_u2286] = anon_sym_u2286,
  [anon_sym_u2282] = anon_sym_u2282,
  [anon_sym_u2284] = anon_sym_u2284,
  [anon_sym_AT_AT] = anon_sym_AT_AT,
  [sym_source_file] = sym_source_file,
  [sym_expressions] = sym_expressions,
  [sym_expression] = sym_expression,
  [sym_statement] = sym_statement,
  [sym_begin_statement] = sym_begin_statement,
  [sym_cancel_statement] = sym_cancel_statement,
  [sym_commit_statement] = sym_commit_statement,
  [sym_define_analyzer_statement] = sym_define_analyzer_statement,
  [sym_define_event_statement] = sym_define_event_statement,
  [sym_define_field_statement] = sym_define_field_statement,
  [sym_define_function_statement] = sym_define_function_statement,
  [sym_define_function] = sym_define_function,
  [sym_define_index_statement] = sym_define_index_statement,
  [sym_define_namespace_statement] = sym_define_namespace_statement,
  [sym_define_param_statement] = sym_define_param_statement,
  [sym_define_param] = sym_define_param,
  [sym_define_scope_statement] = sym_define_scope_statement,
  [sym_define_table_statement] = sym_define_table_statement,
  [sym_define_token_statement] = sym_define_token_statement,
  [sym_define_user_statement] = sym_define_user_statement,
  [sym_remove_statement] = sym_remove_statement,
  [sym_create_statement] = sym_create_statement,
  [sym_update_statement] = sym_update_statement,
  [sym_relate_statement] = sym_relate_statement,
  [sym_delete_statement] = sym_delete_statement,
  [sym_insert_statement] = sym_insert_statement,
  [sym_select_statement] = sym_select_statement,
  [sym_with_clause] = sym_with_clause,
  [sym_where_clause] = sym_where_clause,
  [sym_split_clause] = sym_split_clause,
  [sym_group_clause] = sym_group_clause,
  [sym_order_clause] = sym_order_clause,
  [sym_order_criteria] = sym_order_criteria,
  [sym_limit_clause] = sym_limit_clause,
  [sym_fetch_clause] = sym_fetch_clause,
  [sym_timeout_clause] = sym_timeout_clause,
  [sym_parallel_clause] = sym_parallel_clause,
  [sym_explain_clause] = sym_explain_clause,
  [sym_filter] = sym_filter,
  [sym_tokenizers_clause] = sym_tokenizers_clause,
  [sym_filters_clause] = sym_filters_clause,
  [sym_function_clause] = sym_function_clause,
  [sym_on_table_clause] = sym_on_table_clause,
  [sym_when_then_clause] = sym_when_then_clause,
  [sym_type_clause] = sym_type_clause,
  [sym_default_clause] = sym_default_clause,
  [sym_readonly_clause] = sym_readonly_clause,
  [sym_value_clause] = sym_value_clause,
  [sym_assert_clause] = sym_assert_clause,
  [sym_permissions_for_clause] = sym_permissions_for_clause,
  [sym_permissions_basic_clause] = sym_permissions_basic_clause,
  [sym_comment_clause] = sym_comment_clause,
  [sym_param_list] = sym_param_list,
  [sym_block] = sym_block,
  [sym_fields_columns_clause] = sym_fields_columns_clause,
  [sym_unique_clause] = sym_unique_clause,
  [sym_search_analyzer_clause] = sym_search_analyzer_clause,
  [sym_bm25_clause] = sym_bm25_clause,
  [sym_doc_ids_cache_clause] = sym_doc_ids_cache_clause,
  [sym_doc_ids_order_clause] = sym_doc_ids_order_clause,
  [sym_doc_lengths_cache_clause] = sym_doc_lengths_cache_clause,
  [sym_doc_lengths_order_clause] = sym_doc_lengths_order_clause,
  [sym_postings_cache_clause] = sym_postings_cache_clause,
  [sym_postings_order_clause] = sym_postings_order_clause,
  [sym_terms_cache_clause] = sym_terms_cache_clause,
  [sym_terms_order_clause] = sym_terms_order_clause,
  [sym_session_clause] = sym_session_clause,
  [sym_signin_clause] = sym_signin_clause,
  [sym_signup_clause] = sym_signup_clause,
  [sym_table_type_clause] = sym_table_type_clause,
  [sym_table_view_clause] = sym_table_view_clause,
  [sym_changefeed_clause] = sym_changefeed_clause,
  [sym_token_type_clause] = sym_token_type_clause,
  [sym_if_not_exists_clause] = sym_if_not_exists_clause,
  [sym_if_exists_clause] = sym_if_exists_clause,
  [sym_create_target] = sym_create_target,
  [sym_content_clause] = sym_content_clause,
  [sym_set_clause] = sym_set_clause,
  [sym_unset_clause] = sym_unset_clause,
  [sym_return_clause] = sym_return_clause,
  [sym_relate_subject] = sym_relate_subject,
  [sym_merge_clause] = sym_merge_clause,
  [sym_patch_clause] = sym_patch_clause,
  [sym_field_assignment] = sym_field_assignment,
  [sym_value] = sym_value,
  [sym_function_call] = sym_function_call,
  [sym_base_value] = sym_base_value,
  [sym_binary_expression] = sym_binary_expression,
  [sym_path] = sym_path,
  [sym_path_element] = sym_path_element,
  [sym_graph_path] = sym_graph_path,
  [sym_predicate] = sym_predicate,
  [sym_inclusive_predicate] = sym_inclusive_predicate,
  [sym_graph_predicate] = sym_graph_predicate,
  [sym_subscript] = sym_subscript,
  [sym_version] = sym_version,
  [sym_argument_list] = sym_argument_list,
  [sym_argument_list_count] = sym_argument_list_count,
  [sym_type] = sym_type,
  [sym_type_name] = sym_type_name,
  [sym_parameterized_type] = sym_parameterized_type,
  [sym_analyzer_tokenizers] = sym_analyzer_tokenizers,
  [sym_analyzer_filters] = sym_analyzer_filters,
  [sym_number] = sym_number,
  [sym_identifier] = sym_identifier,
  [sym_array] = sym_array,
  [sym_object] = sym_object,
  [sym_object_content] = sym_object_content,
  [sym_object_property] = sym_object_property,
  [sym_object_key] = sym_object_key,
  [sym_record_id] = sym_record_id,
  [sym_record_id_value] = sym_record_id_value,
  [sym_record_id_range] = sym_record_id_range,
  [sym_sub_query] = sym_sub_query,
  [sym_duration] = sym_duration,
  [sym_point] = sym_point,
  [sym_operator] = sym_operator,
  [sym_binary_operator] = sym_binary_operator,
  [sym_assignment_operator] = sym_assignment_operator,
  [aux_sym_expressions_repeat1] = aux_sym_expressions_repeat1,
  [aux_sym_define_analyzer_statement_repeat1] = aux_sym_define_analyzer_statement_repeat1,
  [aux_sym_define_field_statement_repeat1] = aux_sym_define_field_statement_repeat1,
  [aux_sym_define_function_statement_repeat1] = aux_sym_define_function_statement_repeat1,
  [aux_sym_define_index_statement_repeat1] = aux_sym_define_index_statement_repeat1,
  [aux_sym_define_scope_statement_repeat1] = aux_sym_define_scope_statement_repeat1,
  [aux_sym_define_table_statement_repeat1] = aux_sym_define_table_statement_repeat1,
  [aux_sym_define_user_statement_repeat1] = aux_sym_define_user_statement_repeat1,
  [aux_sym_update_statement_repeat1] = aux_sym_update_statement_repeat1,
  [aux_sym_insert_statement_repeat1] = aux_sym_insert_statement_repeat1,
  [aux_sym_insert_statement_repeat2] = aux_sym_insert_statement_repeat2,
  [aux_sym_insert_statement_repeat3] = aux_sym_insert_statement_repeat3,
  [aux_sym_select_statement_repeat1] = aux_sym_select_statement_repeat1,
  [aux_sym_order_clause_repeat1] = aux_sym_order_clause_repeat1,
  [aux_sym_tokenizers_clause_repeat1] = aux_sym_tokenizers_clause_repeat1,
  [aux_sym_filters_clause_repeat1] = aux_sym_filters_clause_repeat1,
  [aux_sym_when_then_clause_repeat1] = aux_sym_when_then_clause_repeat1,
  [aux_sym_permissions_for_clause_repeat1] = aux_sym_permissions_for_clause_repeat1,
  [aux_sym_permissions_for_clause_repeat2] = aux_sym_permissions_for_clause_repeat2,
  [aux_sym_param_list_repeat1] = aux_sym_param_list_repeat1,
  [aux_sym_search_analyzer_clause_repeat1] = aux_sym_search_analyzer_clause_repeat1,
  [aux_sym_path_repeat1] = aux_sym_path_repeat1,
  [aux_sym_graph_path_repeat1] = aux_sym_graph_path_repeat1,
  [aux_sym_object_content_repeat1] = aux_sym_object_content_repeat1,
  [aux_sym_duration_repeat1] = aux_sym_duration_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_semi_colon] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_on] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_let] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_return] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_else] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_end] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_select] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_from] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_only] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_value] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_as] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_omit] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_explain] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_full] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_parallel] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_timeout] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_fetch] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_start_at] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_limit] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_by] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_rand] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_collate] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_numeric] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_asc] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_desc] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_order] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_with] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_index] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_no_index] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_where] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_split] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_at] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_group] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_all] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_true] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_false] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_begin] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_cancel] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_commit] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_transaction] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_none] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_null] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_and] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_or] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_is] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_not] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_contains] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_contains_not] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_contains_all] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_contains_any] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_contains_none] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_inside] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_in] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_not_inside] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_all_inside] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_any_inside] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_none_inside] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_outside] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_intersects] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_chebyshev] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_cosine] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_euclidean] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_hamming] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_jaccard] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_manhattan] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_minkowski] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_pearson] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_define] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_analyzer] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_event] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_field] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_function] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_namespace] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_param] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_scope] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_drop] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_schemafull] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_schemaless] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_live] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_diff] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_flexible] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_readonly] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_jwks] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_eddsa] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_es256] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_es384] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_es512] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_ps256] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_ps384] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_ps512] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_rs256] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_rs384] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_rs512] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_bm25] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_doc_ids_cache] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_doc_ids_order] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_doc_lengths_cache] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_doc_lengths_order] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_postings_cache] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_postings_order] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_terms_cache] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_terms_order] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_highlights] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_any] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_normal] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_relation] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_out] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_to] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_changefeed] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_content] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_merge] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_patch] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_before] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_after] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_table] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_root] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_token] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_use] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_ns] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_db] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_user] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_roles] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_remove] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_create] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_delete] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_update] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_insert] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_into] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_tokenizers] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_filters] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_when] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_then] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_type] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_default] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_assert] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_permissions] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_relate] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_ignore] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_values] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_for] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_fields] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_columns] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_unique] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_search] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_session] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_signin] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_signup] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_if] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_exists] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_database] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_password] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_password_hash] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_on_duplicate_key_update] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_count] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_set] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_unset] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_dimension] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_mtree] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_dist] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_type_name_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_blank] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_camel] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_class] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_punct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ascii] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_lowercase] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uppercase] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_edgengram] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ngram] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_snowball] = {
    .visible = true,
    .named = false,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_prefixed_string] = {
    .visible = true,
    .named = true,
  },
  [sym_int] = {
    .visible = true,
    .named = true,
  },
  [sym_float] = {
    .visible = true,
    .named = true,
  },
  [sym_decimal] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_name] = {
    .visible = true,
    .named = true,
  },
  [sym_custom_function_name] = {
    .visible = true,
    .named = true,
  },
  [sym_function_name] = {
    .visible = true,
    .named = true,
  },
  [sym_version_number] = {
    .visible = true,
    .named = true,
  },
  [sym_record_id_ident] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [sym_duration_part] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u00d7] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u00f7] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u220b] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u220c] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2287] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2283] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2285] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2208] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2209] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2286] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2282] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2284] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT_AT] = {
    .visible = true,
    .named = false,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_expressions] = {
    .visible = true,
    .named = true,
  },
  [sym_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_begin_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_cancel_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_commit_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_analyzer_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_event_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_field_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_function_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_function] = {
    .visible = true,
    .named = true,
  },
  [sym_define_index_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_namespace_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_param_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_param] = {
    .visible = true,
    .named = true,
  },
  [sym_define_scope_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_table_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_token_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_user_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_remove_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_create_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_update_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_relate_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_delete_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_insert_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_select_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_with_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_where_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_split_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_group_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_order_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_order_criteria] = {
    .visible = true,
    .named = true,
  },
  [sym_limit_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_fetch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_timeout_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_parallel_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_explain_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_filter] = {
    .visible = true,
    .named = true,
  },
  [sym_tokenizers_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_filters_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_function_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_on_table_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_when_then_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_type_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_default_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_readonly_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_value_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_assert_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_permissions_for_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_permissions_basic_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_comment_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_param_list] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_fields_columns_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_unique_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_search_analyzer_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_bm25_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_doc_ids_cache_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_doc_ids_order_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_doc_lengths_cache_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_doc_lengths_order_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_postings_cache_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_postings_order_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_terms_cache_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_terms_order_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_session_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_signin_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_signup_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_table_type_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_table_view_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_changefeed_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_token_type_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_if_not_exists_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_if_exists_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_create_target] = {
    .visible = true,
    .named = true,
  },
  [sym_content_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_set_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_unset_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_return_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_relate_subject] = {
    .visible = true,
    .named = true,
  },
  [sym_merge_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_patch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_field_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_value] = {
    .visible = true,
    .named = true,
  },
  [sym_function_call] = {
    .visible = true,
    .named = true,
  },
  [sym_base_value] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_path] = {
    .visible = true,
    .named = true,
  },
  [sym_path_element] = {
    .visible = true,
    .named = true,
  },
  [sym_graph_path] = {
    .visible = true,
    .named = true,
  },
  [sym_predicate] = {
    .visible = true,
    .named = true,
  },
  [sym_inclusive_predicate] = {
    .visible = true,
    .named = true,
  },
  [sym_graph_predicate] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript] = {
    .visible = true,
    .named = true,
  },
  [sym_version] = {
    .visible = true,
    .named = true,
  },
  [sym_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_argument_list_count] = {
    .visible = true,
    .named = true,
  },
  [sym_type] = {
    .visible = true,
    .named = true,
  },
  [sym_type_name] = {
    .visible = true,
    .named = true,
  },
  [sym_parameterized_type] = {
    .visible = true,
    .named = true,
  },
  [sym_analyzer_tokenizers] = {
    .visible = true,
    .named = true,
  },
  [sym_analyzer_filters] = {
    .visible = true,
    .named = true,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_array] = {
    .visible = true,
    .named = true,
  },
  [sym_object] = {
    .visible = true,
    .named = true,
  },
  [sym_object_content] = {
    .visible = true,
    .named = true,
  },
  [sym_object_property] = {
    .visible = true,
    .named = true,
  },
  [sym_object_key] = {
    .visible = true,
    .named = true,
  },
  [sym_record_id] = {
    .visible = true,
    .named = true,
  },
  [sym_record_id_value] = {
    .visible = true,
    .named = true,
  },
  [sym_record_id_range] = {
    .visible = true,
    .named = true,
  },
  [sym_sub_query] = {
    .visible = true,
    .named = true,
  },
  [sym_duration] = {
    .visible = true,
    .named = true,
  },
  [sym_point] = {
    .visible = true,
    .named = true,
  },
  [sym_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_operator] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_expressions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_define_analyzer_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_define_field_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_define_function_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_define_index_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_define_scope_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_define_table_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_define_user_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_update_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_insert_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_insert_statement_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_insert_statement_repeat3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_select_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_order_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tokenizers_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_filters_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_when_then_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_permissions_for_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_permissions_for_clause_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_param_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_search_analyzer_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_path_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_graph_path_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_content_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_duration_repeat1] = {
    .visible = false,
    .named = false,
  },
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 11,
  [15] = 15,
  [16] = 16,
  [17] = 13,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 2,
  [22] = 22,
  [23] = 23,
  [24] = 15,
  [25] = 25,
  [26] = 16,
  [27] = 12,
  [28] = 28,
  [29] = 18,
  [30] = 30,
  [31] = 7,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 10,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 28,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 37,
  [47] = 30,
  [48] = 45,
  [49] = 36,
  [50] = 33,
  [51] = 9,
  [52] = 8,
  [53] = 41,
  [54] = 39,
  [55] = 34,
  [56] = 38,
  [57] = 32,
  [58] = 25,
  [59] = 23,
  [60] = 44,
  [61] = 42,
  [62] = 19,
  [63] = 43,
  [64] = 22,
  [65] = 20,
  [66] = 6,
  [67] = 3,
  [68] = 5,
  [69] = 4,
  [70] = 19,
  [71] = 71,
  [72] = 3,
  [73] = 23,
  [74] = 74,
  [75] = 75,
  [76] = 76,
  [77] = 74,
  [78] = 5,
  [79] = 23,
  [80] = 42,
  [81] = 4,
  [82] = 6,
  [83] = 71,
  [84] = 84,
  [85] = 42,
  [86] = 86,
  [87] = 75,
  [88] = 84,
  [89] = 19,
  [90] = 76,
  [91] = 9,
  [92] = 8,
  [93] = 16,
  [94] = 11,
  [95] = 12,
  [96] = 15,
  [97] = 9,
  [98] = 13,
  [99] = 86,
  [100] = 8,
  [101] = 18,
  [102] = 10,
  [103] = 45,
  [104] = 22,
  [105] = 42,
  [106] = 7,
  [107] = 32,
  [108] = 2,
  [109] = 23,
  [110] = 25,
  [111] = 28,
  [112] = 30,
  [113] = 33,
  [114] = 34,
  [115] = 19,
  [116] = 37,
  [117] = 41,
  [118] = 2,
  [119] = 43,
  [120] = 20,
  [121] = 36,
  [122] = 44,
  [123] = 39,
  [124] = 38,
  [125] = 125,
  [126] = 2,
  [127] = 127,
  [128] = 128,
  [129] = 128,
  [130] = 127,
  [131] = 125,
  [132] = 132,
  [133] = 133,
  [134] = 134,
  [135] = 135,
  [136] = 133,
  [137] = 137,
  [138] = 133,
  [139] = 134,
  [140] = 135,
  [141] = 135,
  [142] = 134,
  [143] = 5,
  [144] = 5,
  [145] = 135,
  [146] = 135,
  [147] = 133,
  [148] = 133,
  [149] = 6,
  [150] = 5,
  [151] = 134,
  [152] = 6,
  [153] = 135,
  [154] = 132,
  [155] = 4,
  [156] = 134,
  [157] = 3,
  [158] = 4,
  [159] = 133,
  [160] = 6,
  [161] = 135,
  [162] = 4,
  [163] = 134,
  [164] = 137,
  [165] = 133,
  [166] = 3,
  [167] = 134,
  [168] = 3,
  [169] = 135,
  [170] = 134,
  [171] = 133,
  [172] = 6,
  [173] = 76,
  [174] = 19,
  [175] = 4,
  [176] = 5,
  [177] = 133,
  [178] = 134,
  [179] = 23,
  [180] = 135,
  [181] = 133,
  [182] = 135,
  [183] = 134,
  [184] = 133,
  [185] = 3,
  [186] = 134,
  [187] = 135,
  [188] = 42,
  [189] = 133,
  [190] = 134,
  [191] = 135,
  [192] = 86,
  [193] = 84,
  [194] = 74,
  [195] = 75,
  [196] = 135,
  [197] = 134,
  [198] = 133,
  [199] = 71,
  [200] = 134,
  [201] = 135,
  [202] = 133,
  [203] = 135,
  [204] = 135,
  [205] = 135,
  [206] = 134,
  [207] = 133,
  [208] = 134,
  [209] = 133,
  [210] = 133,
  [211] = 135,
  [212] = 134,
  [213] = 134,
  [214] = 133,
  [215] = 135,
  [216] = 133,
  [217] = 134,
  [218] = 133,
  [219] = 135,
  [220] = 8,
  [221] = 9,
  [222] = 134,
  [223] = 15,
  [224] = 11,
  [225] = 16,
  [226] = 18,
  [227] = 227,
  [228] = 227,
  [229] = 15,
  [230] = 12,
  [231] = 13,
  [232] = 10,
  [233] = 10,
  [234] = 13,
  [235] = 16,
  [236] = 11,
  [237] = 12,
  [238] = 227,
  [239] = 9,
  [240] = 8,
  [241] = 18,
  [242] = 20,
  [243] = 28,
  [244] = 134,
  [245] = 19,
  [246] = 133,
  [247] = 23,
  [248] = 42,
  [249] = 19,
  [250] = 135,
  [251] = 23,
  [252] = 227,
  [253] = 30,
  [254] = 33,
  [255] = 34,
  [256] = 36,
  [257] = 38,
  [258] = 39,
  [259] = 45,
  [260] = 20,
  [261] = 43,
  [262] = 41,
  [263] = 37,
  [264] = 32,
  [265] = 7,
  [266] = 22,
  [267] = 44,
  [268] = 227,
  [269] = 227,
  [270] = 28,
  [271] = 271,
  [272] = 272,
  [273] = 25,
  [274] = 274,
  [275] = 12,
  [276] = 2,
  [277] = 30,
  [278] = 33,
  [279] = 16,
  [280] = 13,
  [281] = 34,
  [282] = 10,
  [283] = 36,
  [284] = 38,
  [285] = 39,
  [286] = 45,
  [287] = 42,
  [288] = 11,
  [289] = 37,
  [290] = 32,
  [291] = 227,
  [292] = 18,
  [293] = 44,
  [294] = 43,
  [295] = 22,
  [296] = 227,
  [297] = 41,
  [298] = 15,
  [299] = 7,
  [300] = 25,
  [301] = 7,
  [302] = 302,
  [303] = 32,
  [304] = 135,
  [305] = 37,
  [306] = 271,
  [307] = 134,
  [308] = 133,
  [309] = 41,
  [310] = 43,
  [311] = 20,
  [312] = 45,
  [313] = 39,
  [314] = 19,
  [315] = 42,
  [316] = 38,
  [317] = 36,
  [318] = 34,
  [319] = 302,
  [320] = 33,
  [321] = 30,
  [322] = 23,
  [323] = 323,
  [324] = 227,
  [325] = 323,
  [326] = 272,
  [327] = 227,
  [328] = 135,
  [329] = 227,
  [330] = 227,
  [331] = 227,
  [332] = 25,
  [333] = 28,
  [334] = 22,
  [335] = 44,
  [336] = 134,
  [337] = 133,
  [338] = 338,
  [339] = 339,
  [340] = 340,
  [341] = 341,
  [342] = 227,
  [343] = 227,
  [344] = 227,
  [345] = 227,
  [346] = 339,
  [347] = 341,
  [348] = 341,
  [349] = 349,
  [350] = 339,
  [351] = 135,
  [352] = 352,
  [353] = 134,
  [354] = 133,
  [355] = 355,
  [356] = 135,
  [357] = 134,
  [358] = 133,
  [359] = 341,
  [360] = 340,
  [361] = 133,
  [362] = 339,
  [363] = 134,
  [364] = 349,
  [365] = 365,
  [366] = 135,
  [367] = 341,
  [368] = 227,
  [369] = 355,
  [370] = 352,
  [371] = 365,
  [372] = 339,
  [373] = 339,
  [374] = 341,
  [375] = 133,
  [376] = 134,
  [377] = 377,
  [378] = 378,
  [379] = 379,
  [380] = 380,
  [381] = 377,
  [382] = 382,
  [383] = 383,
  [384] = 227,
  [385] = 385,
  [386] = 382,
  [387] = 383,
  [388] = 135,
  [389] = 133,
  [390] = 227,
  [391] = 385,
  [392] = 135,
  [393] = 134,
  [394] = 379,
  [395] = 378,
  [396] = 378,
  [397] = 397,
  [398] = 134,
  [399] = 135,
  [400] = 382,
  [401] = 378,
  [402] = 378,
  [403] = 382,
  [404] = 134,
  [405] = 133,
  [406] = 133,
  [407] = 135,
  [408] = 378,
  [409] = 397,
  [410] = 382,
  [411] = 135,
  [412] = 380,
  [413] = 382,
  [414] = 134,
  [415] = 133,
  [416] = 378,
  [417] = 417,
  [418] = 378,
  [419] = 419,
  [420] = 86,
  [421] = 417,
  [422] = 422,
  [423] = 19,
  [424] = 422,
  [425] = 74,
  [426] = 42,
  [427] = 378,
  [428] = 23,
  [429] = 227,
  [430] = 135,
  [431] = 75,
  [432] = 42,
  [433] = 419,
  [434] = 135,
  [435] = 382,
  [436] = 133,
  [437] = 378,
  [438] = 134,
  [439] = 378,
  [440] = 133,
  [441] = 71,
  [442] = 378,
  [443] = 133,
  [444] = 134,
  [445] = 135,
  [446] = 382,
  [447] = 378,
  [448] = 19,
  [449] = 76,
  [450] = 84,
  [451] = 422,
  [452] = 76,
  [453] = 71,
  [454] = 75,
  [455] = 86,
  [456] = 23,
  [457] = 134,
  [458] = 84,
  [459] = 74,
  [460] = 422,
  [461] = 135,
  [462] = 134,
  [463] = 133,
  [464] = 135,
  [465] = 134,
  [466] = 422,
  [467] = 76,
  [468] = 133,
  [469] = 227,
  [470] = 71,
  [471] = 422,
  [472] = 378,
  [473] = 23,
  [474] = 227,
  [475] = 75,
  [476] = 74,
  [477] = 84,
  [478] = 86,
  [479] = 479,
  [480] = 19,
  [481] = 378,
  [482] = 42,
  [483] = 483,
  [484] = 484,
  [485] = 378,
  [486] = 378,
  [487] = 422,
  [488] = 378,
  [489] = 378,
  [490] = 227,
  [491] = 378,
  [492] = 227,
  [493] = 422,
  [494] = 227,
  [495] = 484,
  [496] = 483,
  [497] = 479,
  [498] = 227,
  [499] = 227,
  [500] = 378,
  [501] = 382,
  [502] = 227,
  [503] = 227,
  [504] = 504,
  [505] = 227,
  [506] = 227,
  [507] = 504,
  [508] = 227,
  [509] = 504,
  [510] = 382,
  [511] = 227,
  [512] = 378,
  [513] = 227,
  [514] = 378,
  [515] = 515,
  [516] = 378,
  [517] = 382,
  [518] = 378,
  [519] = 515,
  [520] = 227,
  [521] = 504,
  [522] = 378,
  [523] = 422,
  [524] = 378,
  [525] = 378,
  [526] = 382,
  [527] = 527,
  [528] = 528,
  [529] = 527,
  [530] = 527,
  [531] = 527,
  [532] = 527,
  [533] = 527,
  [534] = 422,
  [535] = 422,
  [536] = 536,
  [537] = 422,
  [538] = 504,
  [539] = 378,
  [540] = 378,
  [541] = 422,
  [542] = 378,
  [543] = 378,
  [544] = 544,
  [545] = 545,
  [546] = 422,
  [547] = 544,
  [548] = 378,
  [549] = 545,
  [550] = 550,
  [551] = 382,
  [552] = 552,
  [553] = 552,
  [554] = 544,
  [555] = 545,
  [556] = 545,
  [557] = 552,
  [558] = 558,
  [559] = 545,
  [560] = 552,
  [561] = 552,
  [562] = 378,
  [563] = 544,
  [564] = 564,
  [565] = 504,
  [566] = 566,
  [567] = 545,
  [568] = 568,
  [569] = 569,
  [570] = 566,
  [571] = 544,
  [572] = 545,
  [573] = 378,
  [574] = 545,
  [575] = 545,
  [576] = 576,
  [577] = 577,
  [578] = 545,
  [579] = 544,
  [580] = 545,
  [581] = 552,
  [582] = 545,
  [583] = 558,
  [584] = 550,
  [585] = 585,
  [586] = 422,
  [587] = 587,
  [588] = 569,
  [589] = 564,
  [590] = 378,
  [591] = 576,
  [592] = 592,
  [593] = 593,
  [594] = 593,
  [595] = 595,
  [596] = 595,
  [597] = 595,
  [598] = 595,
  [599] = 593,
  [600] = 593,
  [601] = 593,
  [602] = 422,
  [603] = 595,
  [604] = 593,
  [605] = 595,
  [606] = 606,
  [607] = 606,
  [608] = 608,
  [609] = 609,
  [610] = 610,
  [611] = 610,
  [612] = 609,
  [613] = 613,
  [614] = 614,
  [615] = 615,
  [616] = 616,
  [617] = 613,
  [618] = 613,
  [619] = 615,
  [620] = 615,
  [621] = 613,
  [622] = 615,
  [623] = 613,
  [624] = 614,
  [625] = 615,
  [626] = 613,
  [627] = 615,
  [628] = 628,
  [629] = 628,
  [630] = 630,
  [631] = 628,
  [632] = 628,
  [633] = 633,
  [634] = 628,
  [635] = 633,
  [636] = 630,
  [637] = 628,
  [638] = 638,
  [639] = 628,
  [640] = 628,
  [641] = 633,
  [642] = 633,
  [643] = 643,
  [644] = 628,
  [645] = 633,
  [646] = 643,
  [647] = 628,
  [648] = 628,
  [649] = 628,
  [650] = 633,
  [651] = 638,
  [652] = 652,
  [653] = 653,
  [654] = 653,
  [655] = 655,
  [656] = 655,
  [657] = 657,
  [658] = 655,
  [659] = 653,
  [660] = 653,
  [661] = 655,
  [662] = 662,
  [663] = 663,
  [664] = 655,
  [665] = 665,
  [666] = 666,
  [667] = 662,
  [668] = 655,
  [669] = 653,
  [670] = 655,
  [671] = 653,
  [672] = 653,
  [673] = 653,
  [674] = 674,
  [675] = 662,
  [676] = 666,
  [677] = 653,
  [678] = 655,
  [679] = 653,
  [680] = 680,
  [681] = 662,
  [682] = 653,
  [683] = 657,
  [684] = 684,
  [685] = 666,
  [686] = 653,
  [687] = 687,
  [688] = 687,
  [689] = 689,
  [690] = 653,
  [691] = 653,
  [692] = 692,
  [693] = 655,
  [694] = 694,
  [695] = 695,
  [696] = 662,
  [697] = 692,
  [698] = 653,
  [699] = 655,
  [700] = 662,
  [701] = 655,
  [702] = 653,
  [703] = 692,
  [704] = 653,
  [705] = 653,
  [706] = 653,
  [707] = 662,
  [708] = 663,
  [709] = 666,
  [710] = 710,
  [711] = 653,
  [712] = 680,
  [713] = 689,
  [714] = 714,
  [715] = 653,
  [716] = 666,
  [717] = 714,
  [718] = 653,
  [719] = 692,
  [720] = 655,
  [721] = 653,
  [722] = 653,
  [723] = 723,
  [724] = 662,
  [725] = 655,
  [726] = 662,
  [727] = 674,
  [728] = 652,
  [729] = 653,
  [730] = 710,
  [731] = 653,
  [732] = 653,
  [733] = 723,
  [734] = 692,
  [735] = 735,
  [736] = 736,
  [737] = 653,
  [738] = 653,
  [739] = 653,
  [740] = 692,
  [741] = 655,
  [742] = 653,
  [743] = 735,
  [744] = 653,
  [745] = 653,
  [746] = 653,
  [747] = 666,
  [748] = 662,
  [749] = 655,
  [750] = 653,
  [751] = 662,
  [752] = 653,
  [753] = 662,
  [754] = 662,
  [755] = 655,
  [756] = 756,
  [757] = 757,
  [758] = 758,
  [759] = 759,
  [760] = 760,
  [761] = 761,
  [762] = 762,
  [763] = 759,
  [764] = 760,
  [765] = 761,
  [766] = 766,
  [767] = 767,
  [768] = 768,
  [769] = 769,
  [770] = 770,
  [771] = 771,
  [772] = 767,
  [773] = 773,
  [774] = 774,
  [775] = 775,
  [776] = 768,
  [777] = 777,
  [778] = 778,
  [779] = 779,
  [780] = 780,
  [781] = 781,
  [782] = 781,
  [783] = 779,
  [784] = 784,
  [785] = 778,
  [786] = 780,
  [787] = 787,
  [788] = 788,
  [789] = 789,
  [790] = 790,
  [791] = 791,
  [792] = 792,
  [793] = 793,
  [794] = 794,
  [795] = 795,
  [796] = 796,
  [797] = 797,
  [798] = 794,
  [799] = 788,
  [800] = 133,
  [801] = 790,
  [802] = 135,
  [803] = 787,
  [804] = 797,
  [805] = 792,
  [806] = 796,
  [807] = 134,
  [808] = 791,
  [809] = 789,
  [810] = 810,
  [811] = 811,
  [812] = 795,
  [813] = 813,
  [814] = 814,
  [815] = 815,
  [816] = 816,
  [817] = 817,
  [818] = 818,
  [819] = 135,
  [820] = 820,
  [821] = 134,
  [822] = 822,
  [823] = 133,
  [824] = 824,
  [825] = 825,
  [826] = 826,
  [827] = 827,
  [828] = 828,
  [829] = 829,
  [830] = 793,
  [831] = 813,
  [832] = 832,
  [833] = 833,
  [834] = 825,
  [835] = 815,
  [836] = 836,
  [837] = 824,
  [838] = 838,
  [839] = 829,
  [840] = 840,
  [841] = 814,
  [842] = 820,
  [843] = 827,
  [844] = 816,
  [845] = 845,
  [846] = 846,
  [847] = 847,
  [848] = 848,
  [849] = 849,
  [850] = 817,
  [851] = 851,
  [852] = 826,
  [853] = 828,
  [854] = 818,
  [855] = 855,
  [856] = 856,
  [857] = 857,
  [858] = 858,
  [859] = 859,
  [860] = 860,
  [861] = 859,
  [862] = 862,
  [863] = 863,
  [864] = 864,
  [865] = 2,
  [866] = 866,
  [867] = 867,
  [868] = 868,
  [869] = 869,
  [870] = 870,
  [871] = 871,
  [872] = 872,
  [873] = 873,
  [874] = 866,
  [875] = 875,
  [876] = 876,
  [877] = 877,
  [878] = 878,
  [879] = 879,
  [880] = 858,
  [881] = 881,
  [882] = 875,
  [883] = 883,
  [884] = 884,
  [885] = 885,
  [886] = 886,
  [887] = 887,
  [888] = 859,
  [889] = 889,
  [890] = 862,
  [891] = 856,
  [892] = 892,
  [893] = 870,
  [894] = 894,
  [895] = 895,
  [896] = 859,
  [897] = 863,
  [898] = 859,
  [899] = 899,
  [900] = 900,
  [901] = 864,
  [902] = 902,
  [903] = 868,
  [904] = 904,
  [905] = 859,
  [906] = 867,
  [907] = 907,
  [908] = 908,
  [909] = 909,
  [910] = 910,
  [911] = 911,
  [912] = 912,
  [913] = 913,
  [914] = 914,
  [915] = 915,
  [916] = 899,
  [917] = 917,
  [918] = 918,
  [919] = 859,
  [920] = 911,
  [921] = 921,
  [922] = 922,
  [923] = 923,
  [924] = 924,
  [925] = 924,
  [926] = 926,
  [927] = 927,
  [928] = 928,
  [929] = 912,
  [930] = 930,
  [931] = 909,
  [932] = 932,
  [933] = 913,
  [934] = 793,
  [935] = 932,
  [936] = 936,
  [937] = 859,
  [938] = 938,
  [939] = 939,
  [940] = 940,
  [941] = 930,
  [942] = 942,
  [943] = 921,
  [944] = 944,
  [945] = 945,
  [946] = 918,
  [947] = 947,
  [948] = 948,
  [949] = 949,
  [950] = 950,
  [951] = 951,
  [952] = 952,
  [953] = 953,
  [954] = 950,
  [955] = 904,
  [956] = 956,
  [957] = 957,
  [958] = 911,
  [959] = 911,
  [960] = 936,
  [961] = 961,
  [962] = 962,
  [963] = 963,
  [964] = 928,
  [965] = 963,
  [966] = 921,
  [967] = 947,
  [968] = 968,
  [969] = 942,
  [970] = 970,
  [971] = 971,
  [972] = 972,
  [973] = 973,
  [974] = 974,
  [975] = 975,
  [976] = 227,
  [977] = 887,
  [978] = 883,
  [979] = 979,
  [980] = 980,
  [981] = 981,
  [982] = 784,
  [983] = 921,
  [984] = 984,
  [985] = 985,
  [986] = 873,
  [987] = 968,
  [988] = 988,
  [989] = 227,
  [990] = 990,
  [991] = 991,
  [992] = 992,
  [993] = 991,
  [994] = 994,
  [995] = 995,
  [996] = 996,
  [997] = 997,
  [998] = 998,
  [999] = 999,
  [1000] = 1000,
  [1001] = 1001,
  [1002] = 995,
  [1003] = 1003,
  [1004] = 992,
  [1005] = 1005,
  [1006] = 1006,
  [1007] = 1007,
  [1008] = 1008,
  [1009] = 1009,
  [1010] = 1010,
  [1011] = 1011,
  [1012] = 1012,
  [1013] = 1013,
  [1014] = 1014,
  [1015] = 1015,
  [1016] = 1016,
  [1017] = 990,
  [1018] = 1018,
  [1019] = 1019,
  [1020] = 1020,
  [1021] = 1021,
  [1022] = 1022,
  [1023] = 1023,
  [1024] = 1024,
  [1025] = 1025,
  [1026] = 1026,
  [1027] = 134,
  [1028] = 1025,
  [1029] = 859,
  [1030] = 1025,
  [1031] = 1025,
  [1032] = 133,
  [1033] = 1025,
  [1034] = 1034,
  [1035] = 1035,
  [1036] = 1025,
  [1037] = 1025,
  [1038] = 1025,
  [1039] = 1025,
  [1040] = 1010,
  [1041] = 1041,
  [1042] = 1009,
  [1043] = 1043,
  [1044] = 1025,
  [1045] = 1025,
  [1046] = 135,
  [1047] = 1025,
  [1048] = 1048,
  [1049] = 1049,
  [1050] = 1025,
  [1051] = 1025,
  [1052] = 1025,
  [1053] = 1020,
  [1054] = 1025,
  [1055] = 1025,
  [1056] = 1056,
  [1057] = 1025,
  [1058] = 1058,
  [1059] = 1025,
  [1060] = 1060,
  [1061] = 1061,
  [1062] = 1062,
  [1063] = 1025,
  [1064] = 1064,
  [1065] = 1025,
  [1066] = 1025,
  [1067] = 1025,
  [1068] = 1025,
  [1069] = 1025,
  [1070] = 1025,
  [1071] = 1025,
  [1072] = 1072,
  [1073] = 1073,
  [1074] = 1074,
  [1075] = 1025,
  [1076] = 1076,
  [1077] = 1077,
  [1078] = 1025,
  [1079] = 1079,
  [1080] = 1025,
  [1081] = 1081,
  [1082] = 1025,
  [1083] = 1025,
  [1084] = 1084,
  [1085] = 1025,
  [1086] = 1025,
  [1087] = 1087,
  [1088] = 1088,
  [1089] = 1025,
  [1090] = 1025,
  [1091] = 1091,
  [1092] = 1092,
  [1093] = 1093,
  [1094] = 1094,
  [1095] = 1025,
  [1096] = 1025,
  [1097] = 1097,
  [1098] = 1025,
  [1099] = 1099,
  [1100] = 1100,
  [1101] = 1006,
  [1102] = 1021,
  [1103] = 1103,
  [1104] = 1104,
  [1105] = 1105,
  [1106] = 1106,
  [1107] = 1107,
  [1108] = 1108,
  [1109] = 1109,
  [1110] = 1110,
  [1111] = 1111,
  [1112] = 1112,
  [1113] = 859,
  [1114] = 1041,
  [1115] = 1100,
  [1116] = 1116,
  [1117] = 1117,
  [1118] = 1118,
  [1119] = 1092,
  [1120] = 1120,
  [1121] = 1081,
  [1122] = 1060,
  [1123] = 1123,
  [1124] = 1124,
  [1125] = 1125,
  [1126] = 1126,
  [1127] = 1058,
  [1128] = 1128,
  [1129] = 1129,
  [1130] = 1130,
  [1131] = 1131,
  [1132] = 1097,
  [1133] = 1133,
  [1134] = 1087,
  [1135] = 1043,
  [1136] = 1092,
  [1137] = 1137,
  [1138] = 1061,
  [1139] = 1139,
  [1140] = 1140,
  [1141] = 1062,
  [1142] = 1142,
  [1143] = 1041,
  [1144] = 1144,
  [1145] = 1145,
  [1146] = 1146,
  [1147] = 1147,
  [1148] = 1148,
  [1149] = 1149,
  [1150] = 1060,
  [1151] = 1151,
  [1152] = 1093,
  [1153] = 1153,
  [1154] = 1062,
  [1155] = 1076,
  [1156] = 1049,
  [1157] = 1157,
  [1158] = 1158,
  [1159] = 1159,
  [1160] = 1160,
  [1161] = 1061,
  [1162] = 1162,
  [1163] = 1163,
  [1164] = 1072,
  [1165] = 1165,
  [1166] = 1166,
  [1167] = 1099,
  [1168] = 1123,
  [1169] = 1169,
  [1170] = 1170,
  [1171] = 1061,
  [1172] = 1172,
  [1173] = 1173,
  [1174] = 1174,
  [1175] = 1175,
  [1176] = 1176,
  [1177] = 1177,
  [1178] = 1178,
  [1179] = 1179,
  [1180] = 1160,
  [1181] = 1181,
  [1182] = 1182,
  [1183] = 859,
  [1184] = 1142,
  [1185] = 1185,
  [1186] = 1186,
  [1187] = 1187,
  [1188] = 1062,
  [1189] = 1041,
  [1190] = 1092,
  [1191] = 1191,
  [1192] = 1192,
  [1193] = 1193,
  [1194] = 1194,
  [1195] = 1060,
  [1196] = 1123,
  [1197] = 1197,
  [1198] = 1148,
  [1199] = 1149,
  [1200] = 1200,
  [1201] = 1201,
  [1202] = 1202,
  [1203] = 1203,
  [1204] = 1204,
  [1205] = 1205,
  [1206] = 1206,
  [1207] = 1207,
  [1208] = 1208,
  [1209] = 1209,
  [1210] = 1210,
  [1211] = 1211,
  [1212] = 1212,
  [1213] = 1209,
  [1214] = 1209,
  [1215] = 1215,
  [1216] = 1216,
  [1217] = 1217,
  [1218] = 1218,
  [1219] = 1219,
  [1220] = 1220,
  [1221] = 1221,
  [1222] = 1222,
  [1223] = 1223,
  [1224] = 1224,
  [1225] = 1225,
  [1226] = 1226,
  [1227] = 1227,
  [1228] = 1185,
  [1229] = 1229,
  [1230] = 1230,
  [1231] = 1218,
  [1232] = 1232,
  [1233] = 1233,
  [1234] = 1234,
  [1235] = 1235,
  [1236] = 1236,
  [1237] = 1237,
  [1238] = 1238,
  [1239] = 1239,
  [1240] = 1209,
  [1241] = 1209,
  [1242] = 1242,
  [1243] = 1243,
  [1244] = 1244,
  [1245] = 1218,
  [1246] = 1216,
  [1247] = 1218,
  [1248] = 1209,
  [1249] = 1216,
  [1250] = 1216,
  [1251] = 1251,
  [1252] = 1252,
  [1253] = 1253,
  [1254] = 1254,
  [1255] = 859,
  [1256] = 1256,
  [1257] = 1257,
  [1258] = 1258,
  [1259] = 1259,
  [1260] = 1260,
  [1261] = 1261,
  [1262] = 1262,
  [1263] = 1263,
  [1264] = 1264,
  [1265] = 1265,
  [1266] = 1266,
  [1267] = 1060,
  [1268] = 1268,
  [1269] = 1269,
  [1270] = 1270,
  [1271] = 1271,
  [1272] = 1272,
  [1273] = 1273,
  [1274] = 1274,
  [1275] = 1275,
  [1276] = 1276,
  [1277] = 1277,
  [1278] = 1278,
  [1279] = 1279,
  [1280] = 1280,
  [1281] = 1281,
  [1282] = 1282,
  [1283] = 1283,
  [1284] = 1284,
  [1285] = 1264,
  [1286] = 1286,
  [1287] = 1287,
  [1288] = 1060,
  [1289] = 1289,
  [1290] = 1290,
  [1291] = 1291,
  [1292] = 1280,
  [1293] = 1293,
  [1294] = 1294,
  [1295] = 1295,
  [1296] = 1296,
  [1297] = 1297,
  [1298] = 1283,
  [1299] = 1299,
  [1300] = 1300,
  [1301] = 1301,
  [1302] = 1302,
  [1303] = 1303,
  [1304] = 1304,
  [1305] = 1305,
  [1306] = 1275,
  [1307] = 1274,
  [1308] = 1308,
  [1309] = 1309,
  [1310] = 1310,
  [1311] = 1311,
  [1312] = 1312,
  [1313] = 1313,
  [1314] = 1291,
  [1315] = 1280,
  [1316] = 1316,
  [1317] = 1290,
  [1318] = 1291,
  [1319] = 1319,
  [1320] = 1290,
  [1321] = 1273,
  [1322] = 1322,
  [1323] = 1323,
  [1324] = 1291,
  [1325] = 1325,
  [1326] = 1271,
  [1327] = 1327,
  [1328] = 1328,
  [1329] = 1329,
  [1330] = 859,
  [1331] = 1331,
  [1332] = 1332,
  [1333] = 1333,
  [1334] = 1334,
  [1335] = 1335,
  [1336] = 1295,
  [1337] = 1337,
  [1338] = 1338,
  [1339] = 1339,
  [1340] = 1340,
  [1341] = 1282,
  [1342] = 1342,
  [1343] = 1280,
  [1344] = 1344,
  [1345] = 1345,
  [1346] = 1346,
  [1347] = 1277,
  [1348] = 1348,
  [1349] = 1349,
  [1350] = 1350,
  [1351] = 1351,
  [1352] = 1352,
  [1353] = 1353,
  [1354] = 1354,
  [1355] = 1355,
  [1356] = 1356,
  [1357] = 1301,
  [1358] = 1358,
  [1359] = 1359,
  [1360] = 1294,
  [1361] = 1361,
  [1362] = 1290,
  [1363] = 1363,
  [1364] = 1364,
  [1365] = 1365,
  [1366] = 1269,
  [1367] = 1282,
  [1368] = 1368,
  [1369] = 1369,
  [1370] = 1370,
  [1371] = 1280,
  [1372] = 1372,
  [1373] = 1373,
  [1374] = 1374,
  [1375] = 1375,
  [1376] = 1268,
  [1377] = 1290,
  [1378] = 1378,
  [1379] = 1379,
  [1380] = 1380,
  [1381] = 1381,
  [1382] = 1382,
  [1383] = 1301,
  [1384] = 1384,
  [1385] = 1359,
  [1386] = 1386,
  [1387] = 1283,
  [1388] = 1282,
  [1389] = 1359,
  [1390] = 1290,
  [1391] = 1391,
  [1392] = 1392,
  [1393] = 1301,
  [1394] = 1301,
  [1395] = 1395,
  [1396] = 1283,
  [1397] = 1257,
  [1398] = 1283,
  [1399] = 1301,
  [1400] = 1400,
  [1401] = 1401,
  [1402] = 1402,
  [1403] = 1403,
  [1404] = 1351,
  [1405] = 1405,
  [1406] = 1406,
  [1407] = 1301,
  [1408] = 1408,
  [1409] = 1409,
  [1410] = 1283,
  [1411] = 1266,
  [1412] = 1412,
  [1413] = 1413,
  [1414] = 1316,
  [1415] = 1290,
  [1416] = 1280,
  [1417] = 1417,
  [1418] = 1418,
  [1419] = 1419,
  [1420] = 1420,
  [1421] = 1417,
  [1422] = 1418,
  [1423] = 1423,
  [1424] = 1424,
  [1425] = 1425,
  [1426] = 1426,
  [1427] = 1427,
  [1428] = 227,
  [1429] = 1429,
  [1430] = 1430,
  [1431] = 1431,
  [1432] = 1432,
  [1433] = 1433,
  [1434] = 1434,
  [1435] = 1435,
  [1436] = 1436,
  [1437] = 1437,
  [1438] = 1438,
  [1439] = 1439,
  [1440] = 1440,
  [1441] = 1441,
  [1442] = 1442,
  [1443] = 1443,
  [1444] = 1444,
  [1445] = 1425,
  [1446] = 1446,
  [1447] = 1431,
  [1448] = 1429,
  [1449] = 1449,
  [1450] = 1443,
  [1451] = 1451,
  [1452] = 1452,
  [1453] = 1417,
  [1454] = 1418,
  [1455] = 1423,
  [1456] = 1430,
  [1457] = 1457,
  [1458] = 1458,
  [1459] = 1459,
  [1460] = 1460,
  [1461] = 1461,
  [1462] = 1462,
  [1463] = 1429,
  [1464] = 1464,
  [1465] = 1465,
  [1466] = 1466,
  [1467] = 1424,
  [1468] = 1468,
  [1469] = 1469,
  [1470] = 1470,
  [1471] = 1443,
  [1472] = 1420,
  [1473] = 1473,
  [1474] = 1474,
  [1475] = 1431,
  [1476] = 1429,
  [1477] = 1477,
  [1478] = 1478,
  [1479] = 1426,
  [1480] = 1427,
  [1481] = 1417,
  [1482] = 1418,
  [1483] = 1423,
  [1484] = 1484,
  [1485] = 1485,
  [1486] = 1486,
  [1487] = 1487,
  [1488] = 1488,
  [1489] = 1489,
  [1490] = 1443,
  [1491] = 1491,
  [1492] = 1469,
  [1493] = 1446,
  [1494] = 1494,
  [1495] = 1495,
  [1496] = 1434,
  [1497] = 1484,
  [1498] = 1498,
  [1499] = 1494,
  [1500] = 1500,
  [1501] = 1501,
  [1502] = 1502,
  [1503] = 1431,
  [1504] = 1429,
  [1505] = 1505,
  [1506] = 1506,
  [1507] = 1443,
  [1508] = 1491,
  [1509] = 1417,
  [1510] = 1418,
  [1511] = 1423,
  [1512] = 1498,
  [1513] = 1513,
  [1514] = 1514,
  [1515] = 1515,
  [1516] = 1419,
  [1517] = 1500,
  [1518] = 1433,
  [1519] = 1427,
  [1520] = 1520,
  [1521] = 1426,
  [1522] = 1522,
  [1523] = 1523,
  [1524] = 1437,
  [1525] = 1440,
  [1526] = 1526,
  [1527] = 1466,
  [1528] = 1417,
  [1529] = 1505,
  [1530] = 1530,
  [1531] = 1443,
  [1532] = 1532,
  [1533] = 1533,
  [1534] = 1417,
  [1535] = 1423,
  [1536] = 1473,
  [1537] = 1461,
  [1538] = 1436,
  [1539] = 1417,
  [1540] = 1417,
  [1541] = 1541,
  [1542] = 1435,
  [1543] = 1487,
  [1544] = 1417,
  [1545] = 1545,
  [1546] = 1489,
  [1547] = 1513,
  [1548] = 1514,
  [1549] = 1417,
  [1550] = 1530,
  [1551] = 1551,
  [1552] = 1552,
  [1553] = 1429,
  [1554] = 1533,
  [1555] = 1555,
  [1556] = 1555,
  [1557] = 1417,
  [1558] = 1458,
  [1559] = 1431,
  [1560] = 1427,
  [1561] = 1423,
  [1562] = 1426,
  [1563] = 1515,
  [1564] = 1418,
  [1565] = 1431,
  [1566] = 1566,
  [1567] = 1567,
  [1568] = 1568,
  [1569] = 1569,
  [1570] = 1570,
  [1571] = 1571,
  [1572] = 1572,
  [1573] = 1573,
  [1574] = 1574,
  [1575] = 1575,
  [1576] = 1576,
  [1577] = 1577,
  [1578] = 1578,
  [1579] = 1579,
  [1580] = 1580,
  [1581] = 1581,
  [1582] = 1582,
  [1583] = 1583,
  [1584] = 1584,
  [1585] = 1578,
  [1586] = 1586,
  [1587] = 1577,
  [1588] = 1588,
  [1589] = 1589,
  [1590] = 1590,
  [1591] = 1591,
  [1592] = 1571,
  [1593] = 1593,
  [1594] = 1584,
  [1595] = 1595,
  [1596] = 1596,
  [1597] = 1597,
  [1598] = 1598,
  [1599] = 1599,
  [1600] = 1597,
  [1601] = 1601,
  [1602] = 1602,
  [1603] = 1603,
  [1604] = 1604,
  [1605] = 1605,
  [1606] = 1597,
  [1607] = 1607,
  [1608] = 1608,
  [1609] = 1574,
  [1610] = 1610,
  [1611] = 1611,
  [1612] = 1572,
  [1613] = 1613,
  [1614] = 1591,
  [1615] = 1591,
  [1616] = 1577,
  [1617] = 1584,
  [1618] = 1618,
  [1619] = 1619,
  [1620] = 1620,
  [1621] = 1621,
  [1622] = 1622,
  [1623] = 1623,
  [1624] = 1624,
  [1625] = 1625,
  [1626] = 1626,
  [1627] = 1627,
  [1628] = 1577,
  [1629] = 1629,
  [1630] = 1630,
  [1631] = 1631,
  [1632] = 1608,
  [1633] = 1633,
  [1634] = 1634,
  [1635] = 1584,
  [1636] = 1584,
  [1637] = 1637,
  [1638] = 1638,
  [1639] = 1639,
  [1640] = 1597,
  [1641] = 1641,
  [1642] = 1642,
  [1643] = 1643,
  [1644] = 1573,
  [1645] = 1645,
  [1646] = 1584,
  [1647] = 1647,
  [1648] = 1576,
  [1649] = 1597,
  [1650] = 1650,
  [1651] = 1651,
  [1652] = 1591,
  [1653] = 1653,
  [1654] = 1591,
  [1655] = 1577,
  [1656] = 1656,
  [1657] = 1657,
  [1658] = 1658,
  [1659] = 1598,
  [1660] = 1660,
  [1661] = 1661,
  [1662] = 1662,
  [1663] = 1583,
  [1664] = 1664,
  [1665] = 1576,
  [1666] = 1666,
  [1667] = 1667,
  [1668] = 1611,
  [1669] = 1597,
  [1670] = 1670,
  [1671] = 1671,
  [1672] = 1672,
  [1673] = 1673,
  [1674] = 1588,
  [1675] = 1675,
  [1676] = 1676,
  [1677] = 1591,
  [1678] = 1678,
  [1679] = 1577,
  [1680] = 1620,
  [1681] = 2,
  [1682] = 1604,
  [1683] = 1601,
  [1684] = 1575,
  [1685] = 1685,
  [1686] = 1647,
  [1687] = 1658,
  [1688] = 1688,
  [1689] = 1689,
  [1690] = 1688,
  [1691] = 1691,
  [1692] = 1692,
  [1693] = 1693,
  [1694] = 1694,
  [1695] = 1695,
  [1696] = 1696,
  [1697] = 1697,
  [1698] = 1698,
  [1699] = 1699,
  [1700] = 1700,
  [1701] = 1701,
  [1702] = 1688,
  [1703] = 1703,
  [1704] = 1704,
  [1705] = 1688,
  [1706] = 1706,
  [1707] = 1688,
  [1708] = 1708,
  [1709] = 1709,
  [1710] = 1710,
  [1711] = 1688,
  [1712] = 1712,
  [1713] = 1688,
  [1714] = 1714,
  [1715] = 1715,
  [1716] = 1716,
  [1717] = 1688,
  [1718] = 1688,
  [1719] = 1688,
  [1720] = 1688,
  [1721] = 1721,
  [1722] = 1722,
  [1723] = 1688,
  [1724] = 1724,
  [1725] = 1725,
  [1726] = 1726,
  [1727] = 1688,
  [1728] = 1728,
  [1729] = 1688,
  [1730] = 1730,
  [1731] = 1688,
  [1732] = 1732,
  [1733] = 1688,
  [1734] = 1734,
  [1735] = 1694,
  [1736] = 1736,
  [1737] = 1737,
  [1738] = 1688,
  [1739] = 1688,
  [1740] = 1740,
  [1741] = 1701,
  [1742] = 1742,
  [1743] = 1688,
  [1744] = 1744,
  [1745] = 1745,
  [1746] = 1746,
  [1747] = 1688,
  [1748] = 1748,
  [1749] = 1688,
  [1750] = 1688,
  [1751] = 1688,
  [1752] = 1688,
  [1753] = 1753,
  [1754] = 1688,
  [1755] = 1688,
  [1756] = 1756,
  [1757] = 1688,
  [1758] = 1688,
  [1759] = 1759,
  [1760] = 1760,
  [1761] = 1688,
  [1762] = 1688,
  [1763] = 1763,
  [1764] = 1708,
  [1765] = 1765,
  [1766] = 1766,
  [1767] = 1710,
  [1768] = 1721,
  [1769] = 1769,
  [1770] = 1770,
  [1771] = 1771,
  [1772] = 1688,
  [1773] = 1773,
  [1774] = 1688,
  [1775] = 1710,
  [1776] = 1776,
  [1777] = 1777,
  [1778] = 1721,
  [1779] = 1779,
  [1780] = 1688,
  [1781] = 1688,
  [1782] = 1782,
  [1783] = 1783,
  [1784] = 1784,
  [1785] = 1701,
  [1786] = 1786,
  [1787] = 1782,
  [1788] = 1788,
  [1789] = 1688,
  [1790] = 1790,
  [1791] = 1791,
  [1792] = 1701,
  [1793] = 1793,
  [1794] = 1782,
  [1795] = 1795,
  [1796] = 1688,
  [1797] = 1721,
  [1798] = 1710,
  [1799] = 1701,
  [1800] = 1800,
  [1801] = 1801,
  [1802] = 1782,
  [1803] = 1688,
  [1804] = 1804,
  [1805] = 1763,
  [1806] = 1806,
  [1807] = 1807,
  [1808] = 1779,
  [1809] = 1809,
  [1810] = 1810,
  [1811] = 1728,
  [1812] = 1812,
  [1813] = 1813,
  [1814] = 1726,
  [1815] = 1815,
  [1816] = 1815,
  [1817] = 1708,
  [1818] = 1812,
  [1819] = 1724,
  [1820] = 1708,
  [1821] = 1708,
  [1822] = 1710,
  [1823] = 1823,
  [1824] = 1824,
  [1825] = 1721,
  [1826] = 1782,
  [1827] = 1688,
  [1828] = 1828,
  [1829] = 1829,
  [1830] = 1725,
  [1831] = 1759,
  [1832] = 1832,
  [1833] = 1833,
  [1834] = 1834,
  [1835] = 1835,
  [1836] = 1836,
  [1837] = 1782,
  [1838] = 1630,
  [1839] = 1688,
  [1840] = 1840,
  [1841] = 1721,
  [1842] = 1710,
  [1843] = 1843,
  [1844] = 1823,
  [1845] = 1678,
  [1846] = 1804,
  [1847] = 1708,
  [1848] = 1692,
  [1849] = 1849,
  [1850] = 1850,
  [1851] = 1851,
  [1852] = 1852,
  [1853] = 1853,
  [1854] = 1854,
  [1855] = 1693,
  [1856] = 1722,
  [1857] = 1766,
  [1858] = 1773,
  [1859] = 1696,
  [1860] = 1706,
  [1861] = 1793,
  [1862] = 1697,
  [1863] = 1701,
  [1864] = 1697,
  [1865] = 1865,
  [1866] = 1866,
  [1867] = 1867,
  [1868] = 1868,
  [1869] = 1869,
  [1870] = 1870,
  [1871] = 1871,
  [1872] = 1783,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '"', 22,
        '#', 862,
        '$', 810,
        '&', 38,
        '\'', 39,
        '(', 1115,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1520,
        '.', 1127,
        '/', 1541,
        ':', 1119,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 1118,
        '@', 1521,
        'A', 315,
        'B', 208,
        'C', 77,
        'D', 87,
        'E', 180,
        'F', 89,
        'G', 586,
        'H', 79,
        'I', 316,
        'J', 97,
        'L', 264,
        'M', 94,
        'N', 91,
        'O', 456,
        'P', 80,
        'R', 104,
        'S', 150,
        'T', 81,
        'U', 479,
        'V', 99,
        'W', 343,
        '[', 1113,
        ']', 1114,
        'a', 792,
        'b', 769,
        'c', 739,
        'e', 754,
        'f', 778,
        'l', 784,
        'n', 762,
        'p', 801,
        's', 26,
        'u', 27,
        '{', 1120,
        '|', 76,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
        'd', 25,
        'r', 25,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(817);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1252);
      END_STATE();
    case 1:
      if (lookahead == '\n') ADVANCE(2);
      if (lookahead == '*') ADVANCE(1);
      if (lookahead == '/') ADVANCE(844);
      if (lookahead != 0) ADVANCE(2);
      END_STATE();
    case 2:
      if (lookahead == '\n') ADVANCE(2);
      if (lookahead == '*') ADVANCE(1);
      if (lookahead != 0) ADVANCE(2);
      END_STATE();
    case 3:
      if (lookahead == ' ') ADVANCE(409);
      END_STATE();
    case 4:
      if (lookahead == ' ') ADVANCE(200);
      END_STATE();
    case 5:
      if (lookahead == ' ') ADVANCE(708);
      END_STATE();
    case 6:
      if (lookahead == ' ') ADVANCE(127);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '$', 810,
        '&', 38,
        '*', 1125,
        '+', 1537,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1375,
        'C', 1432,
        'I', 1339,
        'N', 1425,
        'O', 1443,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        '(', 1115,
        '*', 1125,
        '+', 1537,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1375,
        'C', 1432,
        'I', 1402,
        'N', 1425,
        'O', 1443,
        'T', 1352,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1373,
        'C', 1432,
        'I', 1402,
        'N', 1425,
        'O', 1443,
        'W', 1350,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1373,
        'C', 1432,
        'I', 1402,
        'N', 1425,
        'O', 1443,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(10);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1373,
        'C', 1432,
        'F', 1454,
        'I', 1402,
        'N', 1425,
        'O', 1443,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        '*', 1125,
        '+', 1537,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1375,
        'C', 1427,
        'I', 1339,
        'N', 1425,
        'O', 1443,
        'P', 1327,
        '[', 1113,
        'c', 1509,
        'f', 1508,
        '{', 1120,
        '|', 804,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        '"', 22,
        '#', 862,
        '$', 810,
        '\'', 39,
        '(', 1115,
        ')', 1116,
        '*', 1124,
        '-', 44,
        '/', 41,
        '<', 47,
        '?', 1117,
        'C', 1200,
        'F', 1133,
        'N', 1201,
        'R', 1137,
        'T', 1204,
        '[', 1113,
        ']', 1114,
        'f', 1226,
        '{', 1120,
        'd', 1131,
        'r', 1131,
        's', 1131,
        'u', 1131,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(13);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1250);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 14:
      ADVANCE_MAP(
        '"', 22,
        '#', 862,
        '$', 810,
        '\'', 39,
        '(', 1115,
        '*', 1124,
        '-', 44,
        '/', 41,
        '<', 47,
        'C', 1200,
        'F', 1133,
        'N', 1201,
        'R', 1137,
        'T', 1204,
        'V', 1138,
        '[', 1113,
        'f', 1226,
        '{', 1120,
        'd', 1131,
        'r', 1131,
        's', 1131,
        'u', 1131,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(14);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1250);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 15:
      ADVANCE_MAP(
        '"', 22,
        '#', 862,
        '$', 810,
        '\'', 39,
        '(', 1115,
        '-', 44,
        '/', 41,
        '<', 47,
        '?', 1117,
        'B', 1145,
        'C', 1134,
        'D', 1146,
        'F', 1133,
        'I', 1189,
        'N', 1201,
        'R', 1136,
        'S', 1164,
        'T', 1204,
        'U', 1203,
        'W', 1174,
        '[', 1113,
        ']', 1114,
        'f', 1226,
        '{', 1120,
        'd', 1131,
        'r', 1131,
        's', 1131,
        'u', 1131,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1250);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 16:
      ADVANCE_MAP(
        '"', 22,
        '#', 862,
        '$', 810,
        '\'', 39,
        '(', 1115,
        '-', 44,
        '/', 41,
        '<', 47,
        'A', 1172,
        'B', 1162,
        'C', 1200,
        'D', 1176,
        'F', 1133,
        'N', 1201,
        'R', 1137,
        'T', 1204,
        '[', 1113,
        'f', 1226,
        '{', 1120,
        'd', 1131,
        'r', 1131,
        's', 1131,
        'u', 1131,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(16);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1250);
      if (('E' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        '"', 22,
        '#', 862,
        '$', 810,
        '\'', 39,
        '(', 1115,
        '-', 44,
        '/', 41,
        '<', 47,
        'B', 1145,
        'C', 1134,
        'D', 1146,
        'F', 1133,
        'I', 1189,
        'N', 1201,
        'O', 1194,
        'R', 1136,
        'S', 1164,
        'T', 1204,
        'U', 1203,
        '[', 1113,
        'f', 1226,
        '{', 1120,
        'd', 1131,
        'r', 1131,
        's', 1131,
        'u', 1131,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(17);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1250);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 18:
      ADVANCE_MAP(
        '"', 22,
        '#', 862,
        '$', 810,
        '\'', 39,
        '(', 1115,
        '-', 44,
        '/', 41,
        '<', 47,
        'B', 1225,
        'C', 1200,
        'F', 1133,
        'N', 1201,
        'R', 1137,
        'T', 1204,
        '[', 1113,
        'f', 1226,
        '{', 1120,
        'd', 1131,
        'r', 1131,
        's', 1131,
        'u', 1131,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(18);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1250);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 19:
      ADVANCE_MAP(
        '"', 22,
        '#', 862,
        '$', 810,
        '\'', 39,
        '(', 1115,
        '-', 44,
        '/', 41,
        '<', 47,
        'C', 1200,
        'F', 1133,
        'N', 1201,
        'R', 1137,
        'T', 1204,
        'W', 1174,
        '[', 1113,
        'f', 1226,
        '{', 1120,
        'd', 1131,
        'r', 1131,
        's', 1131,
        'u', 1131,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(19);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1250);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 20:
      ADVANCE_MAP(
        '"', 22,
        '#', 862,
        '$', 810,
        '\'', 39,
        '(', 1115,
        '-', 44,
        '/', 41,
        '<', 47,
        'C', 1200,
        'F', 1133,
        'N', 1199,
        'R', 1137,
        'T', 1204,
        '[', 1113,
        'f', 1226,
        '{', 1120,
        'd', 1131,
        'r', 1131,
        's', 1131,
        'u', 1131,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(20);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1250);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 21:
      ADVANCE_MAP(
        '"', 22,
        '#', 862,
        '$', 810,
        '\'', 39,
        '(', 1115,
        '-', 45,
        '/', 41,
        '?', 1117,
        '}', 1121,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(21);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1253);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 22:
      if (lookahead == '"') ADVANCE(1247);
      if (lookahead == '\\') ADVANCE(813);
      if (lookahead != 0) ADVANCE(22);
      END_STATE();
    case 23:
      if (lookahead == '"') ADVANCE(1248);
      if (lookahead == '\\') ADVANCE(815);
      if (lookahead != 0) ADVANCE(23);
      END_STATE();
    case 24:
      if (lookahead == '"') ADVANCE(1249);
      if (lookahead == '\\') ADVANCE(815);
      if (lookahead != 0 &&
          lookahead != '\'') ADVANCE(24);
      END_STATE();
    case 25:
      if (lookahead == '"') ADVANCE(23);
      if (lookahead == '\'') ADVANCE(40);
      END_STATE();
    case 26:
      if (lookahead == '"') ADVANCE(23);
      if (lookahead == '\'') ADVANCE(40);
      if (lookahead == 'n') ADVANCE(786);
      END_STATE();
    case 27:
      if (lookahead == '"') ADVANCE(23);
      if (lookahead == '\'') ADVANCE(40);
      if (lookahead == 'p') ADVANCE(787);
      END_STATE();
    case 28:
      ADVANCE_MAP(
        '#', 862,
        '$', 810,
        '-', 42,
        '/', 41,
        'C', 1200,
        'R', 1137,
        '[', 1113,
        'f', 1226,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(28);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 29:
      ADVANCE_MAP(
        '#', 862,
        '$', 810,
        '-', 46,
        '/', 41,
        'C', 1200,
        'O', 1194,
        'R', 1137,
        '[', 1113,
        'f', 1226,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(29);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1251);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 30:
      if (lookahead == '#') ADVANCE(862);
      if (lookahead == '*') ADVANCE(1124);
      if (lookahead == '-') ADVANCE(42);
      if (lookahead == '/') ADVANCE(41);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(30);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 31:
      if (lookahead == '#') ADVANCE(862);
      if (lookahead == '-') ADVANCE(43);
      if (lookahead == '.') ADVANCE(48);
      if (lookahead == '/') ADVANCE(41);
      if (lookahead == '=') ADVANCE(1514);
      if (lookahead == '[') ADVANCE(1113);
      if (lookahead == '{') ADVANCE(1120);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(31);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 32:
      if (lookahead == '#') ADVANCE(862);
      if (lookahead == '-') ADVANCE(42);
      if (lookahead == '/') ADVANCE(41);
      if (lookahead == 'A') ADVANCE(1234);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(32);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 33:
      ADVANCE_MAP(
        '#', 862,
        '-', 42,
        '/', 41,
        'A', 525,
        'D', 88,
        'E', 719,
        'F', 383,
        'I', 329,
        'N', 92,
        'P', 125,
        'S', 166,
        'T', 82,
        'U', 646,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(33);
      END_STATE();
    case 34:
      if (lookahead == '#') ADVANCE(862);
      if (lookahead == '-') ADVANCE(42);
      if (lookahead == '/') ADVANCE(41);
      if (lookahead == 'B') ADVANCE(1235);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(34);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 35:
      if (lookahead == '#') ADVANCE(862);
      if (lookahead == '-') ADVANCE(42);
      if (lookahead == '/') ADVANCE(41);
      if (lookahead == 'I') ADVANCE(1231);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(35);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 36:
      if (lookahead == '#') ADVANCE(862);
      if (lookahead == '-') ADVANCE(42);
      if (lookahead == '/') ADVANCE(41);
      if (lookahead == 'O') ADVANCE(1233);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(36);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 37:
      if (lookahead == '#') ADVANCE(862);
      if (lookahead == '-') ADVANCE(42);
      if (lookahead == '/') ADVANCE(41);
      if (lookahead == 'T') ADVANCE(1228);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(37);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 38:
      if (lookahead == '&') ADVANCE(1524);
      END_STATE();
    case 39:
      if (lookahead == '\'') ADVANCE(1247);
      if (lookahead == '\\') ADVANCE(814);
      if (lookahead != 0) ADVANCE(39);
      END_STATE();
    case 40:
      if (lookahead == '\'') ADVANCE(1248);
      if (lookahead == '\\') ADVANCE(816);
      if (lookahead != 0) ADVANCE(40);
      END_STATE();
    case 41:
      if (lookahead == '*') ADVANCE(2);
      if (lookahead == '/') ADVANCE(862);
      END_STATE();
    case 42:
      if (lookahead == '-') ADVANCE(851);
      END_STATE();
    case 43:
      if (lookahead == '-') ADVANCE(851);
      if (lookahead == '>') ADVANCE(1112);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1253);
      END_STATE();
    case 44:
      if (lookahead == '-') ADVANCE(851);
      if (lookahead == '>') ADVANCE(1112);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1251);
      END_STATE();
    case 45:
      if (lookahead == '-') ADVANCE(851);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1253);
      END_STATE();
    case 46:
      if (lookahead == '-') ADVANCE(851);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1251);
      END_STATE();
    case 47:
      if (lookahead == '-') ADVANCE(1122);
      END_STATE();
    case 48:
      if (lookahead == '.') ADVANCE(1513);
      END_STATE();
    case 49:
      if (lookahead == '1') ADVANCE(53);
      END_STATE();
    case 50:
      if (lookahead == '1') ADVANCE(54);
      END_STATE();
    case 51:
      if (lookahead == '1') ADVANCE(55);
      END_STATE();
    case 52:
      if (lookahead == '2') ADVANCE(62);
      END_STATE();
    case 53:
      if (lookahead == '2') ADVANCE(1012);
      END_STATE();
    case 54:
      if (lookahead == '2') ADVANCE(1015);
      END_STATE();
    case 55:
      if (lookahead == '2') ADVANCE(1018);
      END_STATE();
    case 56:
      if (lookahead == '2') ADVANCE(63);
      if (lookahead == '3') ADVANCE(69);
      if (lookahead == '5') ADVANCE(49);
      END_STATE();
    case 57:
      if (lookahead == '2') ADVANCE(64);
      if (lookahead == '3') ADVANCE(70);
      if (lookahead == '5') ADVANCE(50);
      END_STATE();
    case 58:
      if (lookahead == '2') ADVANCE(65);
      if (lookahead == '3') ADVANCE(71);
      if (lookahead == '5') ADVANCE(51);
      END_STATE();
    case 59:
      if (lookahead == '4') ADVANCE(1011);
      END_STATE();
    case 60:
      if (lookahead == '4') ADVANCE(1014);
      END_STATE();
    case 61:
      if (lookahead == '4') ADVANCE(1017);
      END_STATE();
    case 62:
      if (lookahead == '5') ADVANCE(1019);
      END_STATE();
    case 63:
      if (lookahead == '5') ADVANCE(66);
      END_STATE();
    case 64:
      if (lookahead == '5') ADVANCE(67);
      END_STATE();
    case 65:
      if (lookahead == '5') ADVANCE(68);
      END_STATE();
    case 66:
      if (lookahead == '6') ADVANCE(1010);
      END_STATE();
    case 67:
      if (lookahead == '6') ADVANCE(1013);
      END_STATE();
    case 68:
      if (lookahead == '6') ADVANCE(1016);
      END_STATE();
    case 69:
      if (lookahead == '8') ADVANCE(59);
      END_STATE();
    case 70:
      if (lookahead == '8') ADVANCE(60);
      END_STATE();
    case 71:
      if (lookahead == '8') ADVANCE(61);
      END_STATE();
    case 72:
      if (lookahead == ':') ADVANCE(1527);
      if (lookahead == '=') ADVANCE(1530);
      if (lookahead == '?') ADVANCE(1526);
      END_STATE();
    case 73:
      if (lookahead == ':') ADVANCE(811);
      END_STATE();
    case 74:
      if (lookahead == ':') ADVANCE(812);
      END_STATE();
    case 75:
      if (lookahead == '=') ADVANCE(1528);
      if (lookahead == '~') ADVANCE(1533);
      END_STATE();
    case 76:
      if (lookahead == '>') ADVANCE(1523);
      if (lookahead == '|') ADVANCE(1525);
      END_STATE();
    case 77:
      if (lookahead == 'A') ADVANCE(500);
      if (lookahead == 'H') ADVANCE(111);
      if (lookahead == 'O') ADVANCE(413);
      if (lookahead == 'R') ADVANCE(257);
      END_STATE();
    case 78:
      if (lookahead == 'A') ADVANCE(460);
      END_STATE();
    case 79:
      if (lookahead == 'A') ADVANCE(460);
      if (lookahead == 'I') ADVANCE(327);
      END_STATE();
    case 80:
      if (lookahead == 'A') ADVANCE(588);
      if (lookahead == 'E') ADVANCE(109);
      if (lookahead == 'O') ADVANCE(637);
      if (lookahead == 'S') ADVANCE(57);
      END_STATE();
    case 81:
      if (lookahead == 'A') ADVANCE(148);
      if (lookahead == 'E') ADVANCE(592);
      if (lookahead == 'H') ADVANCE(275);
      if (lookahead == 'I') ADVANCE(469);
      if (lookahead == 'O') ADVANCE(1034);
      if (lookahead == 'R') ADVANCE(115);
      if (lookahead == 'Y') ADVANCE(568);
      END_STATE();
    case 82:
      if (lookahead == 'A') ADVANCE(148);
      if (lookahead == 'O') ADVANCE(411);
      END_STATE();
    case 83:
      if (lookahead == 'A') ADVANCE(1009);
      END_STATE();
    case 84:
      if (lookahead == 'A') ADVANCE(324);
      END_STATE();
    case 85:
      if (lookahead == 'A') ADVANCE(609);
      if (lookahead == 'E') ADVANCE(590);
      END_STATE();
    case 86:
      if (lookahead == 'A') ADVANCE(609);
      if (lookahead == 'E') ADVANCE(590);
      if (lookahead == 'O') ADVANCE(637);
      END_STATE();
    case 87:
      if (lookahead == 'A') ADVANCE(683);
      if (lookahead == 'B') ADVANCE(1053);
      if (lookahead == 'E') ADVANCE(320);
      if (lookahead == 'I') ADVANCE(318);
      if (lookahead == 'O') ADVANCE(151);
      if (lookahead == 'R') ADVANCE(540);
      END_STATE();
    case 88:
      if (lookahead == 'A') ADVANCE(683);
      if (lookahead == 'E') ADVANCE(326);
      END_STATE();
    case 89:
      if (lookahead == 'A') ADVANCE(443);
      if (lookahead == 'E') ADVANCE(685);
      if (lookahead == 'I') ADVANCE(270);
      if (lookahead == 'L') ADVANCE(210);
      if (lookahead == 'O') ADVANCE(575);
      if (lookahead == 'R') ADVANCE(546);
      if (lookahead == 'U') ADVANCE(429);
      END_STATE();
    case 90:
      if (lookahead == 'A') ADVANCE(433);
      if (lookahead == 'N') ADVANCE(537);
      END_STATE();
    case 91:
      if (lookahead == 'A') ADVANCE(464);
      if (lookahead == 'O') ADVANCE(366);
      if (lookahead == 'S') ADVANCE(1052);
      if (lookahead == 'U') ADVANCE(430);
      END_STATE();
    case 92:
      if (lookahead == 'A') ADVANCE(464);
      if (lookahead == 'O') ADVANCE(365);
      END_STATE();
    case 93:
      if (lookahead == 'A') ADVANCE(447);
      END_STATE();
    case 94:
      if (lookahead == 'A') ADVANCE(498);
      if (lookahead == 'E') ADVANCE(587);
      if (lookahead == 'I') ADVANCE(497);
      if (lookahead == 'T') ADVANCE(595);
      END_STATE();
    case 95:
      if (lookahead == 'A') ADVANCE(498);
      if (lookahead == 'I') ADVANCE(497);
      END_STATE();
    case 96:
      if (lookahead == 'A') ADVANCE(159);
      END_STATE();
    case 97:
      if (lookahead == 'A') ADVANCE(159);
      if (lookahead == 'W') ADVANCE(406);
      END_STATE();
    case 98:
      if (lookahead == 'A') ADVANCE(147);
      END_STATE();
    case 99:
      if (lookahead == 'A') ADVANCE(423);
      END_STATE();
    case 100:
      if (lookahead == 'A') ADVANCE(711);
      END_STATE();
    case 101:
      if (lookahead == 'A') ADVANCE(711);
      if (lookahead == 'I') ADVANCE(518);
      END_STATE();
    case 102:
      if (lookahead == 'A') ADVANCE(415);
      END_STATE();
    case 103:
      if (lookahead == 'A') ADVANCE(415);
      if (lookahead == 'D') ADVANCE(939);
      if (lookahead == 'Y') ADVANCE(1030);
      END_STATE();
    case 104:
      if (lookahead == 'A') ADVANCE(501);
      if (lookahead == 'E') ADVANCE(107);
      if (lookahead == 'O') ADVANCE(431);
      if (lookahead == 'S') ADVANCE(58);
      END_STATE();
    case 105:
      if (lookahead == 'A') ADVANCE(501);
      if (lookahead == 'E') ADVANCE(108);
      END_STATE();
    case 106:
      if (lookahead == 'A') ADVANCE(189);
      END_STATE();
    case 107:
      if (lookahead == 'A') ADVANCE(189);
      if (lookahead == 'L') ADVANCE(120);
      if (lookahead == 'M') ADVANCE(535);
      if (lookahead == 'T') ADVANCE(710);
      END_STATE();
    case 108:
      if (lookahead == 'A') ADVANCE(189);
      if (lookahead == 'T') ADVANCE(710);
      END_STATE();
    case 109:
      if (lookahead == 'A') ADVANCE(591);
      if (lookahead == 'R') ADVANCE(461);
      END_STATE();
    case 110:
      if (lookahead == 'A') ADVANCE(522);
      END_STATE();
    case 111:
      if (lookahead == 'A') ADVANCE(522);
      if (lookahead == 'E') ADVANCE(146);
      END_STATE();
    case 112:
      if (lookahead == 'A') ADVANCE(596);
      if (lookahead == 'L') ADVANCE(306);
      if (lookahead == 'S') ADVANCE(632);
      if (lookahead == 'T') ADVANCE(1104);
      END_STATE();
    case 113:
      if (lookahead == 'A') ADVANCE(596);
      if (lookahead == 'S') ADVANCE(632);
      if (lookahead == 'T') ADVANCE(1104);
      END_STATE();
    case 114:
      if (lookahead == 'A') ADVANCE(600);
      END_STATE();
    case 115:
      if (lookahead == 'A') ADVANCE(521);
      if (lookahead == 'U') ADVANCE(216);
      END_STATE();
    case 116:
      if (lookahead == 'A') ADVANCE(168);
      END_STATE();
    case 117:
      if (lookahead == 'A') ADVANCE(594);
      END_STATE();
    case 118:
      if (lookahead == 'A') ADVANCE(458);
      END_STATE();
    case 119:
      if (lookahead == 'A') ADVANCE(419);
      END_STATE();
    case 120:
      if (lookahead == 'A') ADVANCE(681);
      END_STATE();
    case 121:
      if (lookahead == 'A') ADVANCE(636);
      END_STATE();
    case 122:
      if (lookahead == 'A') ADVANCE(608);
      END_STATE();
    case 123:
      if (lookahead == 'A') ADVANCE(608);
      if (lookahead == 'E') ADVANCE(590);
      END_STATE();
    case 124:
      if (lookahead == 'A') ADVANCE(697);
      END_STATE();
    case 125:
      if (lookahead == 'A') ADVANCE(602);
      END_STATE();
    case 126:
      if (lookahead == 'A') ADVANCE(446);
      END_STATE();
    case 127:
      if (lookahead == 'A') ADVANCE(677);
      END_STATE();
    case 128:
      if (lookahead == 'A') ADVANCE(492);
      END_STATE();
    case 129:
      if (lookahead == 'A') ADVANCE(493);
      END_STATE();
    case 130:
      if (lookahead == 'A') ADVANCE(450);
      END_STATE();
    case 131:
      if (lookahead == 'A') ADVANCE(165);
      END_STATE();
    case 132:
      if (lookahead == 'A') ADVANCE(691);
      END_STATE();
    case 133:
      if (lookahead == 'A') ADVANCE(643);
      END_STATE();
    case 134:
      if (lookahead == 'A') ADVANCE(693);
      END_STATE();
    case 135:
      if (lookahead == 'A') ADVANCE(381);
      END_STATE();
    case 136:
      if (lookahead == 'A') ADVANCE(381);
      if (lookahead == 'E') ADVANCE(516);
      END_STATE();
    case 137:
      if (lookahead == 'A') ADVANCE(694);
      END_STATE();
    case 138:
      if (lookahead == 'A') ADVANCE(382);
      END_STATE();
    case 139:
      if (lookahead == 'A') ADVANCE(695);
      END_STATE();
    case 140:
      if (lookahead == 'A') ADVANCE(696);
      END_STATE();
    case 141:
      if (lookahead == 'A') ADVANCE(169);
      END_STATE();
    case 142:
      if (lookahead == 'A') ADVANCE(170);
      END_STATE();
    case 143:
      if (lookahead == 'A') ADVANCE(171);
      END_STATE();
    case 144:
      if (lookahead == 'A') ADVANCE(703);
      END_STATE();
    case 145:
      if (lookahead == 'A') ADVANCE(179);
      END_STATE();
    case 146:
      if (lookahead == 'B') ADVANCE(731);
      END_STATE();
    case 147:
      if (lookahead == 'B') ADVANCE(133);
      END_STATE();
    case 148:
      if (lookahead == 'B') ADVANCE(440);
      END_STATE();
    case 149:
      if (lookahead == 'B') ADVANCE(442);
      END_STATE();
    case 150:
      if (lookahead == 'C') ADVANCE(347);
      if (lookahead == 'E') ADVANCE(112);
      if (lookahead == 'I') ADVANCE(331);
      if (lookahead == 'P') ADVANCE(449);
      if (lookahead == 'T') ADVANCE(114);
      END_STATE();
    case 151:
      if (lookahead == 'C') ADVANCE(734);
      END_STATE();
    case 152:
      if (lookahead == 'C') ADVANCE(906);
      END_STATE();
    case 153:
      if (lookahead == 'C') ADVANCE(902);
      END_STATE();
    case 154:
      if (lookahead == 'C') ADVANCE(904);
      if (lookahead == 'S') ADVANCE(307);
      END_STATE();
    case 155:
      if (lookahead == 'C') ADVANCE(338);
      END_STATE();
    case 156:
      if (lookahead == 'C') ADVANCE(339);
      END_STATE();
    case 157:
      if (lookahead == 'C') ADVANCE(444);
      END_STATE();
    case 158:
      if (lookahead == 'C') ADVANCE(340);
      END_STATE();
    case 159:
      if (lookahead == 'C') ADVANCE(167);
      END_STATE();
    case 160:
      if (lookahead == 'C') ADVANCE(116);
      if (lookahead == 'O') ADVANCE(598);
      END_STATE();
    case 161:
      if (lookahead == 'C') ADVANCE(700);
      END_STATE();
    case 162:
      if (lookahead == 'C') ADVANCE(280);
      END_STATE();
    case 163:
      if (lookahead == 'C') ADVANCE(672);
      END_STATE();
    case 164:
      if (lookahead == 'C') ADVANCE(690);
      END_STATE();
    case 165:
      if (lookahead == 'C') ADVANCE(241);
      END_STATE();
    case 166:
      if (lookahead == 'C') ADVANCE(558);
      END_STATE();
    case 167:
      if (lookahead == 'C') ADVANCE(117);
      END_STATE();
    case 168:
      if (lookahead == 'C') ADVANCE(352);
      END_STATE();
    case 169:
      if (lookahead == 'C') ADVANCE(353);
      END_STATE();
    case 170:
      if (lookahead == 'C') ADVANCE(354);
      END_STATE();
    case 171:
      if (lookahead == 'C') ADVANCE(355);
      END_STATE();
    case 172:
      if (lookahead == 'C') ADVANCE(346);
      END_STATE();
    case 173:
      if (lookahead == 'C') ADVANCE(346);
      if (lookahead == 'E') ADVANCE(113);
      if (lookahead == 'I') ADVANCE(331);
      END_STATE();
    case 174:
      if (lookahead == 'C') ADVANCE(346);
      if (lookahead == 'E') ADVANCE(661);
      END_STATE();
    case 175:
      if (lookahead == 'C') ADVANCE(141);
      if (lookahead == 'O') ADVANCE(611);
      END_STATE();
    case 176:
      if (lookahead == 'C') ADVANCE(142);
      if (lookahead == 'O') ADVANCE(612);
      END_STATE();
    case 177:
      if (lookahead == 'C') ADVANCE(139);
      END_STATE();
    case 178:
      if (lookahead == 'C') ADVANCE(143);
      if (lookahead == 'O') ADVANCE(613);
      END_STATE();
    case 179:
      if (lookahead == 'C') ADVANCE(702);
      END_STATE();
    case 180:
      if (lookahead == 'D') ADVANCE(188);
      if (lookahead == 'L') ADVANCE(635);
      if (lookahead == 'N') ADVANCE(182);
      if (lookahead == 'S') ADVANCE(56);
      if (lookahead == 'U') ADVANCE(157);
      if (lookahead == 'V') ADVANCE(305);
      if (lookahead == 'X') ADVANCE(388);
      END_STATE();
    case 181:
      if (lookahead == 'D') ADVANCE(939);
      if (lookahead == 'Y') ADVANCE(404);
      END_STATE();
    case 182:
      if (lookahead == 'D') ADVANCE(870);
      END_STATE();
    case 183:
      if (lookahead == 'D') ADVANCE(897);
      END_STATE();
    case 184:
      if (lookahead == 'D') ADVANCE(990);
      END_STATE();
    case 185:
      if (lookahead == 'D') ADVANCE(982);
      END_STATE();
    case 186:
      if (lookahead == 'D') ADVANCE(1099);
      END_STATE();
    case 187:
      if (lookahead == 'D') ADVANCE(1035);
      END_STATE();
    case 188:
      if (lookahead == 'D') ADVANCE(633);
      END_STATE();
    case 189:
      if (lookahead == 'D') ADVANCE(549);
      END_STATE();
    case 190:
      if (lookahead == 'D') ADVANCE(625);
      END_STATE();
    case 191:
      if (lookahead == 'D') ADVANCE(231);
      END_STATE();
    case 192:
      if (lookahead == 'D') ADVANCE(254);
      END_STATE();
    case 193:
      if (lookahead == 'D') ADVANCE(239);
      END_STATE();
    case 194:
      if (lookahead == 'D') ADVANCE(240);
      END_STATE();
    case 195:
      if (lookahead == 'D') ADVANCE(242);
      END_STATE();
    case 196:
      if (lookahead == 'D') ADVANCE(248);
      END_STATE();
    case 197:
      if (lookahead == 'D') ADVANCE(249);
      END_STATE();
    case 198:
      if (lookahead == 'D') ADVANCE(265);
      if (lookahead == 'T') ADVANCE(538);
      END_STATE();
    case 199:
      if (lookahead == 'D') ADVANCE(281);
      END_STATE();
    case 200:
      if (lookahead == 'D') ADVANCE(717);
      END_STATE();
    case 201:
      if (lookahead == 'D') ADVANCE(285);
      END_STATE();
    case 202:
      if (lookahead == 'D') ADVANCE(287);
      END_STATE();
    case 203:
      if (lookahead == 'D') ADVANCE(288);
      END_STATE();
    case 204:
      if (lookahead == 'D') ADVANCE(291);
      END_STATE();
    case 205:
      if (lookahead == 'D') ADVANCE(134);
      END_STATE();
    case 206:
      if (lookahead == 'D') ADVANCE(140);
      END_STATE();
    case 207:
      if (lookahead == 'D') ADVANCE(655);
      END_STATE();
    case 208:
      if (lookahead == 'E') ADVANCE(321);
      if (lookahead == 'M') ADVANCE(52);
      if (lookahead == 'Y') ADVANCE(894);
      END_STATE();
    case 209:
      if (lookahead == 'E') ADVANCE(109);
      END_STATE();
    case 210:
      if (lookahead == 'E') ADVANCE(724);
      END_STATE();
    case 211:
      if (lookahead == 'E') ADVANCE(1051);
      END_STATE();
    case 212:
      if (lookahead == 'E') ADVANCE(482);
      END_STATE();
    case 213:
      if (lookahead == 'E') ADVANCE(869);
      END_STATE();
    case 214:
      if (lookahead == 'E') ADVANCE(1001);
      END_STATE();
    case 215:
      if (lookahead == 'E') ADVANCE(935);
      END_STATE();
    case 216:
      if (lookahead == 'E') ADVANCE(924);
      END_STATE();
    case 217:
      if (lookahead == 'E') ADVANCE(1071);
      END_STATE();
    case 218:
      if (lookahead == 'E') ADVANCE(926);
      END_STATE();
    case 219:
      if (lookahead == 'E') ADVANCE(1039);
      END_STATE();
    case 220:
      if (lookahead == 'E') ADVANCE(1109);
      END_STATE();
    case 221:
      if (lookahead == 'E') ADVANCE(994);
      END_STATE();
    case 222:
      if (lookahead == 'E') ADVANCE(1047);
      END_STATE();
    case 223:
      if (lookahead == 'E') ADVANCE(876);
      END_STATE();
    case 224:
      if (lookahead == 'E') ADVANCE(914);
      END_STATE();
    case 225:
      if (lookahead == 'E') ADVANCE(1043);
      END_STATE();
    case 226:
      if (lookahead == 'E') ADVANCE(979);
      END_STATE();
    case 227:
      if (lookahead == 'E') ADVANCE(1058);
      END_STATE();
    case 228:
      if (lookahead == 'E') ADVANCE(986);
      END_STATE();
    case 229:
      if (lookahead == 'E') ADVANCE(1060);
      END_STATE();
    case 230:
      if (lookahead == 'E') ADVANCE(1081);
      END_STATE();
    case 231:
      if (lookahead == 'E') ADVANCE(961);
      END_STATE();
    case 232:
      if (lookahead == 'E') ADVANCE(1079);
      if (lookahead == 'I') ADVANCE(553);
      END_STATE();
    case 233:
      if (lookahead == 'E') ADVANCE(1056);
      END_STATE();
    case 234:
      if (lookahead == 'E') ADVANCE(1089);
      END_STATE();
    case 235:
      if (lookahead == 'E') ADVANCE(1062);
      END_STATE();
    case 236:
      if (lookahead == 'E') ADVANCE(900);
      END_STATE();
    case 237:
      if (lookahead == 'E') ADVANCE(1098);
      END_STATE();
    case 238:
      if (lookahead == 'E') ADVANCE(1004);
      END_STATE();
    case 239:
      if (lookahead == 'E') ADVANCE(968);
      END_STATE();
    case 240:
      if (lookahead == 'E') ADVANCE(970);
      END_STATE();
    case 241:
      if (lookahead == 'E') ADVANCE(992);
      END_STATE();
    case 242:
      if (lookahead == 'E') ADVANCE(966);
      END_STATE();
    case 243:
      if (lookahead == 'E') ADVANCE(1026);
      END_STATE();
    case 244:
      if (lookahead == 'E') ADVANCE(959);
      END_STATE();
    case 245:
      if (lookahead == 'E') ADVANCE(1020);
      END_STATE();
    case 246:
      if (lookahead == 'E') ADVANCE(1024);
      END_STATE();
    case 247:
      if (lookahead == 'E') ADVANCE(1022);
      END_STATE();
    case 248:
      if (lookahead == 'E') ADVANCE(974);
      END_STATE();
    case 249:
      if (lookahead == 'E') ADVANCE(972);
      END_STATE();
    case 250:
      if (lookahead == 'E') ADVANCE(323);
      END_STATE();
    case 251:
      if (lookahead == 'E') ADVANCE(631);
      if (lookahead == 'I') ADVANCE(331);
      END_STATE();
    case 252:
      if (lookahead == 'E') ADVANCE(1101);
      END_STATE();
    case 253:
      if (lookahead == 'E') ADVANCE(325);
      END_STATE();
    case 254:
      if (lookahead == 'E') ADVANCE(722);
      END_STATE();
    case 255:
      if (lookahead == 'E') ADVANCE(718);
      END_STATE();
    case 256:
      if (lookahead == 'E') ADVANCE(587);
      END_STATE();
    case 257:
      if (lookahead == 'E') ADVANCE(132);
      END_STATE();
    case 258:
      if (lookahead == 'E') ADVANCE(685);
      END_STATE();
    case 259:
      if (lookahead == 'E') ADVANCE(685);
      if (lookahead == 'I') ADVANCE(292);
      if (lookahead == 'L') ADVANCE(210);
      if (lookahead == 'O') ADVANCE(575);
      END_STATE();
    case 260:
      if (lookahead == 'E') ADVANCE(685);
      if (lookahead == 'L') ADVANCE(210);
      END_STATE();
    case 261:
      if (lookahead == 'E') ADVANCE(685);
      if (lookahead == 'L') ADVANCE(210);
      if (lookahead == 'O') ADVANCE(575);
      END_STATE();
    case 262:
      if (lookahead == 'E') ADVANCE(322);
      END_STATE();
    case 263:
      if (lookahead == 'E') ADVANCE(3);
      END_STATE();
    case 264:
      if (lookahead == 'E') ADVANCE(659);
      if (lookahead == 'I') ADVANCE(472);
      END_STATE();
    case 265:
      if (lookahead == 'E') ADVANCE(723);
      END_STATE();
    case 266:
      if (lookahead == 'E') ADVANCE(592);
      if (lookahead == 'H') ADVANCE(275);
      if (lookahead == 'I') ADVANCE(469);
      if (lookahead == 'O') ADVANCE(410);
      if (lookahead == 'Y') ADVANCE(568);
      END_STATE();
    case 267:
      if (lookahead == 'E') ADVANCE(730);
      END_STATE();
    case 268:
      if (lookahead == 'E') ADVANCE(630);
      END_STATE();
    case 269:
      if (lookahead == 'E') ADVANCE(425);
      END_STATE();
    case 270:
      if (lookahead == 'E') ADVANCE(425);
      if (lookahead == 'L') ADVANCE(689);
      END_STATE();
    case 271:
      if (lookahead == 'E') ADVANCE(547);
      END_STATE();
    case 272:
      if (lookahead == 'E') ADVANCE(577);
      END_STATE();
    case 273:
      if (lookahead == 'E') ADVANCE(616);
      END_STATE();
    case 274:
      if (lookahead == 'E') ADVANCE(610);
      END_STATE();
    case 275:
      if (lookahead == 'E') ADVANCE(481);
      END_STATE();
    case 276:
      if (lookahead == 'E') ADVANCE(463);
      END_STATE();
    case 277:
      if (lookahead == 'E') ADVANCE(593);
      END_STATE();
    case 278:
      if (lookahead == 'E') ADVANCE(578);
      END_STATE();
    case 279:
      if (lookahead == 'E') ADVANCE(187);
      END_STATE();
    case 280:
      if (lookahead == 'E') ADVANCE(418);
      END_STATE();
    case 281:
      if (lookahead == 'E') ADVANCE(128);
      END_STATE();
    case 282:
      if (lookahead == 'E') ADVANCE(528);
      END_STATE();
    case 283:
      if (lookahead == 'E') ADVANCE(579);
      END_STATE();
    case 284:
      if (lookahead == 'E') ADVANCE(420);
      END_STATE();
    case 285:
      if (lookahead == 'E') ADVANCE(580);
      END_STATE();
    case 286:
      if (lookahead == 'E') ADVANCE(106);
      END_STATE();
    case 287:
      if (lookahead == 'E') ADVANCE(581);
      END_STATE();
    case 288:
      if (lookahead == 'E') ADVANCE(582);
      END_STATE();
    case 289:
      if (lookahead == 'E') ADVANCE(670);
      END_STATE();
    case 290:
      if (lookahead == 'E') ADVANCE(642);
      END_STATE();
    case 291:
      if (lookahead == 'E') ADVANCE(583);
      END_STATE();
    case 292:
      if (lookahead == 'E') ADVANCE(448);
      END_STATE();
    case 293:
      if (lookahead == 'E') ADVANCE(448);
      if (lookahead == 'L') ADVANCE(689);
      END_STATE();
    case 294:
      if (lookahead == 'E') ADVANCE(504);
      END_STATE();
    case 295:
      if (lookahead == 'E') ADVANCE(576);
      END_STATE();
    case 296:
      if (lookahead == 'E') ADVANCE(220);
      END_STATE();
    case 297:
      if (lookahead == 'E') ADVANCE(451);
      END_STATE();
    case 298:
      if (lookahead == 'E') ADVANCE(626);
      END_STATE();
    case 299:
      if (lookahead == 'E') ADVANCE(680);
      END_STATE();
    case 300:
      if (lookahead == 'E') ADVANCE(661);
      END_STATE();
    case 301:
      if (lookahead == 'E') ADVANCE(507);
      END_STATE();
    case 302:
      if (lookahead == 'E') ADVANCE(496);
      END_STATE();
    case 303:
      if (lookahead == 'E') ADVANCE(279);
      END_STATE();
    case 304:
      if (lookahead == 'E') ADVANCE(599);
      END_STATE();
    case 305:
      if (lookahead == 'E') ADVANCE(510);
      END_STATE();
    case 306:
      if (lookahead == 'E') ADVANCE(163);
      END_STATE();
    case 307:
      if (lookahead == 'E') ADVANCE(606);
      END_STATE();
    case 308:
      if (lookahead == 'E') ADVANCE(603);
      END_STATE();
    case 309:
      if (lookahead == 'E') ADVANCE(514);
      END_STATE();
    case 310:
      if (lookahead == 'E') ADVANCE(514);
      if (lookahead == 'I') ADVANCE(671);
      END_STATE();
    case 311:
      if (lookahead == 'E') ADVANCE(164);
      END_STATE();
    case 312:
      if (lookahead == 'E') ADVANCE(692);
      END_STATE();
    case 313:
      if (lookahead == 'E') ADVANCE(604);
      END_STATE();
    case 314:
      if (lookahead == 'E') ADVANCE(405);
      END_STATE();
    case 315:
      if (lookahead == 'F') ADVANCE(684);
      if (lookahead == 'L') ADVANCE(412);
      if (lookahead == 'N') ADVANCE(103);
      if (lookahead == 'S') ADVANCE(879);
      if (lookahead == 'T') ADVANCE(919);
      END_STATE();
    case 316:
      if (lookahead == 'F') ADVANCE(1094);
      if (lookahead == 'G') ADVANCE(527);
      if (lookahead == 'N') ADVANCE(964);
      if (lookahead == 'S') ADVANCE(945);
      END_STATE();
    case 317:
      if (lookahead == 'F') ADVANCE(1094);
      if (lookahead == 'N') ADVANCE(964);
      if (lookahead == 'S') ADVANCE(945);
      END_STATE();
    case 318:
      if (lookahead == 'F') ADVANCE(319);
      if (lookahead == 'M') ADVANCE(282);
      if (lookahead == 'S') ADVANCE(662);
      END_STATE();
    case 319:
      if (lookahead == 'F') ADVANCE(1002);
      END_STATE();
    case 320:
      if (lookahead == 'F') ADVANCE(101);
      if (lookahead == 'L') ADVANCE(312);
      if (lookahead == 'S') ADVANCE(152);
      END_STATE();
    case 321:
      if (lookahead == 'F') ADVANCE(560);
      if (lookahead == 'G') ADVANCE(371);
      END_STATE();
    case 322:
      if (lookahead == 'F') ADVANCE(100);
      END_STATE();
    case 323:
      if (lookahead == 'F') ADVANCE(100);
      if (lookahead == 'S') ADVANCE(152);
      END_STATE();
    case 324:
      if (lookahead == 'F') ADVANCE(712);
      if (lookahead == 'L') ADVANCE(290);
      END_STATE();
    case 325:
      if (lookahead == 'F') ADVANCE(303);
      END_STATE();
    case 326:
      if (lookahead == 'F') ADVANCE(391);
      END_STATE();
    case 327:
      if (lookahead == 'G') ADVANCE(345);
      END_STATE();
    case 328:
      if (lookahead == 'G') ADVANCE(981);
      END_STATE();
    case 329:
      if (lookahead == 'G') ADVANCE(527);
      if (lookahead == 'N') ADVANCE(198);
      END_STATE();
    case 330:
      if (lookahead == 'G') ADVANCE(350);
      END_STATE();
    case 331:
      if (lookahead == 'G') ADVANCE(480);
      END_STATE();
    case 332:
      if (lookahead == 'G') ADVANCE(219);
      END_STATE();
    case 333:
      if (lookahead == 'G') ADVANCE(686);
      END_STATE();
    case 334:
      if (lookahead == 'G') ADVANCE(253);
      END_STATE();
    case 335:
      if (lookahead == 'G') ADVANCE(656);
      END_STATE();
    case 336:
      if (lookahead == 'H') ADVANCE(111);
      if (lookahead == 'O') ADVANCE(467);
      END_STATE();
    case 337:
      if (lookahead == 'H') ADVANCE(910);
      END_STATE();
    case 338:
      if (lookahead == 'H') ADVANCE(889);
      END_STATE();
    case 339:
      if (lookahead == 'H') ADVANCE(1041);
      END_STATE();
    case 340:
      if (lookahead == 'H') ADVANCE(1090);
      END_STATE();
    case 341:
      if (lookahead == 'H') ADVANCE(1100);
      END_STATE();
    case 342:
      if (lookahead == 'H') ADVANCE(212);
      END_STATE();
    case 343:
      if (lookahead == 'H') ADVANCE(212);
      if (lookahead == 'I') ADVANCE(682);
      END_STATE();
    case 344:
      if (lookahead == 'H') ADVANCE(121);
      if (lookahead == 'W') ADVANCE(548);
      END_STATE();
    case 345:
      if (lookahead == 'H') ADVANCE(427);
      END_STATE();
    case 346:
      if (lookahead == 'H') ADVANCE(276);
      END_STATE();
    case 347:
      if (lookahead == 'H') ADVANCE(276);
      if (lookahead == 'O') ADVANCE(570);
      END_STATE();
    case 348:
      if (lookahead == 'H') ADVANCE(110);
      if (lookahead == 'O') ADVANCE(426);
      END_STATE();
    case 349:
      if (lookahead == 'H') ADVANCE(110);
      if (lookahead == 'O') ADVANCE(465);
      END_STATE();
    case 350:
      if (lookahead == 'H') ADVANCE(688);
      END_STATE();
    case 351:
      if (lookahead == 'H') ADVANCE(255);
      END_STATE();
    case 352:
      if (lookahead == 'H') ADVANCE(243);
      END_STATE();
    case 353:
      if (lookahead == 'H') ADVANCE(245);
      END_STATE();
    case 354:
      if (lookahead == 'H') ADVANCE(246);
      END_STATE();
    case 355:
      if (lookahead == 'H') ADVANCE(247);
      END_STATE();
    case 356:
      if (lookahead == 'H') ADVANCE(313);
      END_STATE();
    case 357:
      if (lookahead == 'H') ADVANCE(313);
      if (lookahead == 'I') ADVANCE(682);
      END_STATE();
    case 358:
      if (lookahead == 'H') ADVANCE(275);
      if (lookahead == 'I') ADVANCE(469);
      if (lookahead == 'Y') ADVANCE(568);
      END_STATE();
    case 359:
      if (lookahead == 'H') ADVANCE(124);
      END_STATE();
    case 360:
      if (lookahead == 'H') ADVANCE(658);
      END_STATE();
    case 361:
      if (lookahead == 'I') ADVANCE(327);
      END_STATE();
    case 362:
      if (lookahead == 'I') ADVANCE(572);
      if (lookahead == 'S') ADVANCE(289);
      END_STATE();
    case 363:
      if (lookahead == 'I') ADVANCE(984);
      END_STATE();
    case 364:
      if (lookahead == 'I') ADVANCE(191);
      END_STATE();
    case 365:
      if (lookahead == 'I') ADVANCE(523);
      END_STATE();
    case 366:
      if (lookahead == 'I') ADVANCE(523);
      if (lookahead == 'N') ADVANCE(215);
      if (lookahead == 'R') ADVANCE(470);
      if (lookahead == 'T') ADVANCE(950);
      END_STATE();
    case 367:
      if (lookahead == 'I') ADVANCE(199);
      END_STATE();
    case 368:
      if (lookahead == 'I') ADVANCE(663);
      END_STATE();
    case 369:
      if (lookahead == 'I') ADVANCE(153);
      END_STATE();
    case 370:
      if (lookahead == 'I') ADVANCE(508);
      END_STATE();
    case 371:
      if (lookahead == 'I') ADVANCE(483);
      END_STATE();
    case 372:
      if (lookahead == 'I') ADVANCE(177);
      END_STATE();
    case 373:
      if (lookahead == 'I') ADVANCE(471);
      END_STATE();
    case 374:
      if (lookahead == 'I') ADVANCE(517);
      END_STATE();
    case 375:
      if (lookahead == 'I') ADVANCE(657);
      END_STATE();
    case 376:
      if (lookahead == 'I') ADVANCE(667);
      END_STATE();
    case 377:
      if (lookahead == 'I') ADVANCE(502);
      END_STATE();
    case 378:
      if (lookahead == 'I') ADVANCE(668);
      END_STATE();
    case 379:
      if (lookahead == 'I') ADVANCE(503);
      END_STATE();
    case 380:
      if (lookahead == 'I') ADVANCE(485);
      if (lookahead == 'U') ADVANCE(564);
      END_STATE();
    case 381:
      if (lookahead == 'I') ADVANCE(513);
      END_STATE();
    case 382:
      if (lookahead == 'I') ADVANCE(486);
      END_STATE();
    case 383:
      if (lookahead == 'I') ADVANCE(269);
      if (lookahead == 'U') ADVANCE(506);
      END_STATE();
    case 384:
      if (lookahead == 'I') ADVANCE(207);
      if (lookahead == 'L') ADVANCE(294);
      END_STATE();
    case 385:
      if (lookahead == 'I') ADVANCE(293);
      if (lookahead == 'O') ADVANCE(575);
      if (lookahead == 'R') ADVANCE(546);
      if (lookahead == 'U') ADVANCE(506);
      END_STATE();
    case 386:
      if (lookahead == 'I') ADVANCE(330);
      END_STATE();
    case 387:
      if (lookahead == 'I') ADVANCE(733);
      END_STATE();
    case 388:
      if (lookahead == 'I') ADVANCE(639);
      if (lookahead == 'P') ADVANCE(428);
      END_STATE();
    case 389:
      if (lookahead == 'I') ADVANCE(469);
      END_STATE();
    case 390:
      if (lookahead == 'I') ADVANCE(469);
      if (lookahead == 'Y') ADVANCE(568);
      END_STATE();
    case 391:
      if (lookahead == 'I') ADVANCE(518);
      END_STATE();
    case 392:
      if (lookahead == 'I') ADVANCE(551);
      END_STATE();
    case 393:
      if (lookahead == 'I') ADVANCE(193);
      END_STATE();
    case 394:
      if (lookahead == 'I') ADVANCE(552);
      END_STATE();
    case 395:
      if (lookahead == 'I') ADVANCE(194);
      END_STATE();
    case 396:
      if (lookahead == 'I') ADVANCE(553);
      END_STATE();
    case 397:
      if (lookahead == 'I') ADVANCE(195);
      END_STATE();
    case 398:
      if (lookahead == 'I') ADVANCE(554);
      END_STATE();
    case 399:
      if (lookahead == 'I') ADVANCE(196);
      END_STATE();
    case 400:
      if (lookahead == 'I') ADVANCE(555);
      END_STATE();
    case 401:
      if (lookahead == 'I') ADVANCE(197);
      END_STATE();
    case 402:
      if (lookahead == 'I') ADVANCE(556);
      END_STATE();
    case 403:
      if (lookahead == 'I') ADVANCE(149);
      END_STATE();
    case 404:
      if (lookahead == 'I') ADVANCE(529);
      END_STATE();
    case 405:
      if (lookahead == 'I') ADVANCE(531);
      END_STATE();
    case 406:
      if (lookahead == 'K') ADVANCE(614);
      END_STATE();
    case 407:
      if (lookahead == 'K') ADVANCE(536);
      END_STATE();
    case 408:
      if (lookahead == 'K') ADVANCE(363);
      END_STATE();
    case 409:
      if (lookahead == 'K') ADVANCE(267);
      END_STATE();
    case 410:
      if (lookahead == 'K') ADVANCE(301);
      END_STATE();
    case 411:
      if (lookahead == 'K') ADVANCE(302);
      END_STATE();
    case 412:
      if (lookahead == 'L') ADVANCE(923);
      END_STATE();
    case 413:
      if (lookahead == 'L') ADVANCE(454);
      if (lookahead == 'M') ADVANCE(459);
      if (lookahead == 'N') ADVANCE(679);
      if (lookahead == 'S') ADVANCE(374);
      if (lookahead == 'U') ADVANCE(509);
      END_STATE();
    case 414:
      if (lookahead == 'L') ADVANCE(454);
      if (lookahead == 'M') ADVANCE(475);
      if (lookahead == 'N') ADVANCE(679);
      END_STATE();
    case 415:
      if (lookahead == 'L') ADVANCE(726);
      END_STATE();
    case 416:
      if (lookahead == 'L') ADVANCE(884);
      END_STATE();
    case 417:
      if (lookahead == 'L') ADVANCE(937);
      END_STATE();
    case 418:
      if (lookahead == 'L') ADVANCE(930);
      END_STATE();
    case 419:
      if (lookahead == 'L') ADVANCE(1031);
      END_STATE();
    case 420:
      if (lookahead == 'L') ADVANCE(885);
      END_STATE();
    case 421:
      if (lookahead == 'L') ADVANCE(997);
      END_STATE();
    case 422:
      if (lookahead == 'L') ADVANCE(955);
      END_STATE();
    case 423:
      if (lookahead == 'L') ADVANCE(714);
      END_STATE();
    case 424:
      if (lookahead == 'L') ADVANCE(727);
      END_STATE();
    case 425:
      if (lookahead == 'L') ADVANCE(184);
      END_STATE();
    case 426:
      if (lookahead == 'L') ADVANCE(709);
      if (lookahead == 'M') ADVANCE(475);
      if (lookahead == 'N') ADVANCE(679);
      END_STATE();
    case 427:
      if (lookahead == 'L') ADVANCE(386);
      END_STATE();
    case 428:
      if (lookahead == 'L') ADVANCE(138);
      END_STATE();
    case 429:
      if (lookahead == 'L') ADVANCE(416);
      if (lookahead == 'N') ADVANCE(161);
      END_STATE();
    case 430:
      if (lookahead == 'L') ADVANCE(417);
      if (lookahead == 'M') ADVANCE(277);
      END_STATE();
    case 431:
      if (lookahead == 'L') ADVANCE(273);
      if (lookahead == 'O') ADVANCE(664);
      END_STATE();
    case 432:
      if (lookahead == 'L') ADVANCE(421);
      END_STATE();
    case 433:
      if (lookahead == 'L') ADVANCE(422);
      if (lookahead == 'N') ADVANCE(728);
      END_STATE();
    case 434:
      if (lookahead == 'L') ADVANCE(452);
      if (lookahead == 'N') ADVANCE(181);
      END_STATE();
    case 435:
      if (lookahead == 'L') ADVANCE(452);
      if (lookahead == 'N') ADVANCE(181);
      if (lookahead == 'S') ADVANCE(879);
      END_STATE();
    case 436:
      if (lookahead == 'L') ADVANCE(452);
      if (lookahead == 'N') ADVANCE(181);
      if (lookahead == 'S') ADVANCE(154);
      END_STATE();
    case 437:
      if (lookahead == 'L') ADVANCE(452);
      if (lookahead == 'N') ADVANCE(181);
      if (lookahead == 'S') ADVANCE(645);
      END_STATE();
    case 438:
      if (lookahead == 'L') ADVANCE(453);
      if (lookahead == 'M') ADVANCE(475);
      if (lookahead == 'N') ADVANCE(679);
      END_STATE();
    case 439:
      if (lookahead == 'L') ADVANCE(675);
      END_STATE();
    case 440:
      if (lookahead == 'L') ADVANCE(222);
      END_STATE();
    case 441:
      if (lookahead == 'L') ADVANCE(284);
      END_STATE();
    case 442:
      if (lookahead == 'L') ADVANCE(238);
      END_STATE();
    case 443:
      if (lookahead == 'L') ADVANCE(641);
      END_STATE();
    case 444:
      if (lookahead == 'L') ADVANCE(367);
      END_STATE();
    case 445:
      if (lookahead == 'L') ADVANCE(372);
      END_STATE();
    case 446:
      if (lookahead == 'L') ADVANCE(441);
      END_STATE();
    case 447:
      if (lookahead == 'L') ADVANCE(441);
      if (lookahead == 'M') ADVANCE(993);
      END_STATE();
    case 448:
      if (lookahead == 'L') ADVANCE(190);
      END_STATE();
    case 449:
      if (lookahead == 'L') ADVANCE(378);
      END_STATE();
    case 450:
      if (lookahead == 'L') ADVANCE(716);
      END_STATE();
    case 451:
      if (lookahead == 'L') ADVANCE(144);
      END_STATE();
    case 452:
      if (lookahead == 'L') ADVANCE(370);
      END_STATE();
    case 453:
      if (lookahead == 'L') ADVANCE(137);
      END_STATE();
    case 454:
      if (lookahead == 'L') ADVANCE(137);
      if (lookahead == 'U') ADVANCE(468);
      END_STATE();
    case 455:
      if (lookahead == 'M') ADVANCE(52);
      END_STATE();
    case 456:
      if (lookahead == 'M') ADVANCE(368);
      if (lookahead == 'N') ADVANCE(864);
      if (lookahead == 'R') ADVANCE(943);
      if (lookahead == 'U') ADVANCE(660);
      END_STATE();
    case 457:
      if (lookahead == 'M') ADVANCE(873);
      END_STATE();
    case 458:
      if (lookahead == 'M') ADVANCE(993);
      END_STATE();
    case 459:
      if (lookahead == 'M') ADVANCE(310);
      END_STATE();
    case 460:
      if (lookahead == 'M') ADVANCE(473);
      END_STATE();
    case 461:
      if (lookahead == 'M') ADVANCE(375);
      END_STATE();
    case 462:
      if (lookahead == 'M') ADVANCE(628);
      END_STATE();
    case 463:
      if (lookahead == 'M') ADVANCE(84);
      END_STATE();
    case 464:
      if (lookahead == 'M') ADVANCE(268);
      END_STATE();
    case 465:
      if (lookahead == 'M') ADVANCE(475);
      if (lookahead == 'N') ADVANCE(679);
      END_STATE();
    case 466:
      if (lookahead == 'M') ADVANCE(475);
      if (lookahead == 'N') ADVANCE(701);
      END_STATE();
    case 467:
      if (lookahead == 'M') ADVANCE(475);
      if (lookahead == 'S') ADVANCE(374);
      END_STATE();
    case 468:
      if (lookahead == 'M') ADVANCE(511);
      END_STATE();
    case 469:
      if (lookahead == 'M') ADVANCE(271);
      END_STATE();
    case 470:
      if (lookahead == 'M') ADVANCE(119);
      END_STATE();
    case 471:
      if (lookahead == 'M') ADVANCE(376);
      END_STATE();
    case 472:
      if (lookahead == 'M') ADVANCE(376);
      if (lookahead == 'V') ADVANCE(214);
      END_STATE();
    case 473:
      if (lookahead == 'M') ADVANCE(377);
      END_STATE();
    case 474:
      if (lookahead == 'M') ADVANCE(277);
      END_STATE();
    case 475:
      if (lookahead == 'M') ADVANCE(309);
      END_STATE();
    case 476:
      if (lookahead == 'N') ADVANCE(964);
      if (lookahead == 'S') ADVANCE(945);
      END_STATE();
    case 477:
      if (lookahead == 'N') ADVANCE(864);
      if (lookahead == 'R') ADVANCE(941);
      if (lookahead == 'U') ADVANCE(704);
      END_STATE();
    case 478:
      if (lookahead == 'N') ADVANCE(362);
      END_STATE();
    case 479:
      if (lookahead == 'N') ADVANCE(362);
      if (lookahead == 'P') ADVANCE(205);
      if (lookahead == 'S') ADVANCE(211);
      END_STATE();
    case 480:
      if (lookahead == 'N') ADVANCE(380);
      END_STATE();
    case 481:
      if (lookahead == 'N') ADVANCE(1069);
      END_STATE();
    case 482:
      if (lookahead == 'N') ADVANCE(1068);
      if (lookahead == 'R') ADVANCE(224);
      END_STATE();
    case 483:
      if (lookahead == 'N') ADVANCE(928);
      END_STATE();
    case 484:
      if (lookahead == 'N') ADVANCE(867);
      END_STATE();
    case 485:
      if (lookahead == 'N') ADVANCE(1092);
      END_STATE();
    case 486:
      if (lookahead == 'N') ADVANCE(882);
      END_STATE();
    case 487:
      if (lookahead == 'N') ADVANCE(985);
      END_STATE();
    case 488:
      if (lookahead == 'N') ADVANCE(1091);
      END_STATE();
    case 489:
      if (lookahead == 'N') ADVANCE(991);
      END_STATE();
    case 490:
      if (lookahead == 'N') ADVANCE(1032);
      END_STATE();
    case 491:
      if (lookahead == 'N') ADVANCE(1108);
      END_STATE();
    case 492:
      if (lookahead == 'N') ADVANCE(980);
      END_STATE();
    case 493:
      if (lookahead == 'N') ADVANCE(983);
      END_STATE();
    case 494:
      if (lookahead == 'N') ADVANCE(934);
      END_STATE();
    case 495:
      if (lookahead == 'N') ADVANCE(963);
      END_STATE();
    case 496:
      if (lookahead == 'N') ADVANCE(1050);
      END_STATE();
    case 497:
      if (lookahead == 'N') ADVANCE(407);
      END_STATE();
    case 498:
      if (lookahead == 'N') ADVANCE(359);
      END_STATE();
    case 499:
      if (lookahead == 'N') ADVANCE(4);
      if (lookahead == 'R') ADVANCE(941);
      if (lookahead == 'U') ADVANCE(704);
      END_STATE();
    case 500:
      if (lookahead == 'N') ADVANCE(162);
      END_STATE();
    case 501:
      if (lookahead == 'N') ADVANCE(183);
      END_STATE();
    case 502:
      if (lookahead == 'N') ADVANCE(328);
      END_STATE();
    case 503:
      if (lookahead == 'N') ADVANCE(335);
      END_STATE();
    case 504:
      if (lookahead == 'N') ADVANCE(333);
      END_STATE();
    case 505:
      if (lookahead == 'N') ADVANCE(729);
      if (lookahead == 'S') ADVANCE(879);
      END_STATE();
    case 506:
      if (lookahead == 'N') ADVANCE(161);
      END_STATE();
    case 507:
      if (lookahead == 'N') ADVANCE(387);
      END_STATE();
    case 508:
      if (lookahead == 'N') ADVANCE(647);
      END_STATE();
    case 509:
      if (lookahead == 'N') ADVANCE(665);
      END_STATE();
    case 510:
      if (lookahead == 'N') ADVANCE(666);
      END_STATE();
    case 511:
      if (lookahead == 'N') ADVANCE(618);
      END_STATE();
    case 512:
      if (lookahead == 'N') ADVANCE(424);
      END_STATE();
    case 513:
      if (lookahead == 'N') ADVANCE(620);
      END_STATE();
    case 514:
      if (lookahead == 'N') ADVANCE(673);
      END_STATE();
    case 515:
      if (lookahead == 'N') ADVANCE(624);
      END_STATE();
    case 516:
      if (lookahead == 'N') ADVANCE(674);
      END_STATE();
    case 517:
      if (lookahead == 'N') ADVANCE(226);
      END_STATE();
    case 518:
      if (lookahead == 'N') ADVANCE(228);
      END_STATE();
    case 519:
      if (lookahead == 'N') ADVANCE(244);
      if (lookahead == 'T') ADVANCE(953);
      END_STATE();
    case 520:
      if (lookahead == 'N') ADVANCE(314);
      if (lookahead == 'T') ADVANCE(950);
      END_STATE();
    case 521:
      if (lookahead == 'N') ADVANCE(638);
      END_STATE();
    case 522:
      if (lookahead == 'N') ADVANCE(334);
      END_STATE();
    case 523:
      if (lookahead == 'N') ADVANCE(192);
      END_STATE();
    case 524:
      if (lookahead == 'N') ADVANCE(701);
      END_STATE();
    case 525:
      if (lookahead == 'N') ADVANCE(102);
      END_STATE();
    case 526:
      if (lookahead == 'N') ADVANCE(640);
      END_STATE();
    case 527:
      if (lookahead == 'N') ADVANCE(561);
      END_STATE();
    case 528:
      if (lookahead == 'N') ADVANCE(650);
      END_STATE();
    case 529:
      if (lookahead == 'N') ADVANCE(649);
      END_STATE();
    case 530:
      if (lookahead == 'N') ADVANCE(651);
      END_STATE();
    case 531:
      if (lookahead == 'N') ADVANCE(654);
      END_STATE();
    case 532:
      if (lookahead == 'O') ADVANCE(151);
      if (lookahead == 'R') ADVANCE(540);
      END_STATE();
    case 533:
      if (lookahead == 'O') ADVANCE(1034);
      if (lookahead == 'Y') ADVANCE(568);
      END_STATE();
    case 534:
      if (lookahead == 'O') ADVANCE(706);
      END_STATE();
    case 535:
      if (lookahead == 'O') ADVANCE(720);
      END_STATE();
    case 536:
      if (lookahead == 'O') ADVANCE(721);
      END_STATE();
    case 537:
      if (lookahead == 'O') ADVANCE(519);
      END_STATE();
    case 538:
      if (lookahead == 'O') ADVANCE(1065);
      END_STATE();
    case 539:
      if (lookahead == 'O') ADVANCE(575);
      if (lookahead == 'R') ADVANCE(546);
      END_STATE();
    case 540:
      if (lookahead == 'O') ADVANCE(562);
      END_STATE();
    case 541:
      if (lookahead == 'O') ADVANCE(520);
      END_STATE();
    case 542:
      if (lookahead == 'O') ADVANCE(520);
      if (lookahead == 'U') ADVANCE(474);
      END_STATE();
    case 543:
      if (lookahead == 'O') ADVANCE(414);
      END_STATE();
    case 544:
      if (lookahead == 'O') ADVANCE(589);
      END_STATE();
    case 545:
      if (lookahead == 'O') ADVANCE(438);
      END_STATE();
    case 546:
      if (lookahead == 'O') ADVANCE(457);
      END_STATE();
    case 547:
      if (lookahead == 'O') ADVANCE(713);
      END_STATE();
    case 548:
      if (lookahead == 'O') ADVANCE(597);
      END_STATE();
    case 549:
      if (lookahead == 'O') ADVANCE(512);
      END_STATE();
    case 550:
      if (lookahead == 'O') ADVANCE(487);
      END_STATE();
    case 551:
      if (lookahead == 'O') ADVANCE(488);
      END_STATE();
    case 552:
      if (lookahead == 'O') ADVANCE(489);
      END_STATE();
    case 553:
      if (lookahead == 'O') ADVANCE(490);
      END_STATE();
    case 554:
      if (lookahead == 'O') ADVANCE(491);
      END_STATE();
    case 555:
      if (lookahead == 'O') ADVANCE(515);
      END_STATE();
    case 556:
      if (lookahead == 'O') ADVANCE(494);
      END_STATE();
    case 557:
      if (lookahead == 'O') ADVANCE(524);
      END_STATE();
    case 558:
      if (lookahead == 'O') ADVANCE(570);
      END_STATE();
    case 559:
      if (lookahead == 'O') ADVANCE(466);
      END_STATE();
    case 560:
      if (lookahead == 'O') ADVANCE(605);
      END_STATE();
    case 561:
      if (lookahead == 'O') ADVANCE(607);
      END_STATE();
    case 562:
      if (lookahead == 'P') ADVANCE(995);
      END_STATE();
    case 563:
      if (lookahead == 'P') ADVANCE(921);
      END_STATE();
    case 564:
      if (lookahead == 'P') ADVANCE(1093);
      END_STATE();
    case 565:
      if (lookahead == 'P') ADVANCE(449);
      END_STATE();
    case 566:
      if (lookahead == 'P') ADVANCE(428);
      END_STATE();
    case 567:
      if (lookahead == 'P') ADVANCE(131);
      END_STATE();
    case 568:
      if (lookahead == 'P') ADVANCE(217);
      END_STATE();
    case 569:
      if (lookahead == 'P') ADVANCE(445);
      END_STATE();
    case 570:
      if (lookahead == 'P') ADVANCE(221);
      END_STATE();
    case 571:
      if (lookahead == 'P') ADVANCE(206);
      END_STATE();
    case 572:
      if (lookahead == 'Q') ADVANCE(715);
      END_STATE();
    case 573:
      if (lookahead == 'R') ADVANCE(540);
      END_STATE();
    case 574:
      if (lookahead == 'R') ADVANCE(943);
      if (lookahead == 'U') ADVANCE(704);
      END_STATE();
    case 575:
      if (lookahead == 'R') ADVANCE(1083);
      END_STATE();
    case 576:
      if (lookahead == 'R') ADVANCE(1054);
      END_STATE();
    case 577:
      if (lookahead == 'R') ADVANCE(1045);
      END_STATE();
    case 578:
      if (lookahead == 'R') ADVANCE(908);
      END_STATE();
    case 579:
      if (lookahead == 'R') ADVANCE(988);
      END_STATE();
    case 580:
      if (lookahead == 'R') ADVANCE(1027);
      END_STATE();
    case 581:
      if (lookahead == 'R') ADVANCE(1021);
      END_STATE();
    case 582:
      if (lookahead == 'R') ADVANCE(1025);
      END_STATE();
    case 583:
      if (lookahead == 'R') ADVANCE(1023);
      END_STATE();
    case 584:
      if (lookahead == 'R') ADVANCE(941);
      if (lookahead == 'U') ADVANCE(704);
      END_STATE();
    case 585:
      if (lookahead == 'R') ADVANCE(546);
      END_STATE();
    case 586:
      if (lookahead == 'R') ADVANCE(534);
      END_STATE();
    case 587:
      if (lookahead == 'R') ADVANCE(332);
      END_STATE();
    case 588:
      if (lookahead == 'R') ADVANCE(93);
      if (lookahead == 'S') ADVANCE(615);
      if (lookahead == 'T') ADVANCE(156);
      END_STATE();
    case 589:
      if (lookahead == 'R') ADVANCE(470);
      if (lookahead == 'T') ADVANCE(947);
      END_STATE();
    case 590:
      if (lookahead == 'R') ADVANCE(461);
      END_STATE();
    case 591:
      if (lookahead == 'R') ADVANCE(644);
      END_STATE();
    case 592:
      if (lookahead == 'R') ADVANCE(462);
      END_STATE();
    case 593:
      if (lookahead == 'R') ADVANCE(369);
      END_STATE();
    case 594:
      if (lookahead == 'R') ADVANCE(185);
      END_STATE();
    case 595:
      if (lookahead == 'R') ADVANCE(296);
      END_STATE();
    case 596:
      if (lookahead == 'R') ADVANCE(158);
      END_STATE();
    case 597:
      if (lookahead == 'R') ADVANCE(186);
      END_STATE();
    case 598:
      if (lookahead == 'R') ADVANCE(201);
      END_STATE();
    case 599:
      if (lookahead == 'R') ADVANCE(619);
      END_STATE();
    case 600:
      if (lookahead == 'R') ADVANCE(669);
      END_STATE();
    case 601:
      if (lookahead == 'R') ADVANCE(484);
      END_STATE();
    case 602:
      if (lookahead == 'R') ADVANCE(118);
      END_STATE();
    case 603:
      if (lookahead == 'R') ADVANCE(627);
      END_STATE();
    case 604:
      if (lookahead == 'R') ADVANCE(224);
      END_STATE();
    case 605:
      if (lookahead == 'R') ADVANCE(225);
      END_STATE();
    case 606:
      if (lookahead == 'R') ADVANCE(678);
      END_STATE();
    case 607:
      if (lookahead == 'R') ADVANCE(230);
      END_STATE();
    case 608:
      if (lookahead == 'R') ADVANCE(126);
      END_STATE();
    case 609:
      if (lookahead == 'R') ADVANCE(126);
      if (lookahead == 'T') ADVANCE(156);
      END_STATE();
    case 610:
      if (lookahead == 'R') ADVANCE(648);
      END_STATE();
    case 611:
      if (lookahead == 'R') ADVANCE(202);
      END_STATE();
    case 612:
      if (lookahead == 'R') ADVANCE(203);
      END_STATE();
    case 613:
      if (lookahead == 'R') ADVANCE(204);
      END_STATE();
    case 614:
      if (lookahead == 'S') ADVANCE(1008);
      END_STATE();
    case 615:
      if (lookahead == 'S') ADVANCE(344);
      END_STATE();
    case 616:
      if (lookahead == 'S') ADVANCE(1055);
      END_STATE();
    case 617:
      if (lookahead == 'S') ADVANCE(1097);
      END_STATE();
    case 618:
      if (lookahead == 'S') ADVANCE(1088);
      END_STATE();
    case 619:
      if (lookahead == 'S') ADVANCE(1067);
      END_STATE();
    case 620:
      if (lookahead == 'S') ADVANCE(90);
      END_STATE();
    case 621:
      if (lookahead == 'S') ADVANCE(1028);
      END_STATE();
    case 622:
      if (lookahead == 'S') ADVANCE(976);
      END_STATE();
    case 623:
      if (lookahead == 'S') ADVANCE(999);
      END_STATE();
    case 624:
      if (lookahead == 'S') ADVANCE(1077);
      END_STATE();
    case 625:
      if (lookahead == 'S') ADVANCE(1087);
      END_STATE();
    case 626:
      if (lookahead == 'S') ADVANCE(1082);
      END_STATE();
    case 627:
      if (lookahead == 'S') ADVANCE(1066);
      END_STATE();
    case 628:
      if (lookahead == 'S') ADVANCE(735);
      END_STATE();
    case 629:
      if (lookahead == 'S') ADVANCE(408);
      END_STATE();
    case 630:
      if (lookahead == 'S') ADVANCE(567);
      END_STATE();
    case 631:
      if (lookahead == 'S') ADVANCE(632);
      if (lookahead == 'T') ADVANCE(1104);
      END_STATE();
    case 632:
      if (lookahead == 'S') ADVANCE(392);
      END_STATE();
    case 633:
      if (lookahead == 'S') ADVANCE(83);
      END_STATE();
    case 634:
      if (lookahead == 'S') ADVANCE(351);
      END_STATE();
    case 635:
      if (lookahead == 'S') ADVANCE(213);
      END_STATE();
    case 636:
      if (lookahead == 'S') ADVANCE(341);
      END_STATE();
    case 637:
      if (lookahead == 'S') ADVANCE(699);
      END_STATE();
    case 638:
      if (lookahead == 'S') ADVANCE(145);
      END_STATE();
    case 639:
      if (lookahead == 'S') ADVANCE(687);
      END_STATE();
    case 640:
      if (lookahead == 'S') ADVANCE(289);
      END_STATE();
    case 641:
      if (lookahead == 'S') ADVANCE(218);
      END_STATE();
    case 642:
      if (lookahead == 'S') ADVANCE(623);
      END_STATE();
    case 643:
      if (lookahead == 'S') ADVANCE(237);
      END_STATE();
    case 644:
      if (lookahead == 'S') ADVANCE(550);
      END_STATE();
    case 645:
      if (lookahead == 'S') ADVANCE(307);
      END_STATE();
    case 646:
      if (lookahead == 'S') ADVANCE(295);
      END_STATE();
    case 647:
      if (lookahead == 'S') ADVANCE(393);
      END_STATE();
    case 648:
      if (lookahead == 'S') ADVANCE(311);
      END_STATE();
    case 649:
      if (lookahead == 'S') ADVANCE(395);
      END_STATE();
    case 650:
      if (lookahead == 'S') ADVANCE(398);
      END_STATE();
    case 651:
      if (lookahead == 'S') ADVANCE(397);
      END_STATE();
    case 652:
      if (lookahead == 'S') ADVANCE(400);
      END_STATE();
    case 653:
      if (lookahead == 'S') ADVANCE(399);
      END_STATE();
    case 654:
      if (lookahead == 'S') ADVANCE(401);
      END_STATE();
    case 655:
      if (lookahead == 'S') ADVANCE(736);
      END_STATE();
    case 656:
      if (lookahead == 'S') ADVANCE(737);
      END_STATE();
    case 657:
      if (lookahead == 'S') ADVANCE(652);
      END_STATE();
    case 658:
      if (lookahead == 'S') ADVANCE(738);
      END_STATE();
    case 659:
      if (lookahead == 'T') ADVANCE(866);
      END_STATE();
    case 660:
      if (lookahead == 'T') ADVANCE(1033);
      END_STATE();
    case 661:
      if (lookahead == 'T') ADVANCE(1104);
      END_STATE();
    case 662:
      if (lookahead == 'T') ADVANCE(1110);
      END_STATE();
    case 663:
      if (lookahead == 'T') ADVANCE(881);
      END_STATE();
    case 664:
      if (lookahead == 'T') ADVANCE(1049);
      END_STATE();
    case 665:
      if (lookahead == 'T') ADVANCE(1102);
      END_STATE();
    case 666:
      if (lookahead == 'T') ADVANCE(989);
      END_STATE();
    case 667:
      if (lookahead == 'T') ADVANCE(892);
      END_STATE();
    case 668:
      if (lookahead == 'T') ADVANCE(917);
      END_STATE();
    case 669:
      if (lookahead == 'T') ADVANCE(6);
      END_STATE();
    case 670:
      if (lookahead == 'T') ADVANCE(1106);
      END_STATE();
    case 671:
      if (lookahead == 'T') ADVANCE(932);
      END_STATE();
    case 672:
      if (lookahead == 'T') ADVANCE(871);
      END_STATE();
    case 673:
      if (lookahead == 'T') ADVANCE(1085);
      END_STATE();
    case 674:
      if (lookahead == 'T') ADVANCE(1037);
      END_STATE();
    case 675:
      if (lookahead == 'T') ADVANCE(1073);
      END_STATE();
    case 676:
      if (lookahead == 'T') ADVANCE(887);
      END_STATE();
    case 677:
      if (lookahead == 'T') ADVANCE(891);
      END_STATE();
    case 678:
      if (lookahead == 'T') ADVANCE(1075);
      END_STATE();
    case 679:
      if (lookahead == 'T') ADVANCE(136);
      END_STATE();
    case 680:
      if (lookahead == 'T') ADVANCE(710);
      END_STATE();
    case 681:
      if (lookahead == 'T') ADVANCE(232);
      END_STATE();
    case 682:
      if (lookahead == 'T') ADVANCE(337);
      END_STATE();
    case 683:
      if (lookahead == 'T') ADVANCE(98);
      END_STATE();
    case 684:
      if (lookahead == 'T') ADVANCE(272);
      END_STATE();
    case 685:
      if (lookahead == 'T') ADVANCE(155);
      END_STATE();
    case 686:
      if (lookahead == 'T') ADVANCE(360);
      END_STATE();
    case 687:
      if (lookahead == 'T') ADVANCE(617);
      END_STATE();
    case 688:
      if (lookahead == 'T') ADVANCE(621);
      END_STATE();
    case 689:
      if (lookahead == 'T') ADVANCE(304);
      END_STATE();
    case 690:
      if (lookahead == 'T') ADVANCE(622);
      END_STATE();
    case 691:
      if (lookahead == 'T') ADVANCE(227);
      END_STATE();
    case 692:
      if (lookahead == 'T') ADVANCE(229);
      END_STATE();
    case 693:
      if (lookahead == 'T') ADVANCE(235);
      END_STATE();
    case 694:
      if (lookahead == 'T') ADVANCE(236);
      END_STATE();
    case 695:
      if (lookahead == 'T') ADVANCE(263);
      END_STATE();
    case 696:
      if (lookahead == 'T') ADVANCE(252);
      END_STATE();
    case 697:
      if (lookahead == 'T') ADVANCE(698);
      END_STATE();
    case 698:
      if (lookahead == 'T') ADVANCE(129);
      END_STATE();
    case 699:
      if (lookahead == 'T') ADVANCE(379);
      END_STATE();
    case 700:
      if (lookahead == 'T') ADVANCE(394);
      END_STATE();
    case 701:
      if (lookahead == 'T') ADVANCE(135);
      END_STATE();
    case 702:
      if (lookahead == 'T') ADVANCE(402);
      END_STATE();
    case 703:
      if (lookahead == 'T') ADVANCE(396);
      END_STATE();
    case 704:
      if (lookahead == 'T') ADVANCE(653);
      END_STATE();
    case 705:
      if (lookahead == 'U') ADVANCE(157);
      END_STATE();
    case 706:
      if (lookahead == 'U') ADVANCE(563);
      END_STATE();
    case 707:
      if (lookahead == 'U') ADVANCE(660);
      END_STATE();
    case 708:
      if (lookahead == 'U') ADVANCE(571);
      END_STATE();
    case 709:
      if (lookahead == 'U') ADVANCE(468);
      END_STATE();
    case 710:
      if (lookahead == 'U') ADVANCE(601);
      END_STATE();
    case 711:
      if (lookahead == 'U') ADVANCE(439);
      END_STATE();
    case 712:
      if (lookahead == 'U') ADVANCE(432);
      END_STATE();
    case 713:
      if (lookahead == 'U') ADVANCE(676);
      END_STATE();
    case 714:
      if (lookahead == 'U') ADVANCE(223);
      END_STATE();
    case 715:
      if (lookahead == 'U') ADVANCE(234);
      END_STATE();
    case 716:
      if (lookahead == 'U') ADVANCE(298);
      END_STATE();
    case 717:
      if (lookahead == 'U') ADVANCE(569);
      END_STATE();
    case 718:
      if (lookahead == 'V') ADVANCE(978);
      END_STATE();
    case 719:
      if (lookahead == 'V') ADVANCE(305);
      END_STATE();
    case 720:
      if (lookahead == 'V') ADVANCE(233);
      END_STATE();
    case 721:
      if (lookahead == 'W') ADVANCE(629);
      END_STATE();
    case 722:
      if (lookahead == 'X') ADVANCE(913);
      END_STATE();
    case 723:
      if (lookahead == 'X') ADVANCE(912);
      END_STATE();
    case 724:
      if (lookahead == 'X') ADVANCE(403);
      END_STATE();
    case 725:
      if (lookahead == 'X') ADVANCE(566);
      END_STATE();
    case 726:
      if (lookahead == 'Y') ADVANCE(732);
      END_STATE();
    case 727:
      if (lookahead == 'Y') ADVANCE(1006);
      END_STATE();
    case 728:
      if (lookahead == 'Y') ADVANCE(957);
      END_STATE();
    case 729:
      if (lookahead == 'Y') ADVANCE(1029);
      END_STATE();
    case 730:
      if (lookahead == 'Y') ADVANCE(5);
      END_STATE();
    case 731:
      if (lookahead == 'Y') ADVANCE(634);
      END_STATE();
    case 732:
      if (lookahead == 'Z') ADVANCE(283);
      END_STATE();
    case 733:
      if (lookahead == 'Z') ADVANCE(308);
      END_STATE();
    case 734:
      if (lookahead == '_') ADVANCE(384);
      END_STATE();
    case 735:
      if (lookahead == '_') ADVANCE(160);
      END_STATE();
    case 736:
      if (lookahead == '_') ADVANCE(175);
      END_STATE();
    case 737:
      if (lookahead == '_') ADVANCE(176);
      END_STATE();
    case 738:
      if (lookahead == '_') ADVANCE(178);
      END_STATE();
    case 739:
      if (lookahead == 'a') ADVANCE(775);
      if (lookahead == 'l') ADVANCE(741);
      if (lookahead == 'o') ADVANCE(779);
      END_STATE();
    case 740:
      if (lookahead == 'a') ADVANCE(776);
      END_STATE();
    case 741:
      if (lookahead == 'a') ADVANCE(796);
      END_STATE();
    case 742:
      if (lookahead == 'a') ADVANCE(772);
      END_STATE();
    case 743:
      if (lookahead == 'a') ADVANCE(777);
      END_STATE();
    case 744:
      if (lookahead == 'a') ADVANCE(767);
      END_STATE();
    case 745:
      if (lookahead == 'a') ADVANCE(780);
      END_STATE();
    case 746:
      if (lookahead == 'a') ADVANCE(797);
      END_STATE();
    case 747:
      if (lookahead == 'a') ADVANCE(798);
      END_STATE();
    case 748:
      if (lookahead == 'b') ADVANCE(742);
      END_STATE();
    case 749:
      if (lookahead == 'c') ADVANCE(766);
      END_STATE();
    case 750:
      if (lookahead == 'c') ADVANCE(1258);
      END_STATE();
    case 751:
      if (lookahead == 'c') ADVANCE(799);
      END_STATE();
    case 752:
      if (lookahead == 'c') ADVANCE(746);
      END_STATE();
    case 753:
      if (lookahead == 'c') ADVANCE(747);
      END_STATE();
    case 754:
      if (lookahead == 'd') ADVANCE(763);
      END_STATE();
    case 755:
      if (lookahead == 'e') ADVANCE(1242);
      END_STATE();
    case 756:
      if (lookahead == 'e') ADVANCE(1243);
      END_STATE();
    case 757:
      if (lookahead == 'e') ADVANCE(770);
      END_STATE();
    case 758:
      if (lookahead == 'e') ADVANCE(788);
      END_STATE();
    case 759:
      if (lookahead == 'e') ADVANCE(750);
      END_STATE();
    case 760:
      if (lookahead == 'e') ADVANCE(783);
      END_STATE();
    case 761:
      if (lookahead == 'e') ADVANCE(791);
      END_STATE();
    case 762:
      if (lookahead == 'g') ADVANCE(789);
      END_STATE();
    case 763:
      if (lookahead == 'g') ADVANCE(760);
      END_STATE();
    case 764:
      if (lookahead == 'g') ADVANCE(790);
      END_STATE();
    case 765:
      if (lookahead == 'i') ADVANCE(1241);
      END_STATE();
    case 766:
      if (lookahead == 'i') ADVANCE(765);
      END_STATE();
    case 767:
      if (lookahead == 'i') ADVANCE(782);
      END_STATE();
    case 768:
      if (lookahead == 'k') ADVANCE(1237);
      END_STATE();
    case 769:
      if (lookahead == 'l') ADVANCE(745);
      END_STATE();
    case 770:
      if (lookahead == 'l') ADVANCE(1238);
      END_STATE();
    case 771:
      if (lookahead == 'l') ADVANCE(1246);
      END_STATE();
    case 772:
      if (lookahead == 'l') ADVANCE(771);
      END_STATE();
    case 773:
      ADVANCE_MAP(
        'm', 1517,
        'n', 793,
        'u', 793,
        0xb5, 793,
        'd', 1516,
        'h', 1516,
        's', 1516,
        'w', 1516,
        'y', 1516,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(773);
      END_STATE();
    case 774:
      ADVANCE_MAP(
        'm', 1517,
        'n', 793,
        'u', 793,
        0xb5, 793,
        'd', 1516,
        'h', 1516,
        's', 1516,
        'w', 1516,
        'y', 1516,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(773);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(774);
      END_STATE();
    case 775:
      if (lookahead == 'm') ADVANCE(757);
      END_STATE();
    case 776:
      if (lookahead == 'm') ADVANCE(1245);
      END_STATE();
    case 777:
      if (lookahead == 'm') ADVANCE(1244);
      END_STATE();
    case 778:
      if (lookahead == 'n') ADVANCE(1260);
      END_STATE();
    case 779:
      if (lookahead == 'n') ADVANCE(800);
      END_STATE();
    case 780:
      if (lookahead == 'n') ADVANCE(768);
      END_STATE();
    case 781:
      if (lookahead == 'n') ADVANCE(751);
      END_STATE();
    case 782:
      if (lookahead == 'n') ADVANCE(795);
      END_STATE();
    case 783:
      if (lookahead == 'n') ADVANCE(764);
      END_STATE();
    case 784:
      if (lookahead == 'o') ADVANCE(803);
      END_STATE();
    case 785:
      if (lookahead == 'o') ADVANCE(779);
      END_STATE();
    case 786:
      if (lookahead == 'o') ADVANCE(802);
      END_STATE();
    case 787:
      if (lookahead == 'p') ADVANCE(761);
      END_STATE();
    case 788:
      if (lookahead == 'r') ADVANCE(752);
      END_STATE();
    case 789:
      if (lookahead == 'r') ADVANCE(740);
      END_STATE();
    case 790:
      if (lookahead == 'r') ADVANCE(743);
      END_STATE();
    case 791:
      if (lookahead == 'r') ADVANCE(753);
      END_STATE();
    case 792:
      if (lookahead == 's') ADVANCE(749);
      END_STATE();
    case 793:
      if (lookahead == 's') ADVANCE(1516);
      END_STATE();
    case 794:
      if (lookahead == 's') ADVANCE(1239);
      END_STATE();
    case 795:
      if (lookahead == 's') ADVANCE(951);
      END_STATE();
    case 796:
      if (lookahead == 's') ADVANCE(794);
      END_STATE();
    case 797:
      if (lookahead == 's') ADVANCE(755);
      END_STATE();
    case 798:
      if (lookahead == 's') ADVANCE(756);
      END_STATE();
    case 799:
      if (lookahead == 't') ADVANCE(1240);
      END_STATE();
    case 800:
      if (lookahead == 't') ADVANCE(744);
      END_STATE();
    case 801:
      if (lookahead == 'u') ADVANCE(781);
      END_STATE();
    case 802:
      if (lookahead == 'w') ADVANCE(748);
      END_STATE();
    case 803:
      if (lookahead == 'w') ADVANCE(758);
      END_STATE();
    case 804:
      if (lookahead == '|') ADVANCE(1525);
      END_STATE();
    case 805:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(807);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1257);
      END_STATE();
    case 806:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1256);
      END_STATE();
    case 807:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1257);
      END_STATE();
    case 808:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1266);
      END_STATE();
    case 809:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1265);
      END_STATE();
    case 810:
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1259);
      END_STATE();
    case 811:
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1261);
      END_STATE();
    case 812:
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1263);
      END_STATE();
    case 813:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(22);
      END_STATE();
    case 814:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(39);
      END_STATE();
    case 815:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(24);
      END_STATE();
    case 816:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(40);
      END_STATE();
    case 817:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '"', 22,
        '#', 862,
        '$', 810,
        '&', 38,
        '\'', 39,
        '(', 1115,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1520,
        '.', 1127,
        '/', 1541,
        ':', 1119,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 1118,
        '@', 1521,
        'A', 315,
        'B', 208,
        'C', 77,
        'D', 87,
        'E', 180,
        'F', 89,
        'G', 586,
        'H', 79,
        'I', 316,
        'J', 97,
        'L', 264,
        'M', 94,
        'N', 91,
        'O', 456,
        'P', 80,
        'R', 104,
        'S', 150,
        'T', 81,
        'U', 479,
        'V', 99,
        'W', 343,
        '[', 1113,
        ']', 1114,
        'a', 792,
        'b', 769,
        'c', 739,
        'e', 754,
        'f', 778,
        'l', 784,
        'n', 762,
        'p', 801,
        's', 26,
        'u', 27,
        '{', 1120,
        '|', 76,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
        'd', 25,
        'r', 25,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(817);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1252);
      END_STATE();
    case 818:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '$', 810,
        '&', 38,
        '(', 1115,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1519,
        '.', 1127,
        '/', 1541,
        ':', 1119,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 1118,
        '@', 1521,
        'A', 435,
        'B', 455,
        'C', 348,
        'D', 532,
        'E', 725,
        'F', 385,
        'G', 586,
        'H', 361,
        'I', 317,
        'M', 256,
        'N', 541,
        'O', 477,
        'P', 86,
        'R', 299,
        'S', 173,
        'T', 266,
        'U', 478,
        'V', 130,
        'W', 342,
        '[', 1113,
        ']', 1114,
        'c', 785,
        'f', 778,
        '{', 1120,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(818);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(774);
      END_STATE();
    case 819:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '$', 810,
        '&', 38,
        '(', 1115,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1519,
        '/', 1541,
        ';', 863,
        '<', 1129,
        '=', 1515,
        '>', 1130,
        '?', 1118,
        '@', 1521,
        'A', 436,
        'C', 545,
        'D', 250,
        'E', 725,
        'F', 261,
        'I', 317,
        'L', 373,
        'M', 256,
        'N', 542,
        'O', 584,
        'P', 85,
        'R', 105,
        'S', 300,
        'T', 358,
        'U', 526,
        'V', 99,
        'W', 356,
        ']', 1114,
        'c', 785,
        'f', 778,
        '{', 1120,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(819);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1264);
      END_STATE();
    case 820:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '$', 810,
        '&', 38,
        '(', 1115,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1518,
        '/', 1541,
        ';', 863,
        '<', 1129,
        '=', 1515,
        '>', 1130,
        '?', 1118,
        '@', 1521,
        'A', 435,
        'C', 349,
        'D', 573,
        'F', 539,
        'G', 586,
        'I', 317,
        'M', 256,
        'N', 541,
        'O', 584,
        'P', 85,
        'R', 299,
        'S', 174,
        'T', 358,
        'U', 526,
        'W', 356,
        ']', 1114,
        'c', 785,
        'f', 778,
        '{', 1120,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(820);
      END_STATE();
    case 821:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        '(', 1115,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1519,
        '.', 1127,
        '/', 1541,
        ':', 1119,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 436,
        'C', 543,
        'D', 250,
        'E', 725,
        'F', 259,
        'I', 476,
        'L', 373,
        'M', 256,
        'N', 542,
        'O', 499,
        'P', 85,
        'R', 105,
        'S', 251,
        'T', 358,
        'U', 526,
        'V', 99,
        'W', 342,
        '[', 1113,
        ']', 1114,
        'c', 785,
        '{', 1120,
        '|', 76,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(821);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(774);
      END_STATE();
    case 822:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 1118,
        '@', 1521,
        'A', 1375,
        'C', 1432,
        'I', 1402,
        'N', 1425,
        'O', 1443,
        '[', 1113,
        ']', 1114,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(822);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 823:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1372,
        'C', 1423,
        'D', 1299,
        'E', 1499,
        'F', 1300,
        'I', 1402,
        'L', 1353,
        'N', 1424,
        'O', 1443,
        'P', 1267,
        'R', 1268,
        'T', 1364,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(823);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 824:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1373,
        'C', 1348,
        'D', 1452,
        'G', 1451,
        'I', 1402,
        'N', 1425,
        'O', 1443,
        'P', 1327,
        'S', 1288,
        'T', 1503,
        'W', 1350,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(824);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 825:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1375,
        'C', 1432,
        'E', 1499,
        'F', 1300,
        'G', 1451,
        'I', 1402,
        'L', 1353,
        'N', 1425,
        'O', 1444,
        'P', 1267,
        'S', 1441,
        'T', 1364,
        'W', 1349,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(825);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 826:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1375,
        'C', 1432,
        'E', 1499,
        'F', 1300,
        'G', 1451,
        'I', 1402,
        'L', 1353,
        'N', 1425,
        'O', 1444,
        'P', 1267,
        'S', 1441,
        'T', 1364,
        'W', 1350,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(826);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 827:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1375,
        'C', 1432,
        'I', 1402,
        'N', 1425,
        'O', 1443,
        'P', 1267,
        'R', 1331,
        'T', 1364,
        'W', 1350,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(827);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 828:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1375,
        'C', 1432,
        'I', 1402,
        'N', 1425,
        'O', 1443,
        'P', 1267,
        'R', 1331,
        'T', 1364,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(828);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 829:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1375,
        'C', 1432,
        'I', 1402,
        'N', 1425,
        'O', 1443,
        'P', 1267,
        'T', 1364,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(829);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 830:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1375,
        'C', 1437,
        'I', 1402,
        'M', 1329,
        'N', 1425,
        'O', 1443,
        'P', 1270,
        'R', 1331,
        'S', 1334,
        'T', 1364,
        'U', 1417,
        'W', 1350,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(830);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 831:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1519,
        '.', 1127,
        '/', 1541,
        ':', 1119,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 437,
        'C', 559,
        'D', 262,
        'E', 725,
        'F', 260,
        'G', 586,
        'I', 476,
        'L', 373,
        'N', 541,
        'O', 574,
        'P', 123,
        'R', 286,
        'S', 565,
        'T', 390,
        'V', 99,
        'W', 357,
        '[', 1113,
        'c', 785,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(831);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(774);
      END_STATE();
    case 832:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        ',', 1111,
        '-', 1518,
        '/', 1541,
        ';', 863,
        '<', 1129,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 434,
        'C', 557,
        'E', 725,
        'F', 258,
        'G', 586,
        'I', 476,
        'L', 373,
        'N', 541,
        'O', 574,
        'P', 122,
        'S', 565,
        'T', 389,
        'W', 357,
        'c', 785,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(832);
      END_STATE();
    case 833:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1373,
        'C', 1348,
        'D', 1452,
        'F', 1433,
        'I', 1402,
        'N', 1425,
        'O', 1443,
        'P', 1327,
        'S', 1288,
        'T', 1503,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(833);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 834:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1373,
        'C', 1348,
        'D', 1452,
        'G', 1451,
        'I', 1402,
        'N', 1425,
        'O', 1443,
        'P', 1327,
        'S', 1288,
        'T', 1503,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(834);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 835:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1374,
        'C', 1427,
        'D', 1318,
        'F', 1389,
        'I', 1402,
        'N', 1425,
        'O', 1443,
        'P', 1327,
        'R', 1330,
        'T', 1503,
        'V', 1277,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(835);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 836:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1374,
        'C', 1427,
        'D', 1318,
        'F', 1390,
        'I', 1402,
        'N', 1425,
        'O', 1443,
        'P', 1327,
        'R', 1330,
        'T', 1503,
        'V', 1277,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(836);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 837:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1375,
        'C', 1432,
        'E', 1499,
        'F', 1300,
        'G', 1451,
        'I', 1402,
        'L', 1353,
        'N', 1425,
        'O', 1444,
        'P', 1267,
        'S', 1441,
        'T', 1364,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(837);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 838:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '!', 75,
        '#', 862,
        '&', 38,
        ')', 1116,
        '*', 1125,
        '+', 1537,
        '-', 1520,
        '.', 1126,
        '/', 1541,
        ';', 863,
        '<', 1128,
        '=', 1515,
        '>', 1130,
        '?', 72,
        '@', 1521,
        'A', 1375,
        'C', 1427,
        'I', 1402,
        'N', 1425,
        'O', 1443,
        'P', 1327,
        '[', 1113,
        'c', 1509,
        '{', 1120,
        '|', 804,
        '}', 1121,
        '~', 1532,
        0xd7, 1540,
        0xf7, 1542,
        0x2208, 1549,
        0x2209, 1550,
        0x220b, 1544,
        0x220c, 1545,
        0x2282, 1552,
        0x2283, 1547,
        0x2284, 1553,
        0x2285, 1548,
        0x2286, 1551,
        0x2287, 1546,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(838);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 839:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '"', 22,
        '#', 862,
        '$', 810,
        '\'', 39,
        '(', 1115,
        ')', 1116,
        '-', 44,
        '/', 41,
        '<', 47,
        'B', 1145,
        'C', 1134,
        'D', 1146,
        'F', 1133,
        'I', 1189,
        'N', 1201,
        'R', 1136,
        'S', 1164,
        'T', 1204,
        'U', 1203,
        '[', 1113,
        'f', 1226,
        '{', 1120,
        '}', 1121,
        'd', 1131,
        'r', 1131,
        's', 1131,
        'u', 1131,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(839);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1250);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 840:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '#', 862,
        ')', 1116,
        '-', 45,
        '/', 41,
        ';', 863,
        '=', 1514,
        'C', 1435,
        'P', 1267,
        'R', 1331,
        'S', 1334,
        'T', 1364,
        'U', 1417,
        '[', 1113,
        '{', 1120,
        '}', 1121,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(840);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 841:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '#', 862,
        ')', 1116,
        '-', 45,
        '/', 41,
        ';', 863,
        '=', 1514,
        'C', 1435,
        'P', 1267,
        'R', 1331,
        'S', 1334,
        'T', 1364,
        '[', 1113,
        '{', 1120,
        '}', 1121,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(841);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 842:
      if (eof) ADVANCE(843);
      ADVANCE_MAP(
        '#', 862,
        ')', 1116,
        '-', 45,
        '/', 41,
        ';', 863,
        'A', 505,
        'C', 336,
        'D', 573,
        'E', 705,
        'F', 585,
        'H', 78,
        'I', 495,
        'J', 96,
        'M', 95,
        'N', 544,
        'O', 707,
        'P', 209,
        'R', 297,
        'S', 172,
        'T', 533,
        '}', 1121,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(842);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1253);
      END_STATE();
    case 843:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 844:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(2);
      if (lookahead == '*') ADVANCE(1);
      if (lookahead != 0) ADVANCE(2);
      END_STATE();
    case 845:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == ' ') ADVANCE(852);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(862);
      END_STATE();
    case 846:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '-') ADVANCE(845);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(862);
      END_STATE();
    case 847:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '-') ADVANCE(846);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(862);
      END_STATE();
    case 848:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '-') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(862);
      END_STATE();
    case 849:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '-') ADVANCE(848);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(862);
      END_STATE();
    case 850:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '-') ADVANCE(849);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(862);
      END_STATE();
    case 851:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '-') ADVANCE(850);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(862);
      END_STATE();
    case 852:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 'Q') ADVANCE(860);
      if (lookahead == 'R') ADVANCE(853);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(862);
      END_STATE();
    case 853:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 'e') ADVANCE(857);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(862);
      END_STATE();
    case 854:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 'e') ADVANCE(856);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(862);
      END_STATE();
    case 855:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 'l') ADVANCE(858);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(862);
      END_STATE();
    case 856:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 'r') ADVANCE(861);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(862);
      END_STATE();
    case 857:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 's') ADVANCE(859);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(862);
      END_STATE();
    case 858:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 't') ADVANCE(862);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(862);
      END_STATE();
    case 859:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 'u') ADVANCE(855);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(862);
      END_STATE();
    case 860:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 'u') ADVANCE(854);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(862);
      END_STATE();
    case 861:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 'y') ADVANCE(862);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(862);
      END_STATE();
    case 862:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(862);
      END_STATE();
    case 863:
      ACCEPT_TOKEN(sym_semi_colon);
      END_STATE();
    case 864:
      ACCEPT_TOKEN(sym_keyword_on);
      END_STATE();
    case 865:
      ACCEPT_TOKEN(sym_keyword_on);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 866:
      ACCEPT_TOKEN(sym_keyword_let);
      END_STATE();
    case 867:
      ACCEPT_TOKEN(sym_keyword_return);
      END_STATE();
    case 868:
      ACCEPT_TOKEN(sym_keyword_return);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 869:
      ACCEPT_TOKEN(sym_keyword_else);
      END_STATE();
    case 870:
      ACCEPT_TOKEN(sym_keyword_end);
      END_STATE();
    case 871:
      ACCEPT_TOKEN(sym_keyword_select);
      END_STATE();
    case 872:
      ACCEPT_TOKEN(sym_keyword_select);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 873:
      ACCEPT_TOKEN(sym_keyword_from);
      END_STATE();
    case 874:
      ACCEPT_TOKEN(sym_keyword_from);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 875:
      ACCEPT_TOKEN(sym_keyword_only);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 876:
      ACCEPT_TOKEN(sym_keyword_value);
      END_STATE();
    case 877:
      ACCEPT_TOKEN(sym_keyword_value);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 878:
      ACCEPT_TOKEN(sym_keyword_value);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 879:
      ACCEPT_TOKEN(sym_keyword_as);
      END_STATE();
    case 880:
      ACCEPT_TOKEN(sym_keyword_as);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 881:
      ACCEPT_TOKEN(sym_keyword_omit);
      END_STATE();
    case 882:
      ACCEPT_TOKEN(sym_keyword_explain);
      END_STATE();
    case 883:
      ACCEPT_TOKEN(sym_keyword_explain);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 884:
      ACCEPT_TOKEN(sym_keyword_full);
      END_STATE();
    case 885:
      ACCEPT_TOKEN(sym_keyword_parallel);
      END_STATE();
    case 886:
      ACCEPT_TOKEN(sym_keyword_parallel);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 887:
      ACCEPT_TOKEN(sym_keyword_timeout);
      END_STATE();
    case 888:
      ACCEPT_TOKEN(sym_keyword_timeout);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 889:
      ACCEPT_TOKEN(sym_keyword_fetch);
      END_STATE();
    case 890:
      ACCEPT_TOKEN(sym_keyword_fetch);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 891:
      ACCEPT_TOKEN(sym_keyword_start_at);
      END_STATE();
    case 892:
      ACCEPT_TOKEN(sym_keyword_limit);
      END_STATE();
    case 893:
      ACCEPT_TOKEN(sym_keyword_limit);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 894:
      ACCEPT_TOKEN(sym_keyword_by);
      END_STATE();
    case 895:
      ACCEPT_TOKEN(sym_keyword_by);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 896:
      ACCEPT_TOKEN(sym_keyword_by);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 897:
      ACCEPT_TOKEN(sym_keyword_rand);
      END_STATE();
    case 898:
      ACCEPT_TOKEN(sym_keyword_rand);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 899:
      ACCEPT_TOKEN(sym_keyword_rand);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 900:
      ACCEPT_TOKEN(sym_keyword_collate);
      END_STATE();
    case 901:
      ACCEPT_TOKEN(sym_keyword_collate);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 902:
      ACCEPT_TOKEN(sym_keyword_numeric);
      END_STATE();
    case 903:
      ACCEPT_TOKEN(sym_keyword_numeric);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 904:
      ACCEPT_TOKEN(sym_keyword_asc);
      END_STATE();
    case 905:
      ACCEPT_TOKEN(sym_keyword_asc);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 906:
      ACCEPT_TOKEN(sym_keyword_desc);
      END_STATE();
    case 907:
      ACCEPT_TOKEN(sym_keyword_desc);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 908:
      ACCEPT_TOKEN(sym_keyword_order);
      END_STATE();
    case 909:
      ACCEPT_TOKEN(sym_keyword_order);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 910:
      ACCEPT_TOKEN(sym_keyword_with);
      END_STATE();
    case 911:
      ACCEPT_TOKEN(sym_keyword_with);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 912:
      ACCEPT_TOKEN(sym_keyword_index);
      END_STATE();
    case 913:
      ACCEPT_TOKEN(sym_keyword_no_index);
      END_STATE();
    case 914:
      ACCEPT_TOKEN(sym_keyword_where);
      END_STATE();
    case 915:
      ACCEPT_TOKEN(sym_keyword_where);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 916:
      ACCEPT_TOKEN(sym_keyword_where);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 917:
      ACCEPT_TOKEN(sym_keyword_split);
      END_STATE();
    case 918:
      ACCEPT_TOKEN(sym_keyword_split);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 919:
      ACCEPT_TOKEN(sym_keyword_at);
      END_STATE();
    case 920:
      ACCEPT_TOKEN(sym_keyword_at);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 921:
      ACCEPT_TOKEN(sym_keyword_group);
      END_STATE();
    case 922:
      ACCEPT_TOKEN(sym_keyword_group);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 923:
      ACCEPT_TOKEN(sym_keyword_all);
      if (lookahead == 'I') ADVANCE(508);
      END_STATE();
    case 924:
      ACCEPT_TOKEN(sym_keyword_true);
      END_STATE();
    case 925:
      ACCEPT_TOKEN(sym_keyword_true);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 926:
      ACCEPT_TOKEN(sym_keyword_false);
      END_STATE();
    case 927:
      ACCEPT_TOKEN(sym_keyword_false);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 928:
      ACCEPT_TOKEN(sym_keyword_begin);
      END_STATE();
    case 929:
      ACCEPT_TOKEN(sym_keyword_begin);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 930:
      ACCEPT_TOKEN(sym_keyword_cancel);
      END_STATE();
    case 931:
      ACCEPT_TOKEN(sym_keyword_cancel);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 932:
      ACCEPT_TOKEN(sym_keyword_commit);
      END_STATE();
    case 933:
      ACCEPT_TOKEN(sym_keyword_commit);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 934:
      ACCEPT_TOKEN(sym_keyword_transaction);
      END_STATE();
    case 935:
      ACCEPT_TOKEN(sym_keyword_none);
      END_STATE();
    case 936:
      ACCEPT_TOKEN(sym_keyword_none);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 937:
      ACCEPT_TOKEN(sym_keyword_null);
      END_STATE();
    case 938:
      ACCEPT_TOKEN(sym_keyword_null);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 939:
      ACCEPT_TOKEN(sym_keyword_and);
      END_STATE();
    case 940:
      ACCEPT_TOKEN(sym_keyword_and);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 941:
      ACCEPT_TOKEN(sym_keyword_or);
      END_STATE();
    case 942:
      ACCEPT_TOKEN(sym_keyword_or);
      if (lookahead == 'D') ADVANCE(1325);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 943:
      ACCEPT_TOKEN(sym_keyword_or);
      if (lookahead == 'D') ADVANCE(278);
      END_STATE();
    case 944:
      ACCEPT_TOKEN(sym_keyword_or);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 945:
      ACCEPT_TOKEN(sym_keyword_is);
      END_STATE();
    case 946:
      ACCEPT_TOKEN(sym_keyword_is);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 947:
      ACCEPT_TOKEN(sym_keyword_not);
      END_STATE();
    case 948:
      ACCEPT_TOKEN(sym_keyword_not);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 949:
      ACCEPT_TOKEN(sym_keyword_not);
      if (lookahead == 'I') ADVANCE(1421);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 950:
      ACCEPT_TOKEN(sym_keyword_not);
      if (lookahead == 'I') ADVANCE(530);
      END_STATE();
    case 951:
      ACCEPT_TOKEN(sym_keyword_contains);
      END_STATE();
    case 952:
      ACCEPT_TOKEN(sym_keyword_contains);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 953:
      ACCEPT_TOKEN(sym_keyword_contains_not);
      END_STATE();
    case 954:
      ACCEPT_TOKEN(sym_keyword_contains_not);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 955:
      ACCEPT_TOKEN(sym_keyword_contains_all);
      END_STATE();
    case 956:
      ACCEPT_TOKEN(sym_keyword_contains_all);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 957:
      ACCEPT_TOKEN(sym_keyword_contains_any);
      END_STATE();
    case 958:
      ACCEPT_TOKEN(sym_keyword_contains_any);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 959:
      ACCEPT_TOKEN(sym_keyword_contains_none);
      END_STATE();
    case 960:
      ACCEPT_TOKEN(sym_keyword_contains_none);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 961:
      ACCEPT_TOKEN(sym_keyword_inside);
      END_STATE();
    case 962:
      ACCEPT_TOKEN(sym_keyword_inside);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 963:
      ACCEPT_TOKEN(sym_keyword_in);
      END_STATE();
    case 964:
      ACCEPT_TOKEN(sym_keyword_in);
      if (lookahead == 'S') ADVANCE(364);
      if (lookahead == 'T') ADVANCE(274);
      END_STATE();
    case 965:
      ACCEPT_TOKEN(sym_keyword_in);
      if (lookahead == 'S') ADVANCE(1356);
      if (lookahead == 'T') ADVANCE(1317);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 966:
      ACCEPT_TOKEN(sym_keyword_not_inside);
      END_STATE();
    case 967:
      ACCEPT_TOKEN(sym_keyword_not_inside);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 968:
      ACCEPT_TOKEN(sym_keyword_all_inside);
      END_STATE();
    case 969:
      ACCEPT_TOKEN(sym_keyword_all_inside);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 970:
      ACCEPT_TOKEN(sym_keyword_any_inside);
      END_STATE();
    case 971:
      ACCEPT_TOKEN(sym_keyword_any_inside);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 972:
      ACCEPT_TOKEN(sym_keyword_none_inside);
      END_STATE();
    case 973:
      ACCEPT_TOKEN(sym_keyword_none_inside);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 974:
      ACCEPT_TOKEN(sym_keyword_outside);
      END_STATE();
    case 975:
      ACCEPT_TOKEN(sym_keyword_outside);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 976:
      ACCEPT_TOKEN(sym_keyword_intersects);
      END_STATE();
    case 977:
      ACCEPT_TOKEN(sym_keyword_intersects);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 978:
      ACCEPT_TOKEN(sym_keyword_chebyshev);
      END_STATE();
    case 979:
      ACCEPT_TOKEN(sym_keyword_cosine);
      END_STATE();
    case 980:
      ACCEPT_TOKEN(sym_keyword_euclidean);
      END_STATE();
    case 981:
      ACCEPT_TOKEN(sym_keyword_hamming);
      END_STATE();
    case 982:
      ACCEPT_TOKEN(sym_keyword_jaccard);
      END_STATE();
    case 983:
      ACCEPT_TOKEN(sym_keyword_manhattan);
      END_STATE();
    case 984:
      ACCEPT_TOKEN(sym_keyword_minkowski);
      END_STATE();
    case 985:
      ACCEPT_TOKEN(sym_keyword_pearson);
      END_STATE();
    case 986:
      ACCEPT_TOKEN(sym_keyword_define);
      END_STATE();
    case 987:
      ACCEPT_TOKEN(sym_keyword_define);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 988:
      ACCEPT_TOKEN(sym_keyword_analyzer);
      END_STATE();
    case 989:
      ACCEPT_TOKEN(sym_keyword_event);
      END_STATE();
    case 990:
      ACCEPT_TOKEN(sym_keyword_field);
      END_STATE();
    case 991:
      ACCEPT_TOKEN(sym_keyword_function);
      END_STATE();
    case 992:
      ACCEPT_TOKEN(sym_keyword_namespace);
      END_STATE();
    case 993:
      ACCEPT_TOKEN(sym_keyword_param);
      END_STATE();
    case 994:
      ACCEPT_TOKEN(sym_keyword_scope);
      END_STATE();
    case 995:
      ACCEPT_TOKEN(sym_keyword_drop);
      END_STATE();
    case 996:
      ACCEPT_TOKEN(sym_keyword_drop);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 997:
      ACCEPT_TOKEN(sym_keyword_schemafull);
      END_STATE();
    case 998:
      ACCEPT_TOKEN(sym_keyword_schemafull);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 999:
      ACCEPT_TOKEN(sym_keyword_schemaless);
      END_STATE();
    case 1000:
      ACCEPT_TOKEN(sym_keyword_schemaless);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1001:
      ACCEPT_TOKEN(sym_keyword_live);
      END_STATE();
    case 1002:
      ACCEPT_TOKEN(sym_keyword_diff);
      END_STATE();
    case 1003:
      ACCEPT_TOKEN(sym_keyword_diff);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1004:
      ACCEPT_TOKEN(sym_keyword_flexible);
      END_STATE();
    case 1005:
      ACCEPT_TOKEN(sym_keyword_flexible);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1006:
      ACCEPT_TOKEN(sym_keyword_readonly);
      END_STATE();
    case 1007:
      ACCEPT_TOKEN(sym_keyword_readonly);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1008:
      ACCEPT_TOKEN(sym_keyword_jwks);
      END_STATE();
    case 1009:
      ACCEPT_TOKEN(sym_keyword_eddsa);
      END_STATE();
    case 1010:
      ACCEPT_TOKEN(sym_keyword_es256);
      END_STATE();
    case 1011:
      ACCEPT_TOKEN(sym_keyword_es384);
      END_STATE();
    case 1012:
      ACCEPT_TOKEN(sym_keyword_es512);
      END_STATE();
    case 1013:
      ACCEPT_TOKEN(sym_keyword_ps256);
      END_STATE();
    case 1014:
      ACCEPT_TOKEN(sym_keyword_ps384);
      END_STATE();
    case 1015:
      ACCEPT_TOKEN(sym_keyword_ps512);
      END_STATE();
    case 1016:
      ACCEPT_TOKEN(sym_keyword_rs256);
      END_STATE();
    case 1017:
      ACCEPT_TOKEN(sym_keyword_rs384);
      END_STATE();
    case 1018:
      ACCEPT_TOKEN(sym_keyword_rs512);
      END_STATE();
    case 1019:
      ACCEPT_TOKEN(sym_keyword_bm25);
      END_STATE();
    case 1020:
      ACCEPT_TOKEN(sym_keyword_doc_ids_cache);
      END_STATE();
    case 1021:
      ACCEPT_TOKEN(sym_keyword_doc_ids_order);
      END_STATE();
    case 1022:
      ACCEPT_TOKEN(sym_keyword_doc_lengths_cache);
      END_STATE();
    case 1023:
      ACCEPT_TOKEN(sym_keyword_doc_lengths_order);
      END_STATE();
    case 1024:
      ACCEPT_TOKEN(sym_keyword_postings_cache);
      END_STATE();
    case 1025:
      ACCEPT_TOKEN(sym_keyword_postings_order);
      END_STATE();
    case 1026:
      ACCEPT_TOKEN(sym_keyword_terms_cache);
      END_STATE();
    case 1027:
      ACCEPT_TOKEN(sym_keyword_terms_order);
      END_STATE();
    case 1028:
      ACCEPT_TOKEN(sym_keyword_highlights);
      END_STATE();
    case 1029:
      ACCEPT_TOKEN(sym_keyword_any);
      END_STATE();
    case 1030:
      ACCEPT_TOKEN(sym_keyword_any);
      if (lookahead == 'I') ADVANCE(529);
      END_STATE();
    case 1031:
      ACCEPT_TOKEN(sym_keyword_normal);
      END_STATE();
    case 1032:
      ACCEPT_TOKEN(sym_keyword_relation);
      END_STATE();
    case 1033:
      ACCEPT_TOKEN(sym_keyword_out);
      END_STATE();
    case 1034:
      ACCEPT_TOKEN(sym_keyword_to);
      END_STATE();
    case 1035:
      ACCEPT_TOKEN(sym_keyword_changefeed);
      END_STATE();
    case 1036:
      ACCEPT_TOKEN(sym_keyword_changefeed);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1037:
      ACCEPT_TOKEN(sym_keyword_content);
      END_STATE();
    case 1038:
      ACCEPT_TOKEN(sym_keyword_content);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1039:
      ACCEPT_TOKEN(sym_keyword_merge);
      END_STATE();
    case 1040:
      ACCEPT_TOKEN(sym_keyword_merge);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1041:
      ACCEPT_TOKEN(sym_keyword_patch);
      END_STATE();
    case 1042:
      ACCEPT_TOKEN(sym_keyword_patch);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1043:
      ACCEPT_TOKEN(sym_keyword_before);
      END_STATE();
    case 1044:
      ACCEPT_TOKEN(sym_keyword_before);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1045:
      ACCEPT_TOKEN(sym_keyword_after);
      END_STATE();
    case 1046:
      ACCEPT_TOKEN(sym_keyword_after);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1047:
      ACCEPT_TOKEN(sym_keyword_table);
      END_STATE();
    case 1048:
      ACCEPT_TOKEN(sym_keyword_table);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 1049:
      ACCEPT_TOKEN(sym_keyword_root);
      END_STATE();
    case 1050:
      ACCEPT_TOKEN(sym_keyword_token);
      END_STATE();
    case 1051:
      ACCEPT_TOKEN(sym_keyword_use);
      if (lookahead == 'R') ADVANCE(1054);
      END_STATE();
    case 1052:
      ACCEPT_TOKEN(sym_keyword_ns);
      END_STATE();
    case 1053:
      ACCEPT_TOKEN(sym_keyword_db);
      END_STATE();
    case 1054:
      ACCEPT_TOKEN(sym_keyword_user);
      END_STATE();
    case 1055:
      ACCEPT_TOKEN(sym_keyword_roles);
      END_STATE();
    case 1056:
      ACCEPT_TOKEN(sym_keyword_remove);
      END_STATE();
    case 1057:
      ACCEPT_TOKEN(sym_keyword_remove);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1058:
      ACCEPT_TOKEN(sym_keyword_create);
      END_STATE();
    case 1059:
      ACCEPT_TOKEN(sym_keyword_create);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1060:
      ACCEPT_TOKEN(sym_keyword_delete);
      END_STATE();
    case 1061:
      ACCEPT_TOKEN(sym_keyword_delete);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1062:
      ACCEPT_TOKEN(sym_keyword_update);
      END_STATE();
    case 1063:
      ACCEPT_TOKEN(sym_keyword_update);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1064:
      ACCEPT_TOKEN(sym_keyword_insert);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1065:
      ACCEPT_TOKEN(sym_keyword_into);
      END_STATE();
    case 1066:
      ACCEPT_TOKEN(sym_keyword_tokenizers);
      END_STATE();
    case 1067:
      ACCEPT_TOKEN(sym_keyword_filters);
      END_STATE();
    case 1068:
      ACCEPT_TOKEN(sym_keyword_when);
      END_STATE();
    case 1069:
      ACCEPT_TOKEN(sym_keyword_then);
      END_STATE();
    case 1070:
      ACCEPT_TOKEN(sym_keyword_then);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1071:
      ACCEPT_TOKEN(sym_keyword_type);
      END_STATE();
    case 1072:
      ACCEPT_TOKEN(sym_keyword_type);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1073:
      ACCEPT_TOKEN(sym_keyword_default);
      END_STATE();
    case 1074:
      ACCEPT_TOKEN(sym_keyword_default);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1075:
      ACCEPT_TOKEN(sym_keyword_assert);
      END_STATE();
    case 1076:
      ACCEPT_TOKEN(sym_keyword_assert);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1077:
      ACCEPT_TOKEN(sym_keyword_permissions);
      END_STATE();
    case 1078:
      ACCEPT_TOKEN(sym_keyword_permissions);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1079:
      ACCEPT_TOKEN(sym_keyword_relate);
      END_STATE();
    case 1080:
      ACCEPT_TOKEN(sym_keyword_relate);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1081:
      ACCEPT_TOKEN(sym_keyword_ignore);
      END_STATE();
    case 1082:
      ACCEPT_TOKEN(sym_keyword_values);
      END_STATE();
    case 1083:
      ACCEPT_TOKEN(sym_keyword_for);
      END_STATE();
    case 1084:
      ACCEPT_TOKEN(sym_keyword_for);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1085:
      ACCEPT_TOKEN(sym_keyword_comment);
      END_STATE();
    case 1086:
      ACCEPT_TOKEN(sym_keyword_comment);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1087:
      ACCEPT_TOKEN(sym_keyword_fields);
      END_STATE();
    case 1088:
      ACCEPT_TOKEN(sym_keyword_columns);
      END_STATE();
    case 1089:
      ACCEPT_TOKEN(sym_keyword_unique);
      END_STATE();
    case 1090:
      ACCEPT_TOKEN(sym_keyword_search);
      END_STATE();
    case 1091:
      ACCEPT_TOKEN(sym_keyword_session);
      END_STATE();
    case 1092:
      ACCEPT_TOKEN(sym_keyword_signin);
      END_STATE();
    case 1093:
      ACCEPT_TOKEN(sym_keyword_signup);
      END_STATE();
    case 1094:
      ACCEPT_TOKEN(sym_keyword_if);
      END_STATE();
    case 1095:
      ACCEPT_TOKEN(sym_keyword_if);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1096:
      ACCEPT_TOKEN(sym_keyword_if);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 1097:
      ACCEPT_TOKEN(sym_keyword_exists);
      END_STATE();
    case 1098:
      ACCEPT_TOKEN(sym_keyword_database);
      END_STATE();
    case 1099:
      ACCEPT_TOKEN(sym_keyword_password);
      END_STATE();
    case 1100:
      ACCEPT_TOKEN(sym_keyword_password_hash);
      END_STATE();
    case 1101:
      ACCEPT_TOKEN(sym_keyword_on_duplicate_key_update);
      END_STATE();
    case 1102:
      ACCEPT_TOKEN(sym_keyword_count);
      END_STATE();
    case 1103:
      ACCEPT_TOKEN(sym_keyword_count);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1104:
      ACCEPT_TOKEN(sym_keyword_set);
      END_STATE();
    case 1105:
      ACCEPT_TOKEN(sym_keyword_set);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1106:
      ACCEPT_TOKEN(sym_keyword_unset);
      END_STATE();
    case 1107:
      ACCEPT_TOKEN(sym_keyword_unset);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1108:
      ACCEPT_TOKEN(sym_keyword_dimension);
      END_STATE();
    case 1109:
      ACCEPT_TOKEN(sym_keyword_mtree);
      END_STATE();
    case 1110:
      ACCEPT_TOKEN(sym_keyword_dist);
      END_STATE();
    case 1111:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 1112:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 1113:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 1114:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 1115:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 1116:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 1117:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 1118:
      ACCEPT_TOKEN(anon_sym_QMARK);
      if (lookahead == ':') ADVANCE(1527);
      if (lookahead == '=') ADVANCE(1530);
      if (lookahead == '?') ADVANCE(1526);
      END_STATE();
    case 1119:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 1120:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 1121:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 1122:
      ACCEPT_TOKEN(anon_sym_LT_DASH);
      if (lookahead == '>') ADVANCE(1123);
      END_STATE();
    case 1123:
      ACCEPT_TOKEN(anon_sym_LT_DASH_GT);
      END_STATE();
    case 1124:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 1125:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(1543);
      if (lookahead == '=') ADVANCE(1531);
      if (lookahead == '~') ADVANCE(1534);
      END_STATE();
    case 1126:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 1127:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(1513);
      END_STATE();
    case 1128:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '-') ADVANCE(1122);
      if (lookahead == '=') ADVANCE(1535);
      if (lookahead == '|') ADVANCE(1522);
      END_STATE();
    case 1129:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(1535);
      if (lookahead == '|') ADVANCE(1522);
      END_STATE();
    case 1130:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(1536);
      END_STATE();
    case 1131:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == '"') ADVANCE(23);
      if (lookahead == '\'') ADVANCE(40);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1132:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(73);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1133:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'A') ADVANCE(1184);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1134:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'A') ADVANCE(1190);
      if (lookahead == 'O') ADVANCE(1187);
      if (lookahead == 'R') ADVANCE(1159);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1135:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'A') ADVANCE(1215);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1136:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'A') ADVANCE(1193);
      if (lookahead == 'E') ADVANCE(1186);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1137:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'A') ADVANCE(1193);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1138:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'A') ADVANCE(1185);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1139:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'A') ADVANCE(1217);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1140:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'A') ADVANCE(1218);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1141:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'C') ADVANCE(1214);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1142:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'C') ADVANCE(1166);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1143:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'D') ADVANCE(898);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1144:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'D') ADVANCE(1140);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1145:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(1173);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1146:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(1171);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1147:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(936);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1148:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(925);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1149:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(927);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1150:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(915);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1151:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(1059);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1152:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(987);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1153:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(1061);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1154:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(1080);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1155:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(1057);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1156:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(1063);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1157:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(877);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1158:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(1044);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1159:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(1135);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1160:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(1207);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1161:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(1141);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1162:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(1169);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1163:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(1206);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1164:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(1183);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1165:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(1205);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1166:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(1180);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1167:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'E') ADVANCE(1216);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1168:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'F') ADVANCE(1003);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1169:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'F') ADVANCE(1202);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1170:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'F') ADVANCE(1168);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1171:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'F') ADVANCE(1178);
      if (lookahead == 'L') ADVANCE(1167);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1172:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'F') ADVANCE(1219);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1173:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'G') ADVANCE(1177);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1174:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'H') ADVANCE(1160);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1175:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'I') ADVANCE(1212);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1176:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'I') ADVANCE(1170);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1177:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'I') ADVANCE(1192);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1178:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'I') ADVANCE(1197);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1179:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'L') ADVANCE(938);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1180:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'L') ADVANCE(931);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1181:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'L') ADVANCE(1224);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1182:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'L') ADVANCE(1179);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1183:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'L') ADVANCE(1161);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1184:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'L') ADVANCE(1210);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1185:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'L') ADVANCE(1222);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1186:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'L') ADVANCE(1139);
      if (lookahead == 'M') ADVANCE(1198);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1187:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'M') ADVANCE(1188);
      if (lookahead == 'U') ADVANCE(1191);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1188:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'M') ADVANCE(1175);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1189:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'N') ADVANCE(1209);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1190:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'N') ADVANCE(1142);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1191:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'N') ADVANCE(1211);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1192:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'N') ADVANCE(929);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1193:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'N') ADVANCE(1143);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1194:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'N') ADVANCE(1181);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1195:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'N') ADVANCE(1147);
      if (lookahead == 'T') ADVANCE(948);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1196:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'N') ADVANCE(1147);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1197:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'N') ADVANCE(1152);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1198:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'O') ADVANCE(1223);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1199:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'O') ADVANCE(1195);
      if (lookahead == 'U') ADVANCE(1182);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1200:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'O') ADVANCE(1220);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1201:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'O') ADVANCE(1196);
      if (lookahead == 'U') ADVANCE(1182);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1202:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'O') ADVANCE(1208);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1203:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'P') ADVANCE(1144);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1204:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'R') ADVANCE(1221);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1205:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'R') ADVANCE(1046);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1206:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'R') ADVANCE(1213);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1207:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'R') ADVANCE(1150);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1208:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'R') ADVANCE(1158);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1209:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'S') ADVANCE(1163);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1210:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'S') ADVANCE(1149);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1211:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'T') ADVANCE(1103);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1212:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'T') ADVANCE(933);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1213:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'T') ADVANCE(1064);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1214:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'T') ADVANCE(872);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1215:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'T') ADVANCE(1151);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1216:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'T') ADVANCE(1153);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1217:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'T') ADVANCE(1154);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1218:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'T') ADVANCE(1156);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1219:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'T') ADVANCE(1165);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1220:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'U') ADVANCE(1191);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1221:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'U') ADVANCE(1148);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1222:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'U') ADVANCE(1157);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1223:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'V') ADVANCE(1155);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1224:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'Y') ADVANCE(875);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1225:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'Y') ADVANCE(895);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1226:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == 'n') ADVANCE(1132);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1227:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1227);
      END_STATE();
    case 1228:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'A') ADVANCE(1229);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 1229:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'B') ADVANCE(1232);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 1230:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'E') ADVANCE(1048);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 1231:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'F') ADVANCE(1096);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 1232:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'L') ADVANCE(1230);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 1233:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'N') ADVANCE(865);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 1234:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'T') ADVANCE(920);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 1235:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'Y') ADVANCE(896);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 1236:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1236);
      END_STATE();
    case 1237:
      ACCEPT_TOKEN(anon_sym_blank);
      END_STATE();
    case 1238:
      ACCEPT_TOKEN(anon_sym_camel);
      END_STATE();
    case 1239:
      ACCEPT_TOKEN(anon_sym_class);
      END_STATE();
    case 1240:
      ACCEPT_TOKEN(anon_sym_punct);
      END_STATE();
    case 1241:
      ACCEPT_TOKEN(anon_sym_ascii);
      END_STATE();
    case 1242:
      ACCEPT_TOKEN(anon_sym_lowercase);
      END_STATE();
    case 1243:
      ACCEPT_TOKEN(anon_sym_uppercase);
      END_STATE();
    case 1244:
      ACCEPT_TOKEN(anon_sym_edgengram);
      END_STATE();
    case 1245:
      ACCEPT_TOKEN(anon_sym_ngram);
      END_STATE();
    case 1246:
      ACCEPT_TOKEN(anon_sym_snowball);
      END_STATE();
    case 1247:
      ACCEPT_TOKEN(sym_string);
      END_STATE();
    case 1248:
      ACCEPT_TOKEN(sym_prefixed_string);
      END_STATE();
    case 1249:
      ACCEPT_TOKEN(sym_prefixed_string);
      if (lookahead == '"') ADVANCE(1249);
      if (lookahead == '\\') ADVANCE(815);
      if (lookahead != 0 &&
          lookahead != '\'') ADVANCE(24);
      END_STATE();
    case 1250:
      ACCEPT_TOKEN(sym_int);
      ADVANCE_MAP(
        '.', 806,
        'm', 1517,
        'n', 793,
        'u', 793,
        0xb5, 793,
        'd', 1516,
        'h', 1516,
        's', 1516,
        'w', 1516,
        'y', 1516,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(773);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1250);
      END_STATE();
    case 1251:
      ACCEPT_TOKEN(sym_int);
      if (lookahead == '.') ADVANCE(806);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1251);
      END_STATE();
    case 1252:
      ACCEPT_TOKEN(sym_int);
      ADVANCE_MAP(
        'm', 1517,
        'n', 793,
        'u', 793,
        0xb5, 793,
        'd', 1516,
        'h', 1516,
        's', 1516,
        'w', 1516,
        'y', 1516,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(773);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1252);
      END_STATE();
    case 1253:
      ACCEPT_TOKEN(sym_int);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1253);
      END_STATE();
    case 1254:
      ACCEPT_TOKEN(sym_int);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1254);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1255:
      ACCEPT_TOKEN(sym_float);
      END_STATE();
    case 1256:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == 'd') ADVANCE(759);
      if (lookahead == 'f') ADVANCE(1255);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(805);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1256);
      END_STATE();
    case 1257:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == 'd') ADVANCE(759);
      if (lookahead == 'f') ADVANCE(1255);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1257);
      END_STATE();
    case 1258:
      ACCEPT_TOKEN(sym_decimal);
      END_STATE();
    case 1259:
      ACCEPT_TOKEN(sym_variable_name);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1259);
      END_STATE();
    case 1260:
      ACCEPT_TOKEN(sym_custom_function_name);
      if (lookahead == ':') ADVANCE(73);
      END_STATE();
    case 1261:
      ACCEPT_TOKEN(sym_custom_function_name);
      if (lookahead == ':') ADVANCE(73);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1261);
      END_STATE();
    case 1262:
      ACCEPT_TOKEN(sym_custom_function_name);
      if (lookahead == ':') ADVANCE(73);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1263:
      ACCEPT_TOKEN(sym_function_name);
      if (lookahead == ':') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1263);
      END_STATE();
    case 1264:
      ACCEPT_TOKEN(sym_version_number);
      if (lookahead == '.') ADVANCE(809);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1264);
      END_STATE();
    case 1265:
      ACCEPT_TOKEN(sym_version_number);
      if (lookahead == '.') ADVANCE(808);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1265);
      END_STATE();
    case 1266:
      ACCEPT_TOKEN(sym_version_number);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1266);
      END_STATE();
    case 1267:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A') ADVANCE(1448);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1268:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A') ADVANCE(1403);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1269:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A') ADVANCE(1340);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1270:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A') ADVANCE(1447);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1271:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A') ADVANCE(1385);
      if (lookahead == 'N') ADVANCE(1428);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1272:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A') ADVANCE(1383);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1273:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A') ADVANCE(1298);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1274:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A') ADVANCE(1491);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1275:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A') ADVANCE(1405);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1276:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A') ADVANCE(1495);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1277:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A') ADVANCE(1384);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1278:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A') ADVANCE(1357);
      if (lookahead == 'E') ADVANCE(1415);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1279:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A') ADVANCE(1357);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1280:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A') ADVANCE(1360);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1281:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'B') ADVANCE(1391);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1282:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'C') ADVANCE(905);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1283:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'C') ADVANCE(907);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1284:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'C') ADVANCE(1345);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1285:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'C') ADVANCE(903);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1286:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'C') ADVANCE(1347);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1287:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'C') ADVANCE(1490);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1288:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'C') ADVANCE(1351);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1289:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D') ADVANCE(940);
      if (lookahead == 'Y') ADVANCE(1370);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1290:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D') ADVANCE(899);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1291:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D') ADVANCE(1036);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1292:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D') ADVANCE(1301);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1293:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D') ADVANCE(1303);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1294:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D') ADVANCE(1304);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1295:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D') ADVANCE(1305);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1296:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D') ADVANCE(1306);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1297:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D') ADVANCE(1307);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1298:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D') ADVANCE(1434);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1299:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1463);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1300:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1487);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1301:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(962);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1302:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(901);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1303:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(975);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1304:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(969);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1305:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(971);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1306:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(967);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1307:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(973);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1308:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(960);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1309:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(916);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1310:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1072);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1311:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1342);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1312:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1040);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1313:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(878);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1314:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1005);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1315:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1426);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1316:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1500);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1317:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1449);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1318:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1341);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1319:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1399);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1320:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1450);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1321:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1291);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1322:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1376);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1323:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1287);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1324:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1456);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1325:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1445);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1326:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1465);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1327:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1457);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1328:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1413);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1329:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1458);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1330:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1273);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1331:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1488);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1332:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1455);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1333:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1407);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1334:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1479);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1335:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1481);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1336:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1321);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1337:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1415);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1338:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E') ADVANCE(1371);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1339:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'F') ADVANCE(1095);
      if (lookahead == 'N') ADVANCE(965);
      if (lookahead == 'S') ADVANCE(946);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1340:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'F') ADVANCE(1498);
      if (lookahead == 'L') ADVANCE(1326);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1341:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'F') ADVANCE(1276);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1342:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'F') ADVANCE(1336);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1343:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'G') ADVANCE(1311);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1344:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'G') ADVANCE(1312);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1345:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'H') ADVANCE(890);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1346:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'H') ADVANCE(911);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1347:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'H') ADVANCE(1042);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1348:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'H') ADVANCE(1275);
      if (lookahead == 'O') ADVANCE(1401);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1349:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'H') ADVANCE(1324);
      if (lookahead == 'I') ADVANCE(1486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1350:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'H') ADVANCE(1324);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1351:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'H') ADVANCE(1319);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1352:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'H') ADVANCE(1333);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1353:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1395);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1354:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1281);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1355:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1419);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1356:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1292);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1357:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1410);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1358:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1285);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1359:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1475);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1360:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1404);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1361:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1469);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1362:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1436);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1363:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1477);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1364:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1397);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1365:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1293);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1366:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1294);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1367:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1295);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1368:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1296);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1369:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1297);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1370:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1420);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1371:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I') ADVANCE(1422);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1372:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1379);
      if (lookahead == 'N') ADVANCE(1289);
      if (lookahead == 'S') ADVANCE(1282);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1373:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1379);
      if (lookahead == 'N') ADVANCE(1289);
      if (lookahead == 'S') ADVANCE(880);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1374:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1379);
      if (lookahead == 'N') ADVANCE(1289);
      if (lookahead == 'S') ADVANCE(1468);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1375:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1379);
      if (lookahead == 'N') ADVANCE(1289);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1376:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(886);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1377:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(956);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1378:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(998);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1379:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1355);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1380:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1382);
      if (lookahead == 'N') ADVANCE(1489);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1381:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1502);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1382:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1274);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1383:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1387);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1384:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1497);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1385:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1377);
      if (lookahead == 'N') ADVANCE(1501);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1386:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1378);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1387:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1322);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1388:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1484);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1389:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1316);
      if (lookahead == 'O') ADVANCE(1446);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1390:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1316);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1391:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1314);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1392:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1363);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1393:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L') ADVANCE(1280);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1394:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'M') ADVANCE(874);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1395:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'M') ADVANCE(1359);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1396:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'M') ADVANCE(1320);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1397:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'M') ADVANCE(1315);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1398:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'M') ADVANCE(1361);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1399:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'M') ADVANCE(1269);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1400:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'M') ADVANCE(1328);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1401:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'M') ADVANCE(1400);
      if (lookahead == 'N') ADVANCE(1489);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1402:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(965);
      if (lookahead == 'S') ADVANCE(946);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1403:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(1290);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1404:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(883);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1405:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(1343);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1406:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(868);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1407:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(1070);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1408:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(1489);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1409:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(1338);
      if (lookahead == 'T') ADVANCE(949);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1410:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(1459);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1411:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(1462);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1412:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(1381);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1413:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(1478);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1414:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(1480);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1415:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(1482);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1416:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(1308);
      if (lookahead == 'T') ADVANCE(954);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1417:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(1467);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1418:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(1492);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1419:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(1471);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1420:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(1472);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1421:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(1473);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1422:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N') ADVANCE(1474);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1423:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O') ADVANCE(1380);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1424:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O') ADVANCE(1409);
      if (lookahead == 'U') ADVANCE(1396);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1425:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O') ADVANCE(1409);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1426:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O') ADVANCE(1494);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1427:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O') ADVANCE(1401);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1428:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O') ADVANCE(1416);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1429:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O') ADVANCE(1493);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1430:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O') ADVANCE(1394);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1431:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O') ADVANCE(1439);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1432:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O') ADVANCE(1408);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1433:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O') ADVANCE(1446);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1434:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O') ADVANCE(1412);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1435:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O') ADVANCE(1418);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1436:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O') ADVANCE(1411);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1437:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O') ADVANCE(1414);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1438:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'P') ADVANCE(922);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1439:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'P') ADVANCE(996);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1440:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'P') ADVANCE(1310);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1441:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'P') ADVANCE(1392);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1442:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'P') ADVANCE(1393);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1443:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R') ADVANCE(944);
      if (lookahead == 'U') ADVANCE(1485);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1444:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R') ADVANCE(942);
      if (lookahead == 'U') ADVANCE(1485);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1445:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R') ADVANCE(909);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1446:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R') ADVANCE(1084);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1447:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R') ADVANCE(1272);
      if (lookahead == 'T') ADVANCE(1286);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1448:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R') ADVANCE(1272);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1449:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R') ADVANCE(1466);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1450:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R') ADVANCE(1358);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1451:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R') ADVANCE(1429);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1452:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R') ADVANCE(1431);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1453:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R') ADVANCE(1406);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1454:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R') ADVANCE(1430);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1455:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R') ADVANCE(1483);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1456:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R') ADVANCE(1309);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1457:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R') ADVANCE(1398);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1458:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R') ADVANCE(1344);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1459:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S') ADVANCE(1271);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1460:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S') ADVANCE(977);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1461:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S') ADVANCE(1000);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1462:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S') ADVANCE(1078);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1463:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S') ADVANCE(1283);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1464:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S') ADVANCE(1362);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1465:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S') ADVANCE(1461);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1466:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S') ADVANCE(1323);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1467:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S') ADVANCE(1335);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1468:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S') ADVANCE(1332);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1469:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S') ADVANCE(1464);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1470:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S') ADVANCE(1365);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1471:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S') ADVANCE(1366);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1472:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S') ADVANCE(1367);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1473:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S') ADVANCE(1368);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1474:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S') ADVANCE(1369);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1475:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T') ADVANCE(893);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1476:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T') ADVANCE(888);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1477:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T') ADVANCE(918);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1478:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T') ADVANCE(1086);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1479:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T') ADVANCE(1105);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1480:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T') ADVANCE(1278);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1481:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T') ADVANCE(1107);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1482:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T') ADVANCE(1038);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1483:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T') ADVANCE(1076);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1484:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T') ADVANCE(1074);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1485:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T') ADVANCE(1470);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1486:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T') ADVANCE(1346);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1487:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T') ADVANCE(1284);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1488:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T') ADVANCE(1496);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1489:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T') ADVANCE(1279);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1490:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T') ADVANCE(1460);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1491:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T') ADVANCE(1302);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1492:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T') ADVANCE(1337);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1493:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'U') ADVANCE(1438);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1494:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'U') ADVANCE(1476);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1495:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'U') ADVANCE(1388);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1496:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'U') ADVANCE(1453);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1497:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'U') ADVANCE(1313);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1498:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'U') ADVANCE(1386);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1499:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'X') ADVANCE(1442);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1500:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'X') ADVANCE(1354);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1501:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'Y') ADVANCE(958);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1502:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'Y') ADVANCE(1007);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1503:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'Y') ADVANCE(1440);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1504:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'a') ADVANCE(1505);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1505:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'i') ADVANCE(1507);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1506:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'n') ADVANCE(1511);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1507:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'n') ADVANCE(1510);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1508:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'n') ADVANCE(1262);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1509:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'o') ADVANCE(1506);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1510:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 's') ADVANCE(952);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1511:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 't') ADVANCE(1504);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1512:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1512);
      END_STATE();
    case 1513:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      END_STATE();
    case 1514:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 1515:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(1529);
      END_STATE();
    case 1516:
      ACCEPT_TOKEN(sym_duration_part);
      END_STATE();
    case 1517:
      ACCEPT_TOKEN(sym_duration_part);
      if (lookahead == 's') ADVANCE(1516);
      END_STATE();
    case 1518:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(851);
      if (lookahead == '=') ADVANCE(1539);
      END_STATE();
    case 1519:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(851);
      if (lookahead == '=') ADVANCE(1539);
      if (lookahead == '>') ADVANCE(1112);
      END_STATE();
    case 1520:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(851);
      if (lookahead == '=') ADVANCE(1539);
      if (lookahead == '>') ADVANCE(1112);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1253);
      END_STATE();
    case 1521:
      ACCEPT_TOKEN(anon_sym_AT);
      if (lookahead == '@') ADVANCE(1554);
      END_STATE();
    case 1522:
      ACCEPT_TOKEN(anon_sym_LT_PIPE);
      END_STATE();
    case 1523:
      ACCEPT_TOKEN(anon_sym_PIPE_GT);
      END_STATE();
    case 1524:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 1525:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 1526:
      ACCEPT_TOKEN(anon_sym_QMARK_QMARK);
      END_STATE();
    case 1527:
      ACCEPT_TOKEN(anon_sym_QMARK_COLON);
      END_STATE();
    case 1528:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 1529:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 1530:
      ACCEPT_TOKEN(anon_sym_QMARK_EQ);
      END_STATE();
    case 1531:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 1532:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 1533:
      ACCEPT_TOKEN(anon_sym_BANG_TILDE);
      END_STATE();
    case 1534:
      ACCEPT_TOKEN(anon_sym_STAR_TILDE);
      END_STATE();
    case 1535:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 1536:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 1537:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '=') ADVANCE(1538);
      END_STATE();
    case 1538:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 1539:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 1540:
      ACCEPT_TOKEN(anon_sym_u00d7);
      END_STATE();
    case 1541:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(2);
      if (lookahead == '/') ADVANCE(862);
      END_STATE();
    case 1542:
      ACCEPT_TOKEN(anon_sym_u00f7);
      END_STATE();
    case 1543:
      ACCEPT_TOKEN(anon_sym_STAR_STAR);
      END_STATE();
    case 1544:
      ACCEPT_TOKEN(anon_sym_u220b);
      END_STATE();
    case 1545:
      ACCEPT_TOKEN(anon_sym_u220c);
      END_STATE();
    case 1546:
      ACCEPT_TOKEN(anon_sym_u2287);
      END_STATE();
    case 1547:
      ACCEPT_TOKEN(anon_sym_u2283);
      END_STATE();
    case 1548:
      ACCEPT_TOKEN(anon_sym_u2285);
      END_STATE();
    case 1549:
      ACCEPT_TOKEN(anon_sym_u2208);
      END_STATE();
    case 1550:
      ACCEPT_TOKEN(anon_sym_u2209);
      END_STATE();
    case 1551:
      ACCEPT_TOKEN(anon_sym_u2286);
      END_STATE();
    case 1552:
      ACCEPT_TOKEN(anon_sym_u2282);
      END_STATE();
    case 1553:
      ACCEPT_TOKEN(anon_sym_u2284);
      END_STATE();
    case 1554:
      ACCEPT_TOKEN(anon_sym_AT_AT);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 15},
  [2] = {.lex_state = 818},
  [3] = {.lex_state = 818},
  [4] = {.lex_state = 818},
  [5] = {.lex_state = 818},
  [6] = {.lex_state = 818},
  [7] = {.lex_state = 821},
  [8] = {.lex_state = 818},
  [9] = {.lex_state = 818},
  [10] = {.lex_state = 818},
  [11] = {.lex_state = 821},
  [12] = {.lex_state = 818},
  [13] = {.lex_state = 821},
  [14] = {.lex_state = 818},
  [15] = {.lex_state = 818},
  [16] = {.lex_state = 818},
  [17] = {.lex_state = 818},
  [18] = {.lex_state = 818},
  [19] = {.lex_state = 818},
  [20] = {.lex_state = 818},
  [21] = {.lex_state = 818},
  [22] = {.lex_state = 818},
  [23] = {.lex_state = 818},
  [24] = {.lex_state = 821},
  [25] = {.lex_state = 818},
  [26] = {.lex_state = 821},
  [27] = {.lex_state = 821},
  [28] = {.lex_state = 821},
  [29] = {.lex_state = 821},
  [30] = {.lex_state = 818},
  [31] = {.lex_state = 818},
  [32] = {.lex_state = 818},
  [33] = {.lex_state = 818},
  [34] = {.lex_state = 818},
  [35] = {.lex_state = 821},
  [36] = {.lex_state = 818},
  [37] = {.lex_state = 818},
  [38] = {.lex_state = 818},
  [39] = {.lex_state = 818},
  [40] = {.lex_state = 818},
  [41] = {.lex_state = 818},
  [42] = {.lex_state = 818},
  [43] = {.lex_state = 818},
  [44] = {.lex_state = 818},
  [45] = {.lex_state = 818},
  [46] = {.lex_state = 821},
  [47] = {.lex_state = 821},
  [48] = {.lex_state = 821},
  [49] = {.lex_state = 821},
  [50] = {.lex_state = 821},
  [51] = {.lex_state = 818},
  [52] = {.lex_state = 818},
  [53] = {.lex_state = 821},
  [54] = {.lex_state = 821},
  [55] = {.lex_state = 821},
  [56] = {.lex_state = 821},
  [57] = {.lex_state = 821},
  [58] = {.lex_state = 821},
  [59] = {.lex_state = 821},
  [60] = {.lex_state = 821},
  [61] = {.lex_state = 821},
  [62] = {.lex_state = 821},
  [63] = {.lex_state = 821},
  [64] = {.lex_state = 821},
  [65] = {.lex_state = 821},
  [66] = {.lex_state = 821},
  [67] = {.lex_state = 821},
  [68] = {.lex_state = 821},
  [69] = {.lex_state = 821},
  [70] = {.lex_state = 819},
  [71] = {.lex_state = 820},
  [72] = {.lex_state = 821},
  [73] = {.lex_state = 820},
  [74] = {.lex_state = 820},
  [75] = {.lex_state = 820},
  [76] = {.lex_state = 819},
  [77] = {.lex_state = 819},
  [78] = {.lex_state = 821},
  [79] = {.lex_state = 819},
  [80] = {.lex_state = 820},
  [81] = {.lex_state = 821},
  [82] = {.lex_state = 821},
  [83] = {.lex_state = 819},
  [84] = {.lex_state = 819},
  [85] = {.lex_state = 819},
  [86] = {.lex_state = 820},
  [87] = {.lex_state = 819},
  [88] = {.lex_state = 820},
  [89] = {.lex_state = 820},
  [90] = {.lex_state = 820},
  [91] = {.lex_state = 821},
  [92] = {.lex_state = 821},
  [93] = {.lex_state = 821},
  [94] = {.lex_state = 821},
  [95] = {.lex_state = 821},
  [96] = {.lex_state = 821},
  [97] = {.lex_state = 821},
  [98] = {.lex_state = 821},
  [99] = {.lex_state = 819},
  [100] = {.lex_state = 821},
  [101] = {.lex_state = 821},
  [102] = {.lex_state = 821},
  [103] = {.lex_state = 821},
  [104] = {.lex_state = 821},
  [105] = {.lex_state = 821},
  [106] = {.lex_state = 821},
  [107] = {.lex_state = 821},
  [108] = {.lex_state = 821},
  [109] = {.lex_state = 821},
  [110] = {.lex_state = 821},
  [111] = {.lex_state = 821},
  [112] = {.lex_state = 821},
  [113] = {.lex_state = 821},
  [114] = {.lex_state = 821},
  [115] = {.lex_state = 821},
  [116] = {.lex_state = 821},
  [117] = {.lex_state = 821},
  [118] = {.lex_state = 831},
  [119] = {.lex_state = 821},
  [120] = {.lex_state = 821},
  [121] = {.lex_state = 821},
  [122] = {.lex_state = 821},
  [123] = {.lex_state = 821},
  [124] = {.lex_state = 821},
  [125] = {.lex_state = 832},
  [126] = {.lex_state = 821},
  [127] = {.lex_state = 832},
  [128] = {.lex_state = 832},
  [129] = {.lex_state = 832},
  [130] = {.lex_state = 832},
  [131] = {.lex_state = 832},
  [132] = {.lex_state = 819},
  [133] = {.lex_state = 823},
  [134] = {.lex_state = 825},
  [135] = {.lex_state = 825},
  [136] = {.lex_state = 824},
  [137] = {.lex_state = 819},
  [138] = {.lex_state = 825},
  [139] = {.lex_state = 823},
  [140] = {.lex_state = 823},
  [141] = {.lex_state = 824},
  [142] = {.lex_state = 824},
  [143] = {.lex_state = 818},
  [144] = {.lex_state = 818},
  [145] = {.lex_state = 826},
  [146] = {.lex_state = 824},
  [147] = {.lex_state = 826},
  [148] = {.lex_state = 824},
  [149] = {.lex_state = 818},
  [150] = {.lex_state = 831},
  [151] = {.lex_state = 826},
  [152] = {.lex_state = 831},
  [153] = {.lex_state = 830},
  [154] = {.lex_state = 819},
  [155] = {.lex_state = 831},
  [156] = {.lex_state = 830},
  [157] = {.lex_state = 831},
  [158] = {.lex_state = 818},
  [159] = {.lex_state = 830},
  [160] = {.lex_state = 818},
  [161] = {.lex_state = 825},
  [162] = {.lex_state = 818},
  [163] = {.lex_state = 825},
  [164] = {.lex_state = 819},
  [165] = {.lex_state = 825},
  [166] = {.lex_state = 818},
  [167] = {.lex_state = 824},
  [168] = {.lex_state = 818},
  [169] = {.lex_state = 823},
  [170] = {.lex_state = 823},
  [171] = {.lex_state = 823},
  [172] = {.lex_state = 831},
  [173] = {.lex_state = 819},
  [174] = {.lex_state = 819},
  [175] = {.lex_state = 831},
  [176] = {.lex_state = 831},
  [177] = {.lex_state = 834},
  [178] = {.lex_state = 834},
  [179] = {.lex_state = 819},
  [180] = {.lex_state = 834},
  [181] = {.lex_state = 835},
  [182] = {.lex_state = 826},
  [183] = {.lex_state = 826},
  [184] = {.lex_state = 826},
  [185] = {.lex_state = 831},
  [186] = {.lex_state = 835},
  [187] = {.lex_state = 835},
  [188] = {.lex_state = 819},
  [189] = {.lex_state = 833},
  [190] = {.lex_state = 833},
  [191] = {.lex_state = 833},
  [192] = {.lex_state = 819},
  [193] = {.lex_state = 819},
  [194] = {.lex_state = 819},
  [195] = {.lex_state = 819},
  [196] = {.lex_state = 830},
  [197] = {.lex_state = 830},
  [198] = {.lex_state = 830},
  [199] = {.lex_state = 819},
  [200] = {.lex_state = 834},
  [201] = {.lex_state = 836},
  [202] = {.lex_state = 834},
  [203] = {.lex_state = 834},
  [204] = {.lex_state = 837},
  [205] = {.lex_state = 833},
  [206] = {.lex_state = 833},
  [207] = {.lex_state = 833},
  [208] = {.lex_state = 837},
  [209] = {.lex_state = 837},
  [210] = {.lex_state = 836},
  [211] = {.lex_state = 835},
  [212] = {.lex_state = 835},
  [213] = {.lex_state = 836},
  [214] = {.lex_state = 835},
  [215] = {.lex_state = 836},
  [216] = {.lex_state = 836},
  [217] = {.lex_state = 837},
  [218] = {.lex_state = 837},
  [219] = {.lex_state = 837},
  [220] = {.lex_state = 831},
  [221] = {.lex_state = 831},
  [222] = {.lex_state = 836},
  [223] = {.lex_state = 818},
  [224] = {.lex_state = 818},
  [225] = {.lex_state = 818},
  [226] = {.lex_state = 818},
  [227] = {.lex_state = 821},
  [228] = {.lex_state = 818},
  [229] = {.lex_state = 831},
  [230] = {.lex_state = 818},
  [231] = {.lex_state = 818},
  [232] = {.lex_state = 831},
  [233] = {.lex_state = 818},
  [234] = {.lex_state = 831},
  [235] = {.lex_state = 831},
  [236] = {.lex_state = 831},
  [237] = {.lex_state = 831},
  [238] = {.lex_state = 831},
  [239] = {.lex_state = 831},
  [240] = {.lex_state = 831},
  [241] = {.lex_state = 831},
  [242] = {.lex_state = 831},
  [243] = {.lex_state = 831},
  [244] = {.lex_state = 827},
  [245] = {.lex_state = 831},
  [246] = {.lex_state = 827},
  [247] = {.lex_state = 818},
  [248] = {.lex_state = 818},
  [249] = {.lex_state = 818},
  [250] = {.lex_state = 827},
  [251] = {.lex_state = 831},
  [252] = {.lex_state = 818},
  [253] = {.lex_state = 818},
  [254] = {.lex_state = 818},
  [255] = {.lex_state = 818},
  [256] = {.lex_state = 818},
  [257] = {.lex_state = 818},
  [258] = {.lex_state = 818},
  [259] = {.lex_state = 818},
  [260] = {.lex_state = 818},
  [261] = {.lex_state = 818},
  [262] = {.lex_state = 818},
  [263] = {.lex_state = 818},
  [264] = {.lex_state = 818},
  [265] = {.lex_state = 818},
  [266] = {.lex_state = 818},
  [267] = {.lex_state = 818},
  [268] = {.lex_state = 831},
  [269] = {.lex_state = 818},
  [270] = {.lex_state = 818},
  [271] = {.lex_state = 820},
  [272] = {.lex_state = 820},
  [273] = {.lex_state = 818},
  [274] = {.lex_state = 839},
  [275] = {.lex_state = 831},
  [276] = {.lex_state = 831},
  [277] = {.lex_state = 831},
  [278] = {.lex_state = 831},
  [279] = {.lex_state = 831},
  [280] = {.lex_state = 831},
  [281] = {.lex_state = 831},
  [282] = {.lex_state = 831},
  [283] = {.lex_state = 831},
  [284] = {.lex_state = 831},
  [285] = {.lex_state = 831},
  [286] = {.lex_state = 831},
  [287] = {.lex_state = 831},
  [288] = {.lex_state = 831},
  [289] = {.lex_state = 831},
  [290] = {.lex_state = 831},
  [291] = {.lex_state = 821},
  [292] = {.lex_state = 831},
  [293] = {.lex_state = 831},
  [294] = {.lex_state = 831},
  [295] = {.lex_state = 831},
  [296] = {.lex_state = 831},
  [297] = {.lex_state = 831},
  [298] = {.lex_state = 831},
  [299] = {.lex_state = 831},
  [300] = {.lex_state = 831},
  [301] = {.lex_state = 831},
  [302] = {.lex_state = 839},
  [303] = {.lex_state = 831},
  [304] = {.lex_state = 828},
  [305] = {.lex_state = 831},
  [306] = {.lex_state = 820},
  [307] = {.lex_state = 828},
  [308] = {.lex_state = 828},
  [309] = {.lex_state = 831},
  [310] = {.lex_state = 831},
  [311] = {.lex_state = 831},
  [312] = {.lex_state = 831},
  [313] = {.lex_state = 831},
  [314] = {.lex_state = 831},
  [315] = {.lex_state = 831},
  [316] = {.lex_state = 831},
  [317] = {.lex_state = 831},
  [318] = {.lex_state = 831},
  [319] = {.lex_state = 839},
  [320] = {.lex_state = 831},
  [321] = {.lex_state = 831},
  [322] = {.lex_state = 831},
  [323] = {.lex_state = 839},
  [324] = {.lex_state = 818},
  [325] = {.lex_state = 839},
  [326] = {.lex_state = 820},
  [327] = {.lex_state = 818},
  [328] = {.lex_state = 827},
  [329] = {.lex_state = 821},
  [330] = {.lex_state = 831},
  [331] = {.lex_state = 818},
  [332] = {.lex_state = 831},
  [333] = {.lex_state = 831},
  [334] = {.lex_state = 831},
  [335] = {.lex_state = 831},
  [336] = {.lex_state = 827},
  [337] = {.lex_state = 827},
  [338] = {.lex_state = 839},
  [339] = {.lex_state = 839},
  [340] = {.lex_state = 17},
  [341] = {.lex_state = 839},
  [342] = {.lex_state = 831},
  [343] = {.lex_state = 821},
  [344] = {.lex_state = 821},
  [345] = {.lex_state = 818},
  [346] = {.lex_state = 839},
  [347] = {.lex_state = 839},
  [348] = {.lex_state = 839},
  [349] = {.lex_state = 17},
  [350] = {.lex_state = 839},
  [351] = {.lex_state = 828},
  [352] = {.lex_state = 17},
  [353] = {.lex_state = 828},
  [354] = {.lex_state = 828},
  [355] = {.lex_state = 17},
  [356] = {.lex_state = 829},
  [357] = {.lex_state = 829},
  [358] = {.lex_state = 829},
  [359] = {.lex_state = 839},
  [360] = {.lex_state = 17},
  [361] = {.lex_state = 822},
  [362] = {.lex_state = 839},
  [363] = {.lex_state = 822},
  [364] = {.lex_state = 17},
  [365] = {.lex_state = 839},
  [366] = {.lex_state = 822},
  [367] = {.lex_state = 839},
  [368] = {.lex_state = 818},
  [369] = {.lex_state = 17},
  [370] = {.lex_state = 17},
  [371] = {.lex_state = 839},
  [372] = {.lex_state = 839},
  [373] = {.lex_state = 839},
  [374] = {.lex_state = 839},
  [375] = {.lex_state = 829},
  [376] = {.lex_state = 838},
  [377] = {.lex_state = 839},
  [378] = {.lex_state = 832},
  [379] = {.lex_state = 839},
  [380] = {.lex_state = 819},
  [381] = {.lex_state = 839},
  [382] = {.lex_state = 820},
  [383] = {.lex_state = 839},
  [384] = {.lex_state = 821},
  [385] = {.lex_state = 839},
  [386] = {.lex_state = 832},
  [387] = {.lex_state = 839},
  [388] = {.lex_state = 838},
  [389] = {.lex_state = 838},
  [390] = {.lex_state = 831},
  [391] = {.lex_state = 839},
  [392] = {.lex_state = 829},
  [393] = {.lex_state = 829},
  [394] = {.lex_state = 839},
  [395] = {.lex_state = 820},
  [396] = {.lex_state = 819},
  [397] = {.lex_state = 832},
  [398] = {.lex_state = 838},
  [399] = {.lex_state = 838},
  [400] = {.lex_state = 832},
  [401] = {.lex_state = 819},
  [402] = {.lex_state = 832},
  [403] = {.lex_state = 819},
  [404] = {.lex_state = 9},
  [405] = {.lex_state = 9},
  [406] = {.lex_state = 838},
  [407] = {.lex_state = 9},
  [408] = {.lex_state = 819},
  [409] = {.lex_state = 832},
  [410] = {.lex_state = 820},
  [411] = {.lex_state = 12},
  [412] = {.lex_state = 819},
  [413] = {.lex_state = 832},
  [414] = {.lex_state = 12},
  [415] = {.lex_state = 12},
  [416] = {.lex_state = 832},
  [417] = {.lex_state = 819},
  [418] = {.lex_state = 820},
  [419] = {.lex_state = 819},
  [420] = {.lex_state = 820},
  [421] = {.lex_state = 819},
  [422] = {.lex_state = 820},
  [423] = {.lex_state = 820},
  [424] = {.lex_state = 820},
  [425] = {.lex_state = 820},
  [426] = {.lex_state = 820},
  [427] = {.lex_state = 819},
  [428] = {.lex_state = 820},
  [429] = {.lex_state = 818},
  [430] = {.lex_state = 822},
  [431] = {.lex_state = 820},
  [432] = {.lex_state = 832},
  [433] = {.lex_state = 819},
  [434] = {.lex_state = 11},
  [435] = {.lex_state = 819},
  [436] = {.lex_state = 822},
  [437] = {.lex_state = 820},
  [438] = {.lex_state = 11},
  [439] = {.lex_state = 820},
  [440] = {.lex_state = 11},
  [441] = {.lex_state = 820},
  [442] = {.lex_state = 819},
  [443] = {.lex_state = 10},
  [444] = {.lex_state = 10},
  [445] = {.lex_state = 10},
  [446] = {.lex_state = 832},
  [447] = {.lex_state = 832},
  [448] = {.lex_state = 832},
  [449] = {.lex_state = 820},
  [450] = {.lex_state = 820},
  [451] = {.lex_state = 819},
  [452] = {.lex_state = 832},
  [453] = {.lex_state = 832},
  [454] = {.lex_state = 832},
  [455] = {.lex_state = 832},
  [456] = {.lex_state = 832},
  [457] = {.lex_state = 822},
  [458] = {.lex_state = 832},
  [459] = {.lex_state = 832},
  [460] = {.lex_state = 832},
  [461] = {.lex_state = 7},
  [462] = {.lex_state = 7},
  [463] = {.lex_state = 7},
  [464] = {.lex_state = 8},
  [465] = {.lex_state = 8},
  [466] = {.lex_state = 820},
  [467] = {.lex_state = 832},
  [468] = {.lex_state = 8},
  [469] = {.lex_state = 818},
  [470] = {.lex_state = 832},
  [471] = {.lex_state = 819},
  [472] = {.lex_state = 819},
  [473] = {.lex_state = 832},
  [474] = {.lex_state = 818},
  [475] = {.lex_state = 832},
  [476] = {.lex_state = 832},
  [477] = {.lex_state = 832},
  [478] = {.lex_state = 832},
  [479] = {.lex_state = 819},
  [480] = {.lex_state = 832},
  [481] = {.lex_state = 832},
  [482] = {.lex_state = 832},
  [483] = {.lex_state = 819},
  [484] = {.lex_state = 819},
  [485] = {.lex_state = 819},
  [486] = {.lex_state = 820},
  [487] = {.lex_state = 820},
  [488] = {.lex_state = 820},
  [489] = {.lex_state = 832},
  [490] = {.lex_state = 818},
  [491] = {.lex_state = 819},
  [492] = {.lex_state = 818},
  [493] = {.lex_state = 832},
  [494] = {.lex_state = 818},
  [495] = {.lex_state = 819},
  [496] = {.lex_state = 819},
  [497] = {.lex_state = 819},
  [498] = {.lex_state = 818},
  [499] = {.lex_state = 818},
  [500] = {.lex_state = 819},
  [501] = {.lex_state = 819},
  [502] = {.lex_state = 818},
  [503] = {.lex_state = 818},
  [504] = {.lex_state = 819},
  [505] = {.lex_state = 818},
  [506] = {.lex_state = 818},
  [507] = {.lex_state = 819},
  [508] = {.lex_state = 818},
  [509] = {.lex_state = 819},
  [510] = {.lex_state = 819},
  [511] = {.lex_state = 818},
  [512] = {.lex_state = 819},
  [513] = {.lex_state = 818},
  [514] = {.lex_state = 819},
  [515] = {.lex_state = 819},
  [516] = {.lex_state = 819},
  [517] = {.lex_state = 819},
  [518] = {.lex_state = 819},
  [519] = {.lex_state = 819},
  [520] = {.lex_state = 818},
  [521] = {.lex_state = 819},
  [522] = {.lex_state = 819},
  [523] = {.lex_state = 819},
  [524] = {.lex_state = 819},
  [525] = {.lex_state = 819},
  [526] = {.lex_state = 819},
  [527] = {.lex_state = 818},
  [528] = {.lex_state = 820},
  [529] = {.lex_state = 818},
  [530] = {.lex_state = 818},
  [531] = {.lex_state = 818},
  [532] = {.lex_state = 818},
  [533] = {.lex_state = 818},
  [534] = {.lex_state = 819},
  [535] = {.lex_state = 819},
  [536] = {.lex_state = 819},
  [537] = {.lex_state = 819},
  [538] = {.lex_state = 819},
  [539] = {.lex_state = 819},
  [540] = {.lex_state = 819},
  [541] = {.lex_state = 819},
  [542] = {.lex_state = 820},
  [543] = {.lex_state = 820},
  [544] = {.lex_state = 819},
  [545] = {.lex_state = 819},
  [546] = {.lex_state = 820},
  [547] = {.lex_state = 819},
  [548] = {.lex_state = 820},
  [549] = {.lex_state = 819},
  [550] = {.lex_state = 819},
  [551] = {.lex_state = 819},
  [552] = {.lex_state = 819},
  [553] = {.lex_state = 819},
  [554] = {.lex_state = 819},
  [555] = {.lex_state = 819},
  [556] = {.lex_state = 819},
  [557] = {.lex_state = 819},
  [558] = {.lex_state = 819},
  [559] = {.lex_state = 819},
  [560] = {.lex_state = 819},
  [561] = {.lex_state = 819},
  [562] = {.lex_state = 819},
  [563] = {.lex_state = 819},
  [564] = {.lex_state = 819},
  [565] = {.lex_state = 819},
  [566] = {.lex_state = 819},
  [567] = {.lex_state = 819},
  [568] = {.lex_state = 820},
  [569] = {.lex_state = 819},
  [570] = {.lex_state = 819},
  [571] = {.lex_state = 819},
  [572] = {.lex_state = 819},
  [573] = {.lex_state = 819},
  [574] = {.lex_state = 819},
  [575] = {.lex_state = 819},
  [576] = {.lex_state = 819},
  [577] = {.lex_state = 819},
  [578] = {.lex_state = 819},
  [579] = {.lex_state = 819},
  [580] = {.lex_state = 819},
  [581] = {.lex_state = 819},
  [582] = {.lex_state = 819},
  [583] = {.lex_state = 819},
  [584] = {.lex_state = 819},
  [585] = {.lex_state = 819},
  [586] = {.lex_state = 819},
  [587] = {.lex_state = 819},
  [588] = {.lex_state = 819},
  [589] = {.lex_state = 819},
  [590] = {.lex_state = 819},
  [591] = {.lex_state = 819},
  [592] = {.lex_state = 819},
  [593] = {.lex_state = 819},
  [594] = {.lex_state = 819},
  [595] = {.lex_state = 819},
  [596] = {.lex_state = 819},
  [597] = {.lex_state = 819},
  [598] = {.lex_state = 819},
  [599] = {.lex_state = 819},
  [600] = {.lex_state = 819},
  [601] = {.lex_state = 819},
  [602] = {.lex_state = 819},
  [603] = {.lex_state = 819},
  [604] = {.lex_state = 819},
  [605] = {.lex_state = 819},
  [606] = {.lex_state = 14},
  [607] = {.lex_state = 14},
  [608] = {.lex_state = 13},
  [609] = {.lex_state = 13},
  [610] = {.lex_state = 16},
  [611] = {.lex_state = 16},
  [612] = {.lex_state = 13},
  [613] = {.lex_state = 19},
  [614] = {.lex_state = 18},
  [615] = {.lex_state = 13},
  [616] = {.lex_state = 13},
  [617] = {.lex_state = 19},
  [618] = {.lex_state = 19},
  [619] = {.lex_state = 13},
  [620] = {.lex_state = 13},
  [621] = {.lex_state = 19},
  [622] = {.lex_state = 13},
  [623] = {.lex_state = 19},
  [624] = {.lex_state = 18},
  [625] = {.lex_state = 13},
  [626] = {.lex_state = 19},
  [627] = {.lex_state = 13},
  [628] = {.lex_state = 13},
  [629] = {.lex_state = 13},
  [630] = {.lex_state = 13},
  [631] = {.lex_state = 13},
  [632] = {.lex_state = 13},
  [633] = {.lex_state = 13},
  [634] = {.lex_state = 13},
  [635] = {.lex_state = 13},
  [636] = {.lex_state = 13},
  [637] = {.lex_state = 13},
  [638] = {.lex_state = 13},
  [639] = {.lex_state = 13},
  [640] = {.lex_state = 13},
  [641] = {.lex_state = 13},
  [642] = {.lex_state = 13},
  [643] = {.lex_state = 13},
  [644] = {.lex_state = 13},
  [645] = {.lex_state = 13},
  [646] = {.lex_state = 13},
  [647] = {.lex_state = 13},
  [648] = {.lex_state = 13},
  [649] = {.lex_state = 13},
  [650] = {.lex_state = 13},
  [651] = {.lex_state = 13},
  [652] = {.lex_state = 13},
  [653] = {.lex_state = 13},
  [654] = {.lex_state = 13},
  [655] = {.lex_state = 13},
  [656] = {.lex_state = 13},
  [657] = {.lex_state = 13},
  [658] = {.lex_state = 13},
  [659] = {.lex_state = 13},
  [660] = {.lex_state = 13},
  [661] = {.lex_state = 13},
  [662] = {.lex_state = 13},
  [663] = {.lex_state = 13},
  [664] = {.lex_state = 13},
  [665] = {.lex_state = 13},
  [666] = {.lex_state = 13},
  [667] = {.lex_state = 13},
  [668] = {.lex_state = 13},
  [669] = {.lex_state = 13},
  [670] = {.lex_state = 13},
  [671] = {.lex_state = 13},
  [672] = {.lex_state = 13},
  [673] = {.lex_state = 13},
  [674] = {.lex_state = 13},
  [675] = {.lex_state = 13},
  [676] = {.lex_state = 13},
  [677] = {.lex_state = 13},
  [678] = {.lex_state = 13},
  [679] = {.lex_state = 13},
  [680] = {.lex_state = 13},
  [681] = {.lex_state = 13},
  [682] = {.lex_state = 13},
  [683] = {.lex_state = 13},
  [684] = {.lex_state = 13},
  [685] = {.lex_state = 13},
  [686] = {.lex_state = 13},
  [687] = {.lex_state = 13},
  [688] = {.lex_state = 13},
  [689] = {.lex_state = 13},
  [690] = {.lex_state = 13},
  [691] = {.lex_state = 13},
  [692] = {.lex_state = 13},
  [693] = {.lex_state = 13},
  [694] = {.lex_state = 13},
  [695] = {.lex_state = 13},
  [696] = {.lex_state = 13},
  [697] = {.lex_state = 13},
  [698] = {.lex_state = 13},
  [699] = {.lex_state = 13},
  [700] = {.lex_state = 13},
  [701] = {.lex_state = 13},
  [702] = {.lex_state = 13},
  [703] = {.lex_state = 13},
  [704] = {.lex_state = 13},
  [705] = {.lex_state = 13},
  [706] = {.lex_state = 13},
  [707] = {.lex_state = 13},
  [708] = {.lex_state = 13},
  [709] = {.lex_state = 13},
  [710] = {.lex_state = 13},
  [711] = {.lex_state = 13},
  [712] = {.lex_state = 13},
  [713] = {.lex_state = 13},
  [714] = {.lex_state = 13},
  [715] = {.lex_state = 13},
  [716] = {.lex_state = 13},
  [717] = {.lex_state = 13},
  [718] = {.lex_state = 13},
  [719] = {.lex_state = 13},
  [720] = {.lex_state = 13},
  [721] = {.lex_state = 13},
  [722] = {.lex_state = 13},
  [723] = {.lex_state = 13},
  [724] = {.lex_state = 13},
  [725] = {.lex_state = 13},
  [726] = {.lex_state = 13},
  [727] = {.lex_state = 13},
  [728] = {.lex_state = 13},
  [729] = {.lex_state = 13},
  [730] = {.lex_state = 13},
  [731] = {.lex_state = 13},
  [732] = {.lex_state = 13},
  [733] = {.lex_state = 13},
  [734] = {.lex_state = 13},
  [735] = {.lex_state = 13},
  [736] = {.lex_state = 13},
  [737] = {.lex_state = 13},
  [738] = {.lex_state = 13},
  [739] = {.lex_state = 13},
  [740] = {.lex_state = 13},
  [741] = {.lex_state = 13},
  [742] = {.lex_state = 13},
  [743] = {.lex_state = 13},
  [744] = {.lex_state = 13},
  [745] = {.lex_state = 13},
  [746] = {.lex_state = 13},
  [747] = {.lex_state = 13},
  [748] = {.lex_state = 13},
  [749] = {.lex_state = 13},
  [750] = {.lex_state = 13},
  [751] = {.lex_state = 13},
  [752] = {.lex_state = 13},
  [753] = {.lex_state = 13},
  [754] = {.lex_state = 13},
  [755] = {.lex_state = 13},
  [756] = {.lex_state = 0},
  [757] = {.lex_state = 0},
  [758] = {.lex_state = 0},
  [759] = {.lex_state = 0},
  [760] = {.lex_state = 0},
  [761] = {.lex_state = 0},
  [762] = {.lex_state = 0},
  [763] = {.lex_state = 0},
  [764] = {.lex_state = 0},
  [765] = {.lex_state = 0},
  [766] = {.lex_state = 20},
  [767] = {.lex_state = 0},
  [768] = {.lex_state = 0},
  [769] = {.lex_state = 13},
  [770] = {.lex_state = 13},
  [771] = {.lex_state = 13},
  [772] = {.lex_state = 0},
  [773] = {.lex_state = 13},
  [774] = {.lex_state = 13},
  [775] = {.lex_state = 13},
  [776] = {.lex_state = 0},
  [777] = {.lex_state = 13},
  [778] = {.lex_state = 0},
  [779] = {.lex_state = 0},
  [780] = {.lex_state = 0},
  [781] = {.lex_state = 0},
  [782] = {.lex_state = 0},
  [783] = {.lex_state = 0},
  [784] = {.lex_state = 818},
  [785] = {.lex_state = 0},
  [786] = {.lex_state = 0},
  [787] = {.lex_state = 821},
  [788] = {.lex_state = 0},
  [789] = {.lex_state = 821},
  [790] = {.lex_state = 821},
  [791] = {.lex_state = 821},
  [792] = {.lex_state = 0},
  [793] = {.lex_state = 0},
  [794] = {.lex_state = 0},
  [795] = {.lex_state = 821},
  [796] = {.lex_state = 0},
  [797] = {.lex_state = 0},
  [798] = {.lex_state = 0},
  [799] = {.lex_state = 0},
  [800] = {.lex_state = 840},
  [801] = {.lex_state = 821},
  [802] = {.lex_state = 840},
  [803] = {.lex_state = 821},
  [804] = {.lex_state = 0},
  [805] = {.lex_state = 0},
  [806] = {.lex_state = 0},
  [807] = {.lex_state = 840},
  [808] = {.lex_state = 821},
  [809] = {.lex_state = 821},
  [810] = {.lex_state = 821},
  [811] = {.lex_state = 821},
  [812] = {.lex_state = 821},
  [813] = {.lex_state = 0},
  [814] = {.lex_state = 0},
  [815] = {.lex_state = 0},
  [816] = {.lex_state = 0},
  [817] = {.lex_state = 0},
  [818] = {.lex_state = 0},
  [819] = {.lex_state = 841},
  [820] = {.lex_state = 0},
  [821] = {.lex_state = 841},
  [822] = {.lex_state = 0},
  [823] = {.lex_state = 841},
  [824] = {.lex_state = 0},
  [825] = {.lex_state = 0},
  [826] = {.lex_state = 0},
  [827] = {.lex_state = 0},
  [828] = {.lex_state = 0},
  [829] = {.lex_state = 0},
  [830] = {.lex_state = 0},
  [831] = {.lex_state = 0},
  [832] = {.lex_state = 0},
  [833] = {.lex_state = 0},
  [834] = {.lex_state = 0},
  [835] = {.lex_state = 0},
  [836] = {.lex_state = 0},
  [837] = {.lex_state = 0},
  [838] = {.lex_state = 0},
  [839] = {.lex_state = 0},
  [840] = {.lex_state = 842},
  [841] = {.lex_state = 0},
  [842] = {.lex_state = 0},
  [843] = {.lex_state = 0},
  [844] = {.lex_state = 0},
  [845] = {.lex_state = 0},
  [846] = {.lex_state = 0},
  [847] = {.lex_state = 0},
  [848] = {.lex_state = 0},
  [849] = {.lex_state = 0},
  [850] = {.lex_state = 0},
  [851] = {.lex_state = 0},
  [852] = {.lex_state = 0},
  [853] = {.lex_state = 0},
  [854] = {.lex_state = 0},
  [855] = {.lex_state = 0},
  [856] = {.lex_state = 0},
  [857] = {.lex_state = 819},
  [858] = {.lex_state = 0},
  [859] = {.lex_state = 0},
  [860] = {.lex_state = 819},
  [861] = {.lex_state = 0},
  [862] = {.lex_state = 0},
  [863] = {.lex_state = 0},
  [864] = {.lex_state = 0},
  [865] = {.lex_state = 0},
  [866] = {.lex_state = 0},
  [867] = {.lex_state = 0},
  [868] = {.lex_state = 0},
  [869] = {.lex_state = 819},
  [870] = {.lex_state = 0},
  [871] = {.lex_state = 0},
  [872] = {.lex_state = 0},
  [873] = {.lex_state = 0},
  [874] = {.lex_state = 0},
  [875] = {.lex_state = 29},
  [876] = {.lex_state = 0},
  [877] = {.lex_state = 0},
  [878] = {.lex_state = 0},
  [879] = {.lex_state = 0},
  [880] = {.lex_state = 0},
  [881] = {.lex_state = 0},
  [882] = {.lex_state = 29},
  [883] = {.lex_state = 0},
  [884] = {.lex_state = 0},
  [885] = {.lex_state = 0},
  [886] = {.lex_state = 0},
  [887] = {.lex_state = 0},
  [888] = {.lex_state = 0},
  [889] = {.lex_state = 0},
  [890] = {.lex_state = 0},
  [891] = {.lex_state = 0},
  [892] = {.lex_state = 0},
  [893] = {.lex_state = 0},
  [894] = {.lex_state = 0},
  [895] = {.lex_state = 0},
  [896] = {.lex_state = 0},
  [897] = {.lex_state = 0},
  [898] = {.lex_state = 0},
  [899] = {.lex_state = 0},
  [900] = {.lex_state = 0},
  [901] = {.lex_state = 0},
  [902] = {.lex_state = 0},
  [903] = {.lex_state = 0},
  [904] = {.lex_state = 0},
  [905] = {.lex_state = 0},
  [906] = {.lex_state = 0},
  [907] = {.lex_state = 0},
  [908] = {.lex_state = 0},
  [909] = {.lex_state = 28},
  [910] = {.lex_state = 818},
  [911] = {.lex_state = 0},
  [912] = {.lex_state = 28},
  [913] = {.lex_state = 0},
  [914] = {.lex_state = 819},
  [915] = {.lex_state = 818},
  [916] = {.lex_state = 0},
  [917] = {.lex_state = 0},
  [918] = {.lex_state = 28},
  [919] = {.lex_state = 0},
  [920] = {.lex_state = 821},
  [921] = {.lex_state = 821},
  [922] = {.lex_state = 0},
  [923] = {.lex_state = 0},
  [924] = {.lex_state = 0},
  [925] = {.lex_state = 821},
  [926] = {.lex_state = 0},
  [927] = {.lex_state = 0},
  [928] = {.lex_state = 0},
  [929] = {.lex_state = 28},
  [930] = {.lex_state = 28},
  [931] = {.lex_state = 28},
  [932] = {.lex_state = 28},
  [933] = {.lex_state = 821},
  [934] = {.lex_state = 0},
  [935] = {.lex_state = 28},
  [936] = {.lex_state = 0},
  [937] = {.lex_state = 0},
  [938] = {.lex_state = 0},
  [939] = {.lex_state = 0},
  [940] = {.lex_state = 0},
  [941] = {.lex_state = 28},
  [942] = {.lex_state = 0},
  [943] = {.lex_state = 0},
  [944] = {.lex_state = 819},
  [945] = {.lex_state = 0},
  [946] = {.lex_state = 28},
  [947] = {.lex_state = 0},
  [948] = {.lex_state = 818},
  [949] = {.lex_state = 0},
  [950] = {.lex_state = 33},
  [951] = {.lex_state = 0},
  [952] = {.lex_state = 0},
  [953] = {.lex_state = 0},
  [954] = {.lex_state = 33},
  [955] = {.lex_state = 0},
  [956] = {.lex_state = 0},
  [957] = {.lex_state = 0},
  [958] = {.lex_state = 0},
  [959] = {.lex_state = 821},
  [960] = {.lex_state = 0},
  [961] = {.lex_state = 0},
  [962] = {.lex_state = 33},
  [963] = {.lex_state = 29},
  [964] = {.lex_state = 0},
  [965] = {.lex_state = 29},
  [966] = {.lex_state = 0},
  [967] = {.lex_state = 0},
  [968] = {.lex_state = 0},
  [969] = {.lex_state = 0},
  [970] = {.lex_state = 0},
  [971] = {.lex_state = 0},
  [972] = {.lex_state = 0},
  [973] = {.lex_state = 0},
  [974] = {.lex_state = 0},
  [975] = {.lex_state = 821},
  [976] = {.lex_state = 0},
  [977] = {.lex_state = 0},
  [978] = {.lex_state = 0},
  [979] = {.lex_state = 821},
  [980] = {.lex_state = 0},
  [981] = {.lex_state = 0},
  [982] = {.lex_state = 821},
  [983] = {.lex_state = 821},
  [984] = {.lex_state = 0},
  [985] = {.lex_state = 0},
  [986] = {.lex_state = 0},
  [987] = {.lex_state = 821},
  [988] = {.lex_state = 0},
  [989] = {.lex_state = 0},
  [990] = {.lex_state = 0},
  [991] = {.lex_state = 28},
  [992] = {.lex_state = 0},
  [993] = {.lex_state = 28},
  [994] = {.lex_state = 0},
  [995] = {.lex_state = 0},
  [996] = {.lex_state = 0},
  [997] = {.lex_state = 0},
  [998] = {.lex_state = 0},
  [999] = {.lex_state = 0},
  [1000] = {.lex_state = 818},
  [1001] = {.lex_state = 0},
  [1002] = {.lex_state = 0},
  [1003] = {.lex_state = 0},
  [1004] = {.lex_state = 0},
  [1005] = {.lex_state = 0},
  [1006] = {.lex_state = 0},
  [1007] = {.lex_state = 0},
  [1008] = {.lex_state = 0},
  [1009] = {.lex_state = 0},
  [1010] = {.lex_state = 0},
  [1011] = {.lex_state = 818},
  [1012] = {.lex_state = 818},
  [1013] = {.lex_state = 818},
  [1014] = {.lex_state = 0},
  [1015] = {.lex_state = 0},
  [1016] = {.lex_state = 0},
  [1017] = {.lex_state = 0},
  [1018] = {.lex_state = 818},
  [1019] = {.lex_state = 0},
  [1020] = {.lex_state = 0},
  [1021] = {.lex_state = 0},
  [1022] = {.lex_state = 0},
  [1023] = {.lex_state = 818},
  [1024] = {.lex_state = 0},
  [1025] = {.lex_state = 31},
  [1026] = {.lex_state = 818},
  [1027] = {.lex_state = 31},
  [1028] = {.lex_state = 31},
  [1029] = {.lex_state = 0},
  [1030] = {.lex_state = 31},
  [1031] = {.lex_state = 31},
  [1032] = {.lex_state = 31},
  [1033] = {.lex_state = 31},
  [1034] = {.lex_state = 0},
  [1035] = {.lex_state = 818},
  [1036] = {.lex_state = 31},
  [1037] = {.lex_state = 31},
  [1038] = {.lex_state = 31},
  [1039] = {.lex_state = 31},
  [1040] = {.lex_state = 0},
  [1041] = {.lex_state = 0},
  [1042] = {.lex_state = 0},
  [1043] = {.lex_state = 0},
  [1044] = {.lex_state = 31},
  [1045] = {.lex_state = 31},
  [1046] = {.lex_state = 31},
  [1047] = {.lex_state = 31},
  [1048] = {.lex_state = 0},
  [1049] = {.lex_state = 0},
  [1050] = {.lex_state = 31},
  [1051] = {.lex_state = 31},
  [1052] = {.lex_state = 31},
  [1053] = {.lex_state = 0},
  [1054] = {.lex_state = 31},
  [1055] = {.lex_state = 31},
  [1056] = {.lex_state = 0},
  [1057] = {.lex_state = 31},
  [1058] = {.lex_state = 0},
  [1059] = {.lex_state = 31},
  [1060] = {.lex_state = 0},
  [1061] = {.lex_state = 0},
  [1062] = {.lex_state = 0},
  [1063] = {.lex_state = 31},
  [1064] = {.lex_state = 842},
  [1065] = {.lex_state = 31},
  [1066] = {.lex_state = 31},
  [1067] = {.lex_state = 31},
  [1068] = {.lex_state = 31},
  [1069] = {.lex_state = 31},
  [1070] = {.lex_state = 31},
  [1071] = {.lex_state = 31},
  [1072] = {.lex_state = 0},
  [1073] = {.lex_state = 0},
  [1074] = {.lex_state = 0},
  [1075] = {.lex_state = 31},
  [1076] = {.lex_state = 0},
  [1077] = {.lex_state = 818},
  [1078] = {.lex_state = 31},
  [1079] = {.lex_state = 818},
  [1080] = {.lex_state = 31},
  [1081] = {.lex_state = 0},
  [1082] = {.lex_state = 31},
  [1083] = {.lex_state = 31},
  [1084] = {.lex_state = 818},
  [1085] = {.lex_state = 31},
  [1086] = {.lex_state = 31},
  [1087] = {.lex_state = 0},
  [1088] = {.lex_state = 818},
  [1089] = {.lex_state = 31},
  [1090] = {.lex_state = 31},
  [1091] = {.lex_state = 0},
  [1092] = {.lex_state = 0},
  [1093] = {.lex_state = 0},
  [1094] = {.lex_state = 0},
  [1095] = {.lex_state = 31},
  [1096] = {.lex_state = 31},
  [1097] = {.lex_state = 0},
  [1098] = {.lex_state = 31},
  [1099] = {.lex_state = 0},
  [1100] = {.lex_state = 0},
  [1101] = {.lex_state = 0},
  [1102] = {.lex_state = 0},
  [1103] = {.lex_state = 0},
  [1104] = {.lex_state = 0},
  [1105] = {.lex_state = 0},
  [1106] = {.lex_state = 0},
  [1107] = {.lex_state = 0},
  [1108] = {.lex_state = 0},
  [1109] = {.lex_state = 0},
  [1110] = {.lex_state = 0},
  [1111] = {.lex_state = 0},
  [1112] = {.lex_state = 0},
  [1113] = {.lex_state = 0},
  [1114] = {.lex_state = 0},
  [1115] = {.lex_state = 0},
  [1116] = {.lex_state = 0},
  [1117] = {.lex_state = 0},
  [1118] = {.lex_state = 0},
  [1119] = {.lex_state = 0},
  [1120] = {.lex_state = 0},
  [1121] = {.lex_state = 0},
  [1122] = {.lex_state = 0},
  [1123] = {.lex_state = 0},
  [1124] = {.lex_state = 818},
  [1125] = {.lex_state = 0},
  [1126] = {.lex_state = 0},
  [1127] = {.lex_state = 0},
  [1128] = {.lex_state = 0},
  [1129] = {.lex_state = 0},
  [1130] = {.lex_state = 0},
  [1131] = {.lex_state = 0},
  [1132] = {.lex_state = 0},
  [1133] = {.lex_state = 0},
  [1134] = {.lex_state = 0},
  [1135] = {.lex_state = 0},
  [1136] = {.lex_state = 0},
  [1137] = {.lex_state = 0},
  [1138] = {.lex_state = 0},
  [1139] = {.lex_state = 0},
  [1140] = {.lex_state = 0},
  [1141] = {.lex_state = 0},
  [1142] = {.lex_state = 0},
  [1143] = {.lex_state = 0},
  [1144] = {.lex_state = 0},
  [1145] = {.lex_state = 0},
  [1146] = {.lex_state = 0},
  [1147] = {.lex_state = 0},
  [1148] = {.lex_state = 0},
  [1149] = {.lex_state = 0},
  [1150] = {.lex_state = 0},
  [1151] = {.lex_state = 0},
  [1152] = {.lex_state = 0},
  [1153] = {.lex_state = 0},
  [1154] = {.lex_state = 0},
  [1155] = {.lex_state = 0},
  [1156] = {.lex_state = 0},
  [1157] = {.lex_state = 0},
  [1158] = {.lex_state = 0},
  [1159] = {.lex_state = 0},
  [1160] = {.lex_state = 0},
  [1161] = {.lex_state = 0},
  [1162] = {.lex_state = 0},
  [1163] = {.lex_state = 0},
  [1164] = {.lex_state = 0},
  [1165] = {.lex_state = 0},
  [1166] = {.lex_state = 0},
  [1167] = {.lex_state = 0},
  [1168] = {.lex_state = 0},
  [1169] = {.lex_state = 0},
  [1170] = {.lex_state = 0},
  [1171] = {.lex_state = 0},
  [1172] = {.lex_state = 0},
  [1173] = {.lex_state = 0},
  [1174] = {.lex_state = 0},
  [1175] = {.lex_state = 0},
  [1176] = {.lex_state = 31},
  [1177] = {.lex_state = 0},
  [1178] = {.lex_state = 0},
  [1179] = {.lex_state = 0},
  [1180] = {.lex_state = 0},
  [1181] = {.lex_state = 31},
  [1182] = {.lex_state = 0},
  [1183] = {.lex_state = 0},
  [1184] = {.lex_state = 0},
  [1185] = {.lex_state = 0},
  [1186] = {.lex_state = 0},
  [1187] = {.lex_state = 0},
  [1188] = {.lex_state = 0},
  [1189] = {.lex_state = 0},
  [1190] = {.lex_state = 0},
  [1191] = {.lex_state = 0},
  [1192] = {.lex_state = 31},
  [1193] = {.lex_state = 0},
  [1194] = {.lex_state = 0},
  [1195] = {.lex_state = 0},
  [1196] = {.lex_state = 0},
  [1197] = {.lex_state = 0},
  [1198] = {.lex_state = 0},
  [1199] = {.lex_state = 0},
  [1200] = {.lex_state = 0},
  [1201] = {.lex_state = 0},
  [1202] = {.lex_state = 0},
  [1203] = {.lex_state = 0},
  [1204] = {.lex_state = 0},
  [1205] = {.lex_state = 0},
  [1206] = {.lex_state = 0},
  [1207] = {.lex_state = 0},
  [1208] = {.lex_state = 0},
  [1209] = {.lex_state = 21},
  [1210] = {.lex_state = 0},
  [1211] = {.lex_state = 0},
  [1212] = {.lex_state = 0},
  [1213] = {.lex_state = 21},
  [1214] = {.lex_state = 21},
  [1215] = {.lex_state = 0},
  [1216] = {.lex_state = 0},
  [1217] = {.lex_state = 0},
  [1218] = {.lex_state = 0},
  [1219] = {.lex_state = 0},
  [1220] = {.lex_state = 0},
  [1221] = {.lex_state = 0},
  [1222] = {.lex_state = 0},
  [1223] = {.lex_state = 0},
  [1224] = {.lex_state = 0},
  [1225] = {.lex_state = 0},
  [1226] = {.lex_state = 0},
  [1227] = {.lex_state = 0},
  [1228] = {.lex_state = 0},
  [1229] = {.lex_state = 0},
  [1230] = {.lex_state = 0},
  [1231] = {.lex_state = 0},
  [1232] = {.lex_state = 0},
  [1233] = {.lex_state = 0},
  [1234] = {.lex_state = 0},
  [1235] = {.lex_state = 0},
  [1236] = {.lex_state = 0},
  [1237] = {.lex_state = 0},
  [1238] = {.lex_state = 0},
  [1239] = {.lex_state = 0},
  [1240] = {.lex_state = 21},
  [1241] = {.lex_state = 21},
  [1242] = {.lex_state = 0},
  [1243] = {.lex_state = 0},
  [1244] = {.lex_state = 0},
  [1245] = {.lex_state = 0},
  [1246] = {.lex_state = 0},
  [1247] = {.lex_state = 0},
  [1248] = {.lex_state = 21},
  [1249] = {.lex_state = 0},
  [1250] = {.lex_state = 0},
  [1251] = {.lex_state = 0},
  [1252] = {.lex_state = 0},
  [1253] = {.lex_state = 0},
  [1254] = {.lex_state = 0},
  [1255] = {.lex_state = 0},
  [1256] = {.lex_state = 0},
  [1257] = {.lex_state = 0},
  [1258] = {.lex_state = 0},
  [1259] = {.lex_state = 0},
  [1260] = {.lex_state = 0},
  [1261] = {.lex_state = 0},
  [1262] = {.lex_state = 0},
  [1263] = {.lex_state = 0},
  [1264] = {.lex_state = 0},
  [1265] = {.lex_state = 0},
  [1266] = {.lex_state = 0},
  [1267] = {.lex_state = 0},
  [1268] = {.lex_state = 0},
  [1269] = {.lex_state = 0},
  [1270] = {.lex_state = 0},
  [1271] = {.lex_state = 0},
  [1272] = {.lex_state = 0},
  [1273] = {.lex_state = 0},
  [1274] = {.lex_state = 0},
  [1275] = {.lex_state = 0},
  [1276] = {.lex_state = 21},
  [1277] = {.lex_state = 0},
  [1278] = {.lex_state = 0},
  [1279] = {.lex_state = 0},
  [1280] = {.lex_state = 0},
  [1281] = {.lex_state = 0},
  [1282] = {.lex_state = 0},
  [1283] = {.lex_state = 819},
  [1284] = {.lex_state = 0},
  [1285] = {.lex_state = 0},
  [1286] = {.lex_state = 0},
  [1287] = {.lex_state = 0},
  [1288] = {.lex_state = 0},
  [1289] = {.lex_state = 0},
  [1290] = {.lex_state = 30},
  [1291] = {.lex_state = 0},
  [1292] = {.lex_state = 0},
  [1293] = {.lex_state = 819},
  [1294] = {.lex_state = 35},
  [1295] = {.lex_state = 0},
  [1296] = {.lex_state = 0},
  [1297] = {.lex_state = 29},
  [1298] = {.lex_state = 819},
  [1299] = {.lex_state = 0},
  [1300] = {.lex_state = 0},
  [1301] = {.lex_state = 21},
  [1302] = {.lex_state = 0},
  [1303] = {.lex_state = 0},
  [1304] = {.lex_state = 0},
  [1305] = {.lex_state = 0},
  [1306] = {.lex_state = 0},
  [1307] = {.lex_state = 0},
  [1308] = {.lex_state = 21},
  [1309] = {.lex_state = 0},
  [1310] = {.lex_state = 0},
  [1311] = {.lex_state = 0},
  [1312] = {.lex_state = 0},
  [1313] = {.lex_state = 0},
  [1314] = {.lex_state = 0},
  [1315] = {.lex_state = 0},
  [1316] = {.lex_state = 0},
  [1317] = {.lex_state = 30},
  [1318] = {.lex_state = 0},
  [1319] = {.lex_state = 0},
  [1320] = {.lex_state = 30},
  [1321] = {.lex_state = 0},
  [1322] = {.lex_state = 0},
  [1323] = {.lex_state = 21},
  [1324] = {.lex_state = 0},
  [1325] = {.lex_state = 0},
  [1326] = {.lex_state = 0},
  [1327] = {.lex_state = 0},
  [1328] = {.lex_state = 0},
  [1329] = {.lex_state = 21},
  [1330] = {.lex_state = 0},
  [1331] = {.lex_state = 0},
  [1332] = {.lex_state = 0},
  [1333] = {.lex_state = 35},
  [1334] = {.lex_state = 35},
  [1335] = {.lex_state = 0},
  [1336] = {.lex_state = 0},
  [1337] = {.lex_state = 0},
  [1338] = {.lex_state = 0},
  [1339] = {.lex_state = 35},
  [1340] = {.lex_state = 0},
  [1341] = {.lex_state = 0},
  [1342] = {.lex_state = 0},
  [1343] = {.lex_state = 0},
  [1344] = {.lex_state = 0},
  [1345] = {.lex_state = 35},
  [1346] = {.lex_state = 35},
  [1347] = {.lex_state = 0},
  [1348] = {.lex_state = 0},
  [1349] = {.lex_state = 35},
  [1350] = {.lex_state = 0},
  [1351] = {.lex_state = 35},
  [1352] = {.lex_state = 0},
  [1353] = {.lex_state = 0},
  [1354] = {.lex_state = 35},
  [1355] = {.lex_state = 0},
  [1356] = {.lex_state = 0},
  [1357] = {.lex_state = 21},
  [1358] = {.lex_state = 0},
  [1359] = {.lex_state = 0},
  [1360] = {.lex_state = 35},
  [1361] = {.lex_state = 0},
  [1362] = {.lex_state = 30},
  [1363] = {.lex_state = 0},
  [1364] = {.lex_state = 35},
  [1365] = {.lex_state = 0},
  [1366] = {.lex_state = 0},
  [1367] = {.lex_state = 0},
  [1368] = {.lex_state = 0},
  [1369] = {.lex_state = 0},
  [1370] = {.lex_state = 0},
  [1371] = {.lex_state = 0},
  [1372] = {.lex_state = 0},
  [1373] = {.lex_state = 0},
  [1374] = {.lex_state = 0},
  [1375] = {.lex_state = 0},
  [1376] = {.lex_state = 0},
  [1377] = {.lex_state = 30},
  [1378] = {.lex_state = 0},
  [1379] = {.lex_state = 0},
  [1380] = {.lex_state = 0},
  [1381] = {.lex_state = 29},
  [1382] = {.lex_state = 0},
  [1383] = {.lex_state = 21},
  [1384] = {.lex_state = 0},
  [1385] = {.lex_state = 0},
  [1386] = {.lex_state = 21},
  [1387] = {.lex_state = 819},
  [1388] = {.lex_state = 0},
  [1389] = {.lex_state = 0},
  [1390] = {.lex_state = 30},
  [1391] = {.lex_state = 0},
  [1392] = {.lex_state = 0},
  [1393] = {.lex_state = 21},
  [1394] = {.lex_state = 21},
  [1395] = {.lex_state = 0},
  [1396] = {.lex_state = 819},
  [1397] = {.lex_state = 0},
  [1398] = {.lex_state = 819},
  [1399] = {.lex_state = 21},
  [1400] = {.lex_state = 0},
  [1401] = {.lex_state = 21},
  [1402] = {.lex_state = 0},
  [1403] = {.lex_state = 0},
  [1404] = {.lex_state = 35},
  [1405] = {.lex_state = 0},
  [1406] = {.lex_state = 0},
  [1407] = {.lex_state = 21},
  [1408] = {.lex_state = 0},
  [1409] = {.lex_state = 0},
  [1410] = {.lex_state = 819},
  [1411] = {.lex_state = 0},
  [1412] = {.lex_state = 0},
  [1413] = {.lex_state = 0},
  [1414] = {.lex_state = 0},
  [1415] = {.lex_state = 30},
  [1416] = {.lex_state = 0},
  [1417] = {.lex_state = 0},
  [1418] = {.lex_state = 0},
  [1419] = {.lex_state = 0},
  [1420] = {.lex_state = 0},
  [1421] = {.lex_state = 0},
  [1422] = {.lex_state = 0},
  [1423] = {.lex_state = 0},
  [1424] = {.lex_state = 0},
  [1425] = {.lex_state = 0},
  [1426] = {.lex_state = 21},
  [1427] = {.lex_state = 21},
  [1428] = {.lex_state = 0},
  [1429] = {.lex_state = 0},
  [1430] = {.lex_state = 0},
  [1431] = {.lex_state = 0},
  [1432] = {.lex_state = 0},
  [1433] = {.lex_state = 0},
  [1434] = {.lex_state = 21},
  [1435] = {.lex_state = 821},
  [1436] = {.lex_state = 821},
  [1437] = {.lex_state = 0},
  [1438] = {.lex_state = 0},
  [1439] = {.lex_state = 0},
  [1440] = {.lex_state = 0},
  [1441] = {.lex_state = 0},
  [1442] = {.lex_state = 0},
  [1443] = {.lex_state = 21},
  [1444] = {.lex_state = 0},
  [1445] = {.lex_state = 0},
  [1446] = {.lex_state = 21},
  [1447] = {.lex_state = 0},
  [1448] = {.lex_state = 0},
  [1449] = {.lex_state = 0},
  [1450] = {.lex_state = 21},
  [1451] = {.lex_state = 0},
  [1452] = {.lex_state = 0},
  [1453] = {.lex_state = 0},
  [1454] = {.lex_state = 0},
  [1455] = {.lex_state = 0},
  [1456] = {.lex_state = 0},
  [1457] = {.lex_state = 36},
  [1458] = {.lex_state = 0},
  [1459] = {.lex_state = 0},
  [1460] = {.lex_state = 0},
  [1461] = {.lex_state = 821},
  [1462] = {.lex_state = 0},
  [1463] = {.lex_state = 0},
  [1464] = {.lex_state = 0},
  [1465] = {.lex_state = 0},
  [1466] = {.lex_state = 0},
  [1467] = {.lex_state = 0},
  [1468] = {.lex_state = 0},
  [1469] = {.lex_state = 21},
  [1470] = {.lex_state = 0},
  [1471] = {.lex_state = 21},
  [1472] = {.lex_state = 0},
  [1473] = {.lex_state = 0},
  [1474] = {.lex_state = 0},
  [1475] = {.lex_state = 0},
  [1476] = {.lex_state = 0},
  [1477] = {.lex_state = 0},
  [1478] = {.lex_state = 0},
  [1479] = {.lex_state = 21},
  [1480] = {.lex_state = 21},
  [1481] = {.lex_state = 0},
  [1482] = {.lex_state = 0},
  [1483] = {.lex_state = 0},
  [1484] = {.lex_state = 0},
  [1485] = {.lex_state = 0},
  [1486] = {.lex_state = 842},
  [1487] = {.lex_state = 821},
  [1488] = {.lex_state = 0},
  [1489] = {.lex_state = 821},
  [1490] = {.lex_state = 21},
  [1491] = {.lex_state = 0},
  [1492] = {.lex_state = 21},
  [1493] = {.lex_state = 21},
  [1494] = {.lex_state = 21},
  [1495] = {.lex_state = 36},
  [1496] = {.lex_state = 21},
  [1497] = {.lex_state = 0},
  [1498] = {.lex_state = 0},
  [1499] = {.lex_state = 21},
  [1500] = {.lex_state = 21},
  [1501] = {.lex_state = 818},
  [1502] = {.lex_state = 0},
  [1503] = {.lex_state = 0},
  [1504] = {.lex_state = 0},
  [1505] = {.lex_state = 0},
  [1506] = {.lex_state = 0},
  [1507] = {.lex_state = 21},
  [1508] = {.lex_state = 0},
  [1509] = {.lex_state = 0},
  [1510] = {.lex_state = 0},
  [1511] = {.lex_state = 0},
  [1512] = {.lex_state = 0},
  [1513] = {.lex_state = 821},
  [1514] = {.lex_state = 821},
  [1515] = {.lex_state = 34},
  [1516] = {.lex_state = 0},
  [1517] = {.lex_state = 21},
  [1518] = {.lex_state = 0},
  [1519] = {.lex_state = 21},
  [1520] = {.lex_state = 32},
  [1521] = {.lex_state = 21},
  [1522] = {.lex_state = 0},
  [1523] = {.lex_state = 819},
  [1524] = {.lex_state = 0},
  [1525] = {.lex_state = 0},
  [1526] = {.lex_state = 0},
  [1527] = {.lex_state = 0},
  [1528] = {.lex_state = 0},
  [1529] = {.lex_state = 0},
  [1530] = {.lex_state = 821},
  [1531] = {.lex_state = 21},
  [1532] = {.lex_state = 818},
  [1533] = {.lex_state = 37},
  [1534] = {.lex_state = 0},
  [1535] = {.lex_state = 0},
  [1536] = {.lex_state = 0},
  [1537] = {.lex_state = 821},
  [1538] = {.lex_state = 821},
  [1539] = {.lex_state = 0},
  [1540] = {.lex_state = 0},
  [1541] = {.lex_state = 0},
  [1542] = {.lex_state = 821},
  [1543] = {.lex_state = 821},
  [1544] = {.lex_state = 0},
  [1545] = {.lex_state = 0},
  [1546] = {.lex_state = 821},
  [1547] = {.lex_state = 821},
  [1548] = {.lex_state = 821},
  [1549] = {.lex_state = 0},
  [1550] = {.lex_state = 821},
  [1551] = {.lex_state = 0},
  [1552] = {.lex_state = 0},
  [1553] = {.lex_state = 0},
  [1554] = {.lex_state = 37},
  [1555] = {.lex_state = 0},
  [1556] = {.lex_state = 0},
  [1557] = {.lex_state = 0},
  [1558] = {.lex_state = 0},
  [1559] = {.lex_state = 0},
  [1560] = {.lex_state = 21},
  [1561] = {.lex_state = 0},
  [1562] = {.lex_state = 21},
  [1563] = {.lex_state = 34},
  [1564] = {.lex_state = 0},
  [1565] = {.lex_state = 0},
  [1566] = {.lex_state = 821},
  [1567] = {.lex_state = 0},
  [1568] = {.lex_state = 0},
  [1569] = {.lex_state = 0},
  [1570] = {.lex_state = 0},
  [1571] = {.lex_state = 33},
  [1572] = {.lex_state = 21},
  [1573] = {.lex_state = 21},
  [1574] = {.lex_state = 21},
  [1575] = {.lex_state = 21},
  [1576] = {.lex_state = 21},
  [1577] = {.lex_state = 0},
  [1578] = {.lex_state = 21},
  [1579] = {.lex_state = 21},
  [1580] = {.lex_state = 21},
  [1581] = {.lex_state = 21},
  [1582] = {.lex_state = 0},
  [1583] = {.lex_state = 21},
  [1584] = {.lex_state = 0},
  [1585] = {.lex_state = 21},
  [1586] = {.lex_state = 21},
  [1587] = {.lex_state = 0},
  [1588] = {.lex_state = 21},
  [1589] = {.lex_state = 21},
  [1590] = {.lex_state = 21},
  [1591] = {.lex_state = 15},
  [1592] = {.lex_state = 33},
  [1593] = {.lex_state = 0},
  [1594] = {.lex_state = 0},
  [1595] = {.lex_state = 0},
  [1596] = {.lex_state = 21},
  [1597] = {.lex_state = 0},
  [1598] = {.lex_state = 0},
  [1599] = {.lex_state = 0},
  [1600] = {.lex_state = 0},
  [1601] = {.lex_state = 0},
  [1602] = {.lex_state = 21},
  [1603] = {.lex_state = 821},
  [1604] = {.lex_state = 33},
  [1605] = {.lex_state = 21},
  [1606] = {.lex_state = 0},
  [1607] = {.lex_state = 0},
  [1608] = {.lex_state = 0},
  [1609] = {.lex_state = 21},
  [1610] = {.lex_state = 0},
  [1611] = {.lex_state = 0},
  [1612] = {.lex_state = 21},
  [1613] = {.lex_state = 21},
  [1614] = {.lex_state = 15},
  [1615] = {.lex_state = 15},
  [1616] = {.lex_state = 0},
  [1617] = {.lex_state = 0},
  [1618] = {.lex_state = 0},
  [1619] = {.lex_state = 0},
  [1620] = {.lex_state = 0},
  [1621] = {.lex_state = 0},
  [1622] = {.lex_state = 21},
  [1623] = {.lex_state = 21},
  [1624] = {.lex_state = 0},
  [1625] = {.lex_state = 21},
  [1626] = {.lex_state = 0},
  [1627] = {.lex_state = 0},
  [1628] = {.lex_state = 0},
  [1629] = {.lex_state = 21},
  [1630] = {.lex_state = 21},
  [1631] = {.lex_state = 21},
  [1632] = {.lex_state = 0},
  [1633] = {.lex_state = 0},
  [1634] = {.lex_state = 0},
  [1635] = {.lex_state = 0},
  [1636] = {.lex_state = 0},
  [1637] = {.lex_state = 0},
  [1638] = {.lex_state = 0},
  [1639] = {.lex_state = 0},
  [1640] = {.lex_state = 0},
  [1641] = {.lex_state = 819},
  [1642] = {.lex_state = 0},
  [1643] = {.lex_state = 0},
  [1644] = {.lex_state = 21},
  [1645] = {.lex_state = 821},
  [1646] = {.lex_state = 0},
  [1647] = {.lex_state = 0},
  [1648] = {.lex_state = 21},
  [1649] = {.lex_state = 0},
  [1650] = {.lex_state = 0},
  [1651] = {.lex_state = 21},
  [1652] = {.lex_state = 15},
  [1653] = {.lex_state = 21},
  [1654] = {.lex_state = 15},
  [1655] = {.lex_state = 0},
  [1656] = {.lex_state = 0},
  [1657] = {.lex_state = 0},
  [1658] = {.lex_state = 21},
  [1659] = {.lex_state = 0},
  [1660] = {.lex_state = 21},
  [1661] = {.lex_state = 21},
  [1662] = {.lex_state = 21},
  [1663] = {.lex_state = 21},
  [1664] = {.lex_state = 21},
  [1665] = {.lex_state = 21},
  [1666] = {.lex_state = 0},
  [1667] = {.lex_state = 0},
  [1668] = {.lex_state = 0},
  [1669] = {.lex_state = 0},
  [1670] = {.lex_state = 21},
  [1671] = {.lex_state = 21},
  [1672] = {.lex_state = 21},
  [1673] = {.lex_state = 21},
  [1674] = {.lex_state = 21},
  [1675] = {.lex_state = 21},
  [1676] = {.lex_state = 21},
  [1677] = {.lex_state = 15},
  [1678] = {.lex_state = 21},
  [1679] = {.lex_state = 0},
  [1680] = {.lex_state = 0},
  [1681] = {.lex_state = 36},
  [1682] = {.lex_state = 33},
  [1683] = {.lex_state = 0},
  [1684] = {.lex_state = 21},
  [1685] = {.lex_state = 0},
  [1686] = {.lex_state = 0},
  [1687] = {.lex_state = 21},
  [1688] = {.lex_state = 0},
  [1689] = {.lex_state = 0},
  [1690] = {.lex_state = 0},
  [1691] = {.lex_state = 0},
  [1692] = {.lex_state = 0},
  [1693] = {.lex_state = 0},
  [1694] = {.lex_state = 0},
  [1695] = {.lex_state = 0},
  [1696] = {.lex_state = 818},
  [1697] = {.lex_state = 0},
  [1698] = {.lex_state = 0},
  [1699] = {.lex_state = 0},
  [1700] = {.lex_state = 0},
  [1701] = {.lex_state = 0},
  [1702] = {.lex_state = 0},
  [1703] = {.lex_state = 0},
  [1704] = {.lex_state = 0},
  [1705] = {.lex_state = 0},
  [1706] = {.lex_state = 818},
  [1707] = {.lex_state = 0},
  [1708] = {.lex_state = 0},
  [1709] = {.lex_state = 0},
  [1710] = {.lex_state = 0},
  [1711] = {.lex_state = 0},
  [1712] = {.lex_state = 0},
  [1713] = {.lex_state = 0},
  [1714] = {.lex_state = 842},
  [1715] = {.lex_state = 15},
  [1716] = {.lex_state = 0},
  [1717] = {.lex_state = 0},
  [1718] = {.lex_state = 0},
  [1719] = {.lex_state = 0},
  [1720] = {.lex_state = 0},
  [1721] = {.lex_state = 0},
  [1722] = {.lex_state = 0},
  [1723] = {.lex_state = 0},
  [1724] = {.lex_state = 0},
  [1725] = {.lex_state = 0},
  [1726] = {.lex_state = 0},
  [1727] = {.lex_state = 0},
  [1728] = {.lex_state = 0},
  [1729] = {.lex_state = 0},
  [1730] = {.lex_state = 0},
  [1731] = {.lex_state = 0},
  [1732] = {.lex_state = 0},
  [1733] = {.lex_state = 0},
  [1734] = {.lex_state = 0},
  [1735] = {.lex_state = 0},
  [1736] = {.lex_state = 842},
  [1737] = {.lex_state = 0},
  [1738] = {.lex_state = 0},
  [1739] = {.lex_state = 0},
  [1740] = {.lex_state = 0},
  [1741] = {.lex_state = 0},
  [1742] = {.lex_state = 0},
  [1743] = {.lex_state = 0},
  [1744] = {.lex_state = 842},
  [1745] = {.lex_state = 0},
  [1746] = {.lex_state = 0},
  [1747] = {.lex_state = 0},
  [1748] = {.lex_state = 0},
  [1749] = {.lex_state = 0},
  [1750] = {.lex_state = 0},
  [1751] = {.lex_state = 0},
  [1752] = {.lex_state = 0},
  [1753] = {.lex_state = 0},
  [1754] = {.lex_state = 0},
  [1755] = {.lex_state = 0},
  [1756] = {.lex_state = 0},
  [1757] = {.lex_state = 0},
  [1758] = {.lex_state = 0},
  [1759] = {.lex_state = 842},
  [1760] = {.lex_state = 0},
  [1761] = {.lex_state = 0},
  [1762] = {.lex_state = 0},
  [1763] = {.lex_state = 0},
  [1764] = {.lex_state = 0},
  [1765] = {.lex_state = 0},
  [1766] = {.lex_state = 0},
  [1767] = {.lex_state = 0},
  [1768] = {.lex_state = 0},
  [1769] = {.lex_state = 842},
  [1770] = {.lex_state = 842},
  [1771] = {.lex_state = 842},
  [1772] = {.lex_state = 0},
  [1773] = {.lex_state = 818},
  [1774] = {.lex_state = 0},
  [1775] = {.lex_state = 0},
  [1776] = {.lex_state = 0},
  [1777] = {.lex_state = 0},
  [1778] = {.lex_state = 0},
  [1779] = {.lex_state = 0},
  [1780] = {.lex_state = 0},
  [1781] = {.lex_state = 0},
  [1782] = {.lex_state = 15},
  [1783] = {.lex_state = 33},
  [1784] = {.lex_state = 0},
  [1785] = {.lex_state = 0},
  [1786] = {.lex_state = 0},
  [1787] = {.lex_state = 15},
  [1788] = {.lex_state = 0},
  [1789] = {.lex_state = 0},
  [1790] = {.lex_state = 0},
  [1791] = {.lex_state = 0},
  [1792] = {.lex_state = 0},
  [1793] = {.lex_state = 0},
  [1794] = {.lex_state = 15},
  [1795] = {.lex_state = 0},
  [1796] = {.lex_state = 0},
  [1797] = {.lex_state = 0},
  [1798] = {.lex_state = 0},
  [1799] = {.lex_state = 0},
  [1800] = {.lex_state = 0},
  [1801] = {.lex_state = 0},
  [1802] = {.lex_state = 15},
  [1803] = {.lex_state = 0},
  [1804] = {.lex_state = 0},
  [1805] = {.lex_state = 0},
  [1806] = {.lex_state = 842},
  [1807] = {.lex_state = 0},
  [1808] = {.lex_state = 0},
  [1809] = {.lex_state = 842},
  [1810] = {.lex_state = 842},
  [1811] = {.lex_state = 0},
  [1812] = {.lex_state = 0},
  [1813] = {.lex_state = 0},
  [1814] = {.lex_state = 0},
  [1815] = {.lex_state = 0},
  [1816] = {.lex_state = 0},
  [1817] = {.lex_state = 0},
  [1818] = {.lex_state = 0},
  [1819] = {.lex_state = 0},
  [1820] = {.lex_state = 0},
  [1821] = {.lex_state = 0},
  [1822] = {.lex_state = 0},
  [1823] = {.lex_state = 0},
  [1824] = {.lex_state = 819},
  [1825] = {.lex_state = 0},
  [1826] = {.lex_state = 15},
  [1827] = {.lex_state = 0},
  [1828] = {.lex_state = 0},
  [1829] = {.lex_state = 0},
  [1830] = {.lex_state = 0},
  [1831] = {.lex_state = 842},
  [1832] = {.lex_state = 0},
  [1833] = {.lex_state = 0},
  [1834] = {.lex_state = 0},
  [1835] = {.lex_state = 0},
  [1836] = {.lex_state = 0},
  [1837] = {.lex_state = 15},
  [1838] = {.lex_state = 0},
  [1839] = {.lex_state = 0},
  [1840] = {.lex_state = 0},
  [1841] = {.lex_state = 0},
  [1842] = {.lex_state = 0},
  [1843] = {.lex_state = 15},
  [1844] = {.lex_state = 0},
  [1845] = {.lex_state = 0},
  [1846] = {.lex_state = 0},
  [1847] = {.lex_state = 0},
  [1848] = {.lex_state = 0},
  [1849] = {.lex_state = 0},
  [1850] = {.lex_state = 0},
  [1851] = {.lex_state = 0},
  [1852] = {.lex_state = 0},
  [1853] = {.lex_state = 0},
  [1854] = {.lex_state = 0},
  [1855] = {.lex_state = 0},
  [1856] = {.lex_state = 0},
  [1857] = {.lex_state = 0},
  [1858] = {.lex_state = 818},
  [1859] = {.lex_state = 818},
  [1860] = {.lex_state = 818},
  [1861] = {.lex_state = 0},
  [1862] = {.lex_state = 0},
  [1863] = {.lex_state = 0},
  [1864] = {.lex_state = 0},
  [1865] = {.lex_state = 0},
  [1866] = {.lex_state = 842},
  [1867] = {.lex_state = 0},
  [1868] = {.lex_state = 842},
  [1869] = {.lex_state = 842},
  [1870] = {.lex_state = 842},
  [1871] = {.lex_state = 0},
  [1872] = {.lex_state = 33},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(1),
    [sym_keyword_on] = ACTIONS(1),
    [sym_keyword_let] = ACTIONS(1),
    [sym_keyword_return] = ACTIONS(1),
    [sym_keyword_else] = ACTIONS(1),
    [sym_keyword_end] = ACTIONS(1),
    [sym_keyword_select] = ACTIONS(1),
    [sym_keyword_from] = ACTIONS(1),
    [sym_keyword_value] = ACTIONS(1),
    [sym_keyword_as] = ACTIONS(1),
    [sym_keyword_omit] = ACTIONS(1),
    [sym_keyword_explain] = ACTIONS(1),
    [sym_keyword_full] = ACTIONS(1),
    [sym_keyword_parallel] = ACTIONS(1),
    [sym_keyword_timeout] = ACTIONS(1),
    [sym_keyword_fetch] = ACTIONS(1),
    [sym_keyword_start_at] = ACTIONS(1),
    [sym_keyword_limit] = ACTIONS(1),
    [sym_keyword_by] = ACTIONS(1),
    [sym_keyword_rand] = ACTIONS(1),
    [sym_keyword_collate] = ACTIONS(1),
    [sym_keyword_numeric] = ACTIONS(1),
    [sym_keyword_desc] = ACTIONS(1),
    [sym_keyword_order] = ACTIONS(1),
    [sym_keyword_with] = ACTIONS(1),
    [sym_keyword_no_index] = ACTIONS(1),
    [sym_keyword_where] = ACTIONS(1),
    [sym_keyword_split] = ACTIONS(1),
    [sym_keyword_at] = ACTIONS(1),
    [sym_keyword_group] = ACTIONS(1),
    [sym_keyword_all] = ACTIONS(1),
    [sym_keyword_true] = ACTIONS(1),
    [sym_keyword_false] = ACTIONS(1),
    [sym_keyword_begin] = ACTIONS(1),
    [sym_keyword_cancel] = ACTIONS(1),
    [sym_keyword_commit] = ACTIONS(1),
    [sym_keyword_transaction] = ACTIONS(1),
    [sym_keyword_none] = ACTIONS(1),
    [sym_keyword_null] = ACTIONS(1),
    [sym_keyword_and] = ACTIONS(1),
    [sym_keyword_or] = ACTIONS(1),
    [sym_keyword_is] = ACTIONS(1),
    [sym_keyword_not] = ACTIONS(1),
    [sym_keyword_contains] = ACTIONS(1),
    [sym_keyword_contains_not] = ACTIONS(1),
    [sym_keyword_contains_all] = ACTIONS(1),
    [sym_keyword_contains_any] = ACTIONS(1),
    [sym_keyword_contains_none] = ACTIONS(1),
    [sym_keyword_inside] = ACTIONS(1),
    [sym_keyword_in] = ACTIONS(1),
    [sym_keyword_not_inside] = ACTIONS(1),
    [sym_keyword_all_inside] = ACTIONS(1),
    [sym_keyword_any_inside] = ACTIONS(1),
    [sym_keyword_intersects] = ACTIONS(1),
    [sym_keyword_chebyshev] = ACTIONS(1),
    [sym_keyword_cosine] = ACTIONS(1),
    [sym_keyword_euclidean] = ACTIONS(1),
    [sym_keyword_hamming] = ACTIONS(1),
    [sym_keyword_jaccard] = ACTIONS(1),
    [sym_keyword_manhattan] = ACTIONS(1),
    [sym_keyword_minkowski] = ACTIONS(1),
    [sym_keyword_pearson] = ACTIONS(1),
    [sym_keyword_define] = ACTIONS(1),
    [sym_keyword_analyzer] = ACTIONS(1),
    [sym_keyword_event] = ACTIONS(1),
    [sym_keyword_field] = ACTIONS(1),
    [sym_keyword_function] = ACTIONS(1),
    [sym_keyword_namespace] = ACTIONS(1),
    [sym_keyword_param] = ACTIONS(1),
    [sym_keyword_scope] = ACTIONS(1),
    [sym_keyword_drop] = ACTIONS(1),
    [sym_keyword_schemafull] = ACTIONS(1),
    [sym_keyword_schemaless] = ACTIONS(1),
    [sym_keyword_live] = ACTIONS(1),
    [sym_keyword_diff] = ACTIONS(1),
    [sym_keyword_flexible] = ACTIONS(1),
    [sym_keyword_readonly] = ACTIONS(1),
    [sym_keyword_jwks] = ACTIONS(1),
    [sym_keyword_eddsa] = ACTIONS(1),
    [sym_keyword_es256] = ACTIONS(1),
    [sym_keyword_es384] = ACTIONS(1),
    [sym_keyword_es512] = ACTIONS(1),
    [sym_keyword_ps256] = ACTIONS(1),
    [sym_keyword_ps384] = ACTIONS(1),
    [sym_keyword_ps512] = ACTIONS(1),
    [sym_keyword_rs256] = ACTIONS(1),
    [sym_keyword_rs384] = ACTIONS(1),
    [sym_keyword_rs512] = ACTIONS(1),
    [sym_keyword_bm25] = ACTIONS(1),
    [sym_keyword_doc_ids_cache] = ACTIONS(1),
    [sym_keyword_doc_ids_order] = ACTIONS(1),
    [sym_keyword_doc_lengths_cache] = ACTIONS(1),
    [sym_keyword_doc_lengths_order] = ACTIONS(1),
    [sym_keyword_postings_cache] = ACTIONS(1),
    [sym_keyword_postings_order] = ACTIONS(1),
    [sym_keyword_terms_cache] = ACTIONS(1),
    [sym_keyword_terms_order] = ACTIONS(1),
    [sym_keyword_highlights] = ACTIONS(1),
    [sym_keyword_any] = ACTIONS(1),
    [sym_keyword_normal] = ACTIONS(1),
    [sym_keyword_relation] = ACTIONS(1),
    [sym_keyword_out] = ACTIONS(1),
    [sym_keyword_to] = ACTIONS(1),
    [sym_keyword_changefeed] = ACTIONS(1),
    [sym_keyword_content] = ACTIONS(1),
    [sym_keyword_merge] = ACTIONS(1),
    [sym_keyword_patch] = ACTIONS(1),
    [sym_keyword_before] = ACTIONS(1),
    [sym_keyword_after] = ACTIONS(1),
    [sym_keyword_table] = ACTIONS(1),
    [sym_keyword_root] = ACTIONS(1),
    [sym_keyword_use] = ACTIONS(1),
    [sym_keyword_ns] = ACTIONS(1),
    [sym_keyword_db] = ACTIONS(1),
    [sym_keyword_user] = ACTIONS(1),
    [sym_keyword_roles] = ACTIONS(1),
    [sym_keyword_remove] = ACTIONS(1),
    [sym_keyword_create] = ACTIONS(1),
    [sym_keyword_delete] = ACTIONS(1),
    [sym_keyword_update] = ACTIONS(1),
    [sym_keyword_filters] = ACTIONS(1),
    [sym_keyword_when] = ACTIONS(1),
    [sym_keyword_then] = ACTIONS(1),
    [sym_keyword_type] = ACTIONS(1),
    [sym_keyword_default] = ACTIONS(1),
    [sym_keyword_permissions] = ACTIONS(1),
    [sym_keyword_relate] = ACTIONS(1),
    [sym_keyword_ignore] = ACTIONS(1),
    [sym_keyword_for] = ACTIONS(1),
    [sym_keyword_comment] = ACTIONS(1),
    [sym_keyword_columns] = ACTIONS(1),
    [sym_keyword_unique] = ACTIONS(1),
    [sym_keyword_search] = ACTIONS(1),
    [sym_keyword_session] = ACTIONS(1),
    [sym_keyword_signin] = ACTIONS(1),
    [sym_keyword_signup] = ACTIONS(1),
    [sym_keyword_if] = ACTIONS(1),
    [sym_keyword_exists] = ACTIONS(1),
    [sym_keyword_database] = ACTIONS(1),
    [sym_keyword_password] = ACTIONS(1),
    [sym_keyword_password_hash] = ACTIONS(1),
    [sym_keyword_count] = ACTIONS(1),
    [sym_keyword_set] = ACTIONS(1),
    [sym_keyword_unset] = ACTIONS(1),
    [sym_keyword_dimension] = ACTIONS(1),
    [sym_keyword_mtree] = ACTIONS(1),
    [sym_keyword_dist] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_LT_DASH] = ACTIONS(1),
    [anon_sym_LT_DASH_GT] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_blank] = ACTIONS(1),
    [anon_sym_camel] = ACTIONS(1),
    [anon_sym_class] = ACTIONS(1),
    [anon_sym_punct] = ACTIONS(1),
    [anon_sym_ascii] = ACTIONS(1),
    [anon_sym_lowercase] = ACTIONS(1),
    [anon_sym_uppercase] = ACTIONS(1),
    [anon_sym_edgengram] = ACTIONS(1),
    [anon_sym_ngram] = ACTIONS(1),
    [anon_sym_snowball] = ACTIONS(1),
    [sym_string] = ACTIONS(1),
    [sym_prefixed_string] = ACTIONS(1),
    [sym_int] = ACTIONS(1),
    [sym_variable_name] = ACTIONS(1),
    [sym_custom_function_name] = ACTIONS(1),
    [anon_sym_DOT_DOT] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [sym_duration_part] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_LT_PIPE] = ACTIONS(1),
    [anon_sym_PIPE_GT] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_QMARK_QMARK] = ACTIONS(1),
    [anon_sym_QMARK_COLON] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_QMARK_EQ] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_BANG_TILDE] = ACTIONS(1),
    [anon_sym_STAR_TILDE] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_u00d7] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_u00f7] = ACTIONS(1),
    [anon_sym_STAR_STAR] = ACTIONS(1),
    [anon_sym_u220b] = ACTIONS(1),
    [anon_sym_u220c] = ACTIONS(1),
    [anon_sym_u2287] = ACTIONS(1),
    [anon_sym_u2283] = ACTIONS(1),
    [anon_sym_u2285] = ACTIONS(1),
    [anon_sym_u2208] = ACTIONS(1),
    [anon_sym_u2209] = ACTIONS(1),
    [anon_sym_u2286] = ACTIONS(1),
    [anon_sym_u2282] = ACTIONS(1),
    [anon_sym_u2284] = ACTIONS(1),
    [anon_sym_AT_AT] = ACTIONS(1),
  },
  [1] = {
    [sym_source_file] = STATE(1834),
    [sym_expressions] = STATE(1833),
    [sym_expression] = STATE(1437),
    [sym_statement] = STATE(1384),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_where_clause] = STATE(1833),
    [sym_value] = STATE(591),
    [sym_function_call] = STATE(99),
    [sym_base_value] = STATE(168),
    [sym_binary_expression] = STATE(99),
    [sym_path] = STATE(99),
    [sym_graph_path] = STATE(162),
    [sym_number] = STATE(58),
    [sym_identifier] = STATE(58),
    [sym_array] = STATE(58),
    [sym_object] = STATE(58),
    [sym_object_key] = STATE(1827),
    [sym_record_id] = STATE(58),
    [sym_sub_query] = STATE(58),
    [sym_duration] = STATE(58),
    [sym_point] = STATE(58),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(5),
    [sym_keyword_rand] = ACTIONS(7),
    [sym_keyword_where] = ACTIONS(9),
    [sym_keyword_true] = ACTIONS(11),
    [sym_keyword_false] = ACTIONS(11),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(11),
    [sym_keyword_null] = ACTIONS(11),
    [sym_keyword_define] = ACTIONS(19),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(23),
    [sym_keyword_delete] = ACTIONS(25),
    [sym_keyword_update] = ACTIONS(27),
    [sym_keyword_insert] = ACTIONS(29),
    [sym_keyword_relate] = ACTIONS(31),
    [sym_keyword_count] = ACTIONS(33),
    [anon_sym_DASH_GT] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(43),
    [anon_sym_LT_DASH_GT] = ACTIONS(35),
    [aux_sym_type_name_token1] = ACTIONS(45),
    [sym_string] = ACTIONS(47),
    [sym_prefixed_string] = ACTIONS(47),
    [sym_int] = ACTIONS(49),
    [sym_float] = ACTIONS(49),
    [sym_decimal] = ACTIONS(51),
    [sym_variable_name] = ACTIONS(47),
    [sym_custom_function_name] = ACTIONS(7),
    [sym_function_name] = ACTIONS(7),
    [sym_duration_part] = ACTIONS(53),
  },
  [2] = {
    [ts_builtin_sym_end] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(55),
    [sym_keyword_on] = ACTIONS(55),
    [sym_keyword_return] = ACTIONS(55),
    [sym_keyword_from] = ACTIONS(55),
    [sym_keyword_as] = ACTIONS(55),
    [sym_keyword_explain] = ACTIONS(55),
    [sym_keyword_parallel] = ACTIONS(55),
    [sym_keyword_timeout] = ACTIONS(55),
    [sym_keyword_where] = ACTIONS(55),
    [sym_keyword_group] = ACTIONS(55),
    [sym_keyword_and] = ACTIONS(55),
    [sym_keyword_or] = ACTIONS(55),
    [sym_keyword_is] = ACTIONS(55),
    [sym_keyword_not] = ACTIONS(57),
    [sym_keyword_contains] = ACTIONS(55),
    [sym_keyword_contains_not] = ACTIONS(55),
    [sym_keyword_contains_all] = ACTIONS(55),
    [sym_keyword_contains_any] = ACTIONS(55),
    [sym_keyword_contains_none] = ACTIONS(55),
    [sym_keyword_inside] = ACTIONS(55),
    [sym_keyword_in] = ACTIONS(57),
    [sym_keyword_not_inside] = ACTIONS(55),
    [sym_keyword_all_inside] = ACTIONS(55),
    [sym_keyword_any_inside] = ACTIONS(55),
    [sym_keyword_none_inside] = ACTIONS(55),
    [sym_keyword_outside] = ACTIONS(55),
    [sym_keyword_intersects] = ACTIONS(55),
    [sym_keyword_function] = ACTIONS(55),
    [sym_keyword_drop] = ACTIONS(55),
    [sym_keyword_schemafull] = ACTIONS(55),
    [sym_keyword_schemaless] = ACTIONS(55),
    [sym_keyword_bm25] = ACTIONS(55),
    [sym_keyword_doc_ids_cache] = ACTIONS(55),
    [sym_keyword_doc_ids_order] = ACTIONS(55),
    [sym_keyword_doc_lengths_cache] = ACTIONS(55),
    [sym_keyword_doc_lengths_order] = ACTIONS(55),
    [sym_keyword_postings_cache] = ACTIONS(55),
    [sym_keyword_postings_order] = ACTIONS(55),
    [sym_keyword_terms_cache] = ACTIONS(55),
    [sym_keyword_terms_order] = ACTIONS(55),
    [sym_keyword_highlights] = ACTIONS(55),
    [sym_keyword_changefeed] = ACTIONS(55),
    [sym_keyword_content] = ACTIONS(55),
    [sym_keyword_merge] = ACTIONS(55),
    [sym_keyword_patch] = ACTIONS(55),
    [sym_keyword_tokenizers] = ACTIONS(55),
    [sym_keyword_filters] = ACTIONS(55),
    [sym_keyword_when] = ACTIONS(55),
    [sym_keyword_then] = ACTIONS(55),
    [sym_keyword_type] = ACTIONS(55),
    [sym_keyword_permissions] = ACTIONS(55),
    [sym_keyword_for] = ACTIONS(55),
    [sym_keyword_comment] = ACTIONS(55),
    [sym_keyword_fields] = ACTIONS(55),
    [sym_keyword_columns] = ACTIONS(55),
    [sym_keyword_unique] = ACTIONS(55),
    [sym_keyword_search] = ACTIONS(55),
    [sym_keyword_session] = ACTIONS(55),
    [sym_keyword_signin] = ACTIONS(55),
    [sym_keyword_signup] = ACTIONS(55),
    [sym_keyword_set] = ACTIONS(55),
    [sym_keyword_unset] = ACTIONS(55),
    [anon_sym_COMMA] = ACTIONS(55),
    [anon_sym_DASH_GT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(55),
    [anon_sym_LPAREN] = ACTIONS(55),
    [anon_sym_RPAREN] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_RBRACE] = ACTIONS(55),
    [anon_sym_LT_DASH] = ACTIONS(57),
    [anon_sym_LT_DASH_GT] = ACTIONS(55),
    [anon_sym_STAR] = ACTIONS(57),
    [anon_sym_DOT] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(57),
    [anon_sym_GT] = ACTIONS(57),
    [anon_sym_EQ] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(57),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LT_PIPE] = ACTIONS(55),
    [anon_sym_AMP_AMP] = ACTIONS(55),
    [anon_sym_PIPE_PIPE] = ACTIONS(55),
    [anon_sym_QMARK_QMARK] = ACTIONS(55),
    [anon_sym_QMARK_COLON] = ACTIONS(55),
    [anon_sym_BANG_EQ] = ACTIONS(55),
    [anon_sym_EQ_EQ] = ACTIONS(55),
    [anon_sym_QMARK_EQ] = ACTIONS(55),
    [anon_sym_STAR_EQ] = ACTIONS(55),
    [anon_sym_TILDE] = ACTIONS(55),
    [anon_sym_BANG_TILDE] = ACTIONS(55),
    [anon_sym_STAR_TILDE] = ACTIONS(55),
    [anon_sym_LT_EQ] = ACTIONS(55),
    [anon_sym_GT_EQ] = ACTIONS(55),
    [anon_sym_PLUS] = ACTIONS(57),
    [anon_sym_PLUS_EQ] = ACTIONS(55),
    [anon_sym_DASH_EQ] = ACTIONS(55),
    [anon_sym_u00d7] = ACTIONS(55),
    [anon_sym_SLASH] = ACTIONS(57),
    [anon_sym_u00f7] = ACTIONS(55),
    [anon_sym_STAR_STAR] = ACTIONS(55),
    [anon_sym_u220b] = ACTIONS(55),
    [anon_sym_u220c] = ACTIONS(55),
    [anon_sym_u2287] = ACTIONS(55),
    [anon_sym_u2283] = ACTIONS(55),
    [anon_sym_u2285] = ACTIONS(55),
    [anon_sym_u2208] = ACTIONS(55),
    [anon_sym_u2209] = ACTIONS(55),
    [anon_sym_u2286] = ACTIONS(55),
    [anon_sym_u2282] = ACTIONS(55),
    [anon_sym_u2284] = ACTIONS(55),
    [anon_sym_AT_AT] = ACTIONS(55),
  },
  [3] = {
    [sym_filter] = STATE(22),
    [sym_path_element] = STATE(6),
    [sym_graph_path] = STATE(22),
    [sym_subscript] = STATE(22),
    [aux_sym_path_repeat1] = STATE(6),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(59),
    [sym_keyword_return] = ACTIONS(59),
    [sym_keyword_from] = ACTIONS(59),
    [sym_keyword_as] = ACTIONS(59),
    [sym_keyword_parallel] = ACTIONS(59),
    [sym_keyword_timeout] = ACTIONS(59),
    [sym_keyword_where] = ACTIONS(59),
    [sym_keyword_group] = ACTIONS(59),
    [sym_keyword_and] = ACTIONS(59),
    [sym_keyword_or] = ACTIONS(59),
    [sym_keyword_is] = ACTIONS(59),
    [sym_keyword_not] = ACTIONS(61),
    [sym_keyword_contains] = ACTIONS(59),
    [sym_keyword_contains_not] = ACTIONS(59),
    [sym_keyword_contains_all] = ACTIONS(59),
    [sym_keyword_contains_any] = ACTIONS(59),
    [sym_keyword_contains_none] = ACTIONS(59),
    [sym_keyword_inside] = ACTIONS(59),
    [sym_keyword_in] = ACTIONS(61),
    [sym_keyword_not_inside] = ACTIONS(59),
    [sym_keyword_all_inside] = ACTIONS(59),
    [sym_keyword_any_inside] = ACTIONS(59),
    [sym_keyword_none_inside] = ACTIONS(59),
    [sym_keyword_outside] = ACTIONS(59),
    [sym_keyword_intersects] = ACTIONS(59),
    [sym_keyword_drop] = ACTIONS(59),
    [sym_keyword_schemafull] = ACTIONS(59),
    [sym_keyword_schemaless] = ACTIONS(59),
    [sym_keyword_changefeed] = ACTIONS(59),
    [sym_keyword_content] = ACTIONS(59),
    [sym_keyword_merge] = ACTIONS(59),
    [sym_keyword_patch] = ACTIONS(59),
    [sym_keyword_then] = ACTIONS(59),
    [sym_keyword_type] = ACTIONS(59),
    [sym_keyword_permissions] = ACTIONS(59),
    [sym_keyword_for] = ACTIONS(59),
    [sym_keyword_comment] = ACTIONS(59),
    [sym_keyword_if] = ACTIONS(59),
    [sym_keyword_set] = ACTIONS(59),
    [sym_keyword_unset] = ACTIONS(59),
    [anon_sym_COMMA] = ACTIONS(59),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_RBRACK] = ACTIONS(59),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_RPAREN] = ACTIONS(59),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(59),
    [anon_sym_RBRACE] = ACTIONS(59),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_DOT] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [sym_variable_name] = ACTIONS(59),
    [sym_custom_function_name] = ACTIONS(59),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(61),
    [anon_sym_LT_PIPE] = ACTIONS(59),
    [anon_sym_AMP_AMP] = ACTIONS(59),
    [anon_sym_PIPE_PIPE] = ACTIONS(59),
    [anon_sym_QMARK_QMARK] = ACTIONS(59),
    [anon_sym_QMARK_COLON] = ACTIONS(59),
    [anon_sym_BANG_EQ] = ACTIONS(59),
    [anon_sym_EQ_EQ] = ACTIONS(59),
    [anon_sym_QMARK_EQ] = ACTIONS(59),
    [anon_sym_STAR_EQ] = ACTIONS(59),
    [anon_sym_TILDE] = ACTIONS(59),
    [anon_sym_BANG_TILDE] = ACTIONS(59),
    [anon_sym_STAR_TILDE] = ACTIONS(59),
    [anon_sym_LT_EQ] = ACTIONS(59),
    [anon_sym_GT_EQ] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_PLUS_EQ] = ACTIONS(59),
    [anon_sym_DASH_EQ] = ACTIONS(59),
    [anon_sym_u00d7] = ACTIONS(59),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_u00f7] = ACTIONS(59),
    [anon_sym_STAR_STAR] = ACTIONS(59),
    [anon_sym_u220b] = ACTIONS(59),
    [anon_sym_u220c] = ACTIONS(59),
    [anon_sym_u2287] = ACTIONS(59),
    [anon_sym_u2283] = ACTIONS(59),
    [anon_sym_u2285] = ACTIONS(59),
    [anon_sym_u2208] = ACTIONS(59),
    [anon_sym_u2209] = ACTIONS(59),
    [anon_sym_u2286] = ACTIONS(59),
    [anon_sym_u2282] = ACTIONS(59),
    [anon_sym_u2284] = ACTIONS(59),
    [anon_sym_AT_AT] = ACTIONS(59),
  },
  [4] = {
    [sym_filter] = STATE(22),
    [sym_path_element] = STATE(6),
    [sym_graph_path] = STATE(22),
    [sym_subscript] = STATE(22),
    [aux_sym_path_repeat1] = STATE(6),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(71),
    [sym_keyword_return] = ACTIONS(71),
    [sym_keyword_from] = ACTIONS(71),
    [sym_keyword_as] = ACTIONS(71),
    [sym_keyword_parallel] = ACTIONS(71),
    [sym_keyword_timeout] = ACTIONS(71),
    [sym_keyword_where] = ACTIONS(71),
    [sym_keyword_group] = ACTIONS(71),
    [sym_keyword_and] = ACTIONS(71),
    [sym_keyword_or] = ACTIONS(71),
    [sym_keyword_is] = ACTIONS(71),
    [sym_keyword_not] = ACTIONS(73),
    [sym_keyword_contains] = ACTIONS(71),
    [sym_keyword_contains_not] = ACTIONS(71),
    [sym_keyword_contains_all] = ACTIONS(71),
    [sym_keyword_contains_any] = ACTIONS(71),
    [sym_keyword_contains_none] = ACTIONS(71),
    [sym_keyword_inside] = ACTIONS(71),
    [sym_keyword_in] = ACTIONS(73),
    [sym_keyword_not_inside] = ACTIONS(71),
    [sym_keyword_all_inside] = ACTIONS(71),
    [sym_keyword_any_inside] = ACTIONS(71),
    [sym_keyword_none_inside] = ACTIONS(71),
    [sym_keyword_outside] = ACTIONS(71),
    [sym_keyword_intersects] = ACTIONS(71),
    [sym_keyword_drop] = ACTIONS(71),
    [sym_keyword_schemafull] = ACTIONS(71),
    [sym_keyword_schemaless] = ACTIONS(71),
    [sym_keyword_changefeed] = ACTIONS(71),
    [sym_keyword_content] = ACTIONS(71),
    [sym_keyword_merge] = ACTIONS(71),
    [sym_keyword_patch] = ACTIONS(71),
    [sym_keyword_then] = ACTIONS(71),
    [sym_keyword_type] = ACTIONS(71),
    [sym_keyword_permissions] = ACTIONS(71),
    [sym_keyword_for] = ACTIONS(71),
    [sym_keyword_comment] = ACTIONS(71),
    [sym_keyword_if] = ACTIONS(71),
    [sym_keyword_set] = ACTIONS(71),
    [sym_keyword_unset] = ACTIONS(71),
    [anon_sym_COMMA] = ACTIONS(71),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_RBRACK] = ACTIONS(71),
    [anon_sym_LPAREN] = ACTIONS(71),
    [anon_sym_RPAREN] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_LBRACE] = ACTIONS(71),
    [anon_sym_RBRACE] = ACTIONS(71),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_DOT] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [sym_variable_name] = ACTIONS(71),
    [sym_custom_function_name] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(73),
    [anon_sym_LT_PIPE] = ACTIONS(71),
    [anon_sym_AMP_AMP] = ACTIONS(71),
    [anon_sym_PIPE_PIPE] = ACTIONS(71),
    [anon_sym_QMARK_QMARK] = ACTIONS(71),
    [anon_sym_QMARK_COLON] = ACTIONS(71),
    [anon_sym_BANG_EQ] = ACTIONS(71),
    [anon_sym_EQ_EQ] = ACTIONS(71),
    [anon_sym_QMARK_EQ] = ACTIONS(71),
    [anon_sym_STAR_EQ] = ACTIONS(71),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_BANG_TILDE] = ACTIONS(71),
    [anon_sym_STAR_TILDE] = ACTIONS(71),
    [anon_sym_LT_EQ] = ACTIONS(71),
    [anon_sym_GT_EQ] = ACTIONS(71),
    [anon_sym_PLUS] = ACTIONS(73),
    [anon_sym_PLUS_EQ] = ACTIONS(71),
    [anon_sym_DASH_EQ] = ACTIONS(71),
    [anon_sym_u00d7] = ACTIONS(71),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_u00f7] = ACTIONS(71),
    [anon_sym_STAR_STAR] = ACTIONS(71),
    [anon_sym_u220b] = ACTIONS(71),
    [anon_sym_u220c] = ACTIONS(71),
    [anon_sym_u2287] = ACTIONS(71),
    [anon_sym_u2283] = ACTIONS(71),
    [anon_sym_u2285] = ACTIONS(71),
    [anon_sym_u2208] = ACTIONS(71),
    [anon_sym_u2209] = ACTIONS(71),
    [anon_sym_u2286] = ACTIONS(71),
    [anon_sym_u2282] = ACTIONS(71),
    [anon_sym_u2284] = ACTIONS(71),
    [anon_sym_AT_AT] = ACTIONS(71),
  },
  [5] = {
    [sym_filter] = STATE(22),
    [sym_path_element] = STATE(5),
    [sym_graph_path] = STATE(22),
    [sym_subscript] = STATE(22),
    [aux_sym_path_repeat1] = STATE(5),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(75),
    [sym_keyword_return] = ACTIONS(75),
    [sym_keyword_from] = ACTIONS(75),
    [sym_keyword_as] = ACTIONS(75),
    [sym_keyword_parallel] = ACTIONS(75),
    [sym_keyword_timeout] = ACTIONS(75),
    [sym_keyword_where] = ACTIONS(75),
    [sym_keyword_group] = ACTIONS(75),
    [sym_keyword_and] = ACTIONS(75),
    [sym_keyword_or] = ACTIONS(75),
    [sym_keyword_is] = ACTIONS(75),
    [sym_keyword_not] = ACTIONS(77),
    [sym_keyword_contains] = ACTIONS(75),
    [sym_keyword_contains_not] = ACTIONS(75),
    [sym_keyword_contains_all] = ACTIONS(75),
    [sym_keyword_contains_any] = ACTIONS(75),
    [sym_keyword_contains_none] = ACTIONS(75),
    [sym_keyword_inside] = ACTIONS(75),
    [sym_keyword_in] = ACTIONS(77),
    [sym_keyword_not_inside] = ACTIONS(75),
    [sym_keyword_all_inside] = ACTIONS(75),
    [sym_keyword_any_inside] = ACTIONS(75),
    [sym_keyword_none_inside] = ACTIONS(75),
    [sym_keyword_outside] = ACTIONS(75),
    [sym_keyword_intersects] = ACTIONS(75),
    [sym_keyword_drop] = ACTIONS(75),
    [sym_keyword_schemafull] = ACTIONS(75),
    [sym_keyword_schemaless] = ACTIONS(75),
    [sym_keyword_changefeed] = ACTIONS(75),
    [sym_keyword_content] = ACTIONS(75),
    [sym_keyword_merge] = ACTIONS(75),
    [sym_keyword_patch] = ACTIONS(75),
    [sym_keyword_then] = ACTIONS(75),
    [sym_keyword_type] = ACTIONS(75),
    [sym_keyword_permissions] = ACTIONS(75),
    [sym_keyword_for] = ACTIONS(75),
    [sym_keyword_comment] = ACTIONS(75),
    [sym_keyword_if] = ACTIONS(75),
    [sym_keyword_set] = ACTIONS(75),
    [sym_keyword_unset] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(75),
    [anon_sym_DASH_GT] = ACTIONS(79),
    [anon_sym_LBRACK] = ACTIONS(82),
    [anon_sym_RBRACK] = ACTIONS(75),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_RPAREN] = ACTIONS(75),
    [anon_sym_QMARK] = ACTIONS(77),
    [anon_sym_LBRACE] = ACTIONS(75),
    [anon_sym_RBRACE] = ACTIONS(75),
    [anon_sym_LT_DASH] = ACTIONS(85),
    [anon_sym_LT_DASH_GT] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(77),
    [anon_sym_DOT] = ACTIONS(88),
    [anon_sym_LT] = ACTIONS(77),
    [anon_sym_GT] = ACTIONS(77),
    [sym_variable_name] = ACTIONS(75),
    [sym_custom_function_name] = ACTIONS(75),
    [anon_sym_EQ] = ACTIONS(77),
    [anon_sym_DASH] = ACTIONS(77),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LT_PIPE] = ACTIONS(75),
    [anon_sym_AMP_AMP] = ACTIONS(75),
    [anon_sym_PIPE_PIPE] = ACTIONS(75),
    [anon_sym_QMARK_QMARK] = ACTIONS(75),
    [anon_sym_QMARK_COLON] = ACTIONS(75),
    [anon_sym_BANG_EQ] = ACTIONS(75),
    [anon_sym_EQ_EQ] = ACTIONS(75),
    [anon_sym_QMARK_EQ] = ACTIONS(75),
    [anon_sym_STAR_EQ] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_BANG_TILDE] = ACTIONS(75),
    [anon_sym_STAR_TILDE] = ACTIONS(75),
    [anon_sym_LT_EQ] = ACTIONS(75),
    [anon_sym_GT_EQ] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(77),
    [anon_sym_PLUS_EQ] = ACTIONS(75),
    [anon_sym_DASH_EQ] = ACTIONS(75),
    [anon_sym_u00d7] = ACTIONS(75),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_u00f7] = ACTIONS(75),
    [anon_sym_STAR_STAR] = ACTIONS(75),
    [anon_sym_u220b] = ACTIONS(75),
    [anon_sym_u220c] = ACTIONS(75),
    [anon_sym_u2287] = ACTIONS(75),
    [anon_sym_u2283] = ACTIONS(75),
    [anon_sym_u2285] = ACTIONS(75),
    [anon_sym_u2208] = ACTIONS(75),
    [anon_sym_u2209] = ACTIONS(75),
    [anon_sym_u2286] = ACTIONS(75),
    [anon_sym_u2282] = ACTIONS(75),
    [anon_sym_u2284] = ACTIONS(75),
    [anon_sym_AT_AT] = ACTIONS(75),
  },
  [6] = {
    [sym_filter] = STATE(22),
    [sym_path_element] = STATE(5),
    [sym_graph_path] = STATE(22),
    [sym_subscript] = STATE(22),
    [aux_sym_path_repeat1] = STATE(5),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(91),
    [sym_keyword_return] = ACTIONS(91),
    [sym_keyword_from] = ACTIONS(91),
    [sym_keyword_as] = ACTIONS(91),
    [sym_keyword_parallel] = ACTIONS(91),
    [sym_keyword_timeout] = ACTIONS(91),
    [sym_keyword_where] = ACTIONS(91),
    [sym_keyword_group] = ACTIONS(91),
    [sym_keyword_and] = ACTIONS(91),
    [sym_keyword_or] = ACTIONS(91),
    [sym_keyword_is] = ACTIONS(91),
    [sym_keyword_not] = ACTIONS(93),
    [sym_keyword_contains] = ACTIONS(91),
    [sym_keyword_contains_not] = ACTIONS(91),
    [sym_keyword_contains_all] = ACTIONS(91),
    [sym_keyword_contains_any] = ACTIONS(91),
    [sym_keyword_contains_none] = ACTIONS(91),
    [sym_keyword_inside] = ACTIONS(91),
    [sym_keyword_in] = ACTIONS(93),
    [sym_keyword_not_inside] = ACTIONS(91),
    [sym_keyword_all_inside] = ACTIONS(91),
    [sym_keyword_any_inside] = ACTIONS(91),
    [sym_keyword_none_inside] = ACTIONS(91),
    [sym_keyword_outside] = ACTIONS(91),
    [sym_keyword_intersects] = ACTIONS(91),
    [sym_keyword_drop] = ACTIONS(91),
    [sym_keyword_schemafull] = ACTIONS(91),
    [sym_keyword_schemaless] = ACTIONS(91),
    [sym_keyword_changefeed] = ACTIONS(91),
    [sym_keyword_content] = ACTIONS(91),
    [sym_keyword_merge] = ACTIONS(91),
    [sym_keyword_patch] = ACTIONS(91),
    [sym_keyword_then] = ACTIONS(91),
    [sym_keyword_type] = ACTIONS(91),
    [sym_keyword_permissions] = ACTIONS(91),
    [sym_keyword_for] = ACTIONS(91),
    [sym_keyword_comment] = ACTIONS(91),
    [sym_keyword_if] = ACTIONS(91),
    [sym_keyword_set] = ACTIONS(91),
    [sym_keyword_unset] = ACTIONS(91),
    [anon_sym_COMMA] = ACTIONS(91),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_RBRACK] = ACTIONS(91),
    [anon_sym_LPAREN] = ACTIONS(91),
    [anon_sym_RPAREN] = ACTIONS(91),
    [anon_sym_QMARK] = ACTIONS(93),
    [anon_sym_LBRACE] = ACTIONS(91),
    [anon_sym_RBRACE] = ACTIONS(91),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [anon_sym_STAR] = ACTIONS(93),
    [anon_sym_DOT] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(93),
    [anon_sym_GT] = ACTIONS(93),
    [sym_variable_name] = ACTIONS(91),
    [sym_custom_function_name] = ACTIONS(91),
    [anon_sym_EQ] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(93),
    [anon_sym_AT] = ACTIONS(93),
    [anon_sym_LT_PIPE] = ACTIONS(91),
    [anon_sym_AMP_AMP] = ACTIONS(91),
    [anon_sym_PIPE_PIPE] = ACTIONS(91),
    [anon_sym_QMARK_QMARK] = ACTIONS(91),
    [anon_sym_QMARK_COLON] = ACTIONS(91),
    [anon_sym_BANG_EQ] = ACTIONS(91),
    [anon_sym_EQ_EQ] = ACTIONS(91),
    [anon_sym_QMARK_EQ] = ACTIONS(91),
    [anon_sym_STAR_EQ] = ACTIONS(91),
    [anon_sym_TILDE] = ACTIONS(91),
    [anon_sym_BANG_TILDE] = ACTIONS(91),
    [anon_sym_STAR_TILDE] = ACTIONS(91),
    [anon_sym_LT_EQ] = ACTIONS(91),
    [anon_sym_GT_EQ] = ACTIONS(91),
    [anon_sym_PLUS] = ACTIONS(93),
    [anon_sym_PLUS_EQ] = ACTIONS(91),
    [anon_sym_DASH_EQ] = ACTIONS(91),
    [anon_sym_u00d7] = ACTIONS(91),
    [anon_sym_SLASH] = ACTIONS(93),
    [anon_sym_u00f7] = ACTIONS(91),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_u220b] = ACTIONS(91),
    [anon_sym_u220c] = ACTIONS(91),
    [anon_sym_u2287] = ACTIONS(91),
    [anon_sym_u2283] = ACTIONS(91),
    [anon_sym_u2285] = ACTIONS(91),
    [anon_sym_u2208] = ACTIONS(91),
    [anon_sym_u2209] = ACTIONS(91),
    [anon_sym_u2286] = ACTIONS(91),
    [anon_sym_u2282] = ACTIONS(91),
    [anon_sym_u2284] = ACTIONS(91),
    [anon_sym_AT_AT] = ACTIONS(91),
  },
  [7] = {
    [ts_builtin_sym_end] = ACTIONS(95),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(95),
    [sym_keyword_return] = ACTIONS(95),
    [sym_keyword_value] = ACTIONS(95),
    [sym_keyword_explain] = ACTIONS(95),
    [sym_keyword_parallel] = ACTIONS(95),
    [sym_keyword_timeout] = ACTIONS(95),
    [sym_keyword_fetch] = ACTIONS(95),
    [sym_keyword_limit] = ACTIONS(95),
    [sym_keyword_rand] = ACTIONS(95),
    [sym_keyword_collate] = ACTIONS(95),
    [sym_keyword_numeric] = ACTIONS(95),
    [sym_keyword_asc] = ACTIONS(95),
    [sym_keyword_desc] = ACTIONS(95),
    [sym_keyword_where] = ACTIONS(95),
    [sym_keyword_and] = ACTIONS(95),
    [sym_keyword_or] = ACTIONS(95),
    [sym_keyword_is] = ACTIONS(95),
    [sym_keyword_not] = ACTIONS(97),
    [sym_keyword_contains] = ACTIONS(95),
    [sym_keyword_contains_not] = ACTIONS(95),
    [sym_keyword_contains_all] = ACTIONS(95),
    [sym_keyword_contains_any] = ACTIONS(95),
    [sym_keyword_contains_none] = ACTIONS(95),
    [sym_keyword_inside] = ACTIONS(95),
    [sym_keyword_in] = ACTIONS(97),
    [sym_keyword_not_inside] = ACTIONS(95),
    [sym_keyword_all_inside] = ACTIONS(95),
    [sym_keyword_any_inside] = ACTIONS(95),
    [sym_keyword_none_inside] = ACTIONS(95),
    [sym_keyword_outside] = ACTIONS(95),
    [sym_keyword_intersects] = ACTIONS(95),
    [sym_keyword_flexible] = ACTIONS(95),
    [sym_keyword_readonly] = ACTIONS(95),
    [sym_keyword_content] = ACTIONS(95),
    [sym_keyword_merge] = ACTIONS(95),
    [sym_keyword_patch] = ACTIONS(95),
    [sym_keyword_type] = ACTIONS(95),
    [sym_keyword_default] = ACTIONS(95),
    [sym_keyword_assert] = ACTIONS(95),
    [sym_keyword_permissions] = ACTIONS(95),
    [sym_keyword_for] = ACTIONS(95),
    [sym_keyword_comment] = ACTIONS(95),
    [sym_keyword_session] = ACTIONS(95),
    [sym_keyword_signin] = ACTIONS(95),
    [sym_keyword_signup] = ACTIONS(95),
    [sym_keyword_set] = ACTIONS(95),
    [sym_keyword_unset] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(95),
    [anon_sym_DASH_GT] = ACTIONS(95),
    [anon_sym_LBRACK] = ACTIONS(95),
    [anon_sym_RPAREN] = ACTIONS(95),
    [anon_sym_RBRACE] = ACTIONS(95),
    [anon_sym_LT_DASH] = ACTIONS(97),
    [anon_sym_LT_DASH_GT] = ACTIONS(95),
    [anon_sym_STAR] = ACTIONS(97),
    [anon_sym_DOT] = ACTIONS(95),
    [anon_sym_LT] = ACTIONS(97),
    [anon_sym_GT] = ACTIONS(97),
    [anon_sym_EQ] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_LT_PIPE] = ACTIONS(95),
    [anon_sym_AMP_AMP] = ACTIONS(95),
    [anon_sym_PIPE_PIPE] = ACTIONS(95),
    [anon_sym_QMARK_QMARK] = ACTIONS(95),
    [anon_sym_QMARK_COLON] = ACTIONS(95),
    [anon_sym_BANG_EQ] = ACTIONS(95),
    [anon_sym_EQ_EQ] = ACTIONS(95),
    [anon_sym_QMARK_EQ] = ACTIONS(95),
    [anon_sym_STAR_EQ] = ACTIONS(95),
    [anon_sym_TILDE] = ACTIONS(95),
    [anon_sym_BANG_TILDE] = ACTIONS(95),
    [anon_sym_STAR_TILDE] = ACTIONS(95),
    [anon_sym_LT_EQ] = ACTIONS(95),
    [anon_sym_GT_EQ] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_PLUS_EQ] = ACTIONS(95),
    [anon_sym_DASH_EQ] = ACTIONS(95),
    [anon_sym_u00d7] = ACTIONS(95),
    [anon_sym_SLASH] = ACTIONS(97),
    [anon_sym_u00f7] = ACTIONS(95),
    [anon_sym_STAR_STAR] = ACTIONS(95),
    [anon_sym_u220b] = ACTIONS(95),
    [anon_sym_u220c] = ACTIONS(95),
    [anon_sym_u2287] = ACTIONS(95),
    [anon_sym_u2283] = ACTIONS(95),
    [anon_sym_u2285] = ACTIONS(95),
    [anon_sym_u2208] = ACTIONS(95),
    [anon_sym_u2209] = ACTIONS(95),
    [anon_sym_u2286] = ACTIONS(95),
    [anon_sym_u2282] = ACTIONS(95),
    [anon_sym_u2284] = ACTIONS(95),
    [anon_sym_AT_AT] = ACTIONS(95),
  },
  [8] = {
    [aux_sym_duration_repeat1] = STATE(9),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(99),
    [sym_keyword_return] = ACTIONS(99),
    [sym_keyword_from] = ACTIONS(99),
    [sym_keyword_as] = ACTIONS(99),
    [sym_keyword_parallel] = ACTIONS(99),
    [sym_keyword_timeout] = ACTIONS(99),
    [sym_keyword_where] = ACTIONS(99),
    [sym_keyword_group] = ACTIONS(99),
    [sym_keyword_and] = ACTIONS(99),
    [sym_keyword_or] = ACTIONS(99),
    [sym_keyword_is] = ACTIONS(99),
    [sym_keyword_not] = ACTIONS(101),
    [sym_keyword_contains] = ACTIONS(99),
    [sym_keyword_contains_not] = ACTIONS(99),
    [sym_keyword_contains_all] = ACTIONS(99),
    [sym_keyword_contains_any] = ACTIONS(99),
    [sym_keyword_contains_none] = ACTIONS(99),
    [sym_keyword_inside] = ACTIONS(99),
    [sym_keyword_in] = ACTIONS(101),
    [sym_keyword_not_inside] = ACTIONS(99),
    [sym_keyword_all_inside] = ACTIONS(99),
    [sym_keyword_any_inside] = ACTIONS(99),
    [sym_keyword_none_inside] = ACTIONS(99),
    [sym_keyword_outside] = ACTIONS(99),
    [sym_keyword_intersects] = ACTIONS(99),
    [sym_keyword_drop] = ACTIONS(99),
    [sym_keyword_schemafull] = ACTIONS(99),
    [sym_keyword_schemaless] = ACTIONS(99),
    [sym_keyword_changefeed] = ACTIONS(99),
    [sym_keyword_content] = ACTIONS(99),
    [sym_keyword_merge] = ACTIONS(99),
    [sym_keyword_patch] = ACTIONS(99),
    [sym_keyword_then] = ACTIONS(99),
    [sym_keyword_type] = ACTIONS(99),
    [sym_keyword_permissions] = ACTIONS(99),
    [sym_keyword_for] = ACTIONS(99),
    [sym_keyword_comment] = ACTIONS(99),
    [sym_keyword_if] = ACTIONS(99),
    [sym_keyword_set] = ACTIONS(99),
    [sym_keyword_unset] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_DASH_GT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(99),
    [anon_sym_RBRACK] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(99),
    [anon_sym_RPAREN] = ACTIONS(99),
    [anon_sym_QMARK] = ACTIONS(101),
    [anon_sym_LBRACE] = ACTIONS(99),
    [anon_sym_RBRACE] = ACTIONS(99),
    [anon_sym_LT_DASH] = ACTIONS(101),
    [anon_sym_LT_DASH_GT] = ACTIONS(99),
    [anon_sym_STAR] = ACTIONS(101),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LT] = ACTIONS(101),
    [anon_sym_GT] = ACTIONS(101),
    [sym_variable_name] = ACTIONS(99),
    [sym_custom_function_name] = ACTIONS(99),
    [anon_sym_EQ] = ACTIONS(101),
    [sym_duration_part] = ACTIONS(103),
    [anon_sym_DASH] = ACTIONS(101),
    [anon_sym_AT] = ACTIONS(101),
    [anon_sym_LT_PIPE] = ACTIONS(99),
    [anon_sym_AMP_AMP] = ACTIONS(99),
    [anon_sym_PIPE_PIPE] = ACTIONS(99),
    [anon_sym_QMARK_QMARK] = ACTIONS(99),
    [anon_sym_QMARK_COLON] = ACTIONS(99),
    [anon_sym_BANG_EQ] = ACTIONS(99),
    [anon_sym_EQ_EQ] = ACTIONS(99),
    [anon_sym_QMARK_EQ] = ACTIONS(99),
    [anon_sym_STAR_EQ] = ACTIONS(99),
    [anon_sym_TILDE] = ACTIONS(99),
    [anon_sym_BANG_TILDE] = ACTIONS(99),
    [anon_sym_STAR_TILDE] = ACTIONS(99),
    [anon_sym_LT_EQ] = ACTIONS(99),
    [anon_sym_GT_EQ] = ACTIONS(99),
    [anon_sym_PLUS] = ACTIONS(101),
    [anon_sym_PLUS_EQ] = ACTIONS(99),
    [anon_sym_DASH_EQ] = ACTIONS(99),
    [anon_sym_u00d7] = ACTIONS(99),
    [anon_sym_SLASH] = ACTIONS(101),
    [anon_sym_u00f7] = ACTIONS(99),
    [anon_sym_STAR_STAR] = ACTIONS(99),
    [anon_sym_u220b] = ACTIONS(99),
    [anon_sym_u220c] = ACTIONS(99),
    [anon_sym_u2287] = ACTIONS(99),
    [anon_sym_u2283] = ACTIONS(99),
    [anon_sym_u2285] = ACTIONS(99),
    [anon_sym_u2208] = ACTIONS(99),
    [anon_sym_u2209] = ACTIONS(99),
    [anon_sym_u2286] = ACTIONS(99),
    [anon_sym_u2282] = ACTIONS(99),
    [anon_sym_u2284] = ACTIONS(99),
    [anon_sym_AT_AT] = ACTIONS(99),
  },
  [9] = {
    [aux_sym_duration_repeat1] = STATE(9),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(105),
    [sym_keyword_return] = ACTIONS(105),
    [sym_keyword_from] = ACTIONS(105),
    [sym_keyword_as] = ACTIONS(105),
    [sym_keyword_parallel] = ACTIONS(105),
    [sym_keyword_timeout] = ACTIONS(105),
    [sym_keyword_where] = ACTIONS(105),
    [sym_keyword_group] = ACTIONS(105),
    [sym_keyword_and] = ACTIONS(105),
    [sym_keyword_or] = ACTIONS(105),
    [sym_keyword_is] = ACTIONS(105),
    [sym_keyword_not] = ACTIONS(107),
    [sym_keyword_contains] = ACTIONS(105),
    [sym_keyword_contains_not] = ACTIONS(105),
    [sym_keyword_contains_all] = ACTIONS(105),
    [sym_keyword_contains_any] = ACTIONS(105),
    [sym_keyword_contains_none] = ACTIONS(105),
    [sym_keyword_inside] = ACTIONS(105),
    [sym_keyword_in] = ACTIONS(107),
    [sym_keyword_not_inside] = ACTIONS(105),
    [sym_keyword_all_inside] = ACTIONS(105),
    [sym_keyword_any_inside] = ACTIONS(105),
    [sym_keyword_none_inside] = ACTIONS(105),
    [sym_keyword_outside] = ACTIONS(105),
    [sym_keyword_intersects] = ACTIONS(105),
    [sym_keyword_drop] = ACTIONS(105),
    [sym_keyword_schemafull] = ACTIONS(105),
    [sym_keyword_schemaless] = ACTIONS(105),
    [sym_keyword_changefeed] = ACTIONS(105),
    [sym_keyword_content] = ACTIONS(105),
    [sym_keyword_merge] = ACTIONS(105),
    [sym_keyword_patch] = ACTIONS(105),
    [sym_keyword_then] = ACTIONS(105),
    [sym_keyword_type] = ACTIONS(105),
    [sym_keyword_permissions] = ACTIONS(105),
    [sym_keyword_for] = ACTIONS(105),
    [sym_keyword_comment] = ACTIONS(105),
    [sym_keyword_if] = ACTIONS(105),
    [sym_keyword_set] = ACTIONS(105),
    [sym_keyword_unset] = ACTIONS(105),
    [anon_sym_COMMA] = ACTIONS(105),
    [anon_sym_DASH_GT] = ACTIONS(105),
    [anon_sym_LBRACK] = ACTIONS(105),
    [anon_sym_RBRACK] = ACTIONS(105),
    [anon_sym_LPAREN] = ACTIONS(105),
    [anon_sym_RPAREN] = ACTIONS(105),
    [anon_sym_QMARK] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(105),
    [anon_sym_RBRACE] = ACTIONS(105),
    [anon_sym_LT_DASH] = ACTIONS(107),
    [anon_sym_LT_DASH_GT] = ACTIONS(105),
    [anon_sym_STAR] = ACTIONS(107),
    [anon_sym_DOT] = ACTIONS(105),
    [anon_sym_LT] = ACTIONS(107),
    [anon_sym_GT] = ACTIONS(107),
    [sym_variable_name] = ACTIONS(105),
    [sym_custom_function_name] = ACTIONS(105),
    [anon_sym_EQ] = ACTIONS(107),
    [sym_duration_part] = ACTIONS(109),
    [anon_sym_DASH] = ACTIONS(107),
    [anon_sym_AT] = ACTIONS(107),
    [anon_sym_LT_PIPE] = ACTIONS(105),
    [anon_sym_AMP_AMP] = ACTIONS(105),
    [anon_sym_PIPE_PIPE] = ACTIONS(105),
    [anon_sym_QMARK_QMARK] = ACTIONS(105),
    [anon_sym_QMARK_COLON] = ACTIONS(105),
    [anon_sym_BANG_EQ] = ACTIONS(105),
    [anon_sym_EQ_EQ] = ACTIONS(105),
    [anon_sym_QMARK_EQ] = ACTIONS(105),
    [anon_sym_STAR_EQ] = ACTIONS(105),
    [anon_sym_TILDE] = ACTIONS(105),
    [anon_sym_BANG_TILDE] = ACTIONS(105),
    [anon_sym_STAR_TILDE] = ACTIONS(105),
    [anon_sym_LT_EQ] = ACTIONS(105),
    [anon_sym_GT_EQ] = ACTIONS(105),
    [anon_sym_PLUS] = ACTIONS(107),
    [anon_sym_PLUS_EQ] = ACTIONS(105),
    [anon_sym_DASH_EQ] = ACTIONS(105),
    [anon_sym_u00d7] = ACTIONS(105),
    [anon_sym_SLASH] = ACTIONS(107),
    [anon_sym_u00f7] = ACTIONS(105),
    [anon_sym_STAR_STAR] = ACTIONS(105),
    [anon_sym_u220b] = ACTIONS(105),
    [anon_sym_u220c] = ACTIONS(105),
    [anon_sym_u2287] = ACTIONS(105),
    [anon_sym_u2283] = ACTIONS(105),
    [anon_sym_u2285] = ACTIONS(105),
    [anon_sym_u2208] = ACTIONS(105),
    [anon_sym_u2209] = ACTIONS(105),
    [anon_sym_u2286] = ACTIONS(105),
    [anon_sym_u2282] = ACTIONS(105),
    [anon_sym_u2284] = ACTIONS(105),
    [anon_sym_AT_AT] = ACTIONS(105),
  },
  [10] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(112),
    [sym_keyword_return] = ACTIONS(112),
    [sym_keyword_from] = ACTIONS(112),
    [sym_keyword_as] = ACTIONS(112),
    [sym_keyword_parallel] = ACTIONS(112),
    [sym_keyword_timeout] = ACTIONS(112),
    [sym_keyword_where] = ACTIONS(112),
    [sym_keyword_group] = ACTIONS(112),
    [sym_keyword_and] = ACTIONS(112),
    [sym_keyword_or] = ACTIONS(112),
    [sym_keyword_is] = ACTIONS(112),
    [sym_keyword_not] = ACTIONS(114),
    [sym_keyword_contains] = ACTIONS(112),
    [sym_keyword_contains_not] = ACTIONS(112),
    [sym_keyword_contains_all] = ACTIONS(112),
    [sym_keyword_contains_any] = ACTIONS(112),
    [sym_keyword_contains_none] = ACTIONS(112),
    [sym_keyword_inside] = ACTIONS(112),
    [sym_keyword_in] = ACTIONS(114),
    [sym_keyword_not_inside] = ACTIONS(112),
    [sym_keyword_all_inside] = ACTIONS(112),
    [sym_keyword_any_inside] = ACTIONS(112),
    [sym_keyword_none_inside] = ACTIONS(112),
    [sym_keyword_outside] = ACTIONS(112),
    [sym_keyword_intersects] = ACTIONS(112),
    [sym_keyword_drop] = ACTIONS(112),
    [sym_keyword_schemafull] = ACTIONS(112),
    [sym_keyword_schemaless] = ACTIONS(112),
    [sym_keyword_changefeed] = ACTIONS(112),
    [sym_keyword_content] = ACTIONS(112),
    [sym_keyword_merge] = ACTIONS(112),
    [sym_keyword_patch] = ACTIONS(112),
    [sym_keyword_then] = ACTIONS(112),
    [sym_keyword_type] = ACTIONS(112),
    [sym_keyword_permissions] = ACTIONS(112),
    [sym_keyword_for] = ACTIONS(112),
    [sym_keyword_comment] = ACTIONS(112),
    [sym_keyword_if] = ACTIONS(112),
    [sym_keyword_set] = ACTIONS(112),
    [sym_keyword_unset] = ACTIONS(112),
    [anon_sym_COMMA] = ACTIONS(112),
    [anon_sym_DASH_GT] = ACTIONS(112),
    [anon_sym_LBRACK] = ACTIONS(112),
    [anon_sym_RBRACK] = ACTIONS(112),
    [anon_sym_LPAREN] = ACTIONS(112),
    [anon_sym_RPAREN] = ACTIONS(112),
    [anon_sym_QMARK] = ACTIONS(114),
    [anon_sym_LBRACE] = ACTIONS(112),
    [anon_sym_RBRACE] = ACTIONS(112),
    [anon_sym_LT_DASH] = ACTIONS(114),
    [anon_sym_LT_DASH_GT] = ACTIONS(112),
    [anon_sym_STAR] = ACTIONS(114),
    [anon_sym_DOT] = ACTIONS(114),
    [anon_sym_LT] = ACTIONS(114),
    [anon_sym_GT] = ACTIONS(114),
    [sym_variable_name] = ACTIONS(112),
    [sym_custom_function_name] = ACTIONS(112),
    [anon_sym_DOT_DOT] = ACTIONS(112),
    [anon_sym_EQ] = ACTIONS(114),
    [anon_sym_DASH] = ACTIONS(114),
    [anon_sym_AT] = ACTIONS(114),
    [anon_sym_LT_PIPE] = ACTIONS(112),
    [anon_sym_AMP_AMP] = ACTIONS(112),
    [anon_sym_PIPE_PIPE] = ACTIONS(112),
    [anon_sym_QMARK_QMARK] = ACTIONS(112),
    [anon_sym_QMARK_COLON] = ACTIONS(112),
    [anon_sym_BANG_EQ] = ACTIONS(112),
    [anon_sym_EQ_EQ] = ACTIONS(112),
    [anon_sym_QMARK_EQ] = ACTIONS(112),
    [anon_sym_STAR_EQ] = ACTIONS(112),
    [anon_sym_TILDE] = ACTIONS(112),
    [anon_sym_BANG_TILDE] = ACTIONS(112),
    [anon_sym_STAR_TILDE] = ACTIONS(112),
    [anon_sym_LT_EQ] = ACTIONS(112),
    [anon_sym_GT_EQ] = ACTIONS(112),
    [anon_sym_PLUS] = ACTIONS(114),
    [anon_sym_PLUS_EQ] = ACTIONS(112),
    [anon_sym_DASH_EQ] = ACTIONS(112),
    [anon_sym_u00d7] = ACTIONS(112),
    [anon_sym_SLASH] = ACTIONS(114),
    [anon_sym_u00f7] = ACTIONS(112),
    [anon_sym_STAR_STAR] = ACTIONS(112),
    [anon_sym_u220b] = ACTIONS(112),
    [anon_sym_u220c] = ACTIONS(112),
    [anon_sym_u2287] = ACTIONS(112),
    [anon_sym_u2283] = ACTIONS(112),
    [anon_sym_u2285] = ACTIONS(112),
    [anon_sym_u2208] = ACTIONS(112),
    [anon_sym_u2209] = ACTIONS(112),
    [anon_sym_u2286] = ACTIONS(112),
    [anon_sym_u2282] = ACTIONS(112),
    [anon_sym_u2284] = ACTIONS(112),
    [anon_sym_AT_AT] = ACTIONS(112),
  },
  [11] = {
    [ts_builtin_sym_end] = ACTIONS(116),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(116),
    [sym_keyword_return] = ACTIONS(116),
    [sym_keyword_value] = ACTIONS(116),
    [sym_keyword_explain] = ACTIONS(116),
    [sym_keyword_parallel] = ACTIONS(116),
    [sym_keyword_timeout] = ACTIONS(116),
    [sym_keyword_fetch] = ACTIONS(116),
    [sym_keyword_limit] = ACTIONS(116),
    [sym_keyword_rand] = ACTIONS(116),
    [sym_keyword_collate] = ACTIONS(116),
    [sym_keyword_numeric] = ACTIONS(116),
    [sym_keyword_asc] = ACTIONS(116),
    [sym_keyword_desc] = ACTIONS(116),
    [sym_keyword_where] = ACTIONS(116),
    [sym_keyword_and] = ACTIONS(116),
    [sym_keyword_or] = ACTIONS(116),
    [sym_keyword_is] = ACTIONS(116),
    [sym_keyword_not] = ACTIONS(118),
    [sym_keyword_contains] = ACTIONS(116),
    [sym_keyword_contains_not] = ACTIONS(116),
    [sym_keyword_contains_all] = ACTIONS(116),
    [sym_keyword_contains_any] = ACTIONS(116),
    [sym_keyword_contains_none] = ACTIONS(116),
    [sym_keyword_inside] = ACTIONS(116),
    [sym_keyword_in] = ACTIONS(118),
    [sym_keyword_not_inside] = ACTIONS(116),
    [sym_keyword_all_inside] = ACTIONS(116),
    [sym_keyword_any_inside] = ACTIONS(116),
    [sym_keyword_none_inside] = ACTIONS(116),
    [sym_keyword_outside] = ACTIONS(116),
    [sym_keyword_intersects] = ACTIONS(116),
    [sym_keyword_flexible] = ACTIONS(116),
    [sym_keyword_readonly] = ACTIONS(116),
    [sym_keyword_content] = ACTIONS(116),
    [sym_keyword_merge] = ACTIONS(116),
    [sym_keyword_patch] = ACTIONS(116),
    [sym_keyword_type] = ACTIONS(116),
    [sym_keyword_default] = ACTIONS(116),
    [sym_keyword_assert] = ACTIONS(116),
    [sym_keyword_permissions] = ACTIONS(116),
    [sym_keyword_for] = ACTIONS(116),
    [sym_keyword_comment] = ACTIONS(116),
    [sym_keyword_set] = ACTIONS(116),
    [sym_keyword_unset] = ACTIONS(116),
    [anon_sym_COMMA] = ACTIONS(116),
    [anon_sym_DASH_GT] = ACTIONS(116),
    [anon_sym_LBRACK] = ACTIONS(116),
    [anon_sym_RBRACK] = ACTIONS(116),
    [anon_sym_RPAREN] = ACTIONS(116),
    [anon_sym_RBRACE] = ACTIONS(116),
    [anon_sym_LT_DASH] = ACTIONS(118),
    [anon_sym_LT_DASH_GT] = ACTIONS(116),
    [anon_sym_STAR] = ACTIONS(118),
    [anon_sym_DOT] = ACTIONS(118),
    [anon_sym_LT] = ACTIONS(118),
    [anon_sym_GT] = ACTIONS(118),
    [anon_sym_DOT_DOT] = ACTIONS(116),
    [anon_sym_EQ] = ACTIONS(118),
    [anon_sym_DASH] = ACTIONS(118),
    [anon_sym_AT] = ACTIONS(118),
    [anon_sym_LT_PIPE] = ACTIONS(116),
    [anon_sym_AMP_AMP] = ACTIONS(116),
    [anon_sym_PIPE_PIPE] = ACTIONS(116),
    [anon_sym_QMARK_QMARK] = ACTIONS(116),
    [anon_sym_QMARK_COLON] = ACTIONS(116),
    [anon_sym_BANG_EQ] = ACTIONS(116),
    [anon_sym_EQ_EQ] = ACTIONS(116),
    [anon_sym_QMARK_EQ] = ACTIONS(116),
    [anon_sym_STAR_EQ] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(116),
    [anon_sym_BANG_TILDE] = ACTIONS(116),
    [anon_sym_STAR_TILDE] = ACTIONS(116),
    [anon_sym_LT_EQ] = ACTIONS(116),
    [anon_sym_GT_EQ] = ACTIONS(116),
    [anon_sym_PLUS] = ACTIONS(118),
    [anon_sym_PLUS_EQ] = ACTIONS(116),
    [anon_sym_DASH_EQ] = ACTIONS(116),
    [anon_sym_u00d7] = ACTIONS(116),
    [anon_sym_SLASH] = ACTIONS(118),
    [anon_sym_u00f7] = ACTIONS(116),
    [anon_sym_STAR_STAR] = ACTIONS(116),
    [anon_sym_u220b] = ACTIONS(116),
    [anon_sym_u220c] = ACTIONS(116),
    [anon_sym_u2287] = ACTIONS(116),
    [anon_sym_u2283] = ACTIONS(116),
    [anon_sym_u2285] = ACTIONS(116),
    [anon_sym_u2208] = ACTIONS(116),
    [anon_sym_u2209] = ACTIONS(116),
    [anon_sym_u2286] = ACTIONS(116),
    [anon_sym_u2282] = ACTIONS(116),
    [anon_sym_u2284] = ACTIONS(116),
    [anon_sym_AT_AT] = ACTIONS(116),
  },
  [12] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(55),
    [sym_keyword_return] = ACTIONS(55),
    [sym_keyword_from] = ACTIONS(55),
    [sym_keyword_as] = ACTIONS(55),
    [sym_keyword_parallel] = ACTIONS(55),
    [sym_keyword_timeout] = ACTIONS(55),
    [sym_keyword_where] = ACTIONS(55),
    [sym_keyword_group] = ACTIONS(55),
    [sym_keyword_and] = ACTIONS(55),
    [sym_keyword_or] = ACTIONS(55),
    [sym_keyword_is] = ACTIONS(55),
    [sym_keyword_not] = ACTIONS(57),
    [sym_keyword_contains] = ACTIONS(55),
    [sym_keyword_contains_not] = ACTIONS(55),
    [sym_keyword_contains_all] = ACTIONS(55),
    [sym_keyword_contains_any] = ACTIONS(55),
    [sym_keyword_contains_none] = ACTIONS(55),
    [sym_keyword_inside] = ACTIONS(55),
    [sym_keyword_in] = ACTIONS(57),
    [sym_keyword_not_inside] = ACTIONS(55),
    [sym_keyword_all_inside] = ACTIONS(55),
    [sym_keyword_any_inside] = ACTIONS(55),
    [sym_keyword_none_inside] = ACTIONS(55),
    [sym_keyword_outside] = ACTIONS(55),
    [sym_keyword_intersects] = ACTIONS(55),
    [sym_keyword_drop] = ACTIONS(55),
    [sym_keyword_schemafull] = ACTIONS(55),
    [sym_keyword_schemaless] = ACTIONS(55),
    [sym_keyword_changefeed] = ACTIONS(55),
    [sym_keyword_content] = ACTIONS(55),
    [sym_keyword_merge] = ACTIONS(55),
    [sym_keyword_patch] = ACTIONS(55),
    [sym_keyword_then] = ACTIONS(55),
    [sym_keyword_type] = ACTIONS(55),
    [sym_keyword_permissions] = ACTIONS(55),
    [sym_keyword_for] = ACTIONS(55),
    [sym_keyword_comment] = ACTIONS(55),
    [sym_keyword_if] = ACTIONS(55),
    [sym_keyword_set] = ACTIONS(55),
    [sym_keyword_unset] = ACTIONS(55),
    [anon_sym_COMMA] = ACTIONS(55),
    [anon_sym_DASH_GT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(55),
    [anon_sym_RBRACK] = ACTIONS(55),
    [anon_sym_LPAREN] = ACTIONS(55),
    [anon_sym_RPAREN] = ACTIONS(55),
    [anon_sym_QMARK] = ACTIONS(57),
    [anon_sym_COLON] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_RBRACE] = ACTIONS(55),
    [anon_sym_LT_DASH] = ACTIONS(57),
    [anon_sym_LT_DASH_GT] = ACTIONS(55),
    [anon_sym_STAR] = ACTIONS(57),
    [anon_sym_DOT] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(57),
    [anon_sym_GT] = ACTIONS(57),
    [sym_variable_name] = ACTIONS(55),
    [sym_custom_function_name] = ACTIONS(55),
    [anon_sym_EQ] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(57),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LT_PIPE] = ACTIONS(55),
    [anon_sym_AMP_AMP] = ACTIONS(55),
    [anon_sym_PIPE_PIPE] = ACTIONS(55),
    [anon_sym_QMARK_QMARK] = ACTIONS(55),
    [anon_sym_QMARK_COLON] = ACTIONS(55),
    [anon_sym_BANG_EQ] = ACTIONS(55),
    [anon_sym_EQ_EQ] = ACTIONS(55),
    [anon_sym_QMARK_EQ] = ACTIONS(55),
    [anon_sym_STAR_EQ] = ACTIONS(55),
    [anon_sym_TILDE] = ACTIONS(55),
    [anon_sym_BANG_TILDE] = ACTIONS(55),
    [anon_sym_STAR_TILDE] = ACTIONS(55),
    [anon_sym_LT_EQ] = ACTIONS(55),
    [anon_sym_GT_EQ] = ACTIONS(55),
    [anon_sym_PLUS] = ACTIONS(57),
    [anon_sym_PLUS_EQ] = ACTIONS(55),
    [anon_sym_DASH_EQ] = ACTIONS(55),
    [anon_sym_u00d7] = ACTIONS(55),
    [anon_sym_SLASH] = ACTIONS(57),
    [anon_sym_u00f7] = ACTIONS(55),
    [anon_sym_STAR_STAR] = ACTIONS(55),
    [anon_sym_u220b] = ACTIONS(55),
    [anon_sym_u220c] = ACTIONS(55),
    [anon_sym_u2287] = ACTIONS(55),
    [anon_sym_u2283] = ACTIONS(55),
    [anon_sym_u2285] = ACTIONS(55),
    [anon_sym_u2208] = ACTIONS(55),
    [anon_sym_u2209] = ACTIONS(55),
    [anon_sym_u2286] = ACTIONS(55),
    [anon_sym_u2282] = ACTIONS(55),
    [anon_sym_u2284] = ACTIONS(55),
    [anon_sym_AT_AT] = ACTIONS(55),
  },
  [13] = {
    [ts_builtin_sym_end] = ACTIONS(122),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(122),
    [sym_keyword_return] = ACTIONS(122),
    [sym_keyword_value] = ACTIONS(122),
    [sym_keyword_explain] = ACTIONS(122),
    [sym_keyword_parallel] = ACTIONS(122),
    [sym_keyword_timeout] = ACTIONS(122),
    [sym_keyword_fetch] = ACTIONS(122),
    [sym_keyword_limit] = ACTIONS(122),
    [sym_keyword_rand] = ACTIONS(122),
    [sym_keyword_collate] = ACTIONS(122),
    [sym_keyword_numeric] = ACTIONS(122),
    [sym_keyword_asc] = ACTIONS(122),
    [sym_keyword_desc] = ACTIONS(122),
    [sym_keyword_where] = ACTIONS(122),
    [sym_keyword_and] = ACTIONS(122),
    [sym_keyword_or] = ACTIONS(122),
    [sym_keyword_is] = ACTIONS(122),
    [sym_keyword_not] = ACTIONS(124),
    [sym_keyword_contains] = ACTIONS(122),
    [sym_keyword_contains_not] = ACTIONS(122),
    [sym_keyword_contains_all] = ACTIONS(122),
    [sym_keyword_contains_any] = ACTIONS(122),
    [sym_keyword_contains_none] = ACTIONS(122),
    [sym_keyword_inside] = ACTIONS(122),
    [sym_keyword_in] = ACTIONS(124),
    [sym_keyword_not_inside] = ACTIONS(122),
    [sym_keyword_all_inside] = ACTIONS(122),
    [sym_keyword_any_inside] = ACTIONS(122),
    [sym_keyword_none_inside] = ACTIONS(122),
    [sym_keyword_outside] = ACTIONS(122),
    [sym_keyword_intersects] = ACTIONS(122),
    [sym_keyword_flexible] = ACTIONS(122),
    [sym_keyword_readonly] = ACTIONS(122),
    [sym_keyword_content] = ACTIONS(122),
    [sym_keyword_merge] = ACTIONS(122),
    [sym_keyword_patch] = ACTIONS(122),
    [sym_keyword_type] = ACTIONS(122),
    [sym_keyword_default] = ACTIONS(122),
    [sym_keyword_assert] = ACTIONS(122),
    [sym_keyword_permissions] = ACTIONS(122),
    [sym_keyword_for] = ACTIONS(122),
    [sym_keyword_comment] = ACTIONS(122),
    [sym_keyword_set] = ACTIONS(122),
    [sym_keyword_unset] = ACTIONS(122),
    [anon_sym_COMMA] = ACTIONS(122),
    [anon_sym_DASH_GT] = ACTIONS(122),
    [anon_sym_LBRACK] = ACTIONS(122),
    [anon_sym_RBRACK] = ACTIONS(122),
    [anon_sym_RPAREN] = ACTIONS(122),
    [anon_sym_RBRACE] = ACTIONS(122),
    [anon_sym_LT_DASH] = ACTIONS(124),
    [anon_sym_LT_DASH_GT] = ACTIONS(122),
    [anon_sym_STAR] = ACTIONS(124),
    [anon_sym_DOT] = ACTIONS(124),
    [anon_sym_LT] = ACTIONS(124),
    [anon_sym_GT] = ACTIONS(124),
    [anon_sym_DOT_DOT] = ACTIONS(122),
    [anon_sym_EQ] = ACTIONS(124),
    [anon_sym_DASH] = ACTIONS(124),
    [anon_sym_AT] = ACTIONS(124),
    [anon_sym_LT_PIPE] = ACTIONS(122),
    [anon_sym_AMP_AMP] = ACTIONS(122),
    [anon_sym_PIPE_PIPE] = ACTIONS(122),
    [anon_sym_QMARK_QMARK] = ACTIONS(122),
    [anon_sym_QMARK_COLON] = ACTIONS(122),
    [anon_sym_BANG_EQ] = ACTIONS(122),
    [anon_sym_EQ_EQ] = ACTIONS(122),
    [anon_sym_QMARK_EQ] = ACTIONS(122),
    [anon_sym_STAR_EQ] = ACTIONS(122),
    [anon_sym_TILDE] = ACTIONS(122),
    [anon_sym_BANG_TILDE] = ACTIONS(122),
    [anon_sym_STAR_TILDE] = ACTIONS(122),
    [anon_sym_LT_EQ] = ACTIONS(122),
    [anon_sym_GT_EQ] = ACTIONS(122),
    [anon_sym_PLUS] = ACTIONS(124),
    [anon_sym_PLUS_EQ] = ACTIONS(122),
    [anon_sym_DASH_EQ] = ACTIONS(122),
    [anon_sym_u00d7] = ACTIONS(122),
    [anon_sym_SLASH] = ACTIONS(124),
    [anon_sym_u00f7] = ACTIONS(122),
    [anon_sym_STAR_STAR] = ACTIONS(122),
    [anon_sym_u220b] = ACTIONS(122),
    [anon_sym_u220c] = ACTIONS(122),
    [anon_sym_u2287] = ACTIONS(122),
    [anon_sym_u2283] = ACTIONS(122),
    [anon_sym_u2285] = ACTIONS(122),
    [anon_sym_u2208] = ACTIONS(122),
    [anon_sym_u2209] = ACTIONS(122),
    [anon_sym_u2286] = ACTIONS(122),
    [anon_sym_u2282] = ACTIONS(122),
    [anon_sym_u2284] = ACTIONS(122),
    [anon_sym_AT_AT] = ACTIONS(122),
  },
  [14] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(116),
    [sym_keyword_return] = ACTIONS(116),
    [sym_keyword_from] = ACTIONS(116),
    [sym_keyword_as] = ACTIONS(116),
    [sym_keyword_parallel] = ACTIONS(116),
    [sym_keyword_timeout] = ACTIONS(116),
    [sym_keyword_where] = ACTIONS(116),
    [sym_keyword_group] = ACTIONS(116),
    [sym_keyword_and] = ACTIONS(116),
    [sym_keyword_or] = ACTIONS(116),
    [sym_keyword_is] = ACTIONS(116),
    [sym_keyword_not] = ACTIONS(118),
    [sym_keyword_contains] = ACTIONS(116),
    [sym_keyword_contains_not] = ACTIONS(116),
    [sym_keyword_contains_all] = ACTIONS(116),
    [sym_keyword_contains_any] = ACTIONS(116),
    [sym_keyword_contains_none] = ACTIONS(116),
    [sym_keyword_inside] = ACTIONS(116),
    [sym_keyword_in] = ACTIONS(118),
    [sym_keyword_not_inside] = ACTIONS(116),
    [sym_keyword_all_inside] = ACTIONS(116),
    [sym_keyword_any_inside] = ACTIONS(116),
    [sym_keyword_none_inside] = ACTIONS(116),
    [sym_keyword_outside] = ACTIONS(116),
    [sym_keyword_intersects] = ACTIONS(116),
    [sym_keyword_drop] = ACTIONS(116),
    [sym_keyword_schemafull] = ACTIONS(116),
    [sym_keyword_schemaless] = ACTIONS(116),
    [sym_keyword_changefeed] = ACTIONS(116),
    [sym_keyword_content] = ACTIONS(116),
    [sym_keyword_merge] = ACTIONS(116),
    [sym_keyword_patch] = ACTIONS(116),
    [sym_keyword_then] = ACTIONS(116),
    [sym_keyword_type] = ACTIONS(116),
    [sym_keyword_permissions] = ACTIONS(116),
    [sym_keyword_for] = ACTIONS(116),
    [sym_keyword_comment] = ACTIONS(116),
    [sym_keyword_if] = ACTIONS(116),
    [sym_keyword_set] = ACTIONS(116),
    [sym_keyword_unset] = ACTIONS(116),
    [anon_sym_COMMA] = ACTIONS(116),
    [anon_sym_DASH_GT] = ACTIONS(116),
    [anon_sym_LBRACK] = ACTIONS(116),
    [anon_sym_RBRACK] = ACTIONS(116),
    [anon_sym_LPAREN] = ACTIONS(116),
    [anon_sym_RPAREN] = ACTIONS(116),
    [anon_sym_QMARK] = ACTIONS(118),
    [anon_sym_LBRACE] = ACTIONS(116),
    [anon_sym_RBRACE] = ACTIONS(116),
    [anon_sym_LT_DASH] = ACTIONS(118),
    [anon_sym_LT_DASH_GT] = ACTIONS(116),
    [anon_sym_STAR] = ACTIONS(118),
    [anon_sym_DOT] = ACTIONS(118),
    [anon_sym_LT] = ACTIONS(118),
    [anon_sym_GT] = ACTIONS(118),
    [sym_variable_name] = ACTIONS(116),
    [sym_custom_function_name] = ACTIONS(116),
    [anon_sym_DOT_DOT] = ACTIONS(116),
    [anon_sym_EQ] = ACTIONS(118),
    [anon_sym_DASH] = ACTIONS(118),
    [anon_sym_AT] = ACTIONS(118),
    [anon_sym_LT_PIPE] = ACTIONS(116),
    [anon_sym_AMP_AMP] = ACTIONS(116),
    [anon_sym_PIPE_PIPE] = ACTIONS(116),
    [anon_sym_QMARK_QMARK] = ACTIONS(116),
    [anon_sym_QMARK_COLON] = ACTIONS(116),
    [anon_sym_BANG_EQ] = ACTIONS(116),
    [anon_sym_EQ_EQ] = ACTIONS(116),
    [anon_sym_QMARK_EQ] = ACTIONS(116),
    [anon_sym_STAR_EQ] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(116),
    [anon_sym_BANG_TILDE] = ACTIONS(116),
    [anon_sym_STAR_TILDE] = ACTIONS(116),
    [anon_sym_LT_EQ] = ACTIONS(116),
    [anon_sym_GT_EQ] = ACTIONS(116),
    [anon_sym_PLUS] = ACTIONS(118),
    [anon_sym_PLUS_EQ] = ACTIONS(116),
    [anon_sym_DASH_EQ] = ACTIONS(116),
    [anon_sym_u00d7] = ACTIONS(116),
    [anon_sym_SLASH] = ACTIONS(118),
    [anon_sym_u00f7] = ACTIONS(116),
    [anon_sym_STAR_STAR] = ACTIONS(116),
    [anon_sym_u220b] = ACTIONS(116),
    [anon_sym_u220c] = ACTIONS(116),
    [anon_sym_u2287] = ACTIONS(116),
    [anon_sym_u2283] = ACTIONS(116),
    [anon_sym_u2285] = ACTIONS(116),
    [anon_sym_u2208] = ACTIONS(116),
    [anon_sym_u2209] = ACTIONS(116),
    [anon_sym_u2286] = ACTIONS(116),
    [anon_sym_u2282] = ACTIONS(116),
    [anon_sym_u2284] = ACTIONS(116),
    [anon_sym_AT_AT] = ACTIONS(116),
  },
  [15] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(126),
    [sym_keyword_return] = ACTIONS(126),
    [sym_keyword_from] = ACTIONS(126),
    [sym_keyword_as] = ACTIONS(126),
    [sym_keyword_parallel] = ACTIONS(126),
    [sym_keyword_timeout] = ACTIONS(126),
    [sym_keyword_where] = ACTIONS(126),
    [sym_keyword_group] = ACTIONS(126),
    [sym_keyword_and] = ACTIONS(126),
    [sym_keyword_or] = ACTIONS(126),
    [sym_keyword_is] = ACTIONS(126),
    [sym_keyword_not] = ACTIONS(128),
    [sym_keyword_contains] = ACTIONS(126),
    [sym_keyword_contains_not] = ACTIONS(126),
    [sym_keyword_contains_all] = ACTIONS(126),
    [sym_keyword_contains_any] = ACTIONS(126),
    [sym_keyword_contains_none] = ACTIONS(126),
    [sym_keyword_inside] = ACTIONS(126),
    [sym_keyword_in] = ACTIONS(128),
    [sym_keyword_not_inside] = ACTIONS(126),
    [sym_keyword_all_inside] = ACTIONS(126),
    [sym_keyword_any_inside] = ACTIONS(126),
    [sym_keyword_none_inside] = ACTIONS(126),
    [sym_keyword_outside] = ACTIONS(126),
    [sym_keyword_intersects] = ACTIONS(126),
    [sym_keyword_drop] = ACTIONS(126),
    [sym_keyword_schemafull] = ACTIONS(126),
    [sym_keyword_schemaless] = ACTIONS(126),
    [sym_keyword_changefeed] = ACTIONS(126),
    [sym_keyword_content] = ACTIONS(126),
    [sym_keyword_merge] = ACTIONS(126),
    [sym_keyword_patch] = ACTIONS(126),
    [sym_keyword_then] = ACTIONS(126),
    [sym_keyword_type] = ACTIONS(126),
    [sym_keyword_permissions] = ACTIONS(126),
    [sym_keyword_for] = ACTIONS(126),
    [sym_keyword_comment] = ACTIONS(126),
    [sym_keyword_if] = ACTIONS(126),
    [sym_keyword_set] = ACTIONS(126),
    [sym_keyword_unset] = ACTIONS(126),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_DASH_GT] = ACTIONS(126),
    [anon_sym_LBRACK] = ACTIONS(126),
    [anon_sym_RBRACK] = ACTIONS(126),
    [anon_sym_LPAREN] = ACTIONS(126),
    [anon_sym_RPAREN] = ACTIONS(126),
    [anon_sym_QMARK] = ACTIONS(128),
    [anon_sym_LBRACE] = ACTIONS(126),
    [anon_sym_RBRACE] = ACTIONS(126),
    [anon_sym_LT_DASH] = ACTIONS(128),
    [anon_sym_LT_DASH_GT] = ACTIONS(126),
    [anon_sym_STAR] = ACTIONS(128),
    [anon_sym_DOT] = ACTIONS(128),
    [anon_sym_LT] = ACTIONS(128),
    [anon_sym_GT] = ACTIONS(128),
    [sym_variable_name] = ACTIONS(126),
    [sym_custom_function_name] = ACTIONS(126),
    [anon_sym_DOT_DOT] = ACTIONS(126),
    [anon_sym_EQ] = ACTIONS(128),
    [anon_sym_DASH] = ACTIONS(128),
    [anon_sym_AT] = ACTIONS(128),
    [anon_sym_LT_PIPE] = ACTIONS(126),
    [anon_sym_AMP_AMP] = ACTIONS(126),
    [anon_sym_PIPE_PIPE] = ACTIONS(126),
    [anon_sym_QMARK_QMARK] = ACTIONS(126),
    [anon_sym_QMARK_COLON] = ACTIONS(126),
    [anon_sym_BANG_EQ] = ACTIONS(126),
    [anon_sym_EQ_EQ] = ACTIONS(126),
    [anon_sym_QMARK_EQ] = ACTIONS(126),
    [anon_sym_STAR_EQ] = ACTIONS(126),
    [anon_sym_TILDE] = ACTIONS(126),
    [anon_sym_BANG_TILDE] = ACTIONS(126),
    [anon_sym_STAR_TILDE] = ACTIONS(126),
    [anon_sym_LT_EQ] = ACTIONS(126),
    [anon_sym_GT_EQ] = ACTIONS(126),
    [anon_sym_PLUS] = ACTIONS(128),
    [anon_sym_PLUS_EQ] = ACTIONS(126),
    [anon_sym_DASH_EQ] = ACTIONS(126),
    [anon_sym_u00d7] = ACTIONS(126),
    [anon_sym_SLASH] = ACTIONS(128),
    [anon_sym_u00f7] = ACTIONS(126),
    [anon_sym_STAR_STAR] = ACTIONS(126),
    [anon_sym_u220b] = ACTIONS(126),
    [anon_sym_u220c] = ACTIONS(126),
    [anon_sym_u2287] = ACTIONS(126),
    [anon_sym_u2283] = ACTIONS(126),
    [anon_sym_u2285] = ACTIONS(126),
    [anon_sym_u2208] = ACTIONS(126),
    [anon_sym_u2209] = ACTIONS(126),
    [anon_sym_u2286] = ACTIONS(126),
    [anon_sym_u2282] = ACTIONS(126),
    [anon_sym_u2284] = ACTIONS(126),
    [anon_sym_AT_AT] = ACTIONS(126),
  },
  [16] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(130),
    [sym_keyword_return] = ACTIONS(130),
    [sym_keyword_from] = ACTIONS(130),
    [sym_keyword_as] = ACTIONS(130),
    [sym_keyword_parallel] = ACTIONS(130),
    [sym_keyword_timeout] = ACTIONS(130),
    [sym_keyword_where] = ACTIONS(130),
    [sym_keyword_group] = ACTIONS(130),
    [sym_keyword_and] = ACTIONS(130),
    [sym_keyword_or] = ACTIONS(130),
    [sym_keyword_is] = ACTIONS(130),
    [sym_keyword_not] = ACTIONS(132),
    [sym_keyword_contains] = ACTIONS(130),
    [sym_keyword_contains_not] = ACTIONS(130),
    [sym_keyword_contains_all] = ACTIONS(130),
    [sym_keyword_contains_any] = ACTIONS(130),
    [sym_keyword_contains_none] = ACTIONS(130),
    [sym_keyword_inside] = ACTIONS(130),
    [sym_keyword_in] = ACTIONS(132),
    [sym_keyword_not_inside] = ACTIONS(130),
    [sym_keyword_all_inside] = ACTIONS(130),
    [sym_keyword_any_inside] = ACTIONS(130),
    [sym_keyword_none_inside] = ACTIONS(130),
    [sym_keyword_outside] = ACTIONS(130),
    [sym_keyword_intersects] = ACTIONS(130),
    [sym_keyword_drop] = ACTIONS(130),
    [sym_keyword_schemafull] = ACTIONS(130),
    [sym_keyword_schemaless] = ACTIONS(130),
    [sym_keyword_changefeed] = ACTIONS(130),
    [sym_keyword_content] = ACTIONS(130),
    [sym_keyword_merge] = ACTIONS(130),
    [sym_keyword_patch] = ACTIONS(130),
    [sym_keyword_then] = ACTIONS(130),
    [sym_keyword_type] = ACTIONS(130),
    [sym_keyword_permissions] = ACTIONS(130),
    [sym_keyword_for] = ACTIONS(130),
    [sym_keyword_comment] = ACTIONS(130),
    [sym_keyword_if] = ACTIONS(130),
    [sym_keyword_set] = ACTIONS(130),
    [sym_keyword_unset] = ACTIONS(130),
    [anon_sym_COMMA] = ACTIONS(130),
    [anon_sym_DASH_GT] = ACTIONS(130),
    [anon_sym_LBRACK] = ACTIONS(130),
    [anon_sym_RBRACK] = ACTIONS(130),
    [anon_sym_LPAREN] = ACTIONS(130),
    [anon_sym_RPAREN] = ACTIONS(130),
    [anon_sym_QMARK] = ACTIONS(132),
    [anon_sym_LBRACE] = ACTIONS(130),
    [anon_sym_RBRACE] = ACTIONS(130),
    [anon_sym_LT_DASH] = ACTIONS(132),
    [anon_sym_LT_DASH_GT] = ACTIONS(130),
    [anon_sym_STAR] = ACTIONS(132),
    [anon_sym_DOT] = ACTIONS(132),
    [anon_sym_LT] = ACTIONS(132),
    [anon_sym_GT] = ACTIONS(132),
    [sym_variable_name] = ACTIONS(130),
    [sym_custom_function_name] = ACTIONS(130),
    [anon_sym_DOT_DOT] = ACTIONS(130),
    [anon_sym_EQ] = ACTIONS(132),
    [anon_sym_DASH] = ACTIONS(132),
    [anon_sym_AT] = ACTIONS(132),
    [anon_sym_LT_PIPE] = ACTIONS(130),
    [anon_sym_AMP_AMP] = ACTIONS(130),
    [anon_sym_PIPE_PIPE] = ACTIONS(130),
    [anon_sym_QMARK_QMARK] = ACTIONS(130),
    [anon_sym_QMARK_COLON] = ACTIONS(130),
    [anon_sym_BANG_EQ] = ACTIONS(130),
    [anon_sym_EQ_EQ] = ACTIONS(130),
    [anon_sym_QMARK_EQ] = ACTIONS(130),
    [anon_sym_STAR_EQ] = ACTIONS(130),
    [anon_sym_TILDE] = ACTIONS(130),
    [anon_sym_BANG_TILDE] = ACTIONS(130),
    [anon_sym_STAR_TILDE] = ACTIONS(130),
    [anon_sym_LT_EQ] = ACTIONS(130),
    [anon_sym_GT_EQ] = ACTIONS(130),
    [anon_sym_PLUS] = ACTIONS(132),
    [anon_sym_PLUS_EQ] = ACTIONS(130),
    [anon_sym_DASH_EQ] = ACTIONS(130),
    [anon_sym_u00d7] = ACTIONS(130),
    [anon_sym_SLASH] = ACTIONS(132),
    [anon_sym_u00f7] = ACTIONS(130),
    [anon_sym_STAR_STAR] = ACTIONS(130),
    [anon_sym_u220b] = ACTIONS(130),
    [anon_sym_u220c] = ACTIONS(130),
    [anon_sym_u2287] = ACTIONS(130),
    [anon_sym_u2283] = ACTIONS(130),
    [anon_sym_u2285] = ACTIONS(130),
    [anon_sym_u2208] = ACTIONS(130),
    [anon_sym_u2209] = ACTIONS(130),
    [anon_sym_u2286] = ACTIONS(130),
    [anon_sym_u2282] = ACTIONS(130),
    [anon_sym_u2284] = ACTIONS(130),
    [anon_sym_AT_AT] = ACTIONS(130),
  },
  [17] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(122),
    [sym_keyword_return] = ACTIONS(122),
    [sym_keyword_from] = ACTIONS(122),
    [sym_keyword_as] = ACTIONS(122),
    [sym_keyword_parallel] = ACTIONS(122),
    [sym_keyword_timeout] = ACTIONS(122),
    [sym_keyword_where] = ACTIONS(122),
    [sym_keyword_group] = ACTIONS(122),
    [sym_keyword_and] = ACTIONS(122),
    [sym_keyword_or] = ACTIONS(122),
    [sym_keyword_is] = ACTIONS(122),
    [sym_keyword_not] = ACTIONS(124),
    [sym_keyword_contains] = ACTIONS(122),
    [sym_keyword_contains_not] = ACTIONS(122),
    [sym_keyword_contains_all] = ACTIONS(122),
    [sym_keyword_contains_any] = ACTIONS(122),
    [sym_keyword_contains_none] = ACTIONS(122),
    [sym_keyword_inside] = ACTIONS(122),
    [sym_keyword_in] = ACTIONS(124),
    [sym_keyword_not_inside] = ACTIONS(122),
    [sym_keyword_all_inside] = ACTIONS(122),
    [sym_keyword_any_inside] = ACTIONS(122),
    [sym_keyword_none_inside] = ACTIONS(122),
    [sym_keyword_outside] = ACTIONS(122),
    [sym_keyword_intersects] = ACTIONS(122),
    [sym_keyword_drop] = ACTIONS(122),
    [sym_keyword_schemafull] = ACTIONS(122),
    [sym_keyword_schemaless] = ACTIONS(122),
    [sym_keyword_changefeed] = ACTIONS(122),
    [sym_keyword_content] = ACTIONS(122),
    [sym_keyword_merge] = ACTIONS(122),
    [sym_keyword_patch] = ACTIONS(122),
    [sym_keyword_then] = ACTIONS(122),
    [sym_keyword_type] = ACTIONS(122),
    [sym_keyword_permissions] = ACTIONS(122),
    [sym_keyword_for] = ACTIONS(122),
    [sym_keyword_comment] = ACTIONS(122),
    [sym_keyword_if] = ACTIONS(122),
    [sym_keyword_set] = ACTIONS(122),
    [sym_keyword_unset] = ACTIONS(122),
    [anon_sym_COMMA] = ACTIONS(122),
    [anon_sym_DASH_GT] = ACTIONS(122),
    [anon_sym_LBRACK] = ACTIONS(122),
    [anon_sym_RBRACK] = ACTIONS(122),
    [anon_sym_LPAREN] = ACTIONS(122),
    [anon_sym_RPAREN] = ACTIONS(122),
    [anon_sym_QMARK] = ACTIONS(124),
    [anon_sym_LBRACE] = ACTIONS(122),
    [anon_sym_RBRACE] = ACTIONS(122),
    [anon_sym_LT_DASH] = ACTIONS(124),
    [anon_sym_LT_DASH_GT] = ACTIONS(122),
    [anon_sym_STAR] = ACTIONS(124),
    [anon_sym_DOT] = ACTIONS(124),
    [anon_sym_LT] = ACTIONS(124),
    [anon_sym_GT] = ACTIONS(124),
    [sym_variable_name] = ACTIONS(122),
    [sym_custom_function_name] = ACTIONS(122),
    [anon_sym_DOT_DOT] = ACTIONS(122),
    [anon_sym_EQ] = ACTIONS(124),
    [anon_sym_DASH] = ACTIONS(124),
    [anon_sym_AT] = ACTIONS(124),
    [anon_sym_LT_PIPE] = ACTIONS(122),
    [anon_sym_AMP_AMP] = ACTIONS(122),
    [anon_sym_PIPE_PIPE] = ACTIONS(122),
    [anon_sym_QMARK_QMARK] = ACTIONS(122),
    [anon_sym_QMARK_COLON] = ACTIONS(122),
    [anon_sym_BANG_EQ] = ACTIONS(122),
    [anon_sym_EQ_EQ] = ACTIONS(122),
    [anon_sym_QMARK_EQ] = ACTIONS(122),
    [anon_sym_STAR_EQ] = ACTIONS(122),
    [anon_sym_TILDE] = ACTIONS(122),
    [anon_sym_BANG_TILDE] = ACTIONS(122),
    [anon_sym_STAR_TILDE] = ACTIONS(122),
    [anon_sym_LT_EQ] = ACTIONS(122),
    [anon_sym_GT_EQ] = ACTIONS(122),
    [anon_sym_PLUS] = ACTIONS(124),
    [anon_sym_PLUS_EQ] = ACTIONS(122),
    [anon_sym_DASH_EQ] = ACTIONS(122),
    [anon_sym_u00d7] = ACTIONS(122),
    [anon_sym_SLASH] = ACTIONS(124),
    [anon_sym_u00f7] = ACTIONS(122),
    [anon_sym_STAR_STAR] = ACTIONS(122),
    [anon_sym_u220b] = ACTIONS(122),
    [anon_sym_u220c] = ACTIONS(122),
    [anon_sym_u2287] = ACTIONS(122),
    [anon_sym_u2283] = ACTIONS(122),
    [anon_sym_u2285] = ACTIONS(122),
    [anon_sym_u2208] = ACTIONS(122),
    [anon_sym_u2209] = ACTIONS(122),
    [anon_sym_u2286] = ACTIONS(122),
    [anon_sym_u2282] = ACTIONS(122),
    [anon_sym_u2284] = ACTIONS(122),
    [anon_sym_AT_AT] = ACTIONS(122),
  },
  [18] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(134),
    [sym_keyword_return] = ACTIONS(134),
    [sym_keyword_from] = ACTIONS(134),
    [sym_keyword_as] = ACTIONS(134),
    [sym_keyword_parallel] = ACTIONS(134),
    [sym_keyword_timeout] = ACTIONS(134),
    [sym_keyword_where] = ACTIONS(134),
    [sym_keyword_group] = ACTIONS(134),
    [sym_keyword_and] = ACTIONS(134),
    [sym_keyword_or] = ACTIONS(134),
    [sym_keyword_is] = ACTIONS(134),
    [sym_keyword_not] = ACTIONS(136),
    [sym_keyword_contains] = ACTIONS(134),
    [sym_keyword_contains_not] = ACTIONS(134),
    [sym_keyword_contains_all] = ACTIONS(134),
    [sym_keyword_contains_any] = ACTIONS(134),
    [sym_keyword_contains_none] = ACTIONS(134),
    [sym_keyword_inside] = ACTIONS(134),
    [sym_keyword_in] = ACTIONS(136),
    [sym_keyword_not_inside] = ACTIONS(134),
    [sym_keyword_all_inside] = ACTIONS(134),
    [sym_keyword_any_inside] = ACTIONS(134),
    [sym_keyword_none_inside] = ACTIONS(134),
    [sym_keyword_outside] = ACTIONS(134),
    [sym_keyword_intersects] = ACTIONS(134),
    [sym_keyword_drop] = ACTIONS(134),
    [sym_keyword_schemafull] = ACTIONS(134),
    [sym_keyword_schemaless] = ACTIONS(134),
    [sym_keyword_changefeed] = ACTIONS(134),
    [sym_keyword_content] = ACTIONS(134),
    [sym_keyword_merge] = ACTIONS(134),
    [sym_keyword_patch] = ACTIONS(134),
    [sym_keyword_then] = ACTIONS(134),
    [sym_keyword_type] = ACTIONS(134),
    [sym_keyword_permissions] = ACTIONS(134),
    [sym_keyword_for] = ACTIONS(134),
    [sym_keyword_comment] = ACTIONS(134),
    [sym_keyword_if] = ACTIONS(134),
    [sym_keyword_set] = ACTIONS(134),
    [sym_keyword_unset] = ACTIONS(134),
    [anon_sym_COMMA] = ACTIONS(134),
    [anon_sym_DASH_GT] = ACTIONS(134),
    [anon_sym_LBRACK] = ACTIONS(134),
    [anon_sym_RBRACK] = ACTIONS(134),
    [anon_sym_LPAREN] = ACTIONS(134),
    [anon_sym_RPAREN] = ACTIONS(134),
    [anon_sym_QMARK] = ACTIONS(136),
    [anon_sym_LBRACE] = ACTIONS(134),
    [anon_sym_RBRACE] = ACTIONS(134),
    [anon_sym_LT_DASH] = ACTIONS(136),
    [anon_sym_LT_DASH_GT] = ACTIONS(134),
    [anon_sym_STAR] = ACTIONS(136),
    [anon_sym_DOT] = ACTIONS(136),
    [anon_sym_LT] = ACTIONS(136),
    [anon_sym_GT] = ACTIONS(136),
    [sym_variable_name] = ACTIONS(134),
    [sym_custom_function_name] = ACTIONS(134),
    [anon_sym_DOT_DOT] = ACTIONS(134),
    [anon_sym_EQ] = ACTIONS(136),
    [anon_sym_DASH] = ACTIONS(136),
    [anon_sym_AT] = ACTIONS(136),
    [anon_sym_LT_PIPE] = ACTIONS(134),
    [anon_sym_AMP_AMP] = ACTIONS(134),
    [anon_sym_PIPE_PIPE] = ACTIONS(134),
    [anon_sym_QMARK_QMARK] = ACTIONS(134),
    [anon_sym_QMARK_COLON] = ACTIONS(134),
    [anon_sym_BANG_EQ] = ACTIONS(134),
    [anon_sym_EQ_EQ] = ACTIONS(134),
    [anon_sym_QMARK_EQ] = ACTIONS(134),
    [anon_sym_STAR_EQ] = ACTIONS(134),
    [anon_sym_TILDE] = ACTIONS(134),
    [anon_sym_BANG_TILDE] = ACTIONS(134),
    [anon_sym_STAR_TILDE] = ACTIONS(134),
    [anon_sym_LT_EQ] = ACTIONS(134),
    [anon_sym_GT_EQ] = ACTIONS(134),
    [anon_sym_PLUS] = ACTIONS(136),
    [anon_sym_PLUS_EQ] = ACTIONS(134),
    [anon_sym_DASH_EQ] = ACTIONS(134),
    [anon_sym_u00d7] = ACTIONS(134),
    [anon_sym_SLASH] = ACTIONS(136),
    [anon_sym_u00f7] = ACTIONS(134),
    [anon_sym_STAR_STAR] = ACTIONS(134),
    [anon_sym_u220b] = ACTIONS(134),
    [anon_sym_u220c] = ACTIONS(134),
    [anon_sym_u2287] = ACTIONS(134),
    [anon_sym_u2283] = ACTIONS(134),
    [anon_sym_u2285] = ACTIONS(134),
    [anon_sym_u2208] = ACTIONS(134),
    [anon_sym_u2209] = ACTIONS(134),
    [anon_sym_u2286] = ACTIONS(134),
    [anon_sym_u2282] = ACTIONS(134),
    [anon_sym_u2284] = ACTIONS(134),
    [anon_sym_AT_AT] = ACTIONS(134),
  },
  [19] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(138),
    [sym_keyword_return] = ACTIONS(138),
    [sym_keyword_from] = ACTIONS(138),
    [sym_keyword_as] = ACTIONS(138),
    [sym_keyword_parallel] = ACTIONS(138),
    [sym_keyword_timeout] = ACTIONS(138),
    [sym_keyword_where] = ACTIONS(138),
    [sym_keyword_group] = ACTIONS(138),
    [sym_keyword_and] = ACTIONS(138),
    [sym_keyword_or] = ACTIONS(138),
    [sym_keyword_is] = ACTIONS(138),
    [sym_keyword_not] = ACTIONS(140),
    [sym_keyword_contains] = ACTIONS(138),
    [sym_keyword_contains_not] = ACTIONS(138),
    [sym_keyword_contains_all] = ACTIONS(138),
    [sym_keyword_contains_any] = ACTIONS(138),
    [sym_keyword_contains_none] = ACTIONS(138),
    [sym_keyword_inside] = ACTIONS(138),
    [sym_keyword_in] = ACTIONS(140),
    [sym_keyword_not_inside] = ACTIONS(138),
    [sym_keyword_all_inside] = ACTIONS(138),
    [sym_keyword_any_inside] = ACTIONS(138),
    [sym_keyword_none_inside] = ACTIONS(138),
    [sym_keyword_outside] = ACTIONS(138),
    [sym_keyword_intersects] = ACTIONS(138),
    [sym_keyword_drop] = ACTIONS(138),
    [sym_keyword_schemafull] = ACTIONS(138),
    [sym_keyword_schemaless] = ACTIONS(138),
    [sym_keyword_changefeed] = ACTIONS(138),
    [sym_keyword_content] = ACTIONS(138),
    [sym_keyword_merge] = ACTIONS(138),
    [sym_keyword_patch] = ACTIONS(138),
    [sym_keyword_then] = ACTIONS(138),
    [sym_keyword_type] = ACTIONS(138),
    [sym_keyword_permissions] = ACTIONS(138),
    [sym_keyword_for] = ACTIONS(138),
    [sym_keyword_comment] = ACTIONS(138),
    [sym_keyword_if] = ACTIONS(138),
    [sym_keyword_set] = ACTIONS(138),
    [sym_keyword_unset] = ACTIONS(138),
    [anon_sym_COMMA] = ACTIONS(138),
    [anon_sym_DASH_GT] = ACTIONS(138),
    [anon_sym_LBRACK] = ACTIONS(138),
    [anon_sym_RBRACK] = ACTIONS(138),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_RPAREN] = ACTIONS(138),
    [anon_sym_QMARK] = ACTIONS(140),
    [anon_sym_LBRACE] = ACTIONS(138),
    [anon_sym_RBRACE] = ACTIONS(138),
    [anon_sym_LT_DASH] = ACTIONS(140),
    [anon_sym_LT_DASH_GT] = ACTIONS(138),
    [anon_sym_STAR] = ACTIONS(140),
    [anon_sym_DOT] = ACTIONS(138),
    [anon_sym_LT] = ACTIONS(140),
    [anon_sym_GT] = ACTIONS(140),
    [sym_variable_name] = ACTIONS(138),
    [sym_custom_function_name] = ACTIONS(138),
    [anon_sym_EQ] = ACTIONS(140),
    [anon_sym_DASH] = ACTIONS(140),
    [anon_sym_AT] = ACTIONS(140),
    [anon_sym_LT_PIPE] = ACTIONS(138),
    [anon_sym_AMP_AMP] = ACTIONS(138),
    [anon_sym_PIPE_PIPE] = ACTIONS(138),
    [anon_sym_QMARK_QMARK] = ACTIONS(138),
    [anon_sym_QMARK_COLON] = ACTIONS(138),
    [anon_sym_BANG_EQ] = ACTIONS(138),
    [anon_sym_EQ_EQ] = ACTIONS(138),
    [anon_sym_QMARK_EQ] = ACTIONS(138),
    [anon_sym_STAR_EQ] = ACTIONS(138),
    [anon_sym_TILDE] = ACTIONS(138),
    [anon_sym_BANG_TILDE] = ACTIONS(138),
    [anon_sym_STAR_TILDE] = ACTIONS(138),
    [anon_sym_LT_EQ] = ACTIONS(138),
    [anon_sym_GT_EQ] = ACTIONS(138),
    [anon_sym_PLUS] = ACTIONS(140),
    [anon_sym_PLUS_EQ] = ACTIONS(138),
    [anon_sym_DASH_EQ] = ACTIONS(138),
    [anon_sym_u00d7] = ACTIONS(138),
    [anon_sym_SLASH] = ACTIONS(140),
    [anon_sym_u00f7] = ACTIONS(138),
    [anon_sym_STAR_STAR] = ACTIONS(138),
    [anon_sym_u220b] = ACTIONS(138),
    [anon_sym_u220c] = ACTIONS(138),
    [anon_sym_u2287] = ACTIONS(138),
    [anon_sym_u2283] = ACTIONS(138),
    [anon_sym_u2285] = ACTIONS(138),
    [anon_sym_u2208] = ACTIONS(138),
    [anon_sym_u2209] = ACTIONS(138),
    [anon_sym_u2286] = ACTIONS(138),
    [anon_sym_u2282] = ACTIONS(138),
    [anon_sym_u2284] = ACTIONS(138),
    [anon_sym_AT_AT] = ACTIONS(138),
  },
  [20] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(142),
    [sym_keyword_return] = ACTIONS(142),
    [sym_keyword_from] = ACTIONS(142),
    [sym_keyword_as] = ACTIONS(142),
    [sym_keyword_parallel] = ACTIONS(142),
    [sym_keyword_timeout] = ACTIONS(142),
    [sym_keyword_where] = ACTIONS(142),
    [sym_keyword_group] = ACTIONS(142),
    [sym_keyword_and] = ACTIONS(142),
    [sym_keyword_or] = ACTIONS(142),
    [sym_keyword_is] = ACTIONS(142),
    [sym_keyword_not] = ACTIONS(144),
    [sym_keyword_contains] = ACTIONS(142),
    [sym_keyword_contains_not] = ACTIONS(142),
    [sym_keyword_contains_all] = ACTIONS(142),
    [sym_keyword_contains_any] = ACTIONS(142),
    [sym_keyword_contains_none] = ACTIONS(142),
    [sym_keyword_inside] = ACTIONS(142),
    [sym_keyword_in] = ACTIONS(144),
    [sym_keyword_not_inside] = ACTIONS(142),
    [sym_keyword_all_inside] = ACTIONS(142),
    [sym_keyword_any_inside] = ACTIONS(142),
    [sym_keyword_none_inside] = ACTIONS(142),
    [sym_keyword_outside] = ACTIONS(142),
    [sym_keyword_intersects] = ACTIONS(142),
    [sym_keyword_drop] = ACTIONS(142),
    [sym_keyword_schemafull] = ACTIONS(142),
    [sym_keyword_schemaless] = ACTIONS(142),
    [sym_keyword_changefeed] = ACTIONS(142),
    [sym_keyword_content] = ACTIONS(142),
    [sym_keyword_merge] = ACTIONS(142),
    [sym_keyword_patch] = ACTIONS(142),
    [sym_keyword_then] = ACTIONS(142),
    [sym_keyword_type] = ACTIONS(142),
    [sym_keyword_permissions] = ACTIONS(142),
    [sym_keyword_for] = ACTIONS(142),
    [sym_keyword_comment] = ACTIONS(142),
    [sym_keyword_if] = ACTIONS(142),
    [sym_keyword_set] = ACTIONS(142),
    [sym_keyword_unset] = ACTIONS(142),
    [anon_sym_COMMA] = ACTIONS(142),
    [anon_sym_DASH_GT] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(142),
    [anon_sym_RBRACK] = ACTIONS(142),
    [anon_sym_LPAREN] = ACTIONS(142),
    [anon_sym_RPAREN] = ACTIONS(142),
    [anon_sym_QMARK] = ACTIONS(144),
    [anon_sym_LBRACE] = ACTIONS(142),
    [anon_sym_RBRACE] = ACTIONS(142),
    [anon_sym_LT_DASH] = ACTIONS(144),
    [anon_sym_LT_DASH_GT] = ACTIONS(142),
    [anon_sym_STAR] = ACTIONS(144),
    [anon_sym_DOT] = ACTIONS(142),
    [anon_sym_LT] = ACTIONS(144),
    [anon_sym_GT] = ACTIONS(144),
    [sym_variable_name] = ACTIONS(142),
    [sym_custom_function_name] = ACTIONS(142),
    [anon_sym_EQ] = ACTIONS(144),
    [anon_sym_DASH] = ACTIONS(144),
    [anon_sym_AT] = ACTIONS(144),
    [anon_sym_LT_PIPE] = ACTIONS(142),
    [anon_sym_AMP_AMP] = ACTIONS(142),
    [anon_sym_PIPE_PIPE] = ACTIONS(142),
    [anon_sym_QMARK_QMARK] = ACTIONS(142),
    [anon_sym_QMARK_COLON] = ACTIONS(142),
    [anon_sym_BANG_EQ] = ACTIONS(142),
    [anon_sym_EQ_EQ] = ACTIONS(142),
    [anon_sym_QMARK_EQ] = ACTIONS(142),
    [anon_sym_STAR_EQ] = ACTIONS(142),
    [anon_sym_TILDE] = ACTIONS(142),
    [anon_sym_BANG_TILDE] = ACTIONS(142),
    [anon_sym_STAR_TILDE] = ACTIONS(142),
    [anon_sym_LT_EQ] = ACTIONS(142),
    [anon_sym_GT_EQ] = ACTIONS(142),
    [anon_sym_PLUS] = ACTIONS(144),
    [anon_sym_PLUS_EQ] = ACTIONS(142),
    [anon_sym_DASH_EQ] = ACTIONS(142),
    [anon_sym_u00d7] = ACTIONS(142),
    [anon_sym_SLASH] = ACTIONS(144),
    [anon_sym_u00f7] = ACTIONS(142),
    [anon_sym_STAR_STAR] = ACTIONS(142),
    [anon_sym_u220b] = ACTIONS(142),
    [anon_sym_u220c] = ACTIONS(142),
    [anon_sym_u2287] = ACTIONS(142),
    [anon_sym_u2283] = ACTIONS(142),
    [anon_sym_u2285] = ACTIONS(142),
    [anon_sym_u2208] = ACTIONS(142),
    [anon_sym_u2209] = ACTIONS(142),
    [anon_sym_u2286] = ACTIONS(142),
    [anon_sym_u2282] = ACTIONS(142),
    [anon_sym_u2284] = ACTIONS(142),
    [anon_sym_AT_AT] = ACTIONS(142),
  },
  [21] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(55),
    [sym_keyword_return] = ACTIONS(55),
    [sym_keyword_from] = ACTIONS(55),
    [sym_keyword_as] = ACTIONS(55),
    [sym_keyword_parallel] = ACTIONS(55),
    [sym_keyword_timeout] = ACTIONS(55),
    [sym_keyword_where] = ACTIONS(55),
    [sym_keyword_group] = ACTIONS(55),
    [sym_keyword_and] = ACTIONS(55),
    [sym_keyword_or] = ACTIONS(55),
    [sym_keyword_is] = ACTIONS(55),
    [sym_keyword_not] = ACTIONS(57),
    [sym_keyword_contains] = ACTIONS(55),
    [sym_keyword_contains_not] = ACTIONS(55),
    [sym_keyword_contains_all] = ACTIONS(55),
    [sym_keyword_contains_any] = ACTIONS(55),
    [sym_keyword_contains_none] = ACTIONS(55),
    [sym_keyword_inside] = ACTIONS(55),
    [sym_keyword_in] = ACTIONS(57),
    [sym_keyword_not_inside] = ACTIONS(55),
    [sym_keyword_all_inside] = ACTIONS(55),
    [sym_keyword_any_inside] = ACTIONS(55),
    [sym_keyword_none_inside] = ACTIONS(55),
    [sym_keyword_outside] = ACTIONS(55),
    [sym_keyword_intersects] = ACTIONS(55),
    [sym_keyword_drop] = ACTIONS(55),
    [sym_keyword_schemafull] = ACTIONS(55),
    [sym_keyword_schemaless] = ACTIONS(55),
    [sym_keyword_changefeed] = ACTIONS(55),
    [sym_keyword_content] = ACTIONS(55),
    [sym_keyword_merge] = ACTIONS(55),
    [sym_keyword_patch] = ACTIONS(55),
    [sym_keyword_then] = ACTIONS(55),
    [sym_keyword_type] = ACTIONS(55),
    [sym_keyword_permissions] = ACTIONS(55),
    [sym_keyword_for] = ACTIONS(55),
    [sym_keyword_comment] = ACTIONS(55),
    [sym_keyword_if] = ACTIONS(55),
    [sym_keyword_set] = ACTIONS(55),
    [sym_keyword_unset] = ACTIONS(55),
    [anon_sym_COMMA] = ACTIONS(55),
    [anon_sym_DASH_GT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(55),
    [anon_sym_RBRACK] = ACTIONS(55),
    [anon_sym_LPAREN] = ACTIONS(55),
    [anon_sym_RPAREN] = ACTIONS(55),
    [anon_sym_QMARK] = ACTIONS(57),
    [anon_sym_LBRACE] = ACTIONS(55),
    [anon_sym_RBRACE] = ACTIONS(55),
    [anon_sym_LT_DASH] = ACTIONS(57),
    [anon_sym_LT_DASH_GT] = ACTIONS(55),
    [anon_sym_STAR] = ACTIONS(57),
    [anon_sym_DOT] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(57),
    [anon_sym_GT] = ACTIONS(57),
    [sym_variable_name] = ACTIONS(55),
    [sym_custom_function_name] = ACTIONS(55),
    [anon_sym_EQ] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(57),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LT_PIPE] = ACTIONS(55),
    [anon_sym_AMP_AMP] = ACTIONS(55),
    [anon_sym_PIPE_PIPE] = ACTIONS(55),
    [anon_sym_QMARK_QMARK] = ACTIONS(55),
    [anon_sym_QMARK_COLON] = ACTIONS(55),
    [anon_sym_BANG_EQ] = ACTIONS(55),
    [anon_sym_EQ_EQ] = ACTIONS(55),
    [anon_sym_QMARK_EQ] = ACTIONS(55),
    [anon_sym_STAR_EQ] = ACTIONS(55),
    [anon_sym_TILDE] = ACTIONS(55),
    [anon_sym_BANG_TILDE] = ACTIONS(55),
    [anon_sym_STAR_TILDE] = ACTIONS(55),
    [anon_sym_LT_EQ] = ACTIONS(55),
    [anon_sym_GT_EQ] = ACTIONS(55),
    [anon_sym_PLUS] = ACTIONS(57),
    [anon_sym_PLUS_EQ] = ACTIONS(55),
    [anon_sym_DASH_EQ] = ACTIONS(55),
    [anon_sym_u00d7] = ACTIONS(55),
    [anon_sym_SLASH] = ACTIONS(57),
    [anon_sym_u00f7] = ACTIONS(55),
    [anon_sym_STAR_STAR] = ACTIONS(55),
    [anon_sym_u220b] = ACTIONS(55),
    [anon_sym_u220c] = ACTIONS(55),
    [anon_sym_u2287] = ACTIONS(55),
    [anon_sym_u2283] = ACTIONS(55),
    [anon_sym_u2285] = ACTIONS(55),
    [anon_sym_u2208] = ACTIONS(55),
    [anon_sym_u2209] = ACTIONS(55),
    [anon_sym_u2286] = ACTIONS(55),
    [anon_sym_u2282] = ACTIONS(55),
    [anon_sym_u2284] = ACTIONS(55),
    [anon_sym_AT_AT] = ACTIONS(55),
  },
  [22] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(146),
    [sym_keyword_return] = ACTIONS(146),
    [sym_keyword_from] = ACTIONS(146),
    [sym_keyword_as] = ACTIONS(146),
    [sym_keyword_parallel] = ACTIONS(146),
    [sym_keyword_timeout] = ACTIONS(146),
    [sym_keyword_where] = ACTIONS(146),
    [sym_keyword_group] = ACTIONS(146),
    [sym_keyword_and] = ACTIONS(146),
    [sym_keyword_or] = ACTIONS(146),
    [sym_keyword_is] = ACTIONS(146),
    [sym_keyword_not] = ACTIONS(148),
    [sym_keyword_contains] = ACTIONS(146),
    [sym_keyword_contains_not] = ACTIONS(146),
    [sym_keyword_contains_all] = ACTIONS(146),
    [sym_keyword_contains_any] = ACTIONS(146),
    [sym_keyword_contains_none] = ACTIONS(146),
    [sym_keyword_inside] = ACTIONS(146),
    [sym_keyword_in] = ACTIONS(148),
    [sym_keyword_not_inside] = ACTIONS(146),
    [sym_keyword_all_inside] = ACTIONS(146),
    [sym_keyword_any_inside] = ACTIONS(146),
    [sym_keyword_none_inside] = ACTIONS(146),
    [sym_keyword_outside] = ACTIONS(146),
    [sym_keyword_intersects] = ACTIONS(146),
    [sym_keyword_drop] = ACTIONS(146),
    [sym_keyword_schemafull] = ACTIONS(146),
    [sym_keyword_schemaless] = ACTIONS(146),
    [sym_keyword_changefeed] = ACTIONS(146),
    [sym_keyword_content] = ACTIONS(146),
    [sym_keyword_merge] = ACTIONS(146),
    [sym_keyword_patch] = ACTIONS(146),
    [sym_keyword_then] = ACTIONS(146),
    [sym_keyword_type] = ACTIONS(146),
    [sym_keyword_permissions] = ACTIONS(146),
    [sym_keyword_for] = ACTIONS(146),
    [sym_keyword_comment] = ACTIONS(146),
    [sym_keyword_if] = ACTIONS(146),
    [sym_keyword_set] = ACTIONS(146),
    [sym_keyword_unset] = ACTIONS(146),
    [anon_sym_COMMA] = ACTIONS(146),
    [anon_sym_DASH_GT] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(146),
    [anon_sym_RBRACK] = ACTIONS(146),
    [anon_sym_LPAREN] = ACTIONS(146),
    [anon_sym_RPAREN] = ACTIONS(146),
    [anon_sym_QMARK] = ACTIONS(148),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_RBRACE] = ACTIONS(146),
    [anon_sym_LT_DASH] = ACTIONS(148),
    [anon_sym_LT_DASH_GT] = ACTIONS(146),
    [anon_sym_STAR] = ACTIONS(148),
    [anon_sym_DOT] = ACTIONS(146),
    [anon_sym_LT] = ACTIONS(148),
    [anon_sym_GT] = ACTIONS(148),
    [sym_variable_name] = ACTIONS(146),
    [sym_custom_function_name] = ACTIONS(146),
    [anon_sym_EQ] = ACTIONS(148),
    [anon_sym_DASH] = ACTIONS(148),
    [anon_sym_AT] = ACTIONS(148),
    [anon_sym_LT_PIPE] = ACTIONS(146),
    [anon_sym_AMP_AMP] = ACTIONS(146),
    [anon_sym_PIPE_PIPE] = ACTIONS(146),
    [anon_sym_QMARK_QMARK] = ACTIONS(146),
    [anon_sym_QMARK_COLON] = ACTIONS(146),
    [anon_sym_BANG_EQ] = ACTIONS(146),
    [anon_sym_EQ_EQ] = ACTIONS(146),
    [anon_sym_QMARK_EQ] = ACTIONS(146),
    [anon_sym_STAR_EQ] = ACTIONS(146),
    [anon_sym_TILDE] = ACTIONS(146),
    [anon_sym_BANG_TILDE] = ACTIONS(146),
    [anon_sym_STAR_TILDE] = ACTIONS(146),
    [anon_sym_LT_EQ] = ACTIONS(146),
    [anon_sym_GT_EQ] = ACTIONS(146),
    [anon_sym_PLUS] = ACTIONS(148),
    [anon_sym_PLUS_EQ] = ACTIONS(146),
    [anon_sym_DASH_EQ] = ACTIONS(146),
    [anon_sym_u00d7] = ACTIONS(146),
    [anon_sym_SLASH] = ACTIONS(148),
    [anon_sym_u00f7] = ACTIONS(146),
    [anon_sym_STAR_STAR] = ACTIONS(146),
    [anon_sym_u220b] = ACTIONS(146),
    [anon_sym_u220c] = ACTIONS(146),
    [anon_sym_u2287] = ACTIONS(146),
    [anon_sym_u2283] = ACTIONS(146),
    [anon_sym_u2285] = ACTIONS(146),
    [anon_sym_u2208] = ACTIONS(146),
    [anon_sym_u2209] = ACTIONS(146),
    [anon_sym_u2286] = ACTIONS(146),
    [anon_sym_u2282] = ACTIONS(146),
    [anon_sym_u2284] = ACTIONS(146),
    [anon_sym_AT_AT] = ACTIONS(146),
  },
  [23] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(150),
    [sym_keyword_return] = ACTIONS(150),
    [sym_keyword_from] = ACTIONS(150),
    [sym_keyword_as] = ACTIONS(150),
    [sym_keyword_parallel] = ACTIONS(150),
    [sym_keyword_timeout] = ACTIONS(150),
    [sym_keyword_where] = ACTIONS(150),
    [sym_keyword_group] = ACTIONS(150),
    [sym_keyword_and] = ACTIONS(150),
    [sym_keyword_or] = ACTIONS(150),
    [sym_keyword_is] = ACTIONS(150),
    [sym_keyword_not] = ACTIONS(152),
    [sym_keyword_contains] = ACTIONS(150),
    [sym_keyword_contains_not] = ACTIONS(150),
    [sym_keyword_contains_all] = ACTIONS(150),
    [sym_keyword_contains_any] = ACTIONS(150),
    [sym_keyword_contains_none] = ACTIONS(150),
    [sym_keyword_inside] = ACTIONS(150),
    [sym_keyword_in] = ACTIONS(152),
    [sym_keyword_not_inside] = ACTIONS(150),
    [sym_keyword_all_inside] = ACTIONS(150),
    [sym_keyword_any_inside] = ACTIONS(150),
    [sym_keyword_none_inside] = ACTIONS(150),
    [sym_keyword_outside] = ACTIONS(150),
    [sym_keyword_intersects] = ACTIONS(150),
    [sym_keyword_drop] = ACTIONS(150),
    [sym_keyword_schemafull] = ACTIONS(150),
    [sym_keyword_schemaless] = ACTIONS(150),
    [sym_keyword_changefeed] = ACTIONS(150),
    [sym_keyword_content] = ACTIONS(150),
    [sym_keyword_merge] = ACTIONS(150),
    [sym_keyword_patch] = ACTIONS(150),
    [sym_keyword_then] = ACTIONS(150),
    [sym_keyword_type] = ACTIONS(150),
    [sym_keyword_permissions] = ACTIONS(150),
    [sym_keyword_for] = ACTIONS(150),
    [sym_keyword_comment] = ACTIONS(150),
    [sym_keyword_if] = ACTIONS(150),
    [sym_keyword_set] = ACTIONS(150),
    [sym_keyword_unset] = ACTIONS(150),
    [anon_sym_COMMA] = ACTIONS(150),
    [anon_sym_DASH_GT] = ACTIONS(150),
    [anon_sym_LBRACK] = ACTIONS(150),
    [anon_sym_RBRACK] = ACTIONS(150),
    [anon_sym_LPAREN] = ACTIONS(150),
    [anon_sym_RPAREN] = ACTIONS(150),
    [anon_sym_QMARK] = ACTIONS(152),
    [anon_sym_LBRACE] = ACTIONS(150),
    [anon_sym_RBRACE] = ACTIONS(150),
    [anon_sym_LT_DASH] = ACTIONS(152),
    [anon_sym_LT_DASH_GT] = ACTIONS(150),
    [anon_sym_STAR] = ACTIONS(152),
    [anon_sym_DOT] = ACTIONS(150),
    [anon_sym_LT] = ACTIONS(152),
    [anon_sym_GT] = ACTIONS(152),
    [sym_variable_name] = ACTIONS(150),
    [sym_custom_function_name] = ACTIONS(150),
    [anon_sym_EQ] = ACTIONS(152),
    [anon_sym_DASH] = ACTIONS(152),
    [anon_sym_AT] = ACTIONS(152),
    [anon_sym_LT_PIPE] = ACTIONS(150),
    [anon_sym_AMP_AMP] = ACTIONS(150),
    [anon_sym_PIPE_PIPE] = ACTIONS(150),
    [anon_sym_QMARK_QMARK] = ACTIONS(150),
    [anon_sym_QMARK_COLON] = ACTIONS(150),
    [anon_sym_BANG_EQ] = ACTIONS(150),
    [anon_sym_EQ_EQ] = ACTIONS(150),
    [anon_sym_QMARK_EQ] = ACTIONS(150),
    [anon_sym_STAR_EQ] = ACTIONS(150),
    [anon_sym_TILDE] = ACTIONS(150),
    [anon_sym_BANG_TILDE] = ACTIONS(150),
    [anon_sym_STAR_TILDE] = ACTIONS(150),
    [anon_sym_LT_EQ] = ACTIONS(150),
    [anon_sym_GT_EQ] = ACTIONS(150),
    [anon_sym_PLUS] = ACTIONS(152),
    [anon_sym_PLUS_EQ] = ACTIONS(150),
    [anon_sym_DASH_EQ] = ACTIONS(150),
    [anon_sym_u00d7] = ACTIONS(150),
    [anon_sym_SLASH] = ACTIONS(152),
    [anon_sym_u00f7] = ACTIONS(150),
    [anon_sym_STAR_STAR] = ACTIONS(150),
    [anon_sym_u220b] = ACTIONS(150),
    [anon_sym_u220c] = ACTIONS(150),
    [anon_sym_u2287] = ACTIONS(150),
    [anon_sym_u2283] = ACTIONS(150),
    [anon_sym_u2285] = ACTIONS(150),
    [anon_sym_u2208] = ACTIONS(150),
    [anon_sym_u2209] = ACTIONS(150),
    [anon_sym_u2286] = ACTIONS(150),
    [anon_sym_u2282] = ACTIONS(150),
    [anon_sym_u2284] = ACTIONS(150),
    [anon_sym_AT_AT] = ACTIONS(150),
  },
  [24] = {
    [ts_builtin_sym_end] = ACTIONS(126),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(126),
    [sym_keyword_return] = ACTIONS(126),
    [sym_keyword_value] = ACTIONS(126),
    [sym_keyword_explain] = ACTIONS(126),
    [sym_keyword_parallel] = ACTIONS(126),
    [sym_keyword_timeout] = ACTIONS(126),
    [sym_keyword_fetch] = ACTIONS(126),
    [sym_keyword_limit] = ACTIONS(126),
    [sym_keyword_rand] = ACTIONS(126),
    [sym_keyword_collate] = ACTIONS(126),
    [sym_keyword_numeric] = ACTIONS(126),
    [sym_keyword_asc] = ACTIONS(126),
    [sym_keyword_desc] = ACTIONS(126),
    [sym_keyword_where] = ACTIONS(126),
    [sym_keyword_and] = ACTIONS(126),
    [sym_keyword_or] = ACTIONS(126),
    [sym_keyword_is] = ACTIONS(126),
    [sym_keyword_not] = ACTIONS(128),
    [sym_keyword_contains] = ACTIONS(126),
    [sym_keyword_contains_not] = ACTIONS(126),
    [sym_keyword_contains_all] = ACTIONS(126),
    [sym_keyword_contains_any] = ACTIONS(126),
    [sym_keyword_contains_none] = ACTIONS(126),
    [sym_keyword_inside] = ACTIONS(126),
    [sym_keyword_in] = ACTIONS(128),
    [sym_keyword_not_inside] = ACTIONS(126),
    [sym_keyword_all_inside] = ACTIONS(126),
    [sym_keyword_any_inside] = ACTIONS(126),
    [sym_keyword_none_inside] = ACTIONS(126),
    [sym_keyword_outside] = ACTIONS(126),
    [sym_keyword_intersects] = ACTIONS(126),
    [sym_keyword_flexible] = ACTIONS(126),
    [sym_keyword_readonly] = ACTIONS(126),
    [sym_keyword_content] = ACTIONS(126),
    [sym_keyword_merge] = ACTIONS(126),
    [sym_keyword_patch] = ACTIONS(126),
    [sym_keyword_type] = ACTIONS(126),
    [sym_keyword_default] = ACTIONS(126),
    [sym_keyword_assert] = ACTIONS(126),
    [sym_keyword_permissions] = ACTIONS(126),
    [sym_keyword_for] = ACTIONS(126),
    [sym_keyword_comment] = ACTIONS(126),
    [sym_keyword_set] = ACTIONS(126),
    [sym_keyword_unset] = ACTIONS(126),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_DASH_GT] = ACTIONS(126),
    [anon_sym_LBRACK] = ACTIONS(126),
    [anon_sym_RPAREN] = ACTIONS(126),
    [anon_sym_RBRACE] = ACTIONS(126),
    [anon_sym_LT_DASH] = ACTIONS(128),
    [anon_sym_LT_DASH_GT] = ACTIONS(126),
    [anon_sym_STAR] = ACTIONS(128),
    [anon_sym_DOT] = ACTIONS(128),
    [anon_sym_LT] = ACTIONS(128),
    [anon_sym_GT] = ACTIONS(128),
    [anon_sym_DOT_DOT] = ACTIONS(126),
    [anon_sym_EQ] = ACTIONS(128),
    [anon_sym_DASH] = ACTIONS(128),
    [anon_sym_AT] = ACTIONS(128),
    [anon_sym_LT_PIPE] = ACTIONS(126),
    [anon_sym_AMP_AMP] = ACTIONS(126),
    [anon_sym_PIPE_PIPE] = ACTIONS(126),
    [anon_sym_QMARK_QMARK] = ACTIONS(126),
    [anon_sym_QMARK_COLON] = ACTIONS(126),
    [anon_sym_BANG_EQ] = ACTIONS(126),
    [anon_sym_EQ_EQ] = ACTIONS(126),
    [anon_sym_QMARK_EQ] = ACTIONS(126),
    [anon_sym_STAR_EQ] = ACTIONS(126),
    [anon_sym_TILDE] = ACTIONS(126),
    [anon_sym_BANG_TILDE] = ACTIONS(126),
    [anon_sym_STAR_TILDE] = ACTIONS(126),
    [anon_sym_LT_EQ] = ACTIONS(126),
    [anon_sym_GT_EQ] = ACTIONS(126),
    [anon_sym_PLUS] = ACTIONS(128),
    [anon_sym_PLUS_EQ] = ACTIONS(126),
    [anon_sym_DASH_EQ] = ACTIONS(126),
    [anon_sym_u00d7] = ACTIONS(126),
    [anon_sym_SLASH] = ACTIONS(128),
    [anon_sym_u00f7] = ACTIONS(126),
    [anon_sym_STAR_STAR] = ACTIONS(126),
    [anon_sym_u220b] = ACTIONS(126),
    [anon_sym_u220c] = ACTIONS(126),
    [anon_sym_u2287] = ACTIONS(126),
    [anon_sym_u2283] = ACTIONS(126),
    [anon_sym_u2285] = ACTIONS(126),
    [anon_sym_u2208] = ACTIONS(126),
    [anon_sym_u2209] = ACTIONS(126),
    [anon_sym_u2286] = ACTIONS(126),
    [anon_sym_u2282] = ACTIONS(126),
    [anon_sym_u2284] = ACTIONS(126),
    [anon_sym_AT_AT] = ACTIONS(126),
  },
  [25] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(154),
    [sym_keyword_return] = ACTIONS(154),
    [sym_keyword_from] = ACTIONS(154),
    [sym_keyword_as] = ACTIONS(154),
    [sym_keyword_parallel] = ACTIONS(154),
    [sym_keyword_timeout] = ACTIONS(154),
    [sym_keyword_where] = ACTIONS(154),
    [sym_keyword_group] = ACTIONS(154),
    [sym_keyword_and] = ACTIONS(154),
    [sym_keyword_or] = ACTIONS(154),
    [sym_keyword_is] = ACTIONS(154),
    [sym_keyword_not] = ACTIONS(156),
    [sym_keyword_contains] = ACTIONS(154),
    [sym_keyword_contains_not] = ACTIONS(154),
    [sym_keyword_contains_all] = ACTIONS(154),
    [sym_keyword_contains_any] = ACTIONS(154),
    [sym_keyword_contains_none] = ACTIONS(154),
    [sym_keyword_inside] = ACTIONS(154),
    [sym_keyword_in] = ACTIONS(156),
    [sym_keyword_not_inside] = ACTIONS(154),
    [sym_keyword_all_inside] = ACTIONS(154),
    [sym_keyword_any_inside] = ACTIONS(154),
    [sym_keyword_none_inside] = ACTIONS(154),
    [sym_keyword_outside] = ACTIONS(154),
    [sym_keyword_intersects] = ACTIONS(154),
    [sym_keyword_drop] = ACTIONS(154),
    [sym_keyword_schemafull] = ACTIONS(154),
    [sym_keyword_schemaless] = ACTIONS(154),
    [sym_keyword_changefeed] = ACTIONS(154),
    [sym_keyword_content] = ACTIONS(154),
    [sym_keyword_merge] = ACTIONS(154),
    [sym_keyword_patch] = ACTIONS(154),
    [sym_keyword_then] = ACTIONS(154),
    [sym_keyword_type] = ACTIONS(154),
    [sym_keyword_permissions] = ACTIONS(154),
    [sym_keyword_for] = ACTIONS(154),
    [sym_keyword_comment] = ACTIONS(154),
    [sym_keyword_if] = ACTIONS(154),
    [sym_keyword_set] = ACTIONS(154),
    [sym_keyword_unset] = ACTIONS(154),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_DASH_GT] = ACTIONS(154),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(154),
    [anon_sym_QMARK] = ACTIONS(156),
    [anon_sym_LBRACE] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_LT_DASH] = ACTIONS(156),
    [anon_sym_LT_DASH_GT] = ACTIONS(154),
    [anon_sym_STAR] = ACTIONS(156),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_LT] = ACTIONS(156),
    [anon_sym_GT] = ACTIONS(156),
    [sym_variable_name] = ACTIONS(154),
    [sym_custom_function_name] = ACTIONS(154),
    [anon_sym_EQ] = ACTIONS(156),
    [anon_sym_DASH] = ACTIONS(156),
    [anon_sym_AT] = ACTIONS(156),
    [anon_sym_LT_PIPE] = ACTIONS(154),
    [anon_sym_AMP_AMP] = ACTIONS(154),
    [anon_sym_PIPE_PIPE] = ACTIONS(154),
    [anon_sym_QMARK_QMARK] = ACTIONS(154),
    [anon_sym_QMARK_COLON] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(154),
    [anon_sym_QMARK_EQ] = ACTIONS(154),
    [anon_sym_STAR_EQ] = ACTIONS(154),
    [anon_sym_TILDE] = ACTIONS(154),
    [anon_sym_BANG_TILDE] = ACTIONS(154),
    [anon_sym_STAR_TILDE] = ACTIONS(154),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_PLUS] = ACTIONS(156),
    [anon_sym_PLUS_EQ] = ACTIONS(154),
    [anon_sym_DASH_EQ] = ACTIONS(154),
    [anon_sym_u00d7] = ACTIONS(154),
    [anon_sym_SLASH] = ACTIONS(156),
    [anon_sym_u00f7] = ACTIONS(154),
    [anon_sym_STAR_STAR] = ACTIONS(154),
    [anon_sym_u220b] = ACTIONS(154),
    [anon_sym_u220c] = ACTIONS(154),
    [anon_sym_u2287] = ACTIONS(154),
    [anon_sym_u2283] = ACTIONS(154),
    [anon_sym_u2285] = ACTIONS(154),
    [anon_sym_u2208] = ACTIONS(154),
    [anon_sym_u2209] = ACTIONS(154),
    [anon_sym_u2286] = ACTIONS(154),
    [anon_sym_u2282] = ACTIONS(154),
    [anon_sym_u2284] = ACTIONS(154),
    [anon_sym_AT_AT] = ACTIONS(154),
  },
  [26] = {
    [ts_builtin_sym_end] = ACTIONS(130),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(130),
    [sym_keyword_return] = ACTIONS(130),
    [sym_keyword_value] = ACTIONS(130),
    [sym_keyword_explain] = ACTIONS(130),
    [sym_keyword_parallel] = ACTIONS(130),
    [sym_keyword_timeout] = ACTIONS(130),
    [sym_keyword_fetch] = ACTIONS(130),
    [sym_keyword_limit] = ACTIONS(130),
    [sym_keyword_rand] = ACTIONS(130),
    [sym_keyword_collate] = ACTIONS(130),
    [sym_keyword_numeric] = ACTIONS(130),
    [sym_keyword_asc] = ACTIONS(130),
    [sym_keyword_desc] = ACTIONS(130),
    [sym_keyword_where] = ACTIONS(130),
    [sym_keyword_and] = ACTIONS(130),
    [sym_keyword_or] = ACTIONS(130),
    [sym_keyword_is] = ACTIONS(130),
    [sym_keyword_not] = ACTIONS(132),
    [sym_keyword_contains] = ACTIONS(130),
    [sym_keyword_contains_not] = ACTIONS(130),
    [sym_keyword_contains_all] = ACTIONS(130),
    [sym_keyword_contains_any] = ACTIONS(130),
    [sym_keyword_contains_none] = ACTIONS(130),
    [sym_keyword_inside] = ACTIONS(130),
    [sym_keyword_in] = ACTIONS(132),
    [sym_keyword_not_inside] = ACTIONS(130),
    [sym_keyword_all_inside] = ACTIONS(130),
    [sym_keyword_any_inside] = ACTIONS(130),
    [sym_keyword_none_inside] = ACTIONS(130),
    [sym_keyword_outside] = ACTIONS(130),
    [sym_keyword_intersects] = ACTIONS(130),
    [sym_keyword_flexible] = ACTIONS(130),
    [sym_keyword_readonly] = ACTIONS(130),
    [sym_keyword_content] = ACTIONS(130),
    [sym_keyword_merge] = ACTIONS(130),
    [sym_keyword_patch] = ACTIONS(130),
    [sym_keyword_type] = ACTIONS(130),
    [sym_keyword_default] = ACTIONS(130),
    [sym_keyword_assert] = ACTIONS(130),
    [sym_keyword_permissions] = ACTIONS(130),
    [sym_keyword_for] = ACTIONS(130),
    [sym_keyword_comment] = ACTIONS(130),
    [sym_keyword_set] = ACTIONS(130),
    [sym_keyword_unset] = ACTIONS(130),
    [anon_sym_COMMA] = ACTIONS(130),
    [anon_sym_DASH_GT] = ACTIONS(130),
    [anon_sym_LBRACK] = ACTIONS(130),
    [anon_sym_RPAREN] = ACTIONS(130),
    [anon_sym_RBRACE] = ACTIONS(130),
    [anon_sym_LT_DASH] = ACTIONS(132),
    [anon_sym_LT_DASH_GT] = ACTIONS(130),
    [anon_sym_STAR] = ACTIONS(132),
    [anon_sym_DOT] = ACTIONS(132),
    [anon_sym_LT] = ACTIONS(132),
    [anon_sym_GT] = ACTIONS(132),
    [anon_sym_DOT_DOT] = ACTIONS(130),
    [anon_sym_EQ] = ACTIONS(132),
    [anon_sym_DASH] = ACTIONS(132),
    [anon_sym_AT] = ACTIONS(132),
    [anon_sym_LT_PIPE] = ACTIONS(130),
    [anon_sym_AMP_AMP] = ACTIONS(130),
    [anon_sym_PIPE_PIPE] = ACTIONS(130),
    [anon_sym_QMARK_QMARK] = ACTIONS(130),
    [anon_sym_QMARK_COLON] = ACTIONS(130),
    [anon_sym_BANG_EQ] = ACTIONS(130),
    [anon_sym_EQ_EQ] = ACTIONS(130),
    [anon_sym_QMARK_EQ] = ACTIONS(130),
    [anon_sym_STAR_EQ] = ACTIONS(130),
    [anon_sym_TILDE] = ACTIONS(130),
    [anon_sym_BANG_TILDE] = ACTIONS(130),
    [anon_sym_STAR_TILDE] = ACTIONS(130),
    [anon_sym_LT_EQ] = ACTIONS(130),
    [anon_sym_GT_EQ] = ACTIONS(130),
    [anon_sym_PLUS] = ACTIONS(132),
    [anon_sym_PLUS_EQ] = ACTIONS(130),
    [anon_sym_DASH_EQ] = ACTIONS(130),
    [anon_sym_u00d7] = ACTIONS(130),
    [anon_sym_SLASH] = ACTIONS(132),
    [anon_sym_u00f7] = ACTIONS(130),
    [anon_sym_STAR_STAR] = ACTIONS(130),
    [anon_sym_u220b] = ACTIONS(130),
    [anon_sym_u220c] = ACTIONS(130),
    [anon_sym_u2287] = ACTIONS(130),
    [anon_sym_u2283] = ACTIONS(130),
    [anon_sym_u2285] = ACTIONS(130),
    [anon_sym_u2208] = ACTIONS(130),
    [anon_sym_u2209] = ACTIONS(130),
    [anon_sym_u2286] = ACTIONS(130),
    [anon_sym_u2282] = ACTIONS(130),
    [anon_sym_u2284] = ACTIONS(130),
    [anon_sym_AT_AT] = ACTIONS(130),
  },
  [27] = {
    [ts_builtin_sym_end] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(55),
    [sym_keyword_return] = ACTIONS(55),
    [sym_keyword_value] = ACTIONS(55),
    [sym_keyword_explain] = ACTIONS(55),
    [sym_keyword_parallel] = ACTIONS(55),
    [sym_keyword_timeout] = ACTIONS(55),
    [sym_keyword_fetch] = ACTIONS(55),
    [sym_keyword_limit] = ACTIONS(55),
    [sym_keyword_rand] = ACTIONS(55),
    [sym_keyword_collate] = ACTIONS(55),
    [sym_keyword_numeric] = ACTIONS(55),
    [sym_keyword_asc] = ACTIONS(55),
    [sym_keyword_desc] = ACTIONS(55),
    [sym_keyword_where] = ACTIONS(55),
    [sym_keyword_and] = ACTIONS(55),
    [sym_keyword_or] = ACTIONS(55),
    [sym_keyword_is] = ACTIONS(55),
    [sym_keyword_not] = ACTIONS(57),
    [sym_keyword_contains] = ACTIONS(55),
    [sym_keyword_contains_not] = ACTIONS(55),
    [sym_keyword_contains_all] = ACTIONS(55),
    [sym_keyword_contains_any] = ACTIONS(55),
    [sym_keyword_contains_none] = ACTIONS(55),
    [sym_keyword_inside] = ACTIONS(55),
    [sym_keyword_in] = ACTIONS(57),
    [sym_keyword_not_inside] = ACTIONS(55),
    [sym_keyword_all_inside] = ACTIONS(55),
    [sym_keyword_any_inside] = ACTIONS(55),
    [sym_keyword_none_inside] = ACTIONS(55),
    [sym_keyword_outside] = ACTIONS(55),
    [sym_keyword_intersects] = ACTIONS(55),
    [sym_keyword_flexible] = ACTIONS(55),
    [sym_keyword_readonly] = ACTIONS(55),
    [sym_keyword_content] = ACTIONS(55),
    [sym_keyword_merge] = ACTIONS(55),
    [sym_keyword_patch] = ACTIONS(55),
    [sym_keyword_type] = ACTIONS(55),
    [sym_keyword_default] = ACTIONS(55),
    [sym_keyword_assert] = ACTIONS(55),
    [sym_keyword_permissions] = ACTIONS(55),
    [sym_keyword_for] = ACTIONS(55),
    [sym_keyword_comment] = ACTIONS(55),
    [sym_keyword_set] = ACTIONS(55),
    [sym_keyword_unset] = ACTIONS(55),
    [anon_sym_COMMA] = ACTIONS(55),
    [anon_sym_DASH_GT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(55),
    [anon_sym_RPAREN] = ACTIONS(55),
    [anon_sym_COLON] = ACTIONS(120),
    [anon_sym_RBRACE] = ACTIONS(55),
    [anon_sym_LT_DASH] = ACTIONS(57),
    [anon_sym_LT_DASH_GT] = ACTIONS(55),
    [anon_sym_STAR] = ACTIONS(57),
    [anon_sym_DOT] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(57),
    [anon_sym_GT] = ACTIONS(57),
    [anon_sym_EQ] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(57),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LT_PIPE] = ACTIONS(55),
    [anon_sym_AMP_AMP] = ACTIONS(55),
    [anon_sym_PIPE_PIPE] = ACTIONS(55),
    [anon_sym_QMARK_QMARK] = ACTIONS(55),
    [anon_sym_QMARK_COLON] = ACTIONS(55),
    [anon_sym_BANG_EQ] = ACTIONS(55),
    [anon_sym_EQ_EQ] = ACTIONS(55),
    [anon_sym_QMARK_EQ] = ACTIONS(55),
    [anon_sym_STAR_EQ] = ACTIONS(55),
    [anon_sym_TILDE] = ACTIONS(55),
    [anon_sym_BANG_TILDE] = ACTIONS(55),
    [anon_sym_STAR_TILDE] = ACTIONS(55),
    [anon_sym_LT_EQ] = ACTIONS(55),
    [anon_sym_GT_EQ] = ACTIONS(55),
    [anon_sym_PLUS] = ACTIONS(57),
    [anon_sym_PLUS_EQ] = ACTIONS(55),
    [anon_sym_DASH_EQ] = ACTIONS(55),
    [anon_sym_u00d7] = ACTIONS(55),
    [anon_sym_SLASH] = ACTIONS(57),
    [anon_sym_u00f7] = ACTIONS(55),
    [anon_sym_STAR_STAR] = ACTIONS(55),
    [anon_sym_u220b] = ACTIONS(55),
    [anon_sym_u220c] = ACTIONS(55),
    [anon_sym_u2287] = ACTIONS(55),
    [anon_sym_u2283] = ACTIONS(55),
    [anon_sym_u2285] = ACTIONS(55),
    [anon_sym_u2208] = ACTIONS(55),
    [anon_sym_u2209] = ACTIONS(55),
    [anon_sym_u2286] = ACTIONS(55),
    [anon_sym_u2282] = ACTIONS(55),
    [anon_sym_u2284] = ACTIONS(55),
    [anon_sym_AT_AT] = ACTIONS(55),
  },
  [28] = {
    [ts_builtin_sym_end] = ACTIONS(158),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(158),
    [sym_keyword_return] = ACTIONS(158),
    [sym_keyword_value] = ACTIONS(158),
    [sym_keyword_explain] = ACTIONS(158),
    [sym_keyword_parallel] = ACTIONS(158),
    [sym_keyword_timeout] = ACTIONS(158),
    [sym_keyword_fetch] = ACTIONS(158),
    [sym_keyword_limit] = ACTIONS(158),
    [sym_keyword_rand] = ACTIONS(158),
    [sym_keyword_collate] = ACTIONS(158),
    [sym_keyword_numeric] = ACTIONS(158),
    [sym_keyword_asc] = ACTIONS(158),
    [sym_keyword_desc] = ACTIONS(158),
    [sym_keyword_where] = ACTIONS(158),
    [sym_keyword_and] = ACTIONS(158),
    [sym_keyword_or] = ACTIONS(158),
    [sym_keyword_is] = ACTIONS(158),
    [sym_keyword_not] = ACTIONS(160),
    [sym_keyword_contains] = ACTIONS(158),
    [sym_keyword_contains_not] = ACTIONS(158),
    [sym_keyword_contains_all] = ACTIONS(158),
    [sym_keyword_contains_any] = ACTIONS(158),
    [sym_keyword_contains_none] = ACTIONS(158),
    [sym_keyword_inside] = ACTIONS(158),
    [sym_keyword_in] = ACTIONS(160),
    [sym_keyword_not_inside] = ACTIONS(158),
    [sym_keyword_all_inside] = ACTIONS(158),
    [sym_keyword_any_inside] = ACTIONS(158),
    [sym_keyword_none_inside] = ACTIONS(158),
    [sym_keyword_outside] = ACTIONS(158),
    [sym_keyword_intersects] = ACTIONS(158),
    [sym_keyword_flexible] = ACTIONS(158),
    [sym_keyword_readonly] = ACTIONS(158),
    [sym_keyword_content] = ACTIONS(158),
    [sym_keyword_merge] = ACTIONS(158),
    [sym_keyword_patch] = ACTIONS(158),
    [sym_keyword_type] = ACTIONS(158),
    [sym_keyword_default] = ACTIONS(158),
    [sym_keyword_assert] = ACTIONS(158),
    [sym_keyword_permissions] = ACTIONS(158),
    [sym_keyword_for] = ACTIONS(158),
    [sym_keyword_comment] = ACTIONS(158),
    [sym_keyword_set] = ACTIONS(158),
    [sym_keyword_unset] = ACTIONS(158),
    [anon_sym_COMMA] = ACTIONS(158),
    [anon_sym_DASH_GT] = ACTIONS(158),
    [anon_sym_LBRACK] = ACTIONS(158),
    [anon_sym_RPAREN] = ACTIONS(158),
    [anon_sym_RBRACE] = ACTIONS(158),
    [anon_sym_LT_DASH] = ACTIONS(160),
    [anon_sym_LT_DASH_GT] = ACTIONS(158),
    [anon_sym_STAR] = ACTIONS(160),
    [anon_sym_DOT] = ACTIONS(158),
    [anon_sym_LT] = ACTIONS(160),
    [anon_sym_GT] = ACTIONS(160),
    [anon_sym_EQ] = ACTIONS(160),
    [anon_sym_DASH] = ACTIONS(160),
    [anon_sym_AT] = ACTIONS(160),
    [anon_sym_LT_PIPE] = ACTIONS(158),
    [anon_sym_PIPE_GT] = ACTIONS(158),
    [anon_sym_AMP_AMP] = ACTIONS(158),
    [anon_sym_PIPE_PIPE] = ACTIONS(158),
    [anon_sym_QMARK_QMARK] = ACTIONS(158),
    [anon_sym_QMARK_COLON] = ACTIONS(158),
    [anon_sym_BANG_EQ] = ACTIONS(158),
    [anon_sym_EQ_EQ] = ACTIONS(158),
    [anon_sym_QMARK_EQ] = ACTIONS(158),
    [anon_sym_STAR_EQ] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(158),
    [anon_sym_BANG_TILDE] = ACTIONS(158),
    [anon_sym_STAR_TILDE] = ACTIONS(158),
    [anon_sym_LT_EQ] = ACTIONS(158),
    [anon_sym_GT_EQ] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(160),
    [anon_sym_PLUS_EQ] = ACTIONS(158),
    [anon_sym_DASH_EQ] = ACTIONS(158),
    [anon_sym_u00d7] = ACTIONS(158),
    [anon_sym_SLASH] = ACTIONS(160),
    [anon_sym_u00f7] = ACTIONS(158),
    [anon_sym_STAR_STAR] = ACTIONS(158),
    [anon_sym_u220b] = ACTIONS(158),
    [anon_sym_u220c] = ACTIONS(158),
    [anon_sym_u2287] = ACTIONS(158),
    [anon_sym_u2283] = ACTIONS(158),
    [anon_sym_u2285] = ACTIONS(158),
    [anon_sym_u2208] = ACTIONS(158),
    [anon_sym_u2209] = ACTIONS(158),
    [anon_sym_u2286] = ACTIONS(158),
    [anon_sym_u2282] = ACTIONS(158),
    [anon_sym_u2284] = ACTIONS(158),
    [anon_sym_AT_AT] = ACTIONS(158),
  },
  [29] = {
    [ts_builtin_sym_end] = ACTIONS(134),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(134),
    [sym_keyword_return] = ACTIONS(134),
    [sym_keyword_value] = ACTIONS(134),
    [sym_keyword_explain] = ACTIONS(134),
    [sym_keyword_parallel] = ACTIONS(134),
    [sym_keyword_timeout] = ACTIONS(134),
    [sym_keyword_fetch] = ACTIONS(134),
    [sym_keyword_limit] = ACTIONS(134),
    [sym_keyword_rand] = ACTIONS(134),
    [sym_keyword_collate] = ACTIONS(134),
    [sym_keyword_numeric] = ACTIONS(134),
    [sym_keyword_asc] = ACTIONS(134),
    [sym_keyword_desc] = ACTIONS(134),
    [sym_keyword_where] = ACTIONS(134),
    [sym_keyword_and] = ACTIONS(134),
    [sym_keyword_or] = ACTIONS(134),
    [sym_keyword_is] = ACTIONS(134),
    [sym_keyword_not] = ACTIONS(136),
    [sym_keyword_contains] = ACTIONS(134),
    [sym_keyword_contains_not] = ACTIONS(134),
    [sym_keyword_contains_all] = ACTIONS(134),
    [sym_keyword_contains_any] = ACTIONS(134),
    [sym_keyword_contains_none] = ACTIONS(134),
    [sym_keyword_inside] = ACTIONS(134),
    [sym_keyword_in] = ACTIONS(136),
    [sym_keyword_not_inside] = ACTIONS(134),
    [sym_keyword_all_inside] = ACTIONS(134),
    [sym_keyword_any_inside] = ACTIONS(134),
    [sym_keyword_none_inside] = ACTIONS(134),
    [sym_keyword_outside] = ACTIONS(134),
    [sym_keyword_intersects] = ACTIONS(134),
    [sym_keyword_flexible] = ACTIONS(134),
    [sym_keyword_readonly] = ACTIONS(134),
    [sym_keyword_content] = ACTIONS(134),
    [sym_keyword_merge] = ACTIONS(134),
    [sym_keyword_patch] = ACTIONS(134),
    [sym_keyword_type] = ACTIONS(134),
    [sym_keyword_default] = ACTIONS(134),
    [sym_keyword_assert] = ACTIONS(134),
    [sym_keyword_permissions] = ACTIONS(134),
    [sym_keyword_for] = ACTIONS(134),
    [sym_keyword_comment] = ACTIONS(134),
    [sym_keyword_set] = ACTIONS(134),
    [sym_keyword_unset] = ACTIONS(134),
    [anon_sym_COMMA] = ACTIONS(134),
    [anon_sym_DASH_GT] = ACTIONS(134),
    [anon_sym_LBRACK] = ACTIONS(134),
    [anon_sym_RPAREN] = ACTIONS(134),
    [anon_sym_RBRACE] = ACTIONS(134),
    [anon_sym_LT_DASH] = ACTIONS(136),
    [anon_sym_LT_DASH_GT] = ACTIONS(134),
    [anon_sym_STAR] = ACTIONS(136),
    [anon_sym_DOT] = ACTIONS(136),
    [anon_sym_LT] = ACTIONS(136),
    [anon_sym_GT] = ACTIONS(136),
    [anon_sym_DOT_DOT] = ACTIONS(134),
    [anon_sym_EQ] = ACTIONS(136),
    [anon_sym_DASH] = ACTIONS(136),
    [anon_sym_AT] = ACTIONS(136),
    [anon_sym_LT_PIPE] = ACTIONS(134),
    [anon_sym_AMP_AMP] = ACTIONS(134),
    [anon_sym_PIPE_PIPE] = ACTIONS(134),
    [anon_sym_QMARK_QMARK] = ACTIONS(134),
    [anon_sym_QMARK_COLON] = ACTIONS(134),
    [anon_sym_BANG_EQ] = ACTIONS(134),
    [anon_sym_EQ_EQ] = ACTIONS(134),
    [anon_sym_QMARK_EQ] = ACTIONS(134),
    [anon_sym_STAR_EQ] = ACTIONS(134),
    [anon_sym_TILDE] = ACTIONS(134),
    [anon_sym_BANG_TILDE] = ACTIONS(134),
    [anon_sym_STAR_TILDE] = ACTIONS(134),
    [anon_sym_LT_EQ] = ACTIONS(134),
    [anon_sym_GT_EQ] = ACTIONS(134),
    [anon_sym_PLUS] = ACTIONS(136),
    [anon_sym_PLUS_EQ] = ACTIONS(134),
    [anon_sym_DASH_EQ] = ACTIONS(134),
    [anon_sym_u00d7] = ACTIONS(134),
    [anon_sym_SLASH] = ACTIONS(136),
    [anon_sym_u00f7] = ACTIONS(134),
    [anon_sym_STAR_STAR] = ACTIONS(134),
    [anon_sym_u220b] = ACTIONS(134),
    [anon_sym_u220c] = ACTIONS(134),
    [anon_sym_u2287] = ACTIONS(134),
    [anon_sym_u2283] = ACTIONS(134),
    [anon_sym_u2285] = ACTIONS(134),
    [anon_sym_u2208] = ACTIONS(134),
    [anon_sym_u2209] = ACTIONS(134),
    [anon_sym_u2286] = ACTIONS(134),
    [anon_sym_u2282] = ACTIONS(134),
    [anon_sym_u2284] = ACTIONS(134),
    [anon_sym_AT_AT] = ACTIONS(134),
  },
  [30] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(162),
    [sym_keyword_return] = ACTIONS(162),
    [sym_keyword_from] = ACTIONS(162),
    [sym_keyword_as] = ACTIONS(162),
    [sym_keyword_parallel] = ACTIONS(162),
    [sym_keyword_timeout] = ACTIONS(162),
    [sym_keyword_where] = ACTIONS(162),
    [sym_keyword_group] = ACTIONS(162),
    [sym_keyword_and] = ACTIONS(162),
    [sym_keyword_or] = ACTIONS(162),
    [sym_keyword_is] = ACTIONS(162),
    [sym_keyword_not] = ACTIONS(164),
    [sym_keyword_contains] = ACTIONS(162),
    [sym_keyword_contains_not] = ACTIONS(162),
    [sym_keyword_contains_all] = ACTIONS(162),
    [sym_keyword_contains_any] = ACTIONS(162),
    [sym_keyword_contains_none] = ACTIONS(162),
    [sym_keyword_inside] = ACTIONS(162),
    [sym_keyword_in] = ACTIONS(164),
    [sym_keyword_not_inside] = ACTIONS(162),
    [sym_keyword_all_inside] = ACTIONS(162),
    [sym_keyword_any_inside] = ACTIONS(162),
    [sym_keyword_none_inside] = ACTIONS(162),
    [sym_keyword_outside] = ACTIONS(162),
    [sym_keyword_intersects] = ACTIONS(162),
    [sym_keyword_drop] = ACTIONS(162),
    [sym_keyword_schemafull] = ACTIONS(162),
    [sym_keyword_schemaless] = ACTIONS(162),
    [sym_keyword_changefeed] = ACTIONS(162),
    [sym_keyword_content] = ACTIONS(162),
    [sym_keyword_merge] = ACTIONS(162),
    [sym_keyword_patch] = ACTIONS(162),
    [sym_keyword_then] = ACTIONS(162),
    [sym_keyword_type] = ACTIONS(162),
    [sym_keyword_permissions] = ACTIONS(162),
    [sym_keyword_for] = ACTIONS(162),
    [sym_keyword_comment] = ACTIONS(162),
    [sym_keyword_if] = ACTIONS(162),
    [sym_keyword_set] = ACTIONS(162),
    [sym_keyword_unset] = ACTIONS(162),
    [anon_sym_COMMA] = ACTIONS(162),
    [anon_sym_DASH_GT] = ACTIONS(162),
    [anon_sym_LBRACK] = ACTIONS(162),
    [anon_sym_RBRACK] = ACTIONS(162),
    [anon_sym_LPAREN] = ACTIONS(162),
    [anon_sym_RPAREN] = ACTIONS(162),
    [anon_sym_QMARK] = ACTIONS(164),
    [anon_sym_LBRACE] = ACTIONS(162),
    [anon_sym_RBRACE] = ACTIONS(162),
    [anon_sym_LT_DASH] = ACTIONS(164),
    [anon_sym_LT_DASH_GT] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_DOT] = ACTIONS(162),
    [anon_sym_LT] = ACTIONS(164),
    [anon_sym_GT] = ACTIONS(164),
    [sym_variable_name] = ACTIONS(162),
    [sym_custom_function_name] = ACTIONS(162),
    [anon_sym_EQ] = ACTIONS(164),
    [anon_sym_DASH] = ACTIONS(164),
    [anon_sym_AT] = ACTIONS(164),
    [anon_sym_LT_PIPE] = ACTIONS(162),
    [anon_sym_AMP_AMP] = ACTIONS(162),
    [anon_sym_PIPE_PIPE] = ACTIONS(162),
    [anon_sym_QMARK_QMARK] = ACTIONS(162),
    [anon_sym_QMARK_COLON] = ACTIONS(162),
    [anon_sym_BANG_EQ] = ACTIONS(162),
    [anon_sym_EQ_EQ] = ACTIONS(162),
    [anon_sym_QMARK_EQ] = ACTIONS(162),
    [anon_sym_STAR_EQ] = ACTIONS(162),
    [anon_sym_TILDE] = ACTIONS(162),
    [anon_sym_BANG_TILDE] = ACTIONS(162),
    [anon_sym_STAR_TILDE] = ACTIONS(162),
    [anon_sym_LT_EQ] = ACTIONS(162),
    [anon_sym_GT_EQ] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(164),
    [anon_sym_PLUS_EQ] = ACTIONS(162),
    [anon_sym_DASH_EQ] = ACTIONS(162),
    [anon_sym_u00d7] = ACTIONS(162),
    [anon_sym_SLASH] = ACTIONS(164),
    [anon_sym_u00f7] = ACTIONS(162),
    [anon_sym_STAR_STAR] = ACTIONS(162),
    [anon_sym_u220b] = ACTIONS(162),
    [anon_sym_u220c] = ACTIONS(162),
    [anon_sym_u2287] = ACTIONS(162),
    [anon_sym_u2283] = ACTIONS(162),
    [anon_sym_u2285] = ACTIONS(162),
    [anon_sym_u2208] = ACTIONS(162),
    [anon_sym_u2209] = ACTIONS(162),
    [anon_sym_u2286] = ACTIONS(162),
    [anon_sym_u2282] = ACTIONS(162),
    [anon_sym_u2284] = ACTIONS(162),
    [anon_sym_AT_AT] = ACTIONS(162),
  },
  [31] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(95),
    [sym_keyword_return] = ACTIONS(95),
    [sym_keyword_from] = ACTIONS(95),
    [sym_keyword_as] = ACTIONS(95),
    [sym_keyword_parallel] = ACTIONS(95),
    [sym_keyword_timeout] = ACTIONS(95),
    [sym_keyword_where] = ACTIONS(95),
    [sym_keyword_group] = ACTIONS(95),
    [sym_keyword_and] = ACTIONS(95),
    [sym_keyword_or] = ACTIONS(95),
    [sym_keyword_is] = ACTIONS(95),
    [sym_keyword_not] = ACTIONS(97),
    [sym_keyword_contains] = ACTIONS(95),
    [sym_keyword_contains_not] = ACTIONS(95),
    [sym_keyword_contains_all] = ACTIONS(95),
    [sym_keyword_contains_any] = ACTIONS(95),
    [sym_keyword_contains_none] = ACTIONS(95),
    [sym_keyword_inside] = ACTIONS(95),
    [sym_keyword_in] = ACTIONS(97),
    [sym_keyword_not_inside] = ACTIONS(95),
    [sym_keyword_all_inside] = ACTIONS(95),
    [sym_keyword_any_inside] = ACTIONS(95),
    [sym_keyword_none_inside] = ACTIONS(95),
    [sym_keyword_outside] = ACTIONS(95),
    [sym_keyword_intersects] = ACTIONS(95),
    [sym_keyword_drop] = ACTIONS(95),
    [sym_keyword_schemafull] = ACTIONS(95),
    [sym_keyword_schemaless] = ACTIONS(95),
    [sym_keyword_changefeed] = ACTIONS(95),
    [sym_keyword_content] = ACTIONS(95),
    [sym_keyword_merge] = ACTIONS(95),
    [sym_keyword_patch] = ACTIONS(95),
    [sym_keyword_then] = ACTIONS(95),
    [sym_keyword_type] = ACTIONS(95),
    [sym_keyword_permissions] = ACTIONS(95),
    [sym_keyword_for] = ACTIONS(95),
    [sym_keyword_comment] = ACTIONS(95),
    [sym_keyword_if] = ACTIONS(95),
    [sym_keyword_set] = ACTIONS(95),
    [sym_keyword_unset] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(95),
    [anon_sym_DASH_GT] = ACTIONS(95),
    [anon_sym_LBRACK] = ACTIONS(95),
    [anon_sym_RBRACK] = ACTIONS(95),
    [anon_sym_LPAREN] = ACTIONS(95),
    [anon_sym_RPAREN] = ACTIONS(95),
    [anon_sym_QMARK] = ACTIONS(97),
    [anon_sym_LBRACE] = ACTIONS(95),
    [anon_sym_RBRACE] = ACTIONS(95),
    [anon_sym_LT_DASH] = ACTIONS(97),
    [anon_sym_LT_DASH_GT] = ACTIONS(95),
    [anon_sym_STAR] = ACTIONS(97),
    [anon_sym_DOT] = ACTIONS(95),
    [anon_sym_LT] = ACTIONS(97),
    [anon_sym_GT] = ACTIONS(97),
    [sym_variable_name] = ACTIONS(95),
    [sym_custom_function_name] = ACTIONS(95),
    [anon_sym_EQ] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_LT_PIPE] = ACTIONS(95),
    [anon_sym_AMP_AMP] = ACTIONS(95),
    [anon_sym_PIPE_PIPE] = ACTIONS(95),
    [anon_sym_QMARK_QMARK] = ACTIONS(95),
    [anon_sym_QMARK_COLON] = ACTIONS(95),
    [anon_sym_BANG_EQ] = ACTIONS(95),
    [anon_sym_EQ_EQ] = ACTIONS(95),
    [anon_sym_QMARK_EQ] = ACTIONS(95),
    [anon_sym_STAR_EQ] = ACTIONS(95),
    [anon_sym_TILDE] = ACTIONS(95),
    [anon_sym_BANG_TILDE] = ACTIONS(95),
    [anon_sym_STAR_TILDE] = ACTIONS(95),
    [anon_sym_LT_EQ] = ACTIONS(95),
    [anon_sym_GT_EQ] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_PLUS_EQ] = ACTIONS(95),
    [anon_sym_DASH_EQ] = ACTIONS(95),
    [anon_sym_u00d7] = ACTIONS(95),
    [anon_sym_SLASH] = ACTIONS(97),
    [anon_sym_u00f7] = ACTIONS(95),
    [anon_sym_STAR_STAR] = ACTIONS(95),
    [anon_sym_u220b] = ACTIONS(95),
    [anon_sym_u220c] = ACTIONS(95),
    [anon_sym_u2287] = ACTIONS(95),
    [anon_sym_u2283] = ACTIONS(95),
    [anon_sym_u2285] = ACTIONS(95),
    [anon_sym_u2208] = ACTIONS(95),
    [anon_sym_u2209] = ACTIONS(95),
    [anon_sym_u2286] = ACTIONS(95),
    [anon_sym_u2282] = ACTIONS(95),
    [anon_sym_u2284] = ACTIONS(95),
    [anon_sym_AT_AT] = ACTIONS(95),
  },
  [32] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(166),
    [sym_keyword_return] = ACTIONS(166),
    [sym_keyword_from] = ACTIONS(166),
    [sym_keyword_as] = ACTIONS(166),
    [sym_keyword_parallel] = ACTIONS(166),
    [sym_keyword_timeout] = ACTIONS(166),
    [sym_keyword_where] = ACTIONS(166),
    [sym_keyword_group] = ACTIONS(166),
    [sym_keyword_and] = ACTIONS(166),
    [sym_keyword_or] = ACTIONS(166),
    [sym_keyword_is] = ACTIONS(166),
    [sym_keyword_not] = ACTIONS(168),
    [sym_keyword_contains] = ACTIONS(166),
    [sym_keyword_contains_not] = ACTIONS(166),
    [sym_keyword_contains_all] = ACTIONS(166),
    [sym_keyword_contains_any] = ACTIONS(166),
    [sym_keyword_contains_none] = ACTIONS(166),
    [sym_keyword_inside] = ACTIONS(166),
    [sym_keyword_in] = ACTIONS(168),
    [sym_keyword_not_inside] = ACTIONS(166),
    [sym_keyword_all_inside] = ACTIONS(166),
    [sym_keyword_any_inside] = ACTIONS(166),
    [sym_keyword_none_inside] = ACTIONS(166),
    [sym_keyword_outside] = ACTIONS(166),
    [sym_keyword_intersects] = ACTIONS(166),
    [sym_keyword_drop] = ACTIONS(166),
    [sym_keyword_schemafull] = ACTIONS(166),
    [sym_keyword_schemaless] = ACTIONS(166),
    [sym_keyword_changefeed] = ACTIONS(166),
    [sym_keyword_content] = ACTIONS(166),
    [sym_keyword_merge] = ACTIONS(166),
    [sym_keyword_patch] = ACTIONS(166),
    [sym_keyword_then] = ACTIONS(166),
    [sym_keyword_type] = ACTIONS(166),
    [sym_keyword_permissions] = ACTIONS(166),
    [sym_keyword_for] = ACTIONS(166),
    [sym_keyword_comment] = ACTIONS(166),
    [sym_keyword_if] = ACTIONS(166),
    [sym_keyword_set] = ACTIONS(166),
    [sym_keyword_unset] = ACTIONS(166),
    [anon_sym_COMMA] = ACTIONS(166),
    [anon_sym_DASH_GT] = ACTIONS(166),
    [anon_sym_LBRACK] = ACTIONS(166),
    [anon_sym_RBRACK] = ACTIONS(166),
    [anon_sym_LPAREN] = ACTIONS(166),
    [anon_sym_RPAREN] = ACTIONS(166),
    [anon_sym_QMARK] = ACTIONS(168),
    [anon_sym_LBRACE] = ACTIONS(166),
    [anon_sym_RBRACE] = ACTIONS(166),
    [anon_sym_LT_DASH] = ACTIONS(168),
    [anon_sym_LT_DASH_GT] = ACTIONS(166),
    [anon_sym_STAR] = ACTIONS(168),
    [anon_sym_DOT] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [anon_sym_GT] = ACTIONS(168),
    [sym_variable_name] = ACTIONS(166),
    [sym_custom_function_name] = ACTIONS(166),
    [anon_sym_EQ] = ACTIONS(168),
    [anon_sym_DASH] = ACTIONS(168),
    [anon_sym_AT] = ACTIONS(168),
    [anon_sym_LT_PIPE] = ACTIONS(166),
    [anon_sym_AMP_AMP] = ACTIONS(166),
    [anon_sym_PIPE_PIPE] = ACTIONS(166),
    [anon_sym_QMARK_QMARK] = ACTIONS(166),
    [anon_sym_QMARK_COLON] = ACTIONS(166),
    [anon_sym_BANG_EQ] = ACTIONS(166),
    [anon_sym_EQ_EQ] = ACTIONS(166),
    [anon_sym_QMARK_EQ] = ACTIONS(166),
    [anon_sym_STAR_EQ] = ACTIONS(166),
    [anon_sym_TILDE] = ACTIONS(166),
    [anon_sym_BANG_TILDE] = ACTIONS(166),
    [anon_sym_STAR_TILDE] = ACTIONS(166),
    [anon_sym_LT_EQ] = ACTIONS(166),
    [anon_sym_GT_EQ] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(168),
    [anon_sym_PLUS_EQ] = ACTIONS(166),
    [anon_sym_DASH_EQ] = ACTIONS(166),
    [anon_sym_u00d7] = ACTIONS(166),
    [anon_sym_SLASH] = ACTIONS(168),
    [anon_sym_u00f7] = ACTIONS(166),
    [anon_sym_STAR_STAR] = ACTIONS(166),
    [anon_sym_u220b] = ACTIONS(166),
    [anon_sym_u220c] = ACTIONS(166),
    [anon_sym_u2287] = ACTIONS(166),
    [anon_sym_u2283] = ACTIONS(166),
    [anon_sym_u2285] = ACTIONS(166),
    [anon_sym_u2208] = ACTIONS(166),
    [anon_sym_u2209] = ACTIONS(166),
    [anon_sym_u2286] = ACTIONS(166),
    [anon_sym_u2282] = ACTIONS(166),
    [anon_sym_u2284] = ACTIONS(166),
    [anon_sym_AT_AT] = ACTIONS(166),
  },
  [33] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(170),
    [sym_keyword_return] = ACTIONS(170),
    [sym_keyword_from] = ACTIONS(170),
    [sym_keyword_as] = ACTIONS(170),
    [sym_keyword_parallel] = ACTIONS(170),
    [sym_keyword_timeout] = ACTIONS(170),
    [sym_keyword_where] = ACTIONS(170),
    [sym_keyword_group] = ACTIONS(170),
    [sym_keyword_and] = ACTIONS(170),
    [sym_keyword_or] = ACTIONS(170),
    [sym_keyword_is] = ACTIONS(170),
    [sym_keyword_not] = ACTIONS(172),
    [sym_keyword_contains] = ACTIONS(170),
    [sym_keyword_contains_not] = ACTIONS(170),
    [sym_keyword_contains_all] = ACTIONS(170),
    [sym_keyword_contains_any] = ACTIONS(170),
    [sym_keyword_contains_none] = ACTIONS(170),
    [sym_keyword_inside] = ACTIONS(170),
    [sym_keyword_in] = ACTIONS(172),
    [sym_keyword_not_inside] = ACTIONS(170),
    [sym_keyword_all_inside] = ACTIONS(170),
    [sym_keyword_any_inside] = ACTIONS(170),
    [sym_keyword_none_inside] = ACTIONS(170),
    [sym_keyword_outside] = ACTIONS(170),
    [sym_keyword_intersects] = ACTIONS(170),
    [sym_keyword_drop] = ACTIONS(170),
    [sym_keyword_schemafull] = ACTIONS(170),
    [sym_keyword_schemaless] = ACTIONS(170),
    [sym_keyword_changefeed] = ACTIONS(170),
    [sym_keyword_content] = ACTIONS(170),
    [sym_keyword_merge] = ACTIONS(170),
    [sym_keyword_patch] = ACTIONS(170),
    [sym_keyword_then] = ACTIONS(170),
    [sym_keyword_type] = ACTIONS(170),
    [sym_keyword_permissions] = ACTIONS(170),
    [sym_keyword_for] = ACTIONS(170),
    [sym_keyword_comment] = ACTIONS(170),
    [sym_keyword_if] = ACTIONS(170),
    [sym_keyword_set] = ACTIONS(170),
    [sym_keyword_unset] = ACTIONS(170),
    [anon_sym_COMMA] = ACTIONS(170),
    [anon_sym_DASH_GT] = ACTIONS(170),
    [anon_sym_LBRACK] = ACTIONS(170),
    [anon_sym_RBRACK] = ACTIONS(170),
    [anon_sym_LPAREN] = ACTIONS(170),
    [anon_sym_RPAREN] = ACTIONS(170),
    [anon_sym_QMARK] = ACTIONS(172),
    [anon_sym_LBRACE] = ACTIONS(170),
    [anon_sym_RBRACE] = ACTIONS(170),
    [anon_sym_LT_DASH] = ACTIONS(172),
    [anon_sym_LT_DASH_GT] = ACTIONS(170),
    [anon_sym_STAR] = ACTIONS(172),
    [anon_sym_DOT] = ACTIONS(170),
    [anon_sym_LT] = ACTIONS(172),
    [anon_sym_GT] = ACTIONS(172),
    [sym_variable_name] = ACTIONS(170),
    [sym_custom_function_name] = ACTIONS(170),
    [anon_sym_EQ] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [anon_sym_AT] = ACTIONS(172),
    [anon_sym_LT_PIPE] = ACTIONS(170),
    [anon_sym_AMP_AMP] = ACTIONS(170),
    [anon_sym_PIPE_PIPE] = ACTIONS(170),
    [anon_sym_QMARK_QMARK] = ACTIONS(170),
    [anon_sym_QMARK_COLON] = ACTIONS(170),
    [anon_sym_BANG_EQ] = ACTIONS(170),
    [anon_sym_EQ_EQ] = ACTIONS(170),
    [anon_sym_QMARK_EQ] = ACTIONS(170),
    [anon_sym_STAR_EQ] = ACTIONS(170),
    [anon_sym_TILDE] = ACTIONS(170),
    [anon_sym_BANG_TILDE] = ACTIONS(170),
    [anon_sym_STAR_TILDE] = ACTIONS(170),
    [anon_sym_LT_EQ] = ACTIONS(170),
    [anon_sym_GT_EQ] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_PLUS_EQ] = ACTIONS(170),
    [anon_sym_DASH_EQ] = ACTIONS(170),
    [anon_sym_u00d7] = ACTIONS(170),
    [anon_sym_SLASH] = ACTIONS(172),
    [anon_sym_u00f7] = ACTIONS(170),
    [anon_sym_STAR_STAR] = ACTIONS(170),
    [anon_sym_u220b] = ACTIONS(170),
    [anon_sym_u220c] = ACTIONS(170),
    [anon_sym_u2287] = ACTIONS(170),
    [anon_sym_u2283] = ACTIONS(170),
    [anon_sym_u2285] = ACTIONS(170),
    [anon_sym_u2208] = ACTIONS(170),
    [anon_sym_u2209] = ACTIONS(170),
    [anon_sym_u2286] = ACTIONS(170),
    [anon_sym_u2282] = ACTIONS(170),
    [anon_sym_u2284] = ACTIONS(170),
    [anon_sym_AT_AT] = ACTIONS(170),
  },
  [34] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(174),
    [sym_keyword_return] = ACTIONS(174),
    [sym_keyword_from] = ACTIONS(174),
    [sym_keyword_as] = ACTIONS(174),
    [sym_keyword_parallel] = ACTIONS(174),
    [sym_keyword_timeout] = ACTIONS(174),
    [sym_keyword_where] = ACTIONS(174),
    [sym_keyword_group] = ACTIONS(174),
    [sym_keyword_and] = ACTIONS(174),
    [sym_keyword_or] = ACTIONS(174),
    [sym_keyword_is] = ACTIONS(174),
    [sym_keyword_not] = ACTIONS(176),
    [sym_keyword_contains] = ACTIONS(174),
    [sym_keyword_contains_not] = ACTIONS(174),
    [sym_keyword_contains_all] = ACTIONS(174),
    [sym_keyword_contains_any] = ACTIONS(174),
    [sym_keyword_contains_none] = ACTIONS(174),
    [sym_keyword_inside] = ACTIONS(174),
    [sym_keyword_in] = ACTIONS(176),
    [sym_keyword_not_inside] = ACTIONS(174),
    [sym_keyword_all_inside] = ACTIONS(174),
    [sym_keyword_any_inside] = ACTIONS(174),
    [sym_keyword_none_inside] = ACTIONS(174),
    [sym_keyword_outside] = ACTIONS(174),
    [sym_keyword_intersects] = ACTIONS(174),
    [sym_keyword_drop] = ACTIONS(174),
    [sym_keyword_schemafull] = ACTIONS(174),
    [sym_keyword_schemaless] = ACTIONS(174),
    [sym_keyword_changefeed] = ACTIONS(174),
    [sym_keyword_content] = ACTIONS(174),
    [sym_keyword_merge] = ACTIONS(174),
    [sym_keyword_patch] = ACTIONS(174),
    [sym_keyword_then] = ACTIONS(174),
    [sym_keyword_type] = ACTIONS(174),
    [sym_keyword_permissions] = ACTIONS(174),
    [sym_keyword_for] = ACTIONS(174),
    [sym_keyword_comment] = ACTIONS(174),
    [sym_keyword_if] = ACTIONS(174),
    [sym_keyword_set] = ACTIONS(174),
    [sym_keyword_unset] = ACTIONS(174),
    [anon_sym_COMMA] = ACTIONS(174),
    [anon_sym_DASH_GT] = ACTIONS(174),
    [anon_sym_LBRACK] = ACTIONS(174),
    [anon_sym_RBRACK] = ACTIONS(174),
    [anon_sym_LPAREN] = ACTIONS(174),
    [anon_sym_RPAREN] = ACTIONS(174),
    [anon_sym_QMARK] = ACTIONS(176),
    [anon_sym_LBRACE] = ACTIONS(174),
    [anon_sym_RBRACE] = ACTIONS(174),
    [anon_sym_LT_DASH] = ACTIONS(176),
    [anon_sym_LT_DASH_GT] = ACTIONS(174),
    [anon_sym_STAR] = ACTIONS(176),
    [anon_sym_DOT] = ACTIONS(174),
    [anon_sym_LT] = ACTIONS(176),
    [anon_sym_GT] = ACTIONS(176),
    [sym_variable_name] = ACTIONS(174),
    [sym_custom_function_name] = ACTIONS(174),
    [anon_sym_EQ] = ACTIONS(176),
    [anon_sym_DASH] = ACTIONS(176),
    [anon_sym_AT] = ACTIONS(176),
    [anon_sym_LT_PIPE] = ACTIONS(174),
    [anon_sym_AMP_AMP] = ACTIONS(174),
    [anon_sym_PIPE_PIPE] = ACTIONS(174),
    [anon_sym_QMARK_QMARK] = ACTIONS(174),
    [anon_sym_QMARK_COLON] = ACTIONS(174),
    [anon_sym_BANG_EQ] = ACTIONS(174),
    [anon_sym_EQ_EQ] = ACTIONS(174),
    [anon_sym_QMARK_EQ] = ACTIONS(174),
    [anon_sym_STAR_EQ] = ACTIONS(174),
    [anon_sym_TILDE] = ACTIONS(174),
    [anon_sym_BANG_TILDE] = ACTIONS(174),
    [anon_sym_STAR_TILDE] = ACTIONS(174),
    [anon_sym_LT_EQ] = ACTIONS(174),
    [anon_sym_GT_EQ] = ACTIONS(174),
    [anon_sym_PLUS] = ACTIONS(176),
    [anon_sym_PLUS_EQ] = ACTIONS(174),
    [anon_sym_DASH_EQ] = ACTIONS(174),
    [anon_sym_u00d7] = ACTIONS(174),
    [anon_sym_SLASH] = ACTIONS(176),
    [anon_sym_u00f7] = ACTIONS(174),
    [anon_sym_STAR_STAR] = ACTIONS(174),
    [anon_sym_u220b] = ACTIONS(174),
    [anon_sym_u220c] = ACTIONS(174),
    [anon_sym_u2287] = ACTIONS(174),
    [anon_sym_u2283] = ACTIONS(174),
    [anon_sym_u2285] = ACTIONS(174),
    [anon_sym_u2208] = ACTIONS(174),
    [anon_sym_u2209] = ACTIONS(174),
    [anon_sym_u2286] = ACTIONS(174),
    [anon_sym_u2282] = ACTIONS(174),
    [anon_sym_u2284] = ACTIONS(174),
    [anon_sym_AT_AT] = ACTIONS(174),
  },
  [35] = {
    [ts_builtin_sym_end] = ACTIONS(112),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(112),
    [sym_keyword_return] = ACTIONS(112),
    [sym_keyword_value] = ACTIONS(112),
    [sym_keyword_explain] = ACTIONS(112),
    [sym_keyword_parallel] = ACTIONS(112),
    [sym_keyword_timeout] = ACTIONS(112),
    [sym_keyword_fetch] = ACTIONS(112),
    [sym_keyword_limit] = ACTIONS(112),
    [sym_keyword_rand] = ACTIONS(112),
    [sym_keyword_collate] = ACTIONS(112),
    [sym_keyword_numeric] = ACTIONS(112),
    [sym_keyword_asc] = ACTIONS(112),
    [sym_keyword_desc] = ACTIONS(112),
    [sym_keyword_where] = ACTIONS(112),
    [sym_keyword_and] = ACTIONS(112),
    [sym_keyword_or] = ACTIONS(112),
    [sym_keyword_is] = ACTIONS(112),
    [sym_keyword_not] = ACTIONS(114),
    [sym_keyword_contains] = ACTIONS(112),
    [sym_keyword_contains_not] = ACTIONS(112),
    [sym_keyword_contains_all] = ACTIONS(112),
    [sym_keyword_contains_any] = ACTIONS(112),
    [sym_keyword_contains_none] = ACTIONS(112),
    [sym_keyword_inside] = ACTIONS(112),
    [sym_keyword_in] = ACTIONS(114),
    [sym_keyword_not_inside] = ACTIONS(112),
    [sym_keyword_all_inside] = ACTIONS(112),
    [sym_keyword_any_inside] = ACTIONS(112),
    [sym_keyword_none_inside] = ACTIONS(112),
    [sym_keyword_outside] = ACTIONS(112),
    [sym_keyword_intersects] = ACTIONS(112),
    [sym_keyword_flexible] = ACTIONS(112),
    [sym_keyword_readonly] = ACTIONS(112),
    [sym_keyword_content] = ACTIONS(112),
    [sym_keyword_merge] = ACTIONS(112),
    [sym_keyword_patch] = ACTIONS(112),
    [sym_keyword_type] = ACTIONS(112),
    [sym_keyword_default] = ACTIONS(112),
    [sym_keyword_assert] = ACTIONS(112),
    [sym_keyword_permissions] = ACTIONS(112),
    [sym_keyword_for] = ACTIONS(112),
    [sym_keyword_comment] = ACTIONS(112),
    [sym_keyword_set] = ACTIONS(112),
    [sym_keyword_unset] = ACTIONS(112),
    [anon_sym_COMMA] = ACTIONS(112),
    [anon_sym_DASH_GT] = ACTIONS(112),
    [anon_sym_LBRACK] = ACTIONS(112),
    [anon_sym_RPAREN] = ACTIONS(112),
    [anon_sym_RBRACE] = ACTIONS(112),
    [anon_sym_LT_DASH] = ACTIONS(114),
    [anon_sym_LT_DASH_GT] = ACTIONS(112),
    [anon_sym_STAR] = ACTIONS(114),
    [anon_sym_DOT] = ACTIONS(114),
    [anon_sym_LT] = ACTIONS(114),
    [anon_sym_GT] = ACTIONS(114),
    [anon_sym_DOT_DOT] = ACTIONS(112),
    [anon_sym_EQ] = ACTIONS(114),
    [anon_sym_DASH] = ACTIONS(114),
    [anon_sym_AT] = ACTIONS(114),
    [anon_sym_LT_PIPE] = ACTIONS(112),
    [anon_sym_AMP_AMP] = ACTIONS(112),
    [anon_sym_PIPE_PIPE] = ACTIONS(112),
    [anon_sym_QMARK_QMARK] = ACTIONS(112),
    [anon_sym_QMARK_COLON] = ACTIONS(112),
    [anon_sym_BANG_EQ] = ACTIONS(112),
    [anon_sym_EQ_EQ] = ACTIONS(112),
    [anon_sym_QMARK_EQ] = ACTIONS(112),
    [anon_sym_STAR_EQ] = ACTIONS(112),
    [anon_sym_TILDE] = ACTIONS(112),
    [anon_sym_BANG_TILDE] = ACTIONS(112),
    [anon_sym_STAR_TILDE] = ACTIONS(112),
    [anon_sym_LT_EQ] = ACTIONS(112),
    [anon_sym_GT_EQ] = ACTIONS(112),
    [anon_sym_PLUS] = ACTIONS(114),
    [anon_sym_PLUS_EQ] = ACTIONS(112),
    [anon_sym_DASH_EQ] = ACTIONS(112),
    [anon_sym_u00d7] = ACTIONS(112),
    [anon_sym_SLASH] = ACTIONS(114),
    [anon_sym_u00f7] = ACTIONS(112),
    [anon_sym_STAR_STAR] = ACTIONS(112),
    [anon_sym_u220b] = ACTIONS(112),
    [anon_sym_u220c] = ACTIONS(112),
    [anon_sym_u2287] = ACTIONS(112),
    [anon_sym_u2283] = ACTIONS(112),
    [anon_sym_u2285] = ACTIONS(112),
    [anon_sym_u2208] = ACTIONS(112),
    [anon_sym_u2209] = ACTIONS(112),
    [anon_sym_u2286] = ACTIONS(112),
    [anon_sym_u2282] = ACTIONS(112),
    [anon_sym_u2284] = ACTIONS(112),
    [anon_sym_AT_AT] = ACTIONS(112),
  },
  [36] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_return] = ACTIONS(178),
    [sym_keyword_from] = ACTIONS(178),
    [sym_keyword_as] = ACTIONS(178),
    [sym_keyword_parallel] = ACTIONS(178),
    [sym_keyword_timeout] = ACTIONS(178),
    [sym_keyword_where] = ACTIONS(178),
    [sym_keyword_group] = ACTIONS(178),
    [sym_keyword_and] = ACTIONS(178),
    [sym_keyword_or] = ACTIONS(178),
    [sym_keyword_is] = ACTIONS(178),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(178),
    [sym_keyword_contains_not] = ACTIONS(178),
    [sym_keyword_contains_all] = ACTIONS(178),
    [sym_keyword_contains_any] = ACTIONS(178),
    [sym_keyword_contains_none] = ACTIONS(178),
    [sym_keyword_inside] = ACTIONS(178),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(178),
    [sym_keyword_all_inside] = ACTIONS(178),
    [sym_keyword_any_inside] = ACTIONS(178),
    [sym_keyword_none_inside] = ACTIONS(178),
    [sym_keyword_outside] = ACTIONS(178),
    [sym_keyword_intersects] = ACTIONS(178),
    [sym_keyword_drop] = ACTIONS(178),
    [sym_keyword_schemafull] = ACTIONS(178),
    [sym_keyword_schemaless] = ACTIONS(178),
    [sym_keyword_changefeed] = ACTIONS(178),
    [sym_keyword_content] = ACTIONS(178),
    [sym_keyword_merge] = ACTIONS(178),
    [sym_keyword_patch] = ACTIONS(178),
    [sym_keyword_then] = ACTIONS(178),
    [sym_keyword_type] = ACTIONS(178),
    [sym_keyword_permissions] = ACTIONS(178),
    [sym_keyword_for] = ACTIONS(178),
    [sym_keyword_comment] = ACTIONS(178),
    [sym_keyword_if] = ACTIONS(178),
    [sym_keyword_set] = ACTIONS(178),
    [sym_keyword_unset] = ACTIONS(178),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RBRACK] = ACTIONS(178),
    [anon_sym_LPAREN] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_QMARK] = ACTIONS(180),
    [anon_sym_LBRACE] = ACTIONS(178),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_variable_name] = ACTIONS(178),
    [sym_custom_function_name] = ACTIONS(178),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [37] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_return] = ACTIONS(182),
    [sym_keyword_from] = ACTIONS(182),
    [sym_keyword_as] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_where] = ACTIONS(182),
    [sym_keyword_group] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_drop] = ACTIONS(182),
    [sym_keyword_schemafull] = ACTIONS(182),
    [sym_keyword_schemaless] = ACTIONS(182),
    [sym_keyword_changefeed] = ACTIONS(182),
    [sym_keyword_content] = ACTIONS(182),
    [sym_keyword_merge] = ACTIONS(182),
    [sym_keyword_patch] = ACTIONS(182),
    [sym_keyword_then] = ACTIONS(182),
    [sym_keyword_type] = ACTIONS(182),
    [sym_keyword_permissions] = ACTIONS(182),
    [sym_keyword_for] = ACTIONS(182),
    [sym_keyword_comment] = ACTIONS(182),
    [sym_keyword_if] = ACTIONS(182),
    [sym_keyword_set] = ACTIONS(182),
    [sym_keyword_unset] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RBRACK] = ACTIONS(182),
    [anon_sym_LPAREN] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_QMARK] = ACTIONS(184),
    [anon_sym_LBRACE] = ACTIONS(182),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(182),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [sym_variable_name] = ACTIONS(182),
    [sym_custom_function_name] = ACTIONS(182),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [38] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(186),
    [sym_keyword_return] = ACTIONS(186),
    [sym_keyword_from] = ACTIONS(186),
    [sym_keyword_as] = ACTIONS(186),
    [sym_keyword_parallel] = ACTIONS(186),
    [sym_keyword_timeout] = ACTIONS(186),
    [sym_keyword_where] = ACTIONS(186),
    [sym_keyword_group] = ACTIONS(186),
    [sym_keyword_and] = ACTIONS(186),
    [sym_keyword_or] = ACTIONS(186),
    [sym_keyword_is] = ACTIONS(186),
    [sym_keyword_not] = ACTIONS(188),
    [sym_keyword_contains] = ACTIONS(186),
    [sym_keyword_contains_not] = ACTIONS(186),
    [sym_keyword_contains_all] = ACTIONS(186),
    [sym_keyword_contains_any] = ACTIONS(186),
    [sym_keyword_contains_none] = ACTIONS(186),
    [sym_keyword_inside] = ACTIONS(186),
    [sym_keyword_in] = ACTIONS(188),
    [sym_keyword_not_inside] = ACTIONS(186),
    [sym_keyword_all_inside] = ACTIONS(186),
    [sym_keyword_any_inside] = ACTIONS(186),
    [sym_keyword_none_inside] = ACTIONS(186),
    [sym_keyword_outside] = ACTIONS(186),
    [sym_keyword_intersects] = ACTIONS(186),
    [sym_keyword_drop] = ACTIONS(186),
    [sym_keyword_schemafull] = ACTIONS(186),
    [sym_keyword_schemaless] = ACTIONS(186),
    [sym_keyword_changefeed] = ACTIONS(186),
    [sym_keyword_content] = ACTIONS(186),
    [sym_keyword_merge] = ACTIONS(186),
    [sym_keyword_patch] = ACTIONS(186),
    [sym_keyword_then] = ACTIONS(186),
    [sym_keyword_type] = ACTIONS(186),
    [sym_keyword_permissions] = ACTIONS(186),
    [sym_keyword_for] = ACTIONS(186),
    [sym_keyword_comment] = ACTIONS(186),
    [sym_keyword_if] = ACTIONS(186),
    [sym_keyword_set] = ACTIONS(186),
    [sym_keyword_unset] = ACTIONS(186),
    [anon_sym_COMMA] = ACTIONS(186),
    [anon_sym_DASH_GT] = ACTIONS(186),
    [anon_sym_LBRACK] = ACTIONS(186),
    [anon_sym_RBRACK] = ACTIONS(186),
    [anon_sym_LPAREN] = ACTIONS(186),
    [anon_sym_RPAREN] = ACTIONS(186),
    [anon_sym_QMARK] = ACTIONS(188),
    [anon_sym_LBRACE] = ACTIONS(186),
    [anon_sym_RBRACE] = ACTIONS(186),
    [anon_sym_LT_DASH] = ACTIONS(188),
    [anon_sym_LT_DASH_GT] = ACTIONS(186),
    [anon_sym_STAR] = ACTIONS(188),
    [anon_sym_DOT] = ACTIONS(186),
    [anon_sym_LT] = ACTIONS(188),
    [anon_sym_GT] = ACTIONS(188),
    [sym_variable_name] = ACTIONS(186),
    [sym_custom_function_name] = ACTIONS(186),
    [anon_sym_EQ] = ACTIONS(188),
    [anon_sym_DASH] = ACTIONS(188),
    [anon_sym_AT] = ACTIONS(188),
    [anon_sym_LT_PIPE] = ACTIONS(186),
    [anon_sym_AMP_AMP] = ACTIONS(186),
    [anon_sym_PIPE_PIPE] = ACTIONS(186),
    [anon_sym_QMARK_QMARK] = ACTIONS(186),
    [anon_sym_QMARK_COLON] = ACTIONS(186),
    [anon_sym_BANG_EQ] = ACTIONS(186),
    [anon_sym_EQ_EQ] = ACTIONS(186),
    [anon_sym_QMARK_EQ] = ACTIONS(186),
    [anon_sym_STAR_EQ] = ACTIONS(186),
    [anon_sym_TILDE] = ACTIONS(186),
    [anon_sym_BANG_TILDE] = ACTIONS(186),
    [anon_sym_STAR_TILDE] = ACTIONS(186),
    [anon_sym_LT_EQ] = ACTIONS(186),
    [anon_sym_GT_EQ] = ACTIONS(186),
    [anon_sym_PLUS] = ACTIONS(188),
    [anon_sym_PLUS_EQ] = ACTIONS(186),
    [anon_sym_DASH_EQ] = ACTIONS(186),
    [anon_sym_u00d7] = ACTIONS(186),
    [anon_sym_SLASH] = ACTIONS(188),
    [anon_sym_u00f7] = ACTIONS(186),
    [anon_sym_STAR_STAR] = ACTIONS(186),
    [anon_sym_u220b] = ACTIONS(186),
    [anon_sym_u220c] = ACTIONS(186),
    [anon_sym_u2287] = ACTIONS(186),
    [anon_sym_u2283] = ACTIONS(186),
    [anon_sym_u2285] = ACTIONS(186),
    [anon_sym_u2208] = ACTIONS(186),
    [anon_sym_u2209] = ACTIONS(186),
    [anon_sym_u2286] = ACTIONS(186),
    [anon_sym_u2282] = ACTIONS(186),
    [anon_sym_u2284] = ACTIONS(186),
    [anon_sym_AT_AT] = ACTIONS(186),
  },
  [39] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(190),
    [sym_keyword_return] = ACTIONS(190),
    [sym_keyword_from] = ACTIONS(190),
    [sym_keyword_as] = ACTIONS(190),
    [sym_keyword_parallel] = ACTIONS(190),
    [sym_keyword_timeout] = ACTIONS(190),
    [sym_keyword_where] = ACTIONS(190),
    [sym_keyword_group] = ACTIONS(190),
    [sym_keyword_and] = ACTIONS(190),
    [sym_keyword_or] = ACTIONS(190),
    [sym_keyword_is] = ACTIONS(190),
    [sym_keyword_not] = ACTIONS(192),
    [sym_keyword_contains] = ACTIONS(190),
    [sym_keyword_contains_not] = ACTIONS(190),
    [sym_keyword_contains_all] = ACTIONS(190),
    [sym_keyword_contains_any] = ACTIONS(190),
    [sym_keyword_contains_none] = ACTIONS(190),
    [sym_keyword_inside] = ACTIONS(190),
    [sym_keyword_in] = ACTIONS(192),
    [sym_keyword_not_inside] = ACTIONS(190),
    [sym_keyword_all_inside] = ACTIONS(190),
    [sym_keyword_any_inside] = ACTIONS(190),
    [sym_keyword_none_inside] = ACTIONS(190),
    [sym_keyword_outside] = ACTIONS(190),
    [sym_keyword_intersects] = ACTIONS(190),
    [sym_keyword_drop] = ACTIONS(190),
    [sym_keyword_schemafull] = ACTIONS(190),
    [sym_keyword_schemaless] = ACTIONS(190),
    [sym_keyword_changefeed] = ACTIONS(190),
    [sym_keyword_content] = ACTIONS(190),
    [sym_keyword_merge] = ACTIONS(190),
    [sym_keyword_patch] = ACTIONS(190),
    [sym_keyword_then] = ACTIONS(190),
    [sym_keyword_type] = ACTIONS(190),
    [sym_keyword_permissions] = ACTIONS(190),
    [sym_keyword_for] = ACTIONS(190),
    [sym_keyword_comment] = ACTIONS(190),
    [sym_keyword_if] = ACTIONS(190),
    [sym_keyword_set] = ACTIONS(190),
    [sym_keyword_unset] = ACTIONS(190),
    [anon_sym_COMMA] = ACTIONS(190),
    [anon_sym_DASH_GT] = ACTIONS(190),
    [anon_sym_LBRACK] = ACTIONS(190),
    [anon_sym_RBRACK] = ACTIONS(190),
    [anon_sym_LPAREN] = ACTIONS(190),
    [anon_sym_RPAREN] = ACTIONS(190),
    [anon_sym_QMARK] = ACTIONS(192),
    [anon_sym_LBRACE] = ACTIONS(190),
    [anon_sym_RBRACE] = ACTIONS(190),
    [anon_sym_LT_DASH] = ACTIONS(192),
    [anon_sym_LT_DASH_GT] = ACTIONS(190),
    [anon_sym_STAR] = ACTIONS(192),
    [anon_sym_DOT] = ACTIONS(190),
    [anon_sym_LT] = ACTIONS(192),
    [anon_sym_GT] = ACTIONS(192),
    [sym_variable_name] = ACTIONS(190),
    [sym_custom_function_name] = ACTIONS(190),
    [anon_sym_EQ] = ACTIONS(192),
    [anon_sym_DASH] = ACTIONS(192),
    [anon_sym_AT] = ACTIONS(192),
    [anon_sym_LT_PIPE] = ACTIONS(190),
    [anon_sym_AMP_AMP] = ACTIONS(190),
    [anon_sym_PIPE_PIPE] = ACTIONS(190),
    [anon_sym_QMARK_QMARK] = ACTIONS(190),
    [anon_sym_QMARK_COLON] = ACTIONS(190),
    [anon_sym_BANG_EQ] = ACTIONS(190),
    [anon_sym_EQ_EQ] = ACTIONS(190),
    [anon_sym_QMARK_EQ] = ACTIONS(190),
    [anon_sym_STAR_EQ] = ACTIONS(190),
    [anon_sym_TILDE] = ACTIONS(190),
    [anon_sym_BANG_TILDE] = ACTIONS(190),
    [anon_sym_STAR_TILDE] = ACTIONS(190),
    [anon_sym_LT_EQ] = ACTIONS(190),
    [anon_sym_GT_EQ] = ACTIONS(190),
    [anon_sym_PLUS] = ACTIONS(192),
    [anon_sym_PLUS_EQ] = ACTIONS(190),
    [anon_sym_DASH_EQ] = ACTIONS(190),
    [anon_sym_u00d7] = ACTIONS(190),
    [anon_sym_SLASH] = ACTIONS(192),
    [anon_sym_u00f7] = ACTIONS(190),
    [anon_sym_STAR_STAR] = ACTIONS(190),
    [anon_sym_u220b] = ACTIONS(190),
    [anon_sym_u220c] = ACTIONS(190),
    [anon_sym_u2287] = ACTIONS(190),
    [anon_sym_u2283] = ACTIONS(190),
    [anon_sym_u2285] = ACTIONS(190),
    [anon_sym_u2208] = ACTIONS(190),
    [anon_sym_u2209] = ACTIONS(190),
    [anon_sym_u2286] = ACTIONS(190),
    [anon_sym_u2282] = ACTIONS(190),
    [anon_sym_u2284] = ACTIONS(190),
    [anon_sym_AT_AT] = ACTIONS(190),
  },
  [40] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(158),
    [sym_keyword_return] = ACTIONS(158),
    [sym_keyword_from] = ACTIONS(158),
    [sym_keyword_as] = ACTIONS(158),
    [sym_keyword_parallel] = ACTIONS(158),
    [sym_keyword_timeout] = ACTIONS(158),
    [sym_keyword_where] = ACTIONS(158),
    [sym_keyword_group] = ACTIONS(158),
    [sym_keyword_and] = ACTIONS(158),
    [sym_keyword_or] = ACTIONS(158),
    [sym_keyword_is] = ACTIONS(158),
    [sym_keyword_not] = ACTIONS(160),
    [sym_keyword_contains] = ACTIONS(158),
    [sym_keyword_contains_not] = ACTIONS(158),
    [sym_keyword_contains_all] = ACTIONS(158),
    [sym_keyword_contains_any] = ACTIONS(158),
    [sym_keyword_contains_none] = ACTIONS(158),
    [sym_keyword_inside] = ACTIONS(158),
    [sym_keyword_in] = ACTIONS(160),
    [sym_keyword_not_inside] = ACTIONS(158),
    [sym_keyword_all_inside] = ACTIONS(158),
    [sym_keyword_any_inside] = ACTIONS(158),
    [sym_keyword_none_inside] = ACTIONS(158),
    [sym_keyword_outside] = ACTIONS(158),
    [sym_keyword_intersects] = ACTIONS(158),
    [sym_keyword_drop] = ACTIONS(158),
    [sym_keyword_schemafull] = ACTIONS(158),
    [sym_keyword_schemaless] = ACTIONS(158),
    [sym_keyword_changefeed] = ACTIONS(158),
    [sym_keyword_content] = ACTIONS(158),
    [sym_keyword_merge] = ACTIONS(158),
    [sym_keyword_patch] = ACTIONS(158),
    [sym_keyword_then] = ACTIONS(158),
    [sym_keyword_type] = ACTIONS(158),
    [sym_keyword_permissions] = ACTIONS(158),
    [sym_keyword_for] = ACTIONS(158),
    [sym_keyword_comment] = ACTIONS(158),
    [sym_keyword_if] = ACTIONS(158),
    [sym_keyword_set] = ACTIONS(158),
    [sym_keyword_unset] = ACTIONS(158),
    [anon_sym_COMMA] = ACTIONS(158),
    [anon_sym_DASH_GT] = ACTIONS(158),
    [anon_sym_LBRACK] = ACTIONS(158),
    [anon_sym_RBRACK] = ACTIONS(158),
    [anon_sym_LPAREN] = ACTIONS(158),
    [anon_sym_RPAREN] = ACTIONS(158),
    [anon_sym_QMARK] = ACTIONS(160),
    [anon_sym_LBRACE] = ACTIONS(158),
    [anon_sym_RBRACE] = ACTIONS(158),
    [anon_sym_LT_DASH] = ACTIONS(160),
    [anon_sym_LT_DASH_GT] = ACTIONS(158),
    [anon_sym_STAR] = ACTIONS(160),
    [anon_sym_DOT] = ACTIONS(158),
    [anon_sym_LT] = ACTIONS(160),
    [anon_sym_GT] = ACTIONS(160),
    [sym_variable_name] = ACTIONS(158),
    [sym_custom_function_name] = ACTIONS(158),
    [anon_sym_EQ] = ACTIONS(160),
    [anon_sym_DASH] = ACTIONS(160),
    [anon_sym_AT] = ACTIONS(160),
    [anon_sym_LT_PIPE] = ACTIONS(158),
    [anon_sym_AMP_AMP] = ACTIONS(158),
    [anon_sym_PIPE_PIPE] = ACTIONS(158),
    [anon_sym_QMARK_QMARK] = ACTIONS(158),
    [anon_sym_QMARK_COLON] = ACTIONS(158),
    [anon_sym_BANG_EQ] = ACTIONS(158),
    [anon_sym_EQ_EQ] = ACTIONS(158),
    [anon_sym_QMARK_EQ] = ACTIONS(158),
    [anon_sym_STAR_EQ] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(158),
    [anon_sym_BANG_TILDE] = ACTIONS(158),
    [anon_sym_STAR_TILDE] = ACTIONS(158),
    [anon_sym_LT_EQ] = ACTIONS(158),
    [anon_sym_GT_EQ] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(160),
    [anon_sym_PLUS_EQ] = ACTIONS(158),
    [anon_sym_DASH_EQ] = ACTIONS(158),
    [anon_sym_u00d7] = ACTIONS(158),
    [anon_sym_SLASH] = ACTIONS(160),
    [anon_sym_u00f7] = ACTIONS(158),
    [anon_sym_STAR_STAR] = ACTIONS(158),
    [anon_sym_u220b] = ACTIONS(158),
    [anon_sym_u220c] = ACTIONS(158),
    [anon_sym_u2287] = ACTIONS(158),
    [anon_sym_u2283] = ACTIONS(158),
    [anon_sym_u2285] = ACTIONS(158),
    [anon_sym_u2208] = ACTIONS(158),
    [anon_sym_u2209] = ACTIONS(158),
    [anon_sym_u2286] = ACTIONS(158),
    [anon_sym_u2282] = ACTIONS(158),
    [anon_sym_u2284] = ACTIONS(158),
    [anon_sym_AT_AT] = ACTIONS(158),
  },
  [41] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(194),
    [sym_keyword_return] = ACTIONS(194),
    [sym_keyword_from] = ACTIONS(194),
    [sym_keyword_as] = ACTIONS(194),
    [sym_keyword_parallel] = ACTIONS(194),
    [sym_keyword_timeout] = ACTIONS(194),
    [sym_keyword_where] = ACTIONS(194),
    [sym_keyword_group] = ACTIONS(194),
    [sym_keyword_and] = ACTIONS(194),
    [sym_keyword_or] = ACTIONS(194),
    [sym_keyword_is] = ACTIONS(194),
    [sym_keyword_not] = ACTIONS(196),
    [sym_keyword_contains] = ACTIONS(194),
    [sym_keyword_contains_not] = ACTIONS(194),
    [sym_keyword_contains_all] = ACTIONS(194),
    [sym_keyword_contains_any] = ACTIONS(194),
    [sym_keyword_contains_none] = ACTIONS(194),
    [sym_keyword_inside] = ACTIONS(194),
    [sym_keyword_in] = ACTIONS(196),
    [sym_keyword_not_inside] = ACTIONS(194),
    [sym_keyword_all_inside] = ACTIONS(194),
    [sym_keyword_any_inside] = ACTIONS(194),
    [sym_keyword_none_inside] = ACTIONS(194),
    [sym_keyword_outside] = ACTIONS(194),
    [sym_keyword_intersects] = ACTIONS(194),
    [sym_keyword_drop] = ACTIONS(194),
    [sym_keyword_schemafull] = ACTIONS(194),
    [sym_keyword_schemaless] = ACTIONS(194),
    [sym_keyword_changefeed] = ACTIONS(194),
    [sym_keyword_content] = ACTIONS(194),
    [sym_keyword_merge] = ACTIONS(194),
    [sym_keyword_patch] = ACTIONS(194),
    [sym_keyword_then] = ACTIONS(194),
    [sym_keyword_type] = ACTIONS(194),
    [sym_keyword_permissions] = ACTIONS(194),
    [sym_keyword_for] = ACTIONS(194),
    [sym_keyword_comment] = ACTIONS(194),
    [sym_keyword_if] = ACTIONS(194),
    [sym_keyword_set] = ACTIONS(194),
    [sym_keyword_unset] = ACTIONS(194),
    [anon_sym_COMMA] = ACTIONS(194),
    [anon_sym_DASH_GT] = ACTIONS(194),
    [anon_sym_LBRACK] = ACTIONS(194),
    [anon_sym_RBRACK] = ACTIONS(194),
    [anon_sym_LPAREN] = ACTIONS(194),
    [anon_sym_RPAREN] = ACTIONS(194),
    [anon_sym_QMARK] = ACTIONS(196),
    [anon_sym_LBRACE] = ACTIONS(194),
    [anon_sym_RBRACE] = ACTIONS(194),
    [anon_sym_LT_DASH] = ACTIONS(196),
    [anon_sym_LT_DASH_GT] = ACTIONS(194),
    [anon_sym_STAR] = ACTIONS(196),
    [anon_sym_DOT] = ACTIONS(194),
    [anon_sym_LT] = ACTIONS(196),
    [anon_sym_GT] = ACTIONS(196),
    [sym_variable_name] = ACTIONS(194),
    [sym_custom_function_name] = ACTIONS(194),
    [anon_sym_EQ] = ACTIONS(196),
    [anon_sym_DASH] = ACTIONS(196),
    [anon_sym_AT] = ACTIONS(196),
    [anon_sym_LT_PIPE] = ACTIONS(194),
    [anon_sym_AMP_AMP] = ACTIONS(194),
    [anon_sym_PIPE_PIPE] = ACTIONS(194),
    [anon_sym_QMARK_QMARK] = ACTIONS(194),
    [anon_sym_QMARK_COLON] = ACTIONS(194),
    [anon_sym_BANG_EQ] = ACTIONS(194),
    [anon_sym_EQ_EQ] = ACTIONS(194),
    [anon_sym_QMARK_EQ] = ACTIONS(194),
    [anon_sym_STAR_EQ] = ACTIONS(194),
    [anon_sym_TILDE] = ACTIONS(194),
    [anon_sym_BANG_TILDE] = ACTIONS(194),
    [anon_sym_STAR_TILDE] = ACTIONS(194),
    [anon_sym_LT_EQ] = ACTIONS(194),
    [anon_sym_GT_EQ] = ACTIONS(194),
    [anon_sym_PLUS] = ACTIONS(196),
    [anon_sym_PLUS_EQ] = ACTIONS(194),
    [anon_sym_DASH_EQ] = ACTIONS(194),
    [anon_sym_u00d7] = ACTIONS(194),
    [anon_sym_SLASH] = ACTIONS(196),
    [anon_sym_u00f7] = ACTIONS(194),
    [anon_sym_STAR_STAR] = ACTIONS(194),
    [anon_sym_u220b] = ACTIONS(194),
    [anon_sym_u220c] = ACTIONS(194),
    [anon_sym_u2287] = ACTIONS(194),
    [anon_sym_u2283] = ACTIONS(194),
    [anon_sym_u2285] = ACTIONS(194),
    [anon_sym_u2208] = ACTIONS(194),
    [anon_sym_u2209] = ACTIONS(194),
    [anon_sym_u2286] = ACTIONS(194),
    [anon_sym_u2282] = ACTIONS(194),
    [anon_sym_u2284] = ACTIONS(194),
    [anon_sym_AT_AT] = ACTIONS(194),
  },
  [42] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(198),
    [sym_keyword_return] = ACTIONS(198),
    [sym_keyword_from] = ACTIONS(198),
    [sym_keyword_as] = ACTIONS(198),
    [sym_keyword_parallel] = ACTIONS(198),
    [sym_keyword_timeout] = ACTIONS(198),
    [sym_keyword_where] = ACTIONS(198),
    [sym_keyword_group] = ACTIONS(198),
    [sym_keyword_and] = ACTIONS(198),
    [sym_keyword_or] = ACTIONS(198),
    [sym_keyword_is] = ACTIONS(198),
    [sym_keyword_not] = ACTIONS(200),
    [sym_keyword_contains] = ACTIONS(198),
    [sym_keyword_contains_not] = ACTIONS(198),
    [sym_keyword_contains_all] = ACTIONS(198),
    [sym_keyword_contains_any] = ACTIONS(198),
    [sym_keyword_contains_none] = ACTIONS(198),
    [sym_keyword_inside] = ACTIONS(198),
    [sym_keyword_in] = ACTIONS(200),
    [sym_keyword_not_inside] = ACTIONS(198),
    [sym_keyword_all_inside] = ACTIONS(198),
    [sym_keyword_any_inside] = ACTIONS(198),
    [sym_keyword_none_inside] = ACTIONS(198),
    [sym_keyword_outside] = ACTIONS(198),
    [sym_keyword_intersects] = ACTIONS(198),
    [sym_keyword_drop] = ACTIONS(198),
    [sym_keyword_schemafull] = ACTIONS(198),
    [sym_keyword_schemaless] = ACTIONS(198),
    [sym_keyword_changefeed] = ACTIONS(198),
    [sym_keyword_content] = ACTIONS(198),
    [sym_keyword_merge] = ACTIONS(198),
    [sym_keyword_patch] = ACTIONS(198),
    [sym_keyword_then] = ACTIONS(198),
    [sym_keyword_type] = ACTIONS(198),
    [sym_keyword_permissions] = ACTIONS(198),
    [sym_keyword_for] = ACTIONS(198),
    [sym_keyword_comment] = ACTIONS(198),
    [sym_keyword_if] = ACTIONS(198),
    [sym_keyword_set] = ACTIONS(198),
    [sym_keyword_unset] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(198),
    [anon_sym_DASH_GT] = ACTIONS(198),
    [anon_sym_LBRACK] = ACTIONS(198),
    [anon_sym_RBRACK] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(198),
    [anon_sym_RPAREN] = ACTIONS(198),
    [anon_sym_QMARK] = ACTIONS(200),
    [anon_sym_LBRACE] = ACTIONS(198),
    [anon_sym_RBRACE] = ACTIONS(198),
    [anon_sym_LT_DASH] = ACTIONS(200),
    [anon_sym_LT_DASH_GT] = ACTIONS(198),
    [anon_sym_STAR] = ACTIONS(200),
    [anon_sym_DOT] = ACTIONS(198),
    [anon_sym_LT] = ACTIONS(200),
    [anon_sym_GT] = ACTIONS(200),
    [sym_variable_name] = ACTIONS(198),
    [sym_custom_function_name] = ACTIONS(198),
    [anon_sym_EQ] = ACTIONS(200),
    [anon_sym_DASH] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(200),
    [anon_sym_LT_PIPE] = ACTIONS(198),
    [anon_sym_AMP_AMP] = ACTIONS(198),
    [anon_sym_PIPE_PIPE] = ACTIONS(198),
    [anon_sym_QMARK_QMARK] = ACTIONS(198),
    [anon_sym_QMARK_COLON] = ACTIONS(198),
    [anon_sym_BANG_EQ] = ACTIONS(198),
    [anon_sym_EQ_EQ] = ACTIONS(198),
    [anon_sym_QMARK_EQ] = ACTIONS(198),
    [anon_sym_STAR_EQ] = ACTIONS(198),
    [anon_sym_TILDE] = ACTIONS(198),
    [anon_sym_BANG_TILDE] = ACTIONS(198),
    [anon_sym_STAR_TILDE] = ACTIONS(198),
    [anon_sym_LT_EQ] = ACTIONS(198),
    [anon_sym_GT_EQ] = ACTIONS(198),
    [anon_sym_PLUS] = ACTIONS(200),
    [anon_sym_PLUS_EQ] = ACTIONS(198),
    [anon_sym_DASH_EQ] = ACTIONS(198),
    [anon_sym_u00d7] = ACTIONS(198),
    [anon_sym_SLASH] = ACTIONS(200),
    [anon_sym_u00f7] = ACTIONS(198),
    [anon_sym_STAR_STAR] = ACTIONS(198),
    [anon_sym_u220b] = ACTIONS(198),
    [anon_sym_u220c] = ACTIONS(198),
    [anon_sym_u2287] = ACTIONS(198),
    [anon_sym_u2283] = ACTIONS(198),
    [anon_sym_u2285] = ACTIONS(198),
    [anon_sym_u2208] = ACTIONS(198),
    [anon_sym_u2209] = ACTIONS(198),
    [anon_sym_u2286] = ACTIONS(198),
    [anon_sym_u2282] = ACTIONS(198),
    [anon_sym_u2284] = ACTIONS(198),
    [anon_sym_AT_AT] = ACTIONS(198),
  },
  [43] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(202),
    [sym_keyword_return] = ACTIONS(202),
    [sym_keyword_from] = ACTIONS(202),
    [sym_keyword_as] = ACTIONS(202),
    [sym_keyword_parallel] = ACTIONS(202),
    [sym_keyword_timeout] = ACTIONS(202),
    [sym_keyword_where] = ACTIONS(202),
    [sym_keyword_group] = ACTIONS(202),
    [sym_keyword_and] = ACTIONS(202),
    [sym_keyword_or] = ACTIONS(202),
    [sym_keyword_is] = ACTIONS(202),
    [sym_keyword_not] = ACTIONS(204),
    [sym_keyword_contains] = ACTIONS(202),
    [sym_keyword_contains_not] = ACTIONS(202),
    [sym_keyword_contains_all] = ACTIONS(202),
    [sym_keyword_contains_any] = ACTIONS(202),
    [sym_keyword_contains_none] = ACTIONS(202),
    [sym_keyword_inside] = ACTIONS(202),
    [sym_keyword_in] = ACTIONS(204),
    [sym_keyword_not_inside] = ACTIONS(202),
    [sym_keyword_all_inside] = ACTIONS(202),
    [sym_keyword_any_inside] = ACTIONS(202),
    [sym_keyword_none_inside] = ACTIONS(202),
    [sym_keyword_outside] = ACTIONS(202),
    [sym_keyword_intersects] = ACTIONS(202),
    [sym_keyword_drop] = ACTIONS(202),
    [sym_keyword_schemafull] = ACTIONS(202),
    [sym_keyword_schemaless] = ACTIONS(202),
    [sym_keyword_changefeed] = ACTIONS(202),
    [sym_keyword_content] = ACTIONS(202),
    [sym_keyword_merge] = ACTIONS(202),
    [sym_keyword_patch] = ACTIONS(202),
    [sym_keyword_then] = ACTIONS(202),
    [sym_keyword_type] = ACTIONS(202),
    [sym_keyword_permissions] = ACTIONS(202),
    [sym_keyword_for] = ACTIONS(202),
    [sym_keyword_comment] = ACTIONS(202),
    [sym_keyword_if] = ACTIONS(202),
    [sym_keyword_set] = ACTIONS(202),
    [sym_keyword_unset] = ACTIONS(202),
    [anon_sym_COMMA] = ACTIONS(202),
    [anon_sym_DASH_GT] = ACTIONS(202),
    [anon_sym_LBRACK] = ACTIONS(202),
    [anon_sym_RBRACK] = ACTIONS(202),
    [anon_sym_LPAREN] = ACTIONS(202),
    [anon_sym_RPAREN] = ACTIONS(202),
    [anon_sym_QMARK] = ACTIONS(204),
    [anon_sym_LBRACE] = ACTIONS(202),
    [anon_sym_RBRACE] = ACTIONS(202),
    [anon_sym_LT_DASH] = ACTIONS(204),
    [anon_sym_LT_DASH_GT] = ACTIONS(202),
    [anon_sym_STAR] = ACTIONS(204),
    [anon_sym_DOT] = ACTIONS(202),
    [anon_sym_LT] = ACTIONS(204),
    [anon_sym_GT] = ACTIONS(204),
    [sym_variable_name] = ACTIONS(202),
    [sym_custom_function_name] = ACTIONS(202),
    [anon_sym_EQ] = ACTIONS(204),
    [anon_sym_DASH] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(204),
    [anon_sym_LT_PIPE] = ACTIONS(202),
    [anon_sym_AMP_AMP] = ACTIONS(202),
    [anon_sym_PIPE_PIPE] = ACTIONS(202),
    [anon_sym_QMARK_QMARK] = ACTIONS(202),
    [anon_sym_QMARK_COLON] = ACTIONS(202),
    [anon_sym_BANG_EQ] = ACTIONS(202),
    [anon_sym_EQ_EQ] = ACTIONS(202),
    [anon_sym_QMARK_EQ] = ACTIONS(202),
    [anon_sym_STAR_EQ] = ACTIONS(202),
    [anon_sym_TILDE] = ACTIONS(202),
    [anon_sym_BANG_TILDE] = ACTIONS(202),
    [anon_sym_STAR_TILDE] = ACTIONS(202),
    [anon_sym_LT_EQ] = ACTIONS(202),
    [anon_sym_GT_EQ] = ACTIONS(202),
    [anon_sym_PLUS] = ACTIONS(204),
    [anon_sym_PLUS_EQ] = ACTIONS(202),
    [anon_sym_DASH_EQ] = ACTIONS(202),
    [anon_sym_u00d7] = ACTIONS(202),
    [anon_sym_SLASH] = ACTIONS(204),
    [anon_sym_u00f7] = ACTIONS(202),
    [anon_sym_STAR_STAR] = ACTIONS(202),
    [anon_sym_u220b] = ACTIONS(202),
    [anon_sym_u220c] = ACTIONS(202),
    [anon_sym_u2287] = ACTIONS(202),
    [anon_sym_u2283] = ACTIONS(202),
    [anon_sym_u2285] = ACTIONS(202),
    [anon_sym_u2208] = ACTIONS(202),
    [anon_sym_u2209] = ACTIONS(202),
    [anon_sym_u2286] = ACTIONS(202),
    [anon_sym_u2282] = ACTIONS(202),
    [anon_sym_u2284] = ACTIONS(202),
    [anon_sym_AT_AT] = ACTIONS(202),
  },
  [44] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(206),
    [sym_keyword_return] = ACTIONS(206),
    [sym_keyword_from] = ACTIONS(206),
    [sym_keyword_as] = ACTIONS(206),
    [sym_keyword_parallel] = ACTIONS(206),
    [sym_keyword_timeout] = ACTIONS(206),
    [sym_keyword_where] = ACTIONS(206),
    [sym_keyword_group] = ACTIONS(206),
    [sym_keyword_and] = ACTIONS(206),
    [sym_keyword_or] = ACTIONS(206),
    [sym_keyword_is] = ACTIONS(206),
    [sym_keyword_not] = ACTIONS(208),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(206),
    [sym_keyword_contains_all] = ACTIONS(206),
    [sym_keyword_contains_any] = ACTIONS(206),
    [sym_keyword_contains_none] = ACTIONS(206),
    [sym_keyword_inside] = ACTIONS(206),
    [sym_keyword_in] = ACTIONS(208),
    [sym_keyword_not_inside] = ACTIONS(206),
    [sym_keyword_all_inside] = ACTIONS(206),
    [sym_keyword_any_inside] = ACTIONS(206),
    [sym_keyword_none_inside] = ACTIONS(206),
    [sym_keyword_outside] = ACTIONS(206),
    [sym_keyword_intersects] = ACTIONS(206),
    [sym_keyword_drop] = ACTIONS(206),
    [sym_keyword_schemafull] = ACTIONS(206),
    [sym_keyword_schemaless] = ACTIONS(206),
    [sym_keyword_changefeed] = ACTIONS(206),
    [sym_keyword_content] = ACTIONS(206),
    [sym_keyword_merge] = ACTIONS(206),
    [sym_keyword_patch] = ACTIONS(206),
    [sym_keyword_then] = ACTIONS(206),
    [sym_keyword_type] = ACTIONS(206),
    [sym_keyword_permissions] = ACTIONS(206),
    [sym_keyword_for] = ACTIONS(206),
    [sym_keyword_comment] = ACTIONS(206),
    [sym_keyword_if] = ACTIONS(206),
    [sym_keyword_set] = ACTIONS(206),
    [sym_keyword_unset] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(206),
    [anon_sym_DASH_GT] = ACTIONS(206),
    [anon_sym_LBRACK] = ACTIONS(206),
    [anon_sym_RBRACK] = ACTIONS(206),
    [anon_sym_LPAREN] = ACTIONS(206),
    [anon_sym_RPAREN] = ACTIONS(206),
    [anon_sym_QMARK] = ACTIONS(208),
    [anon_sym_LBRACE] = ACTIONS(206),
    [anon_sym_RBRACE] = ACTIONS(206),
    [anon_sym_LT_DASH] = ACTIONS(208),
    [anon_sym_LT_DASH_GT] = ACTIONS(206),
    [anon_sym_STAR] = ACTIONS(208),
    [anon_sym_DOT] = ACTIONS(206),
    [anon_sym_LT] = ACTIONS(208),
    [anon_sym_GT] = ACTIONS(208),
    [sym_variable_name] = ACTIONS(206),
    [sym_custom_function_name] = ACTIONS(206),
    [anon_sym_EQ] = ACTIONS(208),
    [anon_sym_DASH] = ACTIONS(208),
    [anon_sym_AT] = ACTIONS(208),
    [anon_sym_LT_PIPE] = ACTIONS(206),
    [anon_sym_AMP_AMP] = ACTIONS(206),
    [anon_sym_PIPE_PIPE] = ACTIONS(206),
    [anon_sym_QMARK_QMARK] = ACTIONS(206),
    [anon_sym_QMARK_COLON] = ACTIONS(206),
    [anon_sym_BANG_EQ] = ACTIONS(206),
    [anon_sym_EQ_EQ] = ACTIONS(206),
    [anon_sym_QMARK_EQ] = ACTIONS(206),
    [anon_sym_STAR_EQ] = ACTIONS(206),
    [anon_sym_TILDE] = ACTIONS(206),
    [anon_sym_BANG_TILDE] = ACTIONS(206),
    [anon_sym_STAR_TILDE] = ACTIONS(206),
    [anon_sym_LT_EQ] = ACTIONS(206),
    [anon_sym_GT_EQ] = ACTIONS(206),
    [anon_sym_PLUS] = ACTIONS(208),
    [anon_sym_PLUS_EQ] = ACTIONS(206),
    [anon_sym_DASH_EQ] = ACTIONS(206),
    [anon_sym_u00d7] = ACTIONS(206),
    [anon_sym_SLASH] = ACTIONS(208),
    [anon_sym_u00f7] = ACTIONS(206),
    [anon_sym_STAR_STAR] = ACTIONS(206),
    [anon_sym_u220b] = ACTIONS(206),
    [anon_sym_u220c] = ACTIONS(206),
    [anon_sym_u2287] = ACTIONS(206),
    [anon_sym_u2283] = ACTIONS(206),
    [anon_sym_u2285] = ACTIONS(206),
    [anon_sym_u2208] = ACTIONS(206),
    [anon_sym_u2209] = ACTIONS(206),
    [anon_sym_u2286] = ACTIONS(206),
    [anon_sym_u2282] = ACTIONS(206),
    [anon_sym_u2284] = ACTIONS(206),
    [anon_sym_AT_AT] = ACTIONS(206),
  },
  [45] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_return] = ACTIONS(210),
    [sym_keyword_from] = ACTIONS(210),
    [sym_keyword_as] = ACTIONS(210),
    [sym_keyword_parallel] = ACTIONS(210),
    [sym_keyword_timeout] = ACTIONS(210),
    [sym_keyword_where] = ACTIONS(210),
    [sym_keyword_group] = ACTIONS(210),
    [sym_keyword_and] = ACTIONS(210),
    [sym_keyword_or] = ACTIONS(210),
    [sym_keyword_is] = ACTIONS(210),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(210),
    [sym_keyword_contains_not] = ACTIONS(210),
    [sym_keyword_contains_all] = ACTIONS(210),
    [sym_keyword_contains_any] = ACTIONS(210),
    [sym_keyword_contains_none] = ACTIONS(210),
    [sym_keyword_inside] = ACTIONS(210),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(210),
    [sym_keyword_all_inside] = ACTIONS(210),
    [sym_keyword_any_inside] = ACTIONS(210),
    [sym_keyword_none_inside] = ACTIONS(210),
    [sym_keyword_outside] = ACTIONS(210),
    [sym_keyword_intersects] = ACTIONS(210),
    [sym_keyword_drop] = ACTIONS(210),
    [sym_keyword_schemafull] = ACTIONS(210),
    [sym_keyword_schemaless] = ACTIONS(210),
    [sym_keyword_changefeed] = ACTIONS(210),
    [sym_keyword_content] = ACTIONS(210),
    [sym_keyword_merge] = ACTIONS(210),
    [sym_keyword_patch] = ACTIONS(210),
    [sym_keyword_then] = ACTIONS(210),
    [sym_keyword_type] = ACTIONS(210),
    [sym_keyword_permissions] = ACTIONS(210),
    [sym_keyword_for] = ACTIONS(210),
    [sym_keyword_comment] = ACTIONS(210),
    [sym_keyword_if] = ACTIONS(210),
    [sym_keyword_set] = ACTIONS(210),
    [sym_keyword_unset] = ACTIONS(210),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RBRACK] = ACTIONS(210),
    [anon_sym_LPAREN] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_QMARK] = ACTIONS(212),
    [anon_sym_LBRACE] = ACTIONS(210),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_variable_name] = ACTIONS(210),
    [sym_custom_function_name] = ACTIONS(210),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [46] = {
    [ts_builtin_sym_end] = ACTIONS(182),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_return] = ACTIONS(182),
    [sym_keyword_value] = ACTIONS(182),
    [sym_keyword_explain] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_fetch] = ACTIONS(182),
    [sym_keyword_limit] = ACTIONS(182),
    [sym_keyword_rand] = ACTIONS(182),
    [sym_keyword_collate] = ACTIONS(182),
    [sym_keyword_numeric] = ACTIONS(182),
    [sym_keyword_asc] = ACTIONS(182),
    [sym_keyword_desc] = ACTIONS(182),
    [sym_keyword_where] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_flexible] = ACTIONS(182),
    [sym_keyword_readonly] = ACTIONS(182),
    [sym_keyword_content] = ACTIONS(182),
    [sym_keyword_merge] = ACTIONS(182),
    [sym_keyword_patch] = ACTIONS(182),
    [sym_keyword_type] = ACTIONS(182),
    [sym_keyword_default] = ACTIONS(182),
    [sym_keyword_assert] = ACTIONS(182),
    [sym_keyword_permissions] = ACTIONS(182),
    [sym_keyword_for] = ACTIONS(182),
    [sym_keyword_comment] = ACTIONS(182),
    [sym_keyword_set] = ACTIONS(182),
    [sym_keyword_unset] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(182),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [47] = {
    [ts_builtin_sym_end] = ACTIONS(162),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(162),
    [sym_keyword_return] = ACTIONS(162),
    [sym_keyword_value] = ACTIONS(162),
    [sym_keyword_explain] = ACTIONS(162),
    [sym_keyword_parallel] = ACTIONS(162),
    [sym_keyword_timeout] = ACTIONS(162),
    [sym_keyword_fetch] = ACTIONS(162),
    [sym_keyword_limit] = ACTIONS(162),
    [sym_keyword_rand] = ACTIONS(162),
    [sym_keyword_collate] = ACTIONS(162),
    [sym_keyword_numeric] = ACTIONS(162),
    [sym_keyword_asc] = ACTIONS(162),
    [sym_keyword_desc] = ACTIONS(162),
    [sym_keyword_where] = ACTIONS(162),
    [sym_keyword_and] = ACTIONS(162),
    [sym_keyword_or] = ACTIONS(162),
    [sym_keyword_is] = ACTIONS(162),
    [sym_keyword_not] = ACTIONS(164),
    [sym_keyword_contains] = ACTIONS(162),
    [sym_keyword_contains_not] = ACTIONS(162),
    [sym_keyword_contains_all] = ACTIONS(162),
    [sym_keyword_contains_any] = ACTIONS(162),
    [sym_keyword_contains_none] = ACTIONS(162),
    [sym_keyword_inside] = ACTIONS(162),
    [sym_keyword_in] = ACTIONS(164),
    [sym_keyword_not_inside] = ACTIONS(162),
    [sym_keyword_all_inside] = ACTIONS(162),
    [sym_keyword_any_inside] = ACTIONS(162),
    [sym_keyword_none_inside] = ACTIONS(162),
    [sym_keyword_outside] = ACTIONS(162),
    [sym_keyword_intersects] = ACTIONS(162),
    [sym_keyword_flexible] = ACTIONS(162),
    [sym_keyword_readonly] = ACTIONS(162),
    [sym_keyword_content] = ACTIONS(162),
    [sym_keyword_merge] = ACTIONS(162),
    [sym_keyword_patch] = ACTIONS(162),
    [sym_keyword_type] = ACTIONS(162),
    [sym_keyword_default] = ACTIONS(162),
    [sym_keyword_assert] = ACTIONS(162),
    [sym_keyword_permissions] = ACTIONS(162),
    [sym_keyword_for] = ACTIONS(162),
    [sym_keyword_comment] = ACTIONS(162),
    [sym_keyword_set] = ACTIONS(162),
    [sym_keyword_unset] = ACTIONS(162),
    [anon_sym_COMMA] = ACTIONS(162),
    [anon_sym_DASH_GT] = ACTIONS(162),
    [anon_sym_LBRACK] = ACTIONS(162),
    [anon_sym_RPAREN] = ACTIONS(162),
    [anon_sym_RBRACE] = ACTIONS(162),
    [anon_sym_LT_DASH] = ACTIONS(164),
    [anon_sym_LT_DASH_GT] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_DOT] = ACTIONS(162),
    [anon_sym_LT] = ACTIONS(164),
    [anon_sym_GT] = ACTIONS(164),
    [anon_sym_EQ] = ACTIONS(164),
    [anon_sym_DASH] = ACTIONS(164),
    [anon_sym_AT] = ACTIONS(164),
    [anon_sym_LT_PIPE] = ACTIONS(162),
    [anon_sym_AMP_AMP] = ACTIONS(162),
    [anon_sym_PIPE_PIPE] = ACTIONS(162),
    [anon_sym_QMARK_QMARK] = ACTIONS(162),
    [anon_sym_QMARK_COLON] = ACTIONS(162),
    [anon_sym_BANG_EQ] = ACTIONS(162),
    [anon_sym_EQ_EQ] = ACTIONS(162),
    [anon_sym_QMARK_EQ] = ACTIONS(162),
    [anon_sym_STAR_EQ] = ACTIONS(162),
    [anon_sym_TILDE] = ACTIONS(162),
    [anon_sym_BANG_TILDE] = ACTIONS(162),
    [anon_sym_STAR_TILDE] = ACTIONS(162),
    [anon_sym_LT_EQ] = ACTIONS(162),
    [anon_sym_GT_EQ] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(164),
    [anon_sym_PLUS_EQ] = ACTIONS(162),
    [anon_sym_DASH_EQ] = ACTIONS(162),
    [anon_sym_u00d7] = ACTIONS(162),
    [anon_sym_SLASH] = ACTIONS(164),
    [anon_sym_u00f7] = ACTIONS(162),
    [anon_sym_STAR_STAR] = ACTIONS(162),
    [anon_sym_u220b] = ACTIONS(162),
    [anon_sym_u220c] = ACTIONS(162),
    [anon_sym_u2287] = ACTIONS(162),
    [anon_sym_u2283] = ACTIONS(162),
    [anon_sym_u2285] = ACTIONS(162),
    [anon_sym_u2208] = ACTIONS(162),
    [anon_sym_u2209] = ACTIONS(162),
    [anon_sym_u2286] = ACTIONS(162),
    [anon_sym_u2282] = ACTIONS(162),
    [anon_sym_u2284] = ACTIONS(162),
    [anon_sym_AT_AT] = ACTIONS(162),
  },
  [48] = {
    [ts_builtin_sym_end] = ACTIONS(210),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_return] = ACTIONS(210),
    [sym_keyword_value] = ACTIONS(210),
    [sym_keyword_explain] = ACTIONS(210),
    [sym_keyword_parallel] = ACTIONS(210),
    [sym_keyword_timeout] = ACTIONS(210),
    [sym_keyword_fetch] = ACTIONS(210),
    [sym_keyword_limit] = ACTIONS(210),
    [sym_keyword_rand] = ACTIONS(210),
    [sym_keyword_collate] = ACTIONS(210),
    [sym_keyword_numeric] = ACTIONS(210),
    [sym_keyword_asc] = ACTIONS(210),
    [sym_keyword_desc] = ACTIONS(210),
    [sym_keyword_where] = ACTIONS(210),
    [sym_keyword_and] = ACTIONS(210),
    [sym_keyword_or] = ACTIONS(210),
    [sym_keyword_is] = ACTIONS(210),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(210),
    [sym_keyword_contains_not] = ACTIONS(210),
    [sym_keyword_contains_all] = ACTIONS(210),
    [sym_keyword_contains_any] = ACTIONS(210),
    [sym_keyword_contains_none] = ACTIONS(210),
    [sym_keyword_inside] = ACTIONS(210),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(210),
    [sym_keyword_all_inside] = ACTIONS(210),
    [sym_keyword_any_inside] = ACTIONS(210),
    [sym_keyword_none_inside] = ACTIONS(210),
    [sym_keyword_outside] = ACTIONS(210),
    [sym_keyword_intersects] = ACTIONS(210),
    [sym_keyword_flexible] = ACTIONS(210),
    [sym_keyword_readonly] = ACTIONS(210),
    [sym_keyword_content] = ACTIONS(210),
    [sym_keyword_merge] = ACTIONS(210),
    [sym_keyword_patch] = ACTIONS(210),
    [sym_keyword_type] = ACTIONS(210),
    [sym_keyword_default] = ACTIONS(210),
    [sym_keyword_assert] = ACTIONS(210),
    [sym_keyword_permissions] = ACTIONS(210),
    [sym_keyword_for] = ACTIONS(210),
    [sym_keyword_comment] = ACTIONS(210),
    [sym_keyword_set] = ACTIONS(210),
    [sym_keyword_unset] = ACTIONS(210),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [49] = {
    [ts_builtin_sym_end] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_return] = ACTIONS(178),
    [sym_keyword_value] = ACTIONS(178),
    [sym_keyword_explain] = ACTIONS(178),
    [sym_keyword_parallel] = ACTIONS(178),
    [sym_keyword_timeout] = ACTIONS(178),
    [sym_keyword_fetch] = ACTIONS(178),
    [sym_keyword_limit] = ACTIONS(178),
    [sym_keyword_rand] = ACTIONS(178),
    [sym_keyword_collate] = ACTIONS(178),
    [sym_keyword_numeric] = ACTIONS(178),
    [sym_keyword_asc] = ACTIONS(178),
    [sym_keyword_desc] = ACTIONS(178),
    [sym_keyword_where] = ACTIONS(178),
    [sym_keyword_and] = ACTIONS(178),
    [sym_keyword_or] = ACTIONS(178),
    [sym_keyword_is] = ACTIONS(178),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(178),
    [sym_keyword_contains_not] = ACTIONS(178),
    [sym_keyword_contains_all] = ACTIONS(178),
    [sym_keyword_contains_any] = ACTIONS(178),
    [sym_keyword_contains_none] = ACTIONS(178),
    [sym_keyword_inside] = ACTIONS(178),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(178),
    [sym_keyword_all_inside] = ACTIONS(178),
    [sym_keyword_any_inside] = ACTIONS(178),
    [sym_keyword_none_inside] = ACTIONS(178),
    [sym_keyword_outside] = ACTIONS(178),
    [sym_keyword_intersects] = ACTIONS(178),
    [sym_keyword_flexible] = ACTIONS(178),
    [sym_keyword_readonly] = ACTIONS(178),
    [sym_keyword_content] = ACTIONS(178),
    [sym_keyword_merge] = ACTIONS(178),
    [sym_keyword_patch] = ACTIONS(178),
    [sym_keyword_type] = ACTIONS(178),
    [sym_keyword_default] = ACTIONS(178),
    [sym_keyword_assert] = ACTIONS(178),
    [sym_keyword_permissions] = ACTIONS(178),
    [sym_keyword_for] = ACTIONS(178),
    [sym_keyword_comment] = ACTIONS(178),
    [sym_keyword_set] = ACTIONS(178),
    [sym_keyword_unset] = ACTIONS(178),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [50] = {
    [ts_builtin_sym_end] = ACTIONS(170),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(170),
    [sym_keyword_return] = ACTIONS(170),
    [sym_keyword_value] = ACTIONS(170),
    [sym_keyword_explain] = ACTIONS(170),
    [sym_keyword_parallel] = ACTIONS(170),
    [sym_keyword_timeout] = ACTIONS(170),
    [sym_keyword_fetch] = ACTIONS(170),
    [sym_keyword_limit] = ACTIONS(170),
    [sym_keyword_rand] = ACTIONS(170),
    [sym_keyword_collate] = ACTIONS(170),
    [sym_keyword_numeric] = ACTIONS(170),
    [sym_keyword_asc] = ACTIONS(170),
    [sym_keyword_desc] = ACTIONS(170),
    [sym_keyword_where] = ACTIONS(170),
    [sym_keyword_and] = ACTIONS(170),
    [sym_keyword_or] = ACTIONS(170),
    [sym_keyword_is] = ACTIONS(170),
    [sym_keyword_not] = ACTIONS(172),
    [sym_keyword_contains] = ACTIONS(170),
    [sym_keyword_contains_not] = ACTIONS(170),
    [sym_keyword_contains_all] = ACTIONS(170),
    [sym_keyword_contains_any] = ACTIONS(170),
    [sym_keyword_contains_none] = ACTIONS(170),
    [sym_keyword_inside] = ACTIONS(170),
    [sym_keyword_in] = ACTIONS(172),
    [sym_keyword_not_inside] = ACTIONS(170),
    [sym_keyword_all_inside] = ACTIONS(170),
    [sym_keyword_any_inside] = ACTIONS(170),
    [sym_keyword_none_inside] = ACTIONS(170),
    [sym_keyword_outside] = ACTIONS(170),
    [sym_keyword_intersects] = ACTIONS(170),
    [sym_keyword_flexible] = ACTIONS(170),
    [sym_keyword_readonly] = ACTIONS(170),
    [sym_keyword_content] = ACTIONS(170),
    [sym_keyword_merge] = ACTIONS(170),
    [sym_keyword_patch] = ACTIONS(170),
    [sym_keyword_type] = ACTIONS(170),
    [sym_keyword_default] = ACTIONS(170),
    [sym_keyword_assert] = ACTIONS(170),
    [sym_keyword_permissions] = ACTIONS(170),
    [sym_keyword_for] = ACTIONS(170),
    [sym_keyword_comment] = ACTIONS(170),
    [sym_keyword_set] = ACTIONS(170),
    [sym_keyword_unset] = ACTIONS(170),
    [anon_sym_COMMA] = ACTIONS(170),
    [anon_sym_DASH_GT] = ACTIONS(170),
    [anon_sym_LBRACK] = ACTIONS(170),
    [anon_sym_RPAREN] = ACTIONS(170),
    [anon_sym_RBRACE] = ACTIONS(170),
    [anon_sym_LT_DASH] = ACTIONS(172),
    [anon_sym_LT_DASH_GT] = ACTIONS(170),
    [anon_sym_STAR] = ACTIONS(172),
    [anon_sym_DOT] = ACTIONS(170),
    [anon_sym_LT] = ACTIONS(172),
    [anon_sym_GT] = ACTIONS(172),
    [anon_sym_EQ] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [anon_sym_AT] = ACTIONS(172),
    [anon_sym_LT_PIPE] = ACTIONS(170),
    [anon_sym_AMP_AMP] = ACTIONS(170),
    [anon_sym_PIPE_PIPE] = ACTIONS(170),
    [anon_sym_QMARK_QMARK] = ACTIONS(170),
    [anon_sym_QMARK_COLON] = ACTIONS(170),
    [anon_sym_BANG_EQ] = ACTIONS(170),
    [anon_sym_EQ_EQ] = ACTIONS(170),
    [anon_sym_QMARK_EQ] = ACTIONS(170),
    [anon_sym_STAR_EQ] = ACTIONS(170),
    [anon_sym_TILDE] = ACTIONS(170),
    [anon_sym_BANG_TILDE] = ACTIONS(170),
    [anon_sym_STAR_TILDE] = ACTIONS(170),
    [anon_sym_LT_EQ] = ACTIONS(170),
    [anon_sym_GT_EQ] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_PLUS_EQ] = ACTIONS(170),
    [anon_sym_DASH_EQ] = ACTIONS(170),
    [anon_sym_u00d7] = ACTIONS(170),
    [anon_sym_SLASH] = ACTIONS(172),
    [anon_sym_u00f7] = ACTIONS(170),
    [anon_sym_STAR_STAR] = ACTIONS(170),
    [anon_sym_u220b] = ACTIONS(170),
    [anon_sym_u220c] = ACTIONS(170),
    [anon_sym_u2287] = ACTIONS(170),
    [anon_sym_u2283] = ACTIONS(170),
    [anon_sym_u2285] = ACTIONS(170),
    [anon_sym_u2208] = ACTIONS(170),
    [anon_sym_u2209] = ACTIONS(170),
    [anon_sym_u2286] = ACTIONS(170),
    [anon_sym_u2282] = ACTIONS(170),
    [anon_sym_u2284] = ACTIONS(170),
    [anon_sym_AT_AT] = ACTIONS(170),
  },
  [51] = {
    [aux_sym_duration_repeat1] = STATE(51),
    [ts_builtin_sym_end] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(105),
    [sym_keyword_return] = ACTIONS(105),
    [sym_keyword_as] = ACTIONS(105),
    [sym_keyword_explain] = ACTIONS(105),
    [sym_keyword_parallel] = ACTIONS(105),
    [sym_keyword_timeout] = ACTIONS(105),
    [sym_keyword_where] = ACTIONS(105),
    [sym_keyword_group] = ACTIONS(105),
    [sym_keyword_and] = ACTIONS(105),
    [sym_keyword_or] = ACTIONS(105),
    [sym_keyword_is] = ACTIONS(105),
    [sym_keyword_not] = ACTIONS(107),
    [sym_keyword_contains] = ACTIONS(105),
    [sym_keyword_contains_not] = ACTIONS(105),
    [sym_keyword_contains_all] = ACTIONS(105),
    [sym_keyword_contains_any] = ACTIONS(105),
    [sym_keyword_contains_none] = ACTIONS(105),
    [sym_keyword_inside] = ACTIONS(105),
    [sym_keyword_in] = ACTIONS(107),
    [sym_keyword_not_inside] = ACTIONS(105),
    [sym_keyword_all_inside] = ACTIONS(105),
    [sym_keyword_any_inside] = ACTIONS(105),
    [sym_keyword_none_inside] = ACTIONS(105),
    [sym_keyword_outside] = ACTIONS(105),
    [sym_keyword_intersects] = ACTIONS(105),
    [sym_keyword_drop] = ACTIONS(105),
    [sym_keyword_schemafull] = ACTIONS(105),
    [sym_keyword_schemaless] = ACTIONS(105),
    [sym_keyword_changefeed] = ACTIONS(105),
    [sym_keyword_content] = ACTIONS(105),
    [sym_keyword_merge] = ACTIONS(105),
    [sym_keyword_patch] = ACTIONS(105),
    [sym_keyword_type] = ACTIONS(105),
    [sym_keyword_permissions] = ACTIONS(105),
    [sym_keyword_for] = ACTIONS(105),
    [sym_keyword_comment] = ACTIONS(105),
    [sym_keyword_session] = ACTIONS(105),
    [sym_keyword_signin] = ACTIONS(105),
    [sym_keyword_signup] = ACTIONS(105),
    [sym_keyword_set] = ACTIONS(105),
    [sym_keyword_unset] = ACTIONS(105),
    [anon_sym_COMMA] = ACTIONS(105),
    [anon_sym_DASH_GT] = ACTIONS(105),
    [anon_sym_LBRACK] = ACTIONS(105),
    [anon_sym_RPAREN] = ACTIONS(105),
    [anon_sym_RBRACE] = ACTIONS(105),
    [anon_sym_LT_DASH] = ACTIONS(107),
    [anon_sym_LT_DASH_GT] = ACTIONS(105),
    [anon_sym_STAR] = ACTIONS(107),
    [anon_sym_DOT] = ACTIONS(105),
    [anon_sym_LT] = ACTIONS(107),
    [anon_sym_GT] = ACTIONS(107),
    [anon_sym_EQ] = ACTIONS(107),
    [sym_duration_part] = ACTIONS(214),
    [anon_sym_DASH] = ACTIONS(107),
    [anon_sym_AT] = ACTIONS(107),
    [anon_sym_LT_PIPE] = ACTIONS(105),
    [anon_sym_AMP_AMP] = ACTIONS(105),
    [anon_sym_PIPE_PIPE] = ACTIONS(105),
    [anon_sym_QMARK_QMARK] = ACTIONS(105),
    [anon_sym_QMARK_COLON] = ACTIONS(105),
    [anon_sym_BANG_EQ] = ACTIONS(105),
    [anon_sym_EQ_EQ] = ACTIONS(105),
    [anon_sym_QMARK_EQ] = ACTIONS(105),
    [anon_sym_STAR_EQ] = ACTIONS(105),
    [anon_sym_TILDE] = ACTIONS(105),
    [anon_sym_BANG_TILDE] = ACTIONS(105),
    [anon_sym_STAR_TILDE] = ACTIONS(105),
    [anon_sym_LT_EQ] = ACTIONS(105),
    [anon_sym_GT_EQ] = ACTIONS(105),
    [anon_sym_PLUS] = ACTIONS(107),
    [anon_sym_PLUS_EQ] = ACTIONS(105),
    [anon_sym_DASH_EQ] = ACTIONS(105),
    [anon_sym_u00d7] = ACTIONS(105),
    [anon_sym_SLASH] = ACTIONS(107),
    [anon_sym_u00f7] = ACTIONS(105),
    [anon_sym_STAR_STAR] = ACTIONS(105),
    [anon_sym_u220b] = ACTIONS(105),
    [anon_sym_u220c] = ACTIONS(105),
    [anon_sym_u2287] = ACTIONS(105),
    [anon_sym_u2283] = ACTIONS(105),
    [anon_sym_u2285] = ACTIONS(105),
    [anon_sym_u2208] = ACTIONS(105),
    [anon_sym_u2209] = ACTIONS(105),
    [anon_sym_u2286] = ACTIONS(105),
    [anon_sym_u2282] = ACTIONS(105),
    [anon_sym_u2284] = ACTIONS(105),
    [anon_sym_AT_AT] = ACTIONS(105),
  },
  [52] = {
    [aux_sym_duration_repeat1] = STATE(51),
    [ts_builtin_sym_end] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(99),
    [sym_keyword_return] = ACTIONS(99),
    [sym_keyword_as] = ACTIONS(99),
    [sym_keyword_explain] = ACTIONS(99),
    [sym_keyword_parallel] = ACTIONS(99),
    [sym_keyword_timeout] = ACTIONS(99),
    [sym_keyword_where] = ACTIONS(99),
    [sym_keyword_group] = ACTIONS(99),
    [sym_keyword_and] = ACTIONS(99),
    [sym_keyword_or] = ACTIONS(99),
    [sym_keyword_is] = ACTIONS(99),
    [sym_keyword_not] = ACTIONS(101),
    [sym_keyword_contains] = ACTIONS(99),
    [sym_keyword_contains_not] = ACTIONS(99),
    [sym_keyword_contains_all] = ACTIONS(99),
    [sym_keyword_contains_any] = ACTIONS(99),
    [sym_keyword_contains_none] = ACTIONS(99),
    [sym_keyword_inside] = ACTIONS(99),
    [sym_keyword_in] = ACTIONS(101),
    [sym_keyword_not_inside] = ACTIONS(99),
    [sym_keyword_all_inside] = ACTIONS(99),
    [sym_keyword_any_inside] = ACTIONS(99),
    [sym_keyword_none_inside] = ACTIONS(99),
    [sym_keyword_outside] = ACTIONS(99),
    [sym_keyword_intersects] = ACTIONS(99),
    [sym_keyword_drop] = ACTIONS(99),
    [sym_keyword_schemafull] = ACTIONS(99),
    [sym_keyword_schemaless] = ACTIONS(99),
    [sym_keyword_changefeed] = ACTIONS(99),
    [sym_keyword_content] = ACTIONS(99),
    [sym_keyword_merge] = ACTIONS(99),
    [sym_keyword_patch] = ACTIONS(99),
    [sym_keyword_type] = ACTIONS(99),
    [sym_keyword_permissions] = ACTIONS(99),
    [sym_keyword_for] = ACTIONS(99),
    [sym_keyword_comment] = ACTIONS(99),
    [sym_keyword_session] = ACTIONS(99),
    [sym_keyword_signin] = ACTIONS(99),
    [sym_keyword_signup] = ACTIONS(99),
    [sym_keyword_set] = ACTIONS(99),
    [sym_keyword_unset] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_DASH_GT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(99),
    [anon_sym_RPAREN] = ACTIONS(99),
    [anon_sym_RBRACE] = ACTIONS(99),
    [anon_sym_LT_DASH] = ACTIONS(101),
    [anon_sym_LT_DASH_GT] = ACTIONS(99),
    [anon_sym_STAR] = ACTIONS(101),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LT] = ACTIONS(101),
    [anon_sym_GT] = ACTIONS(101),
    [anon_sym_EQ] = ACTIONS(101),
    [sym_duration_part] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(101),
    [anon_sym_AT] = ACTIONS(101),
    [anon_sym_LT_PIPE] = ACTIONS(99),
    [anon_sym_AMP_AMP] = ACTIONS(99),
    [anon_sym_PIPE_PIPE] = ACTIONS(99),
    [anon_sym_QMARK_QMARK] = ACTIONS(99),
    [anon_sym_QMARK_COLON] = ACTIONS(99),
    [anon_sym_BANG_EQ] = ACTIONS(99),
    [anon_sym_EQ_EQ] = ACTIONS(99),
    [anon_sym_QMARK_EQ] = ACTIONS(99),
    [anon_sym_STAR_EQ] = ACTIONS(99),
    [anon_sym_TILDE] = ACTIONS(99),
    [anon_sym_BANG_TILDE] = ACTIONS(99),
    [anon_sym_STAR_TILDE] = ACTIONS(99),
    [anon_sym_LT_EQ] = ACTIONS(99),
    [anon_sym_GT_EQ] = ACTIONS(99),
    [anon_sym_PLUS] = ACTIONS(101),
    [anon_sym_PLUS_EQ] = ACTIONS(99),
    [anon_sym_DASH_EQ] = ACTIONS(99),
    [anon_sym_u00d7] = ACTIONS(99),
    [anon_sym_SLASH] = ACTIONS(101),
    [anon_sym_u00f7] = ACTIONS(99),
    [anon_sym_STAR_STAR] = ACTIONS(99),
    [anon_sym_u220b] = ACTIONS(99),
    [anon_sym_u220c] = ACTIONS(99),
    [anon_sym_u2287] = ACTIONS(99),
    [anon_sym_u2283] = ACTIONS(99),
    [anon_sym_u2285] = ACTIONS(99),
    [anon_sym_u2208] = ACTIONS(99),
    [anon_sym_u2209] = ACTIONS(99),
    [anon_sym_u2286] = ACTIONS(99),
    [anon_sym_u2282] = ACTIONS(99),
    [anon_sym_u2284] = ACTIONS(99),
    [anon_sym_AT_AT] = ACTIONS(99),
  },
  [53] = {
    [ts_builtin_sym_end] = ACTIONS(194),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(194),
    [sym_keyword_return] = ACTIONS(194),
    [sym_keyword_value] = ACTIONS(194),
    [sym_keyword_explain] = ACTIONS(194),
    [sym_keyword_parallel] = ACTIONS(194),
    [sym_keyword_timeout] = ACTIONS(194),
    [sym_keyword_fetch] = ACTIONS(194),
    [sym_keyword_limit] = ACTIONS(194),
    [sym_keyword_rand] = ACTIONS(194),
    [sym_keyword_collate] = ACTIONS(194),
    [sym_keyword_numeric] = ACTIONS(194),
    [sym_keyword_asc] = ACTIONS(194),
    [sym_keyword_desc] = ACTIONS(194),
    [sym_keyword_where] = ACTIONS(194),
    [sym_keyword_and] = ACTIONS(194),
    [sym_keyword_or] = ACTIONS(194),
    [sym_keyword_is] = ACTIONS(194),
    [sym_keyword_not] = ACTIONS(196),
    [sym_keyword_contains] = ACTIONS(194),
    [sym_keyword_contains_not] = ACTIONS(194),
    [sym_keyword_contains_all] = ACTIONS(194),
    [sym_keyword_contains_any] = ACTIONS(194),
    [sym_keyword_contains_none] = ACTIONS(194),
    [sym_keyword_inside] = ACTIONS(194),
    [sym_keyword_in] = ACTIONS(196),
    [sym_keyword_not_inside] = ACTIONS(194),
    [sym_keyword_all_inside] = ACTIONS(194),
    [sym_keyword_any_inside] = ACTIONS(194),
    [sym_keyword_none_inside] = ACTIONS(194),
    [sym_keyword_outside] = ACTIONS(194),
    [sym_keyword_intersects] = ACTIONS(194),
    [sym_keyword_flexible] = ACTIONS(194),
    [sym_keyword_readonly] = ACTIONS(194),
    [sym_keyword_content] = ACTIONS(194),
    [sym_keyword_merge] = ACTIONS(194),
    [sym_keyword_patch] = ACTIONS(194),
    [sym_keyword_type] = ACTIONS(194),
    [sym_keyword_default] = ACTIONS(194),
    [sym_keyword_assert] = ACTIONS(194),
    [sym_keyword_permissions] = ACTIONS(194),
    [sym_keyword_for] = ACTIONS(194),
    [sym_keyword_comment] = ACTIONS(194),
    [sym_keyword_set] = ACTIONS(194),
    [sym_keyword_unset] = ACTIONS(194),
    [anon_sym_COMMA] = ACTIONS(194),
    [anon_sym_DASH_GT] = ACTIONS(194),
    [anon_sym_LBRACK] = ACTIONS(194),
    [anon_sym_LT_DASH] = ACTIONS(196),
    [anon_sym_LT_DASH_GT] = ACTIONS(194),
    [anon_sym_STAR] = ACTIONS(196),
    [anon_sym_DOT] = ACTIONS(194),
    [anon_sym_LT] = ACTIONS(196),
    [anon_sym_GT] = ACTIONS(196),
    [anon_sym_EQ] = ACTIONS(196),
    [anon_sym_DASH] = ACTIONS(196),
    [anon_sym_AT] = ACTIONS(196),
    [anon_sym_LT_PIPE] = ACTIONS(194),
    [anon_sym_AMP_AMP] = ACTIONS(194),
    [anon_sym_PIPE_PIPE] = ACTIONS(194),
    [anon_sym_QMARK_QMARK] = ACTIONS(194),
    [anon_sym_QMARK_COLON] = ACTIONS(194),
    [anon_sym_BANG_EQ] = ACTIONS(194),
    [anon_sym_EQ_EQ] = ACTIONS(194),
    [anon_sym_QMARK_EQ] = ACTIONS(194),
    [anon_sym_STAR_EQ] = ACTIONS(194),
    [anon_sym_TILDE] = ACTIONS(194),
    [anon_sym_BANG_TILDE] = ACTIONS(194),
    [anon_sym_STAR_TILDE] = ACTIONS(194),
    [anon_sym_LT_EQ] = ACTIONS(194),
    [anon_sym_GT_EQ] = ACTIONS(194),
    [anon_sym_PLUS] = ACTIONS(196),
    [anon_sym_PLUS_EQ] = ACTIONS(194),
    [anon_sym_DASH_EQ] = ACTIONS(194),
    [anon_sym_u00d7] = ACTIONS(194),
    [anon_sym_SLASH] = ACTIONS(196),
    [anon_sym_u00f7] = ACTIONS(194),
    [anon_sym_STAR_STAR] = ACTIONS(194),
    [anon_sym_u220b] = ACTIONS(194),
    [anon_sym_u220c] = ACTIONS(194),
    [anon_sym_u2287] = ACTIONS(194),
    [anon_sym_u2283] = ACTIONS(194),
    [anon_sym_u2285] = ACTIONS(194),
    [anon_sym_u2208] = ACTIONS(194),
    [anon_sym_u2209] = ACTIONS(194),
    [anon_sym_u2286] = ACTIONS(194),
    [anon_sym_u2282] = ACTIONS(194),
    [anon_sym_u2284] = ACTIONS(194),
    [anon_sym_AT_AT] = ACTIONS(194),
  },
  [54] = {
    [ts_builtin_sym_end] = ACTIONS(190),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(190),
    [sym_keyword_return] = ACTIONS(190),
    [sym_keyword_value] = ACTIONS(190),
    [sym_keyword_explain] = ACTIONS(190),
    [sym_keyword_parallel] = ACTIONS(190),
    [sym_keyword_timeout] = ACTIONS(190),
    [sym_keyword_fetch] = ACTIONS(190),
    [sym_keyword_limit] = ACTIONS(190),
    [sym_keyword_rand] = ACTIONS(190),
    [sym_keyword_collate] = ACTIONS(190),
    [sym_keyword_numeric] = ACTIONS(190),
    [sym_keyword_asc] = ACTIONS(190),
    [sym_keyword_desc] = ACTIONS(190),
    [sym_keyword_where] = ACTIONS(190),
    [sym_keyword_and] = ACTIONS(190),
    [sym_keyword_or] = ACTIONS(190),
    [sym_keyword_is] = ACTIONS(190),
    [sym_keyword_not] = ACTIONS(192),
    [sym_keyword_contains] = ACTIONS(190),
    [sym_keyword_contains_not] = ACTIONS(190),
    [sym_keyword_contains_all] = ACTIONS(190),
    [sym_keyword_contains_any] = ACTIONS(190),
    [sym_keyword_contains_none] = ACTIONS(190),
    [sym_keyword_inside] = ACTIONS(190),
    [sym_keyword_in] = ACTIONS(192),
    [sym_keyword_not_inside] = ACTIONS(190),
    [sym_keyword_all_inside] = ACTIONS(190),
    [sym_keyword_any_inside] = ACTIONS(190),
    [sym_keyword_none_inside] = ACTIONS(190),
    [sym_keyword_outside] = ACTIONS(190),
    [sym_keyword_intersects] = ACTIONS(190),
    [sym_keyword_flexible] = ACTIONS(190),
    [sym_keyword_readonly] = ACTIONS(190),
    [sym_keyword_content] = ACTIONS(190),
    [sym_keyword_merge] = ACTIONS(190),
    [sym_keyword_patch] = ACTIONS(190),
    [sym_keyword_type] = ACTIONS(190),
    [sym_keyword_default] = ACTIONS(190),
    [sym_keyword_assert] = ACTIONS(190),
    [sym_keyword_permissions] = ACTIONS(190),
    [sym_keyword_for] = ACTIONS(190),
    [sym_keyword_comment] = ACTIONS(190),
    [sym_keyword_set] = ACTIONS(190),
    [sym_keyword_unset] = ACTIONS(190),
    [anon_sym_COMMA] = ACTIONS(190),
    [anon_sym_DASH_GT] = ACTIONS(190),
    [anon_sym_LBRACK] = ACTIONS(190),
    [anon_sym_LT_DASH] = ACTIONS(192),
    [anon_sym_LT_DASH_GT] = ACTIONS(190),
    [anon_sym_STAR] = ACTIONS(192),
    [anon_sym_DOT] = ACTIONS(190),
    [anon_sym_LT] = ACTIONS(192),
    [anon_sym_GT] = ACTIONS(192),
    [anon_sym_EQ] = ACTIONS(192),
    [anon_sym_DASH] = ACTIONS(192),
    [anon_sym_AT] = ACTIONS(192),
    [anon_sym_LT_PIPE] = ACTIONS(190),
    [anon_sym_AMP_AMP] = ACTIONS(190),
    [anon_sym_PIPE_PIPE] = ACTIONS(190),
    [anon_sym_QMARK_QMARK] = ACTIONS(190),
    [anon_sym_QMARK_COLON] = ACTIONS(190),
    [anon_sym_BANG_EQ] = ACTIONS(190),
    [anon_sym_EQ_EQ] = ACTIONS(190),
    [anon_sym_QMARK_EQ] = ACTIONS(190),
    [anon_sym_STAR_EQ] = ACTIONS(190),
    [anon_sym_TILDE] = ACTIONS(190),
    [anon_sym_BANG_TILDE] = ACTIONS(190),
    [anon_sym_STAR_TILDE] = ACTIONS(190),
    [anon_sym_LT_EQ] = ACTIONS(190),
    [anon_sym_GT_EQ] = ACTIONS(190),
    [anon_sym_PLUS] = ACTIONS(192),
    [anon_sym_PLUS_EQ] = ACTIONS(190),
    [anon_sym_DASH_EQ] = ACTIONS(190),
    [anon_sym_u00d7] = ACTIONS(190),
    [anon_sym_SLASH] = ACTIONS(192),
    [anon_sym_u00f7] = ACTIONS(190),
    [anon_sym_STAR_STAR] = ACTIONS(190),
    [anon_sym_u220b] = ACTIONS(190),
    [anon_sym_u220c] = ACTIONS(190),
    [anon_sym_u2287] = ACTIONS(190),
    [anon_sym_u2283] = ACTIONS(190),
    [anon_sym_u2285] = ACTIONS(190),
    [anon_sym_u2208] = ACTIONS(190),
    [anon_sym_u2209] = ACTIONS(190),
    [anon_sym_u2286] = ACTIONS(190),
    [anon_sym_u2282] = ACTIONS(190),
    [anon_sym_u2284] = ACTIONS(190),
    [anon_sym_AT_AT] = ACTIONS(190),
  },
  [55] = {
    [ts_builtin_sym_end] = ACTIONS(174),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(174),
    [sym_keyword_return] = ACTIONS(174),
    [sym_keyword_value] = ACTIONS(174),
    [sym_keyword_explain] = ACTIONS(174),
    [sym_keyword_parallel] = ACTIONS(174),
    [sym_keyword_timeout] = ACTIONS(174),
    [sym_keyword_fetch] = ACTIONS(174),
    [sym_keyword_limit] = ACTIONS(174),
    [sym_keyword_rand] = ACTIONS(174),
    [sym_keyword_collate] = ACTIONS(174),
    [sym_keyword_numeric] = ACTIONS(174),
    [sym_keyword_asc] = ACTIONS(174),
    [sym_keyword_desc] = ACTIONS(174),
    [sym_keyword_where] = ACTIONS(174),
    [sym_keyword_and] = ACTIONS(174),
    [sym_keyword_or] = ACTIONS(174),
    [sym_keyword_is] = ACTIONS(174),
    [sym_keyword_not] = ACTIONS(176),
    [sym_keyword_contains] = ACTIONS(174),
    [sym_keyword_contains_not] = ACTIONS(174),
    [sym_keyword_contains_all] = ACTIONS(174),
    [sym_keyword_contains_any] = ACTIONS(174),
    [sym_keyword_contains_none] = ACTIONS(174),
    [sym_keyword_inside] = ACTIONS(174),
    [sym_keyword_in] = ACTIONS(176),
    [sym_keyword_not_inside] = ACTIONS(174),
    [sym_keyword_all_inside] = ACTIONS(174),
    [sym_keyword_any_inside] = ACTIONS(174),
    [sym_keyword_none_inside] = ACTIONS(174),
    [sym_keyword_outside] = ACTIONS(174),
    [sym_keyword_intersects] = ACTIONS(174),
    [sym_keyword_flexible] = ACTIONS(174),
    [sym_keyword_readonly] = ACTIONS(174),
    [sym_keyword_content] = ACTIONS(174),
    [sym_keyword_merge] = ACTIONS(174),
    [sym_keyword_patch] = ACTIONS(174),
    [sym_keyword_type] = ACTIONS(174),
    [sym_keyword_default] = ACTIONS(174),
    [sym_keyword_assert] = ACTIONS(174),
    [sym_keyword_permissions] = ACTIONS(174),
    [sym_keyword_for] = ACTIONS(174),
    [sym_keyword_comment] = ACTIONS(174),
    [sym_keyword_set] = ACTIONS(174),
    [sym_keyword_unset] = ACTIONS(174),
    [anon_sym_COMMA] = ACTIONS(174),
    [anon_sym_DASH_GT] = ACTIONS(174),
    [anon_sym_LBRACK] = ACTIONS(174),
    [anon_sym_LT_DASH] = ACTIONS(176),
    [anon_sym_LT_DASH_GT] = ACTIONS(174),
    [anon_sym_STAR] = ACTIONS(176),
    [anon_sym_DOT] = ACTIONS(174),
    [anon_sym_LT] = ACTIONS(176),
    [anon_sym_GT] = ACTIONS(176),
    [anon_sym_EQ] = ACTIONS(176),
    [anon_sym_DASH] = ACTIONS(176),
    [anon_sym_AT] = ACTIONS(176),
    [anon_sym_LT_PIPE] = ACTIONS(174),
    [anon_sym_AMP_AMP] = ACTIONS(174),
    [anon_sym_PIPE_PIPE] = ACTIONS(174),
    [anon_sym_QMARK_QMARK] = ACTIONS(174),
    [anon_sym_QMARK_COLON] = ACTIONS(174),
    [anon_sym_BANG_EQ] = ACTIONS(174),
    [anon_sym_EQ_EQ] = ACTIONS(174),
    [anon_sym_QMARK_EQ] = ACTIONS(174),
    [anon_sym_STAR_EQ] = ACTIONS(174),
    [anon_sym_TILDE] = ACTIONS(174),
    [anon_sym_BANG_TILDE] = ACTIONS(174),
    [anon_sym_STAR_TILDE] = ACTIONS(174),
    [anon_sym_LT_EQ] = ACTIONS(174),
    [anon_sym_GT_EQ] = ACTIONS(174),
    [anon_sym_PLUS] = ACTIONS(176),
    [anon_sym_PLUS_EQ] = ACTIONS(174),
    [anon_sym_DASH_EQ] = ACTIONS(174),
    [anon_sym_u00d7] = ACTIONS(174),
    [anon_sym_SLASH] = ACTIONS(176),
    [anon_sym_u00f7] = ACTIONS(174),
    [anon_sym_STAR_STAR] = ACTIONS(174),
    [anon_sym_u220b] = ACTIONS(174),
    [anon_sym_u220c] = ACTIONS(174),
    [anon_sym_u2287] = ACTIONS(174),
    [anon_sym_u2283] = ACTIONS(174),
    [anon_sym_u2285] = ACTIONS(174),
    [anon_sym_u2208] = ACTIONS(174),
    [anon_sym_u2209] = ACTIONS(174),
    [anon_sym_u2286] = ACTIONS(174),
    [anon_sym_u2282] = ACTIONS(174),
    [anon_sym_u2284] = ACTIONS(174),
    [anon_sym_AT_AT] = ACTIONS(174),
  },
  [56] = {
    [ts_builtin_sym_end] = ACTIONS(186),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(186),
    [sym_keyword_return] = ACTIONS(186),
    [sym_keyword_value] = ACTIONS(186),
    [sym_keyword_explain] = ACTIONS(186),
    [sym_keyword_parallel] = ACTIONS(186),
    [sym_keyword_timeout] = ACTIONS(186),
    [sym_keyword_fetch] = ACTIONS(186),
    [sym_keyword_limit] = ACTIONS(186),
    [sym_keyword_rand] = ACTIONS(186),
    [sym_keyword_collate] = ACTIONS(186),
    [sym_keyword_numeric] = ACTIONS(186),
    [sym_keyword_asc] = ACTIONS(186),
    [sym_keyword_desc] = ACTIONS(186),
    [sym_keyword_where] = ACTIONS(186),
    [sym_keyword_and] = ACTIONS(186),
    [sym_keyword_or] = ACTIONS(186),
    [sym_keyword_is] = ACTIONS(186),
    [sym_keyword_not] = ACTIONS(188),
    [sym_keyword_contains] = ACTIONS(186),
    [sym_keyword_contains_not] = ACTIONS(186),
    [sym_keyword_contains_all] = ACTIONS(186),
    [sym_keyword_contains_any] = ACTIONS(186),
    [sym_keyword_contains_none] = ACTIONS(186),
    [sym_keyword_inside] = ACTIONS(186),
    [sym_keyword_in] = ACTIONS(188),
    [sym_keyword_not_inside] = ACTIONS(186),
    [sym_keyword_all_inside] = ACTIONS(186),
    [sym_keyword_any_inside] = ACTIONS(186),
    [sym_keyword_none_inside] = ACTIONS(186),
    [sym_keyword_outside] = ACTIONS(186),
    [sym_keyword_intersects] = ACTIONS(186),
    [sym_keyword_flexible] = ACTIONS(186),
    [sym_keyword_readonly] = ACTIONS(186),
    [sym_keyword_content] = ACTIONS(186),
    [sym_keyword_merge] = ACTIONS(186),
    [sym_keyword_patch] = ACTIONS(186),
    [sym_keyword_type] = ACTIONS(186),
    [sym_keyword_default] = ACTIONS(186),
    [sym_keyword_assert] = ACTIONS(186),
    [sym_keyword_permissions] = ACTIONS(186),
    [sym_keyword_for] = ACTIONS(186),
    [sym_keyword_comment] = ACTIONS(186),
    [sym_keyword_set] = ACTIONS(186),
    [sym_keyword_unset] = ACTIONS(186),
    [anon_sym_COMMA] = ACTIONS(186),
    [anon_sym_DASH_GT] = ACTIONS(186),
    [anon_sym_LBRACK] = ACTIONS(186),
    [anon_sym_LT_DASH] = ACTIONS(188),
    [anon_sym_LT_DASH_GT] = ACTIONS(186),
    [anon_sym_STAR] = ACTIONS(188),
    [anon_sym_DOT] = ACTIONS(186),
    [anon_sym_LT] = ACTIONS(188),
    [anon_sym_GT] = ACTIONS(188),
    [anon_sym_EQ] = ACTIONS(188),
    [anon_sym_DASH] = ACTIONS(188),
    [anon_sym_AT] = ACTIONS(188),
    [anon_sym_LT_PIPE] = ACTIONS(186),
    [anon_sym_AMP_AMP] = ACTIONS(186),
    [anon_sym_PIPE_PIPE] = ACTIONS(186),
    [anon_sym_QMARK_QMARK] = ACTIONS(186),
    [anon_sym_QMARK_COLON] = ACTIONS(186),
    [anon_sym_BANG_EQ] = ACTIONS(186),
    [anon_sym_EQ_EQ] = ACTIONS(186),
    [anon_sym_QMARK_EQ] = ACTIONS(186),
    [anon_sym_STAR_EQ] = ACTIONS(186),
    [anon_sym_TILDE] = ACTIONS(186),
    [anon_sym_BANG_TILDE] = ACTIONS(186),
    [anon_sym_STAR_TILDE] = ACTIONS(186),
    [anon_sym_LT_EQ] = ACTIONS(186),
    [anon_sym_GT_EQ] = ACTIONS(186),
    [anon_sym_PLUS] = ACTIONS(188),
    [anon_sym_PLUS_EQ] = ACTIONS(186),
    [anon_sym_DASH_EQ] = ACTIONS(186),
    [anon_sym_u00d7] = ACTIONS(186),
    [anon_sym_SLASH] = ACTIONS(188),
    [anon_sym_u00f7] = ACTIONS(186),
    [anon_sym_STAR_STAR] = ACTIONS(186),
    [anon_sym_u220b] = ACTIONS(186),
    [anon_sym_u220c] = ACTIONS(186),
    [anon_sym_u2287] = ACTIONS(186),
    [anon_sym_u2283] = ACTIONS(186),
    [anon_sym_u2285] = ACTIONS(186),
    [anon_sym_u2208] = ACTIONS(186),
    [anon_sym_u2209] = ACTIONS(186),
    [anon_sym_u2286] = ACTIONS(186),
    [anon_sym_u2282] = ACTIONS(186),
    [anon_sym_u2284] = ACTIONS(186),
    [anon_sym_AT_AT] = ACTIONS(186),
  },
  [57] = {
    [ts_builtin_sym_end] = ACTIONS(166),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(166),
    [sym_keyword_return] = ACTIONS(166),
    [sym_keyword_value] = ACTIONS(166),
    [sym_keyword_explain] = ACTIONS(166),
    [sym_keyword_parallel] = ACTIONS(166),
    [sym_keyword_timeout] = ACTIONS(166),
    [sym_keyword_fetch] = ACTIONS(166),
    [sym_keyword_limit] = ACTIONS(166),
    [sym_keyword_rand] = ACTIONS(166),
    [sym_keyword_collate] = ACTIONS(166),
    [sym_keyword_numeric] = ACTIONS(166),
    [sym_keyword_asc] = ACTIONS(166),
    [sym_keyword_desc] = ACTIONS(166),
    [sym_keyword_where] = ACTIONS(166),
    [sym_keyword_and] = ACTIONS(166),
    [sym_keyword_or] = ACTIONS(166),
    [sym_keyword_is] = ACTIONS(166),
    [sym_keyword_not] = ACTIONS(168),
    [sym_keyword_contains] = ACTIONS(166),
    [sym_keyword_contains_not] = ACTIONS(166),
    [sym_keyword_contains_all] = ACTIONS(166),
    [sym_keyword_contains_any] = ACTIONS(166),
    [sym_keyword_contains_none] = ACTIONS(166),
    [sym_keyword_inside] = ACTIONS(166),
    [sym_keyword_in] = ACTIONS(168),
    [sym_keyword_not_inside] = ACTIONS(166),
    [sym_keyword_all_inside] = ACTIONS(166),
    [sym_keyword_any_inside] = ACTIONS(166),
    [sym_keyword_none_inside] = ACTIONS(166),
    [sym_keyword_outside] = ACTIONS(166),
    [sym_keyword_intersects] = ACTIONS(166),
    [sym_keyword_flexible] = ACTIONS(166),
    [sym_keyword_readonly] = ACTIONS(166),
    [sym_keyword_content] = ACTIONS(166),
    [sym_keyword_merge] = ACTIONS(166),
    [sym_keyword_patch] = ACTIONS(166),
    [sym_keyword_type] = ACTIONS(166),
    [sym_keyword_default] = ACTIONS(166),
    [sym_keyword_assert] = ACTIONS(166),
    [sym_keyword_permissions] = ACTIONS(166),
    [sym_keyword_for] = ACTIONS(166),
    [sym_keyword_comment] = ACTIONS(166),
    [sym_keyword_set] = ACTIONS(166),
    [sym_keyword_unset] = ACTIONS(166),
    [anon_sym_COMMA] = ACTIONS(166),
    [anon_sym_DASH_GT] = ACTIONS(166),
    [anon_sym_LBRACK] = ACTIONS(166),
    [anon_sym_LT_DASH] = ACTIONS(168),
    [anon_sym_LT_DASH_GT] = ACTIONS(166),
    [anon_sym_STAR] = ACTIONS(168),
    [anon_sym_DOT] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [anon_sym_GT] = ACTIONS(168),
    [anon_sym_EQ] = ACTIONS(168),
    [anon_sym_DASH] = ACTIONS(168),
    [anon_sym_AT] = ACTIONS(168),
    [anon_sym_LT_PIPE] = ACTIONS(166),
    [anon_sym_AMP_AMP] = ACTIONS(166),
    [anon_sym_PIPE_PIPE] = ACTIONS(166),
    [anon_sym_QMARK_QMARK] = ACTIONS(166),
    [anon_sym_QMARK_COLON] = ACTIONS(166),
    [anon_sym_BANG_EQ] = ACTIONS(166),
    [anon_sym_EQ_EQ] = ACTIONS(166),
    [anon_sym_QMARK_EQ] = ACTIONS(166),
    [anon_sym_STAR_EQ] = ACTIONS(166),
    [anon_sym_TILDE] = ACTIONS(166),
    [anon_sym_BANG_TILDE] = ACTIONS(166),
    [anon_sym_STAR_TILDE] = ACTIONS(166),
    [anon_sym_LT_EQ] = ACTIONS(166),
    [anon_sym_GT_EQ] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(168),
    [anon_sym_PLUS_EQ] = ACTIONS(166),
    [anon_sym_DASH_EQ] = ACTIONS(166),
    [anon_sym_u00d7] = ACTIONS(166),
    [anon_sym_SLASH] = ACTIONS(168),
    [anon_sym_u00f7] = ACTIONS(166),
    [anon_sym_STAR_STAR] = ACTIONS(166),
    [anon_sym_u220b] = ACTIONS(166),
    [anon_sym_u220c] = ACTIONS(166),
    [anon_sym_u2287] = ACTIONS(166),
    [anon_sym_u2283] = ACTIONS(166),
    [anon_sym_u2285] = ACTIONS(166),
    [anon_sym_u2208] = ACTIONS(166),
    [anon_sym_u2209] = ACTIONS(166),
    [anon_sym_u2286] = ACTIONS(166),
    [anon_sym_u2282] = ACTIONS(166),
    [anon_sym_u2284] = ACTIONS(166),
    [anon_sym_AT_AT] = ACTIONS(166),
  },
  [58] = {
    [ts_builtin_sym_end] = ACTIONS(154),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(154),
    [sym_keyword_return] = ACTIONS(154),
    [sym_keyword_value] = ACTIONS(154),
    [sym_keyword_explain] = ACTIONS(154),
    [sym_keyword_parallel] = ACTIONS(154),
    [sym_keyword_timeout] = ACTIONS(154),
    [sym_keyword_fetch] = ACTIONS(154),
    [sym_keyword_limit] = ACTIONS(154),
    [sym_keyword_rand] = ACTIONS(154),
    [sym_keyword_collate] = ACTIONS(154),
    [sym_keyword_numeric] = ACTIONS(154),
    [sym_keyword_asc] = ACTIONS(154),
    [sym_keyword_desc] = ACTIONS(154),
    [sym_keyword_where] = ACTIONS(154),
    [sym_keyword_and] = ACTIONS(154),
    [sym_keyword_or] = ACTIONS(154),
    [sym_keyword_is] = ACTIONS(154),
    [sym_keyword_not] = ACTIONS(156),
    [sym_keyword_contains] = ACTIONS(154),
    [sym_keyword_contains_not] = ACTIONS(154),
    [sym_keyword_contains_all] = ACTIONS(154),
    [sym_keyword_contains_any] = ACTIONS(154),
    [sym_keyword_contains_none] = ACTIONS(154),
    [sym_keyword_inside] = ACTIONS(154),
    [sym_keyword_in] = ACTIONS(156),
    [sym_keyword_not_inside] = ACTIONS(154),
    [sym_keyword_all_inside] = ACTIONS(154),
    [sym_keyword_any_inside] = ACTIONS(154),
    [sym_keyword_none_inside] = ACTIONS(154),
    [sym_keyword_outside] = ACTIONS(154),
    [sym_keyword_intersects] = ACTIONS(154),
    [sym_keyword_flexible] = ACTIONS(154),
    [sym_keyword_readonly] = ACTIONS(154),
    [sym_keyword_content] = ACTIONS(154),
    [sym_keyword_merge] = ACTIONS(154),
    [sym_keyword_patch] = ACTIONS(154),
    [sym_keyword_type] = ACTIONS(154),
    [sym_keyword_default] = ACTIONS(154),
    [sym_keyword_assert] = ACTIONS(154),
    [sym_keyword_permissions] = ACTIONS(154),
    [sym_keyword_for] = ACTIONS(154),
    [sym_keyword_comment] = ACTIONS(154),
    [sym_keyword_set] = ACTIONS(154),
    [sym_keyword_unset] = ACTIONS(154),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_DASH_GT] = ACTIONS(154),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_LT_DASH] = ACTIONS(156),
    [anon_sym_LT_DASH_GT] = ACTIONS(154),
    [anon_sym_STAR] = ACTIONS(156),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_LT] = ACTIONS(156),
    [anon_sym_GT] = ACTIONS(156),
    [anon_sym_EQ] = ACTIONS(156),
    [anon_sym_DASH] = ACTIONS(156),
    [anon_sym_AT] = ACTIONS(156),
    [anon_sym_LT_PIPE] = ACTIONS(154),
    [anon_sym_AMP_AMP] = ACTIONS(154),
    [anon_sym_PIPE_PIPE] = ACTIONS(154),
    [anon_sym_QMARK_QMARK] = ACTIONS(154),
    [anon_sym_QMARK_COLON] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(154),
    [anon_sym_QMARK_EQ] = ACTIONS(154),
    [anon_sym_STAR_EQ] = ACTIONS(154),
    [anon_sym_TILDE] = ACTIONS(154),
    [anon_sym_BANG_TILDE] = ACTIONS(154),
    [anon_sym_STAR_TILDE] = ACTIONS(154),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_PLUS] = ACTIONS(156),
    [anon_sym_PLUS_EQ] = ACTIONS(154),
    [anon_sym_DASH_EQ] = ACTIONS(154),
    [anon_sym_u00d7] = ACTIONS(154),
    [anon_sym_SLASH] = ACTIONS(156),
    [anon_sym_u00f7] = ACTIONS(154),
    [anon_sym_STAR_STAR] = ACTIONS(154),
    [anon_sym_u220b] = ACTIONS(154),
    [anon_sym_u220c] = ACTIONS(154),
    [anon_sym_u2287] = ACTIONS(154),
    [anon_sym_u2283] = ACTIONS(154),
    [anon_sym_u2285] = ACTIONS(154),
    [anon_sym_u2208] = ACTIONS(154),
    [anon_sym_u2209] = ACTIONS(154),
    [anon_sym_u2286] = ACTIONS(154),
    [anon_sym_u2282] = ACTIONS(154),
    [anon_sym_u2284] = ACTIONS(154),
    [anon_sym_AT_AT] = ACTIONS(154),
  },
  [59] = {
    [ts_builtin_sym_end] = ACTIONS(150),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(150),
    [sym_keyword_return] = ACTIONS(150),
    [sym_keyword_value] = ACTIONS(150),
    [sym_keyword_explain] = ACTIONS(150),
    [sym_keyword_parallel] = ACTIONS(150),
    [sym_keyword_timeout] = ACTIONS(150),
    [sym_keyword_fetch] = ACTIONS(150),
    [sym_keyword_limit] = ACTIONS(150),
    [sym_keyword_rand] = ACTIONS(150),
    [sym_keyword_collate] = ACTIONS(150),
    [sym_keyword_numeric] = ACTIONS(150),
    [sym_keyword_asc] = ACTIONS(150),
    [sym_keyword_desc] = ACTIONS(150),
    [sym_keyword_where] = ACTIONS(150),
    [sym_keyword_and] = ACTIONS(150),
    [sym_keyword_or] = ACTIONS(150),
    [sym_keyword_is] = ACTIONS(150),
    [sym_keyword_not] = ACTIONS(152),
    [sym_keyword_contains] = ACTIONS(150),
    [sym_keyword_contains_not] = ACTIONS(150),
    [sym_keyword_contains_all] = ACTIONS(150),
    [sym_keyword_contains_any] = ACTIONS(150),
    [sym_keyword_contains_none] = ACTIONS(150),
    [sym_keyword_inside] = ACTIONS(150),
    [sym_keyword_in] = ACTIONS(152),
    [sym_keyword_not_inside] = ACTIONS(150),
    [sym_keyword_all_inside] = ACTIONS(150),
    [sym_keyword_any_inside] = ACTIONS(150),
    [sym_keyword_none_inside] = ACTIONS(150),
    [sym_keyword_outside] = ACTIONS(150),
    [sym_keyword_intersects] = ACTIONS(150),
    [sym_keyword_flexible] = ACTIONS(150),
    [sym_keyword_readonly] = ACTIONS(150),
    [sym_keyword_content] = ACTIONS(150),
    [sym_keyword_merge] = ACTIONS(150),
    [sym_keyword_patch] = ACTIONS(150),
    [sym_keyword_type] = ACTIONS(150),
    [sym_keyword_default] = ACTIONS(150),
    [sym_keyword_assert] = ACTIONS(150),
    [sym_keyword_permissions] = ACTIONS(150),
    [sym_keyword_for] = ACTIONS(150),
    [sym_keyword_comment] = ACTIONS(150),
    [sym_keyword_set] = ACTIONS(150),
    [sym_keyword_unset] = ACTIONS(150),
    [anon_sym_COMMA] = ACTIONS(150),
    [anon_sym_DASH_GT] = ACTIONS(150),
    [anon_sym_LBRACK] = ACTIONS(150),
    [anon_sym_LT_DASH] = ACTIONS(152),
    [anon_sym_LT_DASH_GT] = ACTIONS(150),
    [anon_sym_STAR] = ACTIONS(152),
    [anon_sym_DOT] = ACTIONS(150),
    [anon_sym_LT] = ACTIONS(152),
    [anon_sym_GT] = ACTIONS(152),
    [anon_sym_EQ] = ACTIONS(152),
    [anon_sym_DASH] = ACTIONS(152),
    [anon_sym_AT] = ACTIONS(152),
    [anon_sym_LT_PIPE] = ACTIONS(150),
    [anon_sym_AMP_AMP] = ACTIONS(150),
    [anon_sym_PIPE_PIPE] = ACTIONS(150),
    [anon_sym_QMARK_QMARK] = ACTIONS(150),
    [anon_sym_QMARK_COLON] = ACTIONS(150),
    [anon_sym_BANG_EQ] = ACTIONS(150),
    [anon_sym_EQ_EQ] = ACTIONS(150),
    [anon_sym_QMARK_EQ] = ACTIONS(150),
    [anon_sym_STAR_EQ] = ACTIONS(150),
    [anon_sym_TILDE] = ACTIONS(150),
    [anon_sym_BANG_TILDE] = ACTIONS(150),
    [anon_sym_STAR_TILDE] = ACTIONS(150),
    [anon_sym_LT_EQ] = ACTIONS(150),
    [anon_sym_GT_EQ] = ACTIONS(150),
    [anon_sym_PLUS] = ACTIONS(152),
    [anon_sym_PLUS_EQ] = ACTIONS(150),
    [anon_sym_DASH_EQ] = ACTIONS(150),
    [anon_sym_u00d7] = ACTIONS(150),
    [anon_sym_SLASH] = ACTIONS(152),
    [anon_sym_u00f7] = ACTIONS(150),
    [anon_sym_STAR_STAR] = ACTIONS(150),
    [anon_sym_u220b] = ACTIONS(150),
    [anon_sym_u220c] = ACTIONS(150),
    [anon_sym_u2287] = ACTIONS(150),
    [anon_sym_u2283] = ACTIONS(150),
    [anon_sym_u2285] = ACTIONS(150),
    [anon_sym_u2208] = ACTIONS(150),
    [anon_sym_u2209] = ACTIONS(150),
    [anon_sym_u2286] = ACTIONS(150),
    [anon_sym_u2282] = ACTIONS(150),
    [anon_sym_u2284] = ACTIONS(150),
    [anon_sym_AT_AT] = ACTIONS(150),
  },
  [60] = {
    [ts_builtin_sym_end] = ACTIONS(206),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(206),
    [sym_keyword_return] = ACTIONS(206),
    [sym_keyword_value] = ACTIONS(206),
    [sym_keyword_explain] = ACTIONS(206),
    [sym_keyword_parallel] = ACTIONS(206),
    [sym_keyword_timeout] = ACTIONS(206),
    [sym_keyword_fetch] = ACTIONS(206),
    [sym_keyword_limit] = ACTIONS(206),
    [sym_keyword_rand] = ACTIONS(206),
    [sym_keyword_collate] = ACTIONS(206),
    [sym_keyword_numeric] = ACTIONS(206),
    [sym_keyword_asc] = ACTIONS(206),
    [sym_keyword_desc] = ACTIONS(206),
    [sym_keyword_where] = ACTIONS(206),
    [sym_keyword_and] = ACTIONS(206),
    [sym_keyword_or] = ACTIONS(206),
    [sym_keyword_is] = ACTIONS(206),
    [sym_keyword_not] = ACTIONS(208),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(206),
    [sym_keyword_contains_all] = ACTIONS(206),
    [sym_keyword_contains_any] = ACTIONS(206),
    [sym_keyword_contains_none] = ACTIONS(206),
    [sym_keyword_inside] = ACTIONS(206),
    [sym_keyword_in] = ACTIONS(208),
    [sym_keyword_not_inside] = ACTIONS(206),
    [sym_keyword_all_inside] = ACTIONS(206),
    [sym_keyword_any_inside] = ACTIONS(206),
    [sym_keyword_none_inside] = ACTIONS(206),
    [sym_keyword_outside] = ACTIONS(206),
    [sym_keyword_intersects] = ACTIONS(206),
    [sym_keyword_flexible] = ACTIONS(206),
    [sym_keyword_readonly] = ACTIONS(206),
    [sym_keyword_content] = ACTIONS(206),
    [sym_keyword_merge] = ACTIONS(206),
    [sym_keyword_patch] = ACTIONS(206),
    [sym_keyword_type] = ACTIONS(206),
    [sym_keyword_default] = ACTIONS(206),
    [sym_keyword_assert] = ACTIONS(206),
    [sym_keyword_permissions] = ACTIONS(206),
    [sym_keyword_for] = ACTIONS(206),
    [sym_keyword_comment] = ACTIONS(206),
    [sym_keyword_set] = ACTIONS(206),
    [sym_keyword_unset] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(206),
    [anon_sym_DASH_GT] = ACTIONS(206),
    [anon_sym_LBRACK] = ACTIONS(206),
    [anon_sym_LT_DASH] = ACTIONS(208),
    [anon_sym_LT_DASH_GT] = ACTIONS(206),
    [anon_sym_STAR] = ACTIONS(208),
    [anon_sym_DOT] = ACTIONS(206),
    [anon_sym_LT] = ACTIONS(208),
    [anon_sym_GT] = ACTIONS(208),
    [anon_sym_EQ] = ACTIONS(208),
    [anon_sym_DASH] = ACTIONS(208),
    [anon_sym_AT] = ACTIONS(208),
    [anon_sym_LT_PIPE] = ACTIONS(206),
    [anon_sym_AMP_AMP] = ACTIONS(206),
    [anon_sym_PIPE_PIPE] = ACTIONS(206),
    [anon_sym_QMARK_QMARK] = ACTIONS(206),
    [anon_sym_QMARK_COLON] = ACTIONS(206),
    [anon_sym_BANG_EQ] = ACTIONS(206),
    [anon_sym_EQ_EQ] = ACTIONS(206),
    [anon_sym_QMARK_EQ] = ACTIONS(206),
    [anon_sym_STAR_EQ] = ACTIONS(206),
    [anon_sym_TILDE] = ACTIONS(206),
    [anon_sym_BANG_TILDE] = ACTIONS(206),
    [anon_sym_STAR_TILDE] = ACTIONS(206),
    [anon_sym_LT_EQ] = ACTIONS(206),
    [anon_sym_GT_EQ] = ACTIONS(206),
    [anon_sym_PLUS] = ACTIONS(208),
    [anon_sym_PLUS_EQ] = ACTIONS(206),
    [anon_sym_DASH_EQ] = ACTIONS(206),
    [anon_sym_u00d7] = ACTIONS(206),
    [anon_sym_SLASH] = ACTIONS(208),
    [anon_sym_u00f7] = ACTIONS(206),
    [anon_sym_STAR_STAR] = ACTIONS(206),
    [anon_sym_u220b] = ACTIONS(206),
    [anon_sym_u220c] = ACTIONS(206),
    [anon_sym_u2287] = ACTIONS(206),
    [anon_sym_u2283] = ACTIONS(206),
    [anon_sym_u2285] = ACTIONS(206),
    [anon_sym_u2208] = ACTIONS(206),
    [anon_sym_u2209] = ACTIONS(206),
    [anon_sym_u2286] = ACTIONS(206),
    [anon_sym_u2282] = ACTIONS(206),
    [anon_sym_u2284] = ACTIONS(206),
    [anon_sym_AT_AT] = ACTIONS(206),
  },
  [61] = {
    [ts_builtin_sym_end] = ACTIONS(198),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(198),
    [sym_keyword_return] = ACTIONS(198),
    [sym_keyword_value] = ACTIONS(198),
    [sym_keyword_explain] = ACTIONS(198),
    [sym_keyword_parallel] = ACTIONS(198),
    [sym_keyword_timeout] = ACTIONS(198),
    [sym_keyword_fetch] = ACTIONS(198),
    [sym_keyword_limit] = ACTIONS(198),
    [sym_keyword_rand] = ACTIONS(198),
    [sym_keyword_collate] = ACTIONS(198),
    [sym_keyword_numeric] = ACTIONS(198),
    [sym_keyword_asc] = ACTIONS(198),
    [sym_keyword_desc] = ACTIONS(198),
    [sym_keyword_where] = ACTIONS(198),
    [sym_keyword_and] = ACTIONS(198),
    [sym_keyword_or] = ACTIONS(198),
    [sym_keyword_is] = ACTIONS(198),
    [sym_keyword_not] = ACTIONS(200),
    [sym_keyword_contains] = ACTIONS(198),
    [sym_keyword_contains_not] = ACTIONS(198),
    [sym_keyword_contains_all] = ACTIONS(198),
    [sym_keyword_contains_any] = ACTIONS(198),
    [sym_keyword_contains_none] = ACTIONS(198),
    [sym_keyword_inside] = ACTIONS(198),
    [sym_keyword_in] = ACTIONS(200),
    [sym_keyword_not_inside] = ACTIONS(198),
    [sym_keyword_all_inside] = ACTIONS(198),
    [sym_keyword_any_inside] = ACTIONS(198),
    [sym_keyword_none_inside] = ACTIONS(198),
    [sym_keyword_outside] = ACTIONS(198),
    [sym_keyword_intersects] = ACTIONS(198),
    [sym_keyword_flexible] = ACTIONS(198),
    [sym_keyword_readonly] = ACTIONS(198),
    [sym_keyword_content] = ACTIONS(198),
    [sym_keyword_merge] = ACTIONS(198),
    [sym_keyword_patch] = ACTIONS(198),
    [sym_keyword_type] = ACTIONS(198),
    [sym_keyword_default] = ACTIONS(198),
    [sym_keyword_assert] = ACTIONS(198),
    [sym_keyword_permissions] = ACTIONS(198),
    [sym_keyword_for] = ACTIONS(198),
    [sym_keyword_comment] = ACTIONS(198),
    [sym_keyword_set] = ACTIONS(198),
    [sym_keyword_unset] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(198),
    [anon_sym_DASH_GT] = ACTIONS(198),
    [anon_sym_LBRACK] = ACTIONS(198),
    [anon_sym_LT_DASH] = ACTIONS(200),
    [anon_sym_LT_DASH_GT] = ACTIONS(198),
    [anon_sym_STAR] = ACTIONS(200),
    [anon_sym_DOT] = ACTIONS(198),
    [anon_sym_LT] = ACTIONS(200),
    [anon_sym_GT] = ACTIONS(200),
    [anon_sym_EQ] = ACTIONS(200),
    [anon_sym_DASH] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(200),
    [anon_sym_LT_PIPE] = ACTIONS(198),
    [anon_sym_AMP_AMP] = ACTIONS(198),
    [anon_sym_PIPE_PIPE] = ACTIONS(198),
    [anon_sym_QMARK_QMARK] = ACTIONS(198),
    [anon_sym_QMARK_COLON] = ACTIONS(198),
    [anon_sym_BANG_EQ] = ACTIONS(198),
    [anon_sym_EQ_EQ] = ACTIONS(198),
    [anon_sym_QMARK_EQ] = ACTIONS(198),
    [anon_sym_STAR_EQ] = ACTIONS(198),
    [anon_sym_TILDE] = ACTIONS(198),
    [anon_sym_BANG_TILDE] = ACTIONS(198),
    [anon_sym_STAR_TILDE] = ACTIONS(198),
    [anon_sym_LT_EQ] = ACTIONS(198),
    [anon_sym_GT_EQ] = ACTIONS(198),
    [anon_sym_PLUS] = ACTIONS(200),
    [anon_sym_PLUS_EQ] = ACTIONS(198),
    [anon_sym_DASH_EQ] = ACTIONS(198),
    [anon_sym_u00d7] = ACTIONS(198),
    [anon_sym_SLASH] = ACTIONS(200),
    [anon_sym_u00f7] = ACTIONS(198),
    [anon_sym_STAR_STAR] = ACTIONS(198),
    [anon_sym_u220b] = ACTIONS(198),
    [anon_sym_u220c] = ACTIONS(198),
    [anon_sym_u2287] = ACTIONS(198),
    [anon_sym_u2283] = ACTIONS(198),
    [anon_sym_u2285] = ACTIONS(198),
    [anon_sym_u2208] = ACTIONS(198),
    [anon_sym_u2209] = ACTIONS(198),
    [anon_sym_u2286] = ACTIONS(198),
    [anon_sym_u2282] = ACTIONS(198),
    [anon_sym_u2284] = ACTIONS(198),
    [anon_sym_AT_AT] = ACTIONS(198),
  },
  [62] = {
    [ts_builtin_sym_end] = ACTIONS(138),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(138),
    [sym_keyword_return] = ACTIONS(138),
    [sym_keyword_value] = ACTIONS(138),
    [sym_keyword_explain] = ACTIONS(138),
    [sym_keyword_parallel] = ACTIONS(138),
    [sym_keyword_timeout] = ACTIONS(138),
    [sym_keyword_fetch] = ACTIONS(138),
    [sym_keyword_limit] = ACTIONS(138),
    [sym_keyword_rand] = ACTIONS(138),
    [sym_keyword_collate] = ACTIONS(138),
    [sym_keyword_numeric] = ACTIONS(138),
    [sym_keyword_asc] = ACTIONS(138),
    [sym_keyword_desc] = ACTIONS(138),
    [sym_keyword_where] = ACTIONS(138),
    [sym_keyword_and] = ACTIONS(138),
    [sym_keyword_or] = ACTIONS(138),
    [sym_keyword_is] = ACTIONS(138),
    [sym_keyword_not] = ACTIONS(140),
    [sym_keyword_contains] = ACTIONS(138),
    [sym_keyword_contains_not] = ACTIONS(138),
    [sym_keyword_contains_all] = ACTIONS(138),
    [sym_keyword_contains_any] = ACTIONS(138),
    [sym_keyword_contains_none] = ACTIONS(138),
    [sym_keyword_inside] = ACTIONS(138),
    [sym_keyword_in] = ACTIONS(140),
    [sym_keyword_not_inside] = ACTIONS(138),
    [sym_keyword_all_inside] = ACTIONS(138),
    [sym_keyword_any_inside] = ACTIONS(138),
    [sym_keyword_none_inside] = ACTIONS(138),
    [sym_keyword_outside] = ACTIONS(138),
    [sym_keyword_intersects] = ACTIONS(138),
    [sym_keyword_flexible] = ACTIONS(138),
    [sym_keyword_readonly] = ACTIONS(138),
    [sym_keyword_content] = ACTIONS(138),
    [sym_keyword_merge] = ACTIONS(138),
    [sym_keyword_patch] = ACTIONS(138),
    [sym_keyword_type] = ACTIONS(138),
    [sym_keyword_default] = ACTIONS(138),
    [sym_keyword_assert] = ACTIONS(138),
    [sym_keyword_permissions] = ACTIONS(138),
    [sym_keyword_for] = ACTIONS(138),
    [sym_keyword_comment] = ACTIONS(138),
    [sym_keyword_set] = ACTIONS(138),
    [sym_keyword_unset] = ACTIONS(138),
    [anon_sym_COMMA] = ACTIONS(138),
    [anon_sym_DASH_GT] = ACTIONS(138),
    [anon_sym_LBRACK] = ACTIONS(138),
    [anon_sym_LT_DASH] = ACTIONS(140),
    [anon_sym_LT_DASH_GT] = ACTIONS(138),
    [anon_sym_STAR] = ACTIONS(140),
    [anon_sym_DOT] = ACTIONS(138),
    [anon_sym_LT] = ACTIONS(140),
    [anon_sym_GT] = ACTIONS(140),
    [anon_sym_EQ] = ACTIONS(140),
    [anon_sym_DASH] = ACTIONS(140),
    [anon_sym_AT] = ACTIONS(140),
    [anon_sym_LT_PIPE] = ACTIONS(138),
    [anon_sym_AMP_AMP] = ACTIONS(138),
    [anon_sym_PIPE_PIPE] = ACTIONS(138),
    [anon_sym_QMARK_QMARK] = ACTIONS(138),
    [anon_sym_QMARK_COLON] = ACTIONS(138),
    [anon_sym_BANG_EQ] = ACTIONS(138),
    [anon_sym_EQ_EQ] = ACTIONS(138),
    [anon_sym_QMARK_EQ] = ACTIONS(138),
    [anon_sym_STAR_EQ] = ACTIONS(138),
    [anon_sym_TILDE] = ACTIONS(138),
    [anon_sym_BANG_TILDE] = ACTIONS(138),
    [anon_sym_STAR_TILDE] = ACTIONS(138),
    [anon_sym_LT_EQ] = ACTIONS(138),
    [anon_sym_GT_EQ] = ACTIONS(138),
    [anon_sym_PLUS] = ACTIONS(140),
    [anon_sym_PLUS_EQ] = ACTIONS(138),
    [anon_sym_DASH_EQ] = ACTIONS(138),
    [anon_sym_u00d7] = ACTIONS(138),
    [anon_sym_SLASH] = ACTIONS(140),
    [anon_sym_u00f7] = ACTIONS(138),
    [anon_sym_STAR_STAR] = ACTIONS(138),
    [anon_sym_u220b] = ACTIONS(138),
    [anon_sym_u220c] = ACTIONS(138),
    [anon_sym_u2287] = ACTIONS(138),
    [anon_sym_u2283] = ACTIONS(138),
    [anon_sym_u2285] = ACTIONS(138),
    [anon_sym_u2208] = ACTIONS(138),
    [anon_sym_u2209] = ACTIONS(138),
    [anon_sym_u2286] = ACTIONS(138),
    [anon_sym_u2282] = ACTIONS(138),
    [anon_sym_u2284] = ACTIONS(138),
    [anon_sym_AT_AT] = ACTIONS(138),
  },
  [63] = {
    [ts_builtin_sym_end] = ACTIONS(202),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(202),
    [sym_keyword_return] = ACTIONS(202),
    [sym_keyword_value] = ACTIONS(202),
    [sym_keyword_explain] = ACTIONS(202),
    [sym_keyword_parallel] = ACTIONS(202),
    [sym_keyword_timeout] = ACTIONS(202),
    [sym_keyword_fetch] = ACTIONS(202),
    [sym_keyword_limit] = ACTIONS(202),
    [sym_keyword_rand] = ACTIONS(202),
    [sym_keyword_collate] = ACTIONS(202),
    [sym_keyword_numeric] = ACTIONS(202),
    [sym_keyword_asc] = ACTIONS(202),
    [sym_keyword_desc] = ACTIONS(202),
    [sym_keyword_where] = ACTIONS(202),
    [sym_keyword_and] = ACTIONS(202),
    [sym_keyword_or] = ACTIONS(202),
    [sym_keyword_is] = ACTIONS(202),
    [sym_keyword_not] = ACTIONS(204),
    [sym_keyword_contains] = ACTIONS(202),
    [sym_keyword_contains_not] = ACTIONS(202),
    [sym_keyword_contains_all] = ACTIONS(202),
    [sym_keyword_contains_any] = ACTIONS(202),
    [sym_keyword_contains_none] = ACTIONS(202),
    [sym_keyword_inside] = ACTIONS(202),
    [sym_keyword_in] = ACTIONS(204),
    [sym_keyword_not_inside] = ACTIONS(202),
    [sym_keyword_all_inside] = ACTIONS(202),
    [sym_keyword_any_inside] = ACTIONS(202),
    [sym_keyword_none_inside] = ACTIONS(202),
    [sym_keyword_outside] = ACTIONS(202),
    [sym_keyword_intersects] = ACTIONS(202),
    [sym_keyword_flexible] = ACTIONS(202),
    [sym_keyword_readonly] = ACTIONS(202),
    [sym_keyword_content] = ACTIONS(202),
    [sym_keyword_merge] = ACTIONS(202),
    [sym_keyword_patch] = ACTIONS(202),
    [sym_keyword_type] = ACTIONS(202),
    [sym_keyword_default] = ACTIONS(202),
    [sym_keyword_assert] = ACTIONS(202),
    [sym_keyword_permissions] = ACTIONS(202),
    [sym_keyword_for] = ACTIONS(202),
    [sym_keyword_comment] = ACTIONS(202),
    [sym_keyword_set] = ACTIONS(202),
    [sym_keyword_unset] = ACTIONS(202),
    [anon_sym_COMMA] = ACTIONS(202),
    [anon_sym_DASH_GT] = ACTIONS(202),
    [anon_sym_LBRACK] = ACTIONS(202),
    [anon_sym_LT_DASH] = ACTIONS(204),
    [anon_sym_LT_DASH_GT] = ACTIONS(202),
    [anon_sym_STAR] = ACTIONS(204),
    [anon_sym_DOT] = ACTIONS(202),
    [anon_sym_LT] = ACTIONS(204),
    [anon_sym_GT] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(204),
    [anon_sym_DASH] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(204),
    [anon_sym_LT_PIPE] = ACTIONS(202),
    [anon_sym_AMP_AMP] = ACTIONS(202),
    [anon_sym_PIPE_PIPE] = ACTIONS(202),
    [anon_sym_QMARK_QMARK] = ACTIONS(202),
    [anon_sym_QMARK_COLON] = ACTIONS(202),
    [anon_sym_BANG_EQ] = ACTIONS(202),
    [anon_sym_EQ_EQ] = ACTIONS(202),
    [anon_sym_QMARK_EQ] = ACTIONS(202),
    [anon_sym_STAR_EQ] = ACTIONS(202),
    [anon_sym_TILDE] = ACTIONS(202),
    [anon_sym_BANG_TILDE] = ACTIONS(202),
    [anon_sym_STAR_TILDE] = ACTIONS(202),
    [anon_sym_LT_EQ] = ACTIONS(202),
    [anon_sym_GT_EQ] = ACTIONS(202),
    [anon_sym_PLUS] = ACTIONS(204),
    [anon_sym_PLUS_EQ] = ACTIONS(202),
    [anon_sym_DASH_EQ] = ACTIONS(202),
    [anon_sym_u00d7] = ACTIONS(202),
    [anon_sym_SLASH] = ACTIONS(204),
    [anon_sym_u00f7] = ACTIONS(202),
    [anon_sym_STAR_STAR] = ACTIONS(202),
    [anon_sym_u220b] = ACTIONS(202),
    [anon_sym_u220c] = ACTIONS(202),
    [anon_sym_u2287] = ACTIONS(202),
    [anon_sym_u2283] = ACTIONS(202),
    [anon_sym_u2285] = ACTIONS(202),
    [anon_sym_u2208] = ACTIONS(202),
    [anon_sym_u2209] = ACTIONS(202),
    [anon_sym_u2286] = ACTIONS(202),
    [anon_sym_u2282] = ACTIONS(202),
    [anon_sym_u2284] = ACTIONS(202),
    [anon_sym_AT_AT] = ACTIONS(202),
  },
  [64] = {
    [ts_builtin_sym_end] = ACTIONS(146),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(146),
    [sym_keyword_return] = ACTIONS(146),
    [sym_keyword_value] = ACTIONS(146),
    [sym_keyword_explain] = ACTIONS(146),
    [sym_keyword_parallel] = ACTIONS(146),
    [sym_keyword_timeout] = ACTIONS(146),
    [sym_keyword_fetch] = ACTIONS(146),
    [sym_keyword_limit] = ACTIONS(146),
    [sym_keyword_rand] = ACTIONS(146),
    [sym_keyword_collate] = ACTIONS(146),
    [sym_keyword_numeric] = ACTIONS(146),
    [sym_keyword_asc] = ACTIONS(146),
    [sym_keyword_desc] = ACTIONS(146),
    [sym_keyword_where] = ACTIONS(146),
    [sym_keyword_and] = ACTIONS(146),
    [sym_keyword_or] = ACTIONS(146),
    [sym_keyword_is] = ACTIONS(146),
    [sym_keyword_not] = ACTIONS(148),
    [sym_keyword_contains] = ACTIONS(146),
    [sym_keyword_contains_not] = ACTIONS(146),
    [sym_keyword_contains_all] = ACTIONS(146),
    [sym_keyword_contains_any] = ACTIONS(146),
    [sym_keyword_contains_none] = ACTIONS(146),
    [sym_keyword_inside] = ACTIONS(146),
    [sym_keyword_in] = ACTIONS(148),
    [sym_keyword_not_inside] = ACTIONS(146),
    [sym_keyword_all_inside] = ACTIONS(146),
    [sym_keyword_any_inside] = ACTIONS(146),
    [sym_keyword_none_inside] = ACTIONS(146),
    [sym_keyword_outside] = ACTIONS(146),
    [sym_keyword_intersects] = ACTIONS(146),
    [sym_keyword_flexible] = ACTIONS(146),
    [sym_keyword_readonly] = ACTIONS(146),
    [sym_keyword_content] = ACTIONS(146),
    [sym_keyword_merge] = ACTIONS(146),
    [sym_keyword_patch] = ACTIONS(146),
    [sym_keyword_type] = ACTIONS(146),
    [sym_keyword_default] = ACTIONS(146),
    [sym_keyword_assert] = ACTIONS(146),
    [sym_keyword_permissions] = ACTIONS(146),
    [sym_keyword_for] = ACTIONS(146),
    [sym_keyword_comment] = ACTIONS(146),
    [sym_keyword_set] = ACTIONS(146),
    [sym_keyword_unset] = ACTIONS(146),
    [anon_sym_COMMA] = ACTIONS(146),
    [anon_sym_DASH_GT] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(146),
    [anon_sym_LT_DASH] = ACTIONS(148),
    [anon_sym_LT_DASH_GT] = ACTIONS(146),
    [anon_sym_STAR] = ACTIONS(148),
    [anon_sym_DOT] = ACTIONS(146),
    [anon_sym_LT] = ACTIONS(148),
    [anon_sym_GT] = ACTIONS(148),
    [anon_sym_EQ] = ACTIONS(148),
    [anon_sym_DASH] = ACTIONS(148),
    [anon_sym_AT] = ACTIONS(148),
    [anon_sym_LT_PIPE] = ACTIONS(146),
    [anon_sym_AMP_AMP] = ACTIONS(146),
    [anon_sym_PIPE_PIPE] = ACTIONS(146),
    [anon_sym_QMARK_QMARK] = ACTIONS(146),
    [anon_sym_QMARK_COLON] = ACTIONS(146),
    [anon_sym_BANG_EQ] = ACTIONS(146),
    [anon_sym_EQ_EQ] = ACTIONS(146),
    [anon_sym_QMARK_EQ] = ACTIONS(146),
    [anon_sym_STAR_EQ] = ACTIONS(146),
    [anon_sym_TILDE] = ACTIONS(146),
    [anon_sym_BANG_TILDE] = ACTIONS(146),
    [anon_sym_STAR_TILDE] = ACTIONS(146),
    [anon_sym_LT_EQ] = ACTIONS(146),
    [anon_sym_GT_EQ] = ACTIONS(146),
    [anon_sym_PLUS] = ACTIONS(148),
    [anon_sym_PLUS_EQ] = ACTIONS(146),
    [anon_sym_DASH_EQ] = ACTIONS(146),
    [anon_sym_u00d7] = ACTIONS(146),
    [anon_sym_SLASH] = ACTIONS(148),
    [anon_sym_u00f7] = ACTIONS(146),
    [anon_sym_STAR_STAR] = ACTIONS(146),
    [anon_sym_u220b] = ACTIONS(146),
    [anon_sym_u220c] = ACTIONS(146),
    [anon_sym_u2287] = ACTIONS(146),
    [anon_sym_u2283] = ACTIONS(146),
    [anon_sym_u2285] = ACTIONS(146),
    [anon_sym_u2208] = ACTIONS(146),
    [anon_sym_u2209] = ACTIONS(146),
    [anon_sym_u2286] = ACTIONS(146),
    [anon_sym_u2282] = ACTIONS(146),
    [anon_sym_u2284] = ACTIONS(146),
    [anon_sym_AT_AT] = ACTIONS(146),
  },
  [65] = {
    [ts_builtin_sym_end] = ACTIONS(142),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(142),
    [sym_keyword_return] = ACTIONS(142),
    [sym_keyword_value] = ACTIONS(142),
    [sym_keyword_explain] = ACTIONS(142),
    [sym_keyword_parallel] = ACTIONS(142),
    [sym_keyword_timeout] = ACTIONS(142),
    [sym_keyword_fetch] = ACTIONS(142),
    [sym_keyword_limit] = ACTIONS(142),
    [sym_keyword_rand] = ACTIONS(142),
    [sym_keyword_collate] = ACTIONS(142),
    [sym_keyword_numeric] = ACTIONS(142),
    [sym_keyword_asc] = ACTIONS(142),
    [sym_keyword_desc] = ACTIONS(142),
    [sym_keyword_where] = ACTIONS(142),
    [sym_keyword_and] = ACTIONS(142),
    [sym_keyword_or] = ACTIONS(142),
    [sym_keyword_is] = ACTIONS(142),
    [sym_keyword_not] = ACTIONS(144),
    [sym_keyword_contains] = ACTIONS(142),
    [sym_keyword_contains_not] = ACTIONS(142),
    [sym_keyword_contains_all] = ACTIONS(142),
    [sym_keyword_contains_any] = ACTIONS(142),
    [sym_keyword_contains_none] = ACTIONS(142),
    [sym_keyword_inside] = ACTIONS(142),
    [sym_keyword_in] = ACTIONS(144),
    [sym_keyword_not_inside] = ACTIONS(142),
    [sym_keyword_all_inside] = ACTIONS(142),
    [sym_keyword_any_inside] = ACTIONS(142),
    [sym_keyword_none_inside] = ACTIONS(142),
    [sym_keyword_outside] = ACTIONS(142),
    [sym_keyword_intersects] = ACTIONS(142),
    [sym_keyword_flexible] = ACTIONS(142),
    [sym_keyword_readonly] = ACTIONS(142),
    [sym_keyword_content] = ACTIONS(142),
    [sym_keyword_merge] = ACTIONS(142),
    [sym_keyword_patch] = ACTIONS(142),
    [sym_keyword_type] = ACTIONS(142),
    [sym_keyword_default] = ACTIONS(142),
    [sym_keyword_assert] = ACTIONS(142),
    [sym_keyword_permissions] = ACTIONS(142),
    [sym_keyword_for] = ACTIONS(142),
    [sym_keyword_comment] = ACTIONS(142),
    [sym_keyword_set] = ACTIONS(142),
    [sym_keyword_unset] = ACTIONS(142),
    [anon_sym_COMMA] = ACTIONS(142),
    [anon_sym_DASH_GT] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(142),
    [anon_sym_LT_DASH] = ACTIONS(144),
    [anon_sym_LT_DASH_GT] = ACTIONS(142),
    [anon_sym_STAR] = ACTIONS(144),
    [anon_sym_DOT] = ACTIONS(142),
    [anon_sym_LT] = ACTIONS(144),
    [anon_sym_GT] = ACTIONS(144),
    [anon_sym_EQ] = ACTIONS(144),
    [anon_sym_DASH] = ACTIONS(144),
    [anon_sym_AT] = ACTIONS(144),
    [anon_sym_LT_PIPE] = ACTIONS(142),
    [anon_sym_AMP_AMP] = ACTIONS(142),
    [anon_sym_PIPE_PIPE] = ACTIONS(142),
    [anon_sym_QMARK_QMARK] = ACTIONS(142),
    [anon_sym_QMARK_COLON] = ACTIONS(142),
    [anon_sym_BANG_EQ] = ACTIONS(142),
    [anon_sym_EQ_EQ] = ACTIONS(142),
    [anon_sym_QMARK_EQ] = ACTIONS(142),
    [anon_sym_STAR_EQ] = ACTIONS(142),
    [anon_sym_TILDE] = ACTIONS(142),
    [anon_sym_BANG_TILDE] = ACTIONS(142),
    [anon_sym_STAR_TILDE] = ACTIONS(142),
    [anon_sym_LT_EQ] = ACTIONS(142),
    [anon_sym_GT_EQ] = ACTIONS(142),
    [anon_sym_PLUS] = ACTIONS(144),
    [anon_sym_PLUS_EQ] = ACTIONS(142),
    [anon_sym_DASH_EQ] = ACTIONS(142),
    [anon_sym_u00d7] = ACTIONS(142),
    [anon_sym_SLASH] = ACTIONS(144),
    [anon_sym_u00f7] = ACTIONS(142),
    [anon_sym_STAR_STAR] = ACTIONS(142),
    [anon_sym_u220b] = ACTIONS(142),
    [anon_sym_u220c] = ACTIONS(142),
    [anon_sym_u2287] = ACTIONS(142),
    [anon_sym_u2283] = ACTIONS(142),
    [anon_sym_u2285] = ACTIONS(142),
    [anon_sym_u2208] = ACTIONS(142),
    [anon_sym_u2209] = ACTIONS(142),
    [anon_sym_u2286] = ACTIONS(142),
    [anon_sym_u2282] = ACTIONS(142),
    [anon_sym_u2284] = ACTIONS(142),
    [anon_sym_AT_AT] = ACTIONS(142),
  },
  [66] = {
    [sym_filter] = STATE(104),
    [sym_path_element] = STATE(68),
    [sym_graph_path] = STATE(104),
    [sym_subscript] = STATE(104),
    [aux_sym_path_repeat1] = STATE(68),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(91),
    [sym_keyword_value] = ACTIONS(91),
    [sym_keyword_explain] = ACTIONS(91),
    [sym_keyword_parallel] = ACTIONS(91),
    [sym_keyword_timeout] = ACTIONS(91),
    [sym_keyword_fetch] = ACTIONS(91),
    [sym_keyword_limit] = ACTIONS(91),
    [sym_keyword_rand] = ACTIONS(91),
    [sym_keyword_collate] = ACTIONS(91),
    [sym_keyword_numeric] = ACTIONS(91),
    [sym_keyword_asc] = ACTIONS(91),
    [sym_keyword_desc] = ACTIONS(91),
    [sym_keyword_and] = ACTIONS(91),
    [sym_keyword_or] = ACTIONS(91),
    [sym_keyword_is] = ACTIONS(91),
    [sym_keyword_not] = ACTIONS(93),
    [sym_keyword_contains] = ACTIONS(91),
    [sym_keyword_contains_not] = ACTIONS(91),
    [sym_keyword_contains_all] = ACTIONS(91),
    [sym_keyword_contains_any] = ACTIONS(91),
    [sym_keyword_contains_none] = ACTIONS(91),
    [sym_keyword_inside] = ACTIONS(91),
    [sym_keyword_in] = ACTIONS(93),
    [sym_keyword_not_inside] = ACTIONS(91),
    [sym_keyword_all_inside] = ACTIONS(91),
    [sym_keyword_any_inside] = ACTIONS(91),
    [sym_keyword_none_inside] = ACTIONS(91),
    [sym_keyword_outside] = ACTIONS(91),
    [sym_keyword_intersects] = ACTIONS(91),
    [sym_keyword_flexible] = ACTIONS(91),
    [sym_keyword_readonly] = ACTIONS(91),
    [sym_keyword_type] = ACTIONS(91),
    [sym_keyword_default] = ACTIONS(91),
    [sym_keyword_assert] = ACTIONS(91),
    [sym_keyword_permissions] = ACTIONS(91),
    [sym_keyword_for] = ACTIONS(91),
    [sym_keyword_comment] = ACTIONS(91),
    [anon_sym_COMMA] = ACTIONS(91),
    [anon_sym_DASH_GT] = ACTIONS(219),
    [anon_sym_LBRACK] = ACTIONS(221),
    [anon_sym_RPAREN] = ACTIONS(91),
    [anon_sym_RBRACE] = ACTIONS(91),
    [anon_sym_LT_DASH] = ACTIONS(223),
    [anon_sym_LT_DASH_GT] = ACTIONS(219),
    [anon_sym_STAR] = ACTIONS(93),
    [anon_sym_DOT] = ACTIONS(225),
    [anon_sym_LT] = ACTIONS(93),
    [anon_sym_GT] = ACTIONS(93),
    [anon_sym_EQ] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(93),
    [anon_sym_AT] = ACTIONS(93),
    [anon_sym_LT_PIPE] = ACTIONS(91),
    [anon_sym_AMP_AMP] = ACTIONS(91),
    [anon_sym_PIPE_PIPE] = ACTIONS(91),
    [anon_sym_QMARK_QMARK] = ACTIONS(91),
    [anon_sym_QMARK_COLON] = ACTIONS(91),
    [anon_sym_BANG_EQ] = ACTIONS(91),
    [anon_sym_EQ_EQ] = ACTIONS(91),
    [anon_sym_QMARK_EQ] = ACTIONS(91),
    [anon_sym_STAR_EQ] = ACTIONS(91),
    [anon_sym_TILDE] = ACTIONS(91),
    [anon_sym_BANG_TILDE] = ACTIONS(91),
    [anon_sym_STAR_TILDE] = ACTIONS(91),
    [anon_sym_LT_EQ] = ACTIONS(91),
    [anon_sym_GT_EQ] = ACTIONS(91),
    [anon_sym_PLUS] = ACTIONS(93),
    [anon_sym_PLUS_EQ] = ACTIONS(91),
    [anon_sym_DASH_EQ] = ACTIONS(91),
    [anon_sym_u00d7] = ACTIONS(91),
    [anon_sym_SLASH] = ACTIONS(93),
    [anon_sym_u00f7] = ACTIONS(91),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_u220b] = ACTIONS(91),
    [anon_sym_u220c] = ACTIONS(91),
    [anon_sym_u2287] = ACTIONS(91),
    [anon_sym_u2283] = ACTIONS(91),
    [anon_sym_u2285] = ACTIONS(91),
    [anon_sym_u2208] = ACTIONS(91),
    [anon_sym_u2209] = ACTIONS(91),
    [anon_sym_u2286] = ACTIONS(91),
    [anon_sym_u2282] = ACTIONS(91),
    [anon_sym_u2284] = ACTIONS(91),
    [anon_sym_AT_AT] = ACTIONS(91),
  },
  [67] = {
    [sym_filter] = STATE(104),
    [sym_path_element] = STATE(66),
    [sym_graph_path] = STATE(104),
    [sym_subscript] = STATE(104),
    [aux_sym_path_repeat1] = STATE(66),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(59),
    [sym_keyword_value] = ACTIONS(59),
    [sym_keyword_explain] = ACTIONS(59),
    [sym_keyword_parallel] = ACTIONS(59),
    [sym_keyword_timeout] = ACTIONS(59),
    [sym_keyword_fetch] = ACTIONS(59),
    [sym_keyword_limit] = ACTIONS(59),
    [sym_keyword_rand] = ACTIONS(59),
    [sym_keyword_collate] = ACTIONS(59),
    [sym_keyword_numeric] = ACTIONS(59),
    [sym_keyword_asc] = ACTIONS(59),
    [sym_keyword_desc] = ACTIONS(59),
    [sym_keyword_and] = ACTIONS(59),
    [sym_keyword_or] = ACTIONS(59),
    [sym_keyword_is] = ACTIONS(59),
    [sym_keyword_not] = ACTIONS(61),
    [sym_keyword_contains] = ACTIONS(59),
    [sym_keyword_contains_not] = ACTIONS(59),
    [sym_keyword_contains_all] = ACTIONS(59),
    [sym_keyword_contains_any] = ACTIONS(59),
    [sym_keyword_contains_none] = ACTIONS(59),
    [sym_keyword_inside] = ACTIONS(59),
    [sym_keyword_in] = ACTIONS(61),
    [sym_keyword_not_inside] = ACTIONS(59),
    [sym_keyword_all_inside] = ACTIONS(59),
    [sym_keyword_any_inside] = ACTIONS(59),
    [sym_keyword_none_inside] = ACTIONS(59),
    [sym_keyword_outside] = ACTIONS(59),
    [sym_keyword_intersects] = ACTIONS(59),
    [sym_keyword_flexible] = ACTIONS(59),
    [sym_keyword_readonly] = ACTIONS(59),
    [sym_keyword_type] = ACTIONS(59),
    [sym_keyword_default] = ACTIONS(59),
    [sym_keyword_assert] = ACTIONS(59),
    [sym_keyword_permissions] = ACTIONS(59),
    [sym_keyword_for] = ACTIONS(59),
    [sym_keyword_comment] = ACTIONS(59),
    [anon_sym_COMMA] = ACTIONS(59),
    [anon_sym_DASH_GT] = ACTIONS(219),
    [anon_sym_LBRACK] = ACTIONS(221),
    [anon_sym_RPAREN] = ACTIONS(59),
    [anon_sym_RBRACE] = ACTIONS(59),
    [anon_sym_LT_DASH] = ACTIONS(223),
    [anon_sym_LT_DASH_GT] = ACTIONS(219),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_DOT] = ACTIONS(225),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(61),
    [anon_sym_LT_PIPE] = ACTIONS(59),
    [anon_sym_AMP_AMP] = ACTIONS(59),
    [anon_sym_PIPE_PIPE] = ACTIONS(59),
    [anon_sym_QMARK_QMARK] = ACTIONS(59),
    [anon_sym_QMARK_COLON] = ACTIONS(59),
    [anon_sym_BANG_EQ] = ACTIONS(59),
    [anon_sym_EQ_EQ] = ACTIONS(59),
    [anon_sym_QMARK_EQ] = ACTIONS(59),
    [anon_sym_STAR_EQ] = ACTIONS(59),
    [anon_sym_TILDE] = ACTIONS(59),
    [anon_sym_BANG_TILDE] = ACTIONS(59),
    [anon_sym_STAR_TILDE] = ACTIONS(59),
    [anon_sym_LT_EQ] = ACTIONS(59),
    [anon_sym_GT_EQ] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_PLUS_EQ] = ACTIONS(59),
    [anon_sym_DASH_EQ] = ACTIONS(59),
    [anon_sym_u00d7] = ACTIONS(59),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_u00f7] = ACTIONS(59),
    [anon_sym_STAR_STAR] = ACTIONS(59),
    [anon_sym_u220b] = ACTIONS(59),
    [anon_sym_u220c] = ACTIONS(59),
    [anon_sym_u2287] = ACTIONS(59),
    [anon_sym_u2283] = ACTIONS(59),
    [anon_sym_u2285] = ACTIONS(59),
    [anon_sym_u2208] = ACTIONS(59),
    [anon_sym_u2209] = ACTIONS(59),
    [anon_sym_u2286] = ACTIONS(59),
    [anon_sym_u2282] = ACTIONS(59),
    [anon_sym_u2284] = ACTIONS(59),
    [anon_sym_AT_AT] = ACTIONS(59),
  },
  [68] = {
    [sym_filter] = STATE(104),
    [sym_path_element] = STATE(68),
    [sym_graph_path] = STATE(104),
    [sym_subscript] = STATE(104),
    [aux_sym_path_repeat1] = STATE(68),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(75),
    [sym_keyword_value] = ACTIONS(75),
    [sym_keyword_explain] = ACTIONS(75),
    [sym_keyword_parallel] = ACTIONS(75),
    [sym_keyword_timeout] = ACTIONS(75),
    [sym_keyword_fetch] = ACTIONS(75),
    [sym_keyword_limit] = ACTIONS(75),
    [sym_keyword_rand] = ACTIONS(75),
    [sym_keyword_collate] = ACTIONS(75),
    [sym_keyword_numeric] = ACTIONS(75),
    [sym_keyword_asc] = ACTIONS(75),
    [sym_keyword_desc] = ACTIONS(75),
    [sym_keyword_and] = ACTIONS(75),
    [sym_keyword_or] = ACTIONS(75),
    [sym_keyword_is] = ACTIONS(75),
    [sym_keyword_not] = ACTIONS(77),
    [sym_keyword_contains] = ACTIONS(75),
    [sym_keyword_contains_not] = ACTIONS(75),
    [sym_keyword_contains_all] = ACTIONS(75),
    [sym_keyword_contains_any] = ACTIONS(75),
    [sym_keyword_contains_none] = ACTIONS(75),
    [sym_keyword_inside] = ACTIONS(75),
    [sym_keyword_in] = ACTIONS(77),
    [sym_keyword_not_inside] = ACTIONS(75),
    [sym_keyword_all_inside] = ACTIONS(75),
    [sym_keyword_any_inside] = ACTIONS(75),
    [sym_keyword_none_inside] = ACTIONS(75),
    [sym_keyword_outside] = ACTIONS(75),
    [sym_keyword_intersects] = ACTIONS(75),
    [sym_keyword_flexible] = ACTIONS(75),
    [sym_keyword_readonly] = ACTIONS(75),
    [sym_keyword_type] = ACTIONS(75),
    [sym_keyword_default] = ACTIONS(75),
    [sym_keyword_assert] = ACTIONS(75),
    [sym_keyword_permissions] = ACTIONS(75),
    [sym_keyword_for] = ACTIONS(75),
    [sym_keyword_comment] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(75),
    [anon_sym_DASH_GT] = ACTIONS(227),
    [anon_sym_LBRACK] = ACTIONS(230),
    [anon_sym_RPAREN] = ACTIONS(75),
    [anon_sym_RBRACE] = ACTIONS(75),
    [anon_sym_LT_DASH] = ACTIONS(233),
    [anon_sym_LT_DASH_GT] = ACTIONS(227),
    [anon_sym_STAR] = ACTIONS(77),
    [anon_sym_DOT] = ACTIONS(236),
    [anon_sym_LT] = ACTIONS(77),
    [anon_sym_GT] = ACTIONS(77),
    [anon_sym_EQ] = ACTIONS(77),
    [anon_sym_DASH] = ACTIONS(77),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LT_PIPE] = ACTIONS(75),
    [anon_sym_AMP_AMP] = ACTIONS(75),
    [anon_sym_PIPE_PIPE] = ACTIONS(75),
    [anon_sym_QMARK_QMARK] = ACTIONS(75),
    [anon_sym_QMARK_COLON] = ACTIONS(75),
    [anon_sym_BANG_EQ] = ACTIONS(75),
    [anon_sym_EQ_EQ] = ACTIONS(75),
    [anon_sym_QMARK_EQ] = ACTIONS(75),
    [anon_sym_STAR_EQ] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_BANG_TILDE] = ACTIONS(75),
    [anon_sym_STAR_TILDE] = ACTIONS(75),
    [anon_sym_LT_EQ] = ACTIONS(75),
    [anon_sym_GT_EQ] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(77),
    [anon_sym_PLUS_EQ] = ACTIONS(75),
    [anon_sym_DASH_EQ] = ACTIONS(75),
    [anon_sym_u00d7] = ACTIONS(75),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_u00f7] = ACTIONS(75),
    [anon_sym_STAR_STAR] = ACTIONS(75),
    [anon_sym_u220b] = ACTIONS(75),
    [anon_sym_u220c] = ACTIONS(75),
    [anon_sym_u2287] = ACTIONS(75),
    [anon_sym_u2283] = ACTIONS(75),
    [anon_sym_u2285] = ACTIONS(75),
    [anon_sym_u2208] = ACTIONS(75),
    [anon_sym_u2209] = ACTIONS(75),
    [anon_sym_u2286] = ACTIONS(75),
    [anon_sym_u2282] = ACTIONS(75),
    [anon_sym_u2284] = ACTIONS(75),
    [anon_sym_AT_AT] = ACTIONS(75),
  },
  [69] = {
    [sym_filter] = STATE(104),
    [sym_path_element] = STATE(66),
    [sym_graph_path] = STATE(104),
    [sym_subscript] = STATE(104),
    [aux_sym_path_repeat1] = STATE(66),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(71),
    [sym_keyword_value] = ACTIONS(71),
    [sym_keyword_explain] = ACTIONS(71),
    [sym_keyword_parallel] = ACTIONS(71),
    [sym_keyword_timeout] = ACTIONS(71),
    [sym_keyword_fetch] = ACTIONS(71),
    [sym_keyword_limit] = ACTIONS(71),
    [sym_keyword_rand] = ACTIONS(71),
    [sym_keyword_collate] = ACTIONS(71),
    [sym_keyword_numeric] = ACTIONS(71),
    [sym_keyword_asc] = ACTIONS(71),
    [sym_keyword_desc] = ACTIONS(71),
    [sym_keyword_and] = ACTIONS(71),
    [sym_keyword_or] = ACTIONS(71),
    [sym_keyword_is] = ACTIONS(71),
    [sym_keyword_not] = ACTIONS(73),
    [sym_keyword_contains] = ACTIONS(71),
    [sym_keyword_contains_not] = ACTIONS(71),
    [sym_keyword_contains_all] = ACTIONS(71),
    [sym_keyword_contains_any] = ACTIONS(71),
    [sym_keyword_contains_none] = ACTIONS(71),
    [sym_keyword_inside] = ACTIONS(71),
    [sym_keyword_in] = ACTIONS(73),
    [sym_keyword_not_inside] = ACTIONS(71),
    [sym_keyword_all_inside] = ACTIONS(71),
    [sym_keyword_any_inside] = ACTIONS(71),
    [sym_keyword_none_inside] = ACTIONS(71),
    [sym_keyword_outside] = ACTIONS(71),
    [sym_keyword_intersects] = ACTIONS(71),
    [sym_keyword_flexible] = ACTIONS(71),
    [sym_keyword_readonly] = ACTIONS(71),
    [sym_keyword_type] = ACTIONS(71),
    [sym_keyword_default] = ACTIONS(71),
    [sym_keyword_assert] = ACTIONS(71),
    [sym_keyword_permissions] = ACTIONS(71),
    [sym_keyword_for] = ACTIONS(71),
    [sym_keyword_comment] = ACTIONS(71),
    [anon_sym_COMMA] = ACTIONS(71),
    [anon_sym_DASH_GT] = ACTIONS(219),
    [anon_sym_LBRACK] = ACTIONS(221),
    [anon_sym_RPAREN] = ACTIONS(71),
    [anon_sym_RBRACE] = ACTIONS(71),
    [anon_sym_LT_DASH] = ACTIONS(223),
    [anon_sym_LT_DASH_GT] = ACTIONS(219),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_DOT] = ACTIONS(225),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(73),
    [anon_sym_LT_PIPE] = ACTIONS(71),
    [anon_sym_AMP_AMP] = ACTIONS(71),
    [anon_sym_PIPE_PIPE] = ACTIONS(71),
    [anon_sym_QMARK_QMARK] = ACTIONS(71),
    [anon_sym_QMARK_COLON] = ACTIONS(71),
    [anon_sym_BANG_EQ] = ACTIONS(71),
    [anon_sym_EQ_EQ] = ACTIONS(71),
    [anon_sym_QMARK_EQ] = ACTIONS(71),
    [anon_sym_STAR_EQ] = ACTIONS(71),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_BANG_TILDE] = ACTIONS(71),
    [anon_sym_STAR_TILDE] = ACTIONS(71),
    [anon_sym_LT_EQ] = ACTIONS(71),
    [anon_sym_GT_EQ] = ACTIONS(71),
    [anon_sym_PLUS] = ACTIONS(73),
    [anon_sym_PLUS_EQ] = ACTIONS(71),
    [anon_sym_DASH_EQ] = ACTIONS(71),
    [anon_sym_u00d7] = ACTIONS(71),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_u00f7] = ACTIONS(71),
    [anon_sym_STAR_STAR] = ACTIONS(71),
    [anon_sym_u220b] = ACTIONS(71),
    [anon_sym_u220c] = ACTIONS(71),
    [anon_sym_u2287] = ACTIONS(71),
    [anon_sym_u2283] = ACTIONS(71),
    [anon_sym_u2285] = ACTIONS(71),
    [anon_sym_u2208] = ACTIONS(71),
    [anon_sym_u2209] = ACTIONS(71),
    [anon_sym_u2286] = ACTIONS(71),
    [anon_sym_u2282] = ACTIONS(71),
    [anon_sym_u2284] = ACTIONS(71),
    [anon_sym_AT_AT] = ACTIONS(71),
  },
  [70] = {
    [ts_builtin_sym_end] = ACTIONS(138),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(138),
    [sym_keyword_return] = ACTIONS(138),
    [sym_keyword_value] = ACTIONS(138),
    [sym_keyword_explain] = ACTIONS(138),
    [sym_keyword_parallel] = ACTIONS(138),
    [sym_keyword_timeout] = ACTIONS(138),
    [sym_keyword_fetch] = ACTIONS(138),
    [sym_keyword_limit] = ACTIONS(138),
    [sym_keyword_rand] = ACTIONS(138),
    [sym_keyword_collate] = ACTIONS(138),
    [sym_keyword_numeric] = ACTIONS(138),
    [sym_keyword_asc] = ACTIONS(138),
    [sym_keyword_desc] = ACTIONS(138),
    [sym_keyword_where] = ACTIONS(138),
    [sym_keyword_and] = ACTIONS(138),
    [sym_keyword_or] = ACTIONS(138),
    [sym_keyword_is] = ACTIONS(138),
    [sym_keyword_not] = ACTIONS(140),
    [sym_keyword_contains] = ACTIONS(138),
    [sym_keyword_contains_not] = ACTIONS(138),
    [sym_keyword_contains_all] = ACTIONS(138),
    [sym_keyword_contains_any] = ACTIONS(138),
    [sym_keyword_contains_none] = ACTIONS(138),
    [sym_keyword_inside] = ACTIONS(138),
    [sym_keyword_in] = ACTIONS(140),
    [sym_keyword_not_inside] = ACTIONS(138),
    [sym_keyword_all_inside] = ACTIONS(138),
    [sym_keyword_any_inside] = ACTIONS(138),
    [sym_keyword_none_inside] = ACTIONS(138),
    [sym_keyword_outside] = ACTIONS(138),
    [sym_keyword_intersects] = ACTIONS(138),
    [sym_keyword_flexible] = ACTIONS(138),
    [sym_keyword_readonly] = ACTIONS(138),
    [sym_keyword_content] = ACTIONS(138),
    [sym_keyword_merge] = ACTIONS(138),
    [sym_keyword_patch] = ACTIONS(138),
    [sym_keyword_type] = ACTIONS(138),
    [sym_keyword_default] = ACTIONS(138),
    [sym_keyword_assert] = ACTIONS(138),
    [sym_keyword_permissions] = ACTIONS(138),
    [sym_keyword_for] = ACTIONS(138),
    [sym_keyword_comment] = ACTIONS(138),
    [sym_keyword_set] = ACTIONS(138),
    [sym_keyword_unset] = ACTIONS(138),
    [anon_sym_COMMA] = ACTIONS(138),
    [anon_sym_DASH_GT] = ACTIONS(138),
    [anon_sym_RPAREN] = ACTIONS(138),
    [anon_sym_RBRACE] = ACTIONS(138),
    [anon_sym_STAR] = ACTIONS(140),
    [anon_sym_LT] = ACTIONS(140),
    [anon_sym_GT] = ACTIONS(140),
    [anon_sym_EQ] = ACTIONS(140),
    [anon_sym_DASH] = ACTIONS(140),
    [anon_sym_AT] = ACTIONS(140),
    [anon_sym_LT_PIPE] = ACTIONS(138),
    [anon_sym_AMP_AMP] = ACTIONS(138),
    [anon_sym_PIPE_PIPE] = ACTIONS(138),
    [anon_sym_QMARK_QMARK] = ACTIONS(138),
    [anon_sym_QMARK_COLON] = ACTIONS(138),
    [anon_sym_BANG_EQ] = ACTIONS(138),
    [anon_sym_EQ_EQ] = ACTIONS(138),
    [anon_sym_QMARK_EQ] = ACTIONS(138),
    [anon_sym_STAR_EQ] = ACTIONS(138),
    [anon_sym_TILDE] = ACTIONS(138),
    [anon_sym_BANG_TILDE] = ACTIONS(138),
    [anon_sym_STAR_TILDE] = ACTIONS(138),
    [anon_sym_LT_EQ] = ACTIONS(138),
    [anon_sym_GT_EQ] = ACTIONS(138),
    [anon_sym_PLUS] = ACTIONS(140),
    [anon_sym_PLUS_EQ] = ACTIONS(138),
    [anon_sym_DASH_EQ] = ACTIONS(138),
    [anon_sym_u00d7] = ACTIONS(138),
    [anon_sym_SLASH] = ACTIONS(140),
    [anon_sym_u00f7] = ACTIONS(138),
    [anon_sym_STAR_STAR] = ACTIONS(138),
    [anon_sym_u220b] = ACTIONS(138),
    [anon_sym_u220c] = ACTIONS(138),
    [anon_sym_u2287] = ACTIONS(138),
    [anon_sym_u2283] = ACTIONS(138),
    [anon_sym_u2285] = ACTIONS(138),
    [anon_sym_u2208] = ACTIONS(138),
    [anon_sym_u2209] = ACTIONS(138),
    [anon_sym_u2286] = ACTIONS(138),
    [anon_sym_u2282] = ACTIONS(138),
    [anon_sym_u2284] = ACTIONS(138),
    [anon_sym_AT_AT] = ACTIONS(138),
  },
  [71] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(239),
    [sym_keyword_return] = ACTIONS(239),
    [sym_keyword_from] = ACTIONS(239),
    [sym_keyword_as] = ACTIONS(239),
    [sym_keyword_parallel] = ACTIONS(239),
    [sym_keyword_timeout] = ACTIONS(239),
    [sym_keyword_where] = ACTIONS(239),
    [sym_keyword_group] = ACTIONS(239),
    [sym_keyword_and] = ACTIONS(239),
    [sym_keyword_or] = ACTIONS(239),
    [sym_keyword_is] = ACTIONS(239),
    [sym_keyword_not] = ACTIONS(241),
    [sym_keyword_contains] = ACTIONS(239),
    [sym_keyword_contains_not] = ACTIONS(239),
    [sym_keyword_contains_all] = ACTIONS(239),
    [sym_keyword_contains_any] = ACTIONS(239),
    [sym_keyword_contains_none] = ACTIONS(239),
    [sym_keyword_inside] = ACTIONS(239),
    [sym_keyword_in] = ACTIONS(241),
    [sym_keyword_not_inside] = ACTIONS(239),
    [sym_keyword_all_inside] = ACTIONS(239),
    [sym_keyword_any_inside] = ACTIONS(239),
    [sym_keyword_none_inside] = ACTIONS(239),
    [sym_keyword_outside] = ACTIONS(239),
    [sym_keyword_intersects] = ACTIONS(239),
    [sym_keyword_drop] = ACTIONS(239),
    [sym_keyword_schemafull] = ACTIONS(239),
    [sym_keyword_schemaless] = ACTIONS(239),
    [sym_keyword_changefeed] = ACTIONS(239),
    [sym_keyword_content] = ACTIONS(239),
    [sym_keyword_merge] = ACTIONS(239),
    [sym_keyword_patch] = ACTIONS(239),
    [sym_keyword_then] = ACTIONS(239),
    [sym_keyword_type] = ACTIONS(239),
    [sym_keyword_permissions] = ACTIONS(239),
    [sym_keyword_for] = ACTIONS(239),
    [sym_keyword_comment] = ACTIONS(239),
    [sym_keyword_if] = ACTIONS(239),
    [sym_keyword_set] = ACTIONS(239),
    [sym_keyword_unset] = ACTIONS(239),
    [anon_sym_COMMA] = ACTIONS(239),
    [anon_sym_RBRACK] = ACTIONS(239),
    [anon_sym_LPAREN] = ACTIONS(239),
    [anon_sym_RPAREN] = ACTIONS(239),
    [anon_sym_QMARK] = ACTIONS(241),
    [anon_sym_LBRACE] = ACTIONS(239),
    [anon_sym_RBRACE] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(241),
    [anon_sym_LT] = ACTIONS(241),
    [anon_sym_GT] = ACTIONS(241),
    [sym_variable_name] = ACTIONS(239),
    [sym_custom_function_name] = ACTIONS(239),
    [anon_sym_EQ] = ACTIONS(241),
    [anon_sym_DASH] = ACTIONS(241),
    [anon_sym_AT] = ACTIONS(241),
    [anon_sym_LT_PIPE] = ACTIONS(239),
    [anon_sym_AMP_AMP] = ACTIONS(239),
    [anon_sym_PIPE_PIPE] = ACTIONS(239),
    [anon_sym_QMARK_QMARK] = ACTIONS(239),
    [anon_sym_QMARK_COLON] = ACTIONS(239),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(239),
    [anon_sym_QMARK_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_TILDE] = ACTIONS(239),
    [anon_sym_BANG_TILDE] = ACTIONS(239),
    [anon_sym_STAR_TILDE] = ACTIONS(239),
    [anon_sym_LT_EQ] = ACTIONS(239),
    [anon_sym_GT_EQ] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(241),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_u00d7] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(241),
    [anon_sym_u00f7] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_u220b] = ACTIONS(239),
    [anon_sym_u220c] = ACTIONS(239),
    [anon_sym_u2287] = ACTIONS(239),
    [anon_sym_u2283] = ACTIONS(239),
    [anon_sym_u2285] = ACTIONS(239),
    [anon_sym_u2208] = ACTIONS(239),
    [anon_sym_u2209] = ACTIONS(239),
    [anon_sym_u2286] = ACTIONS(239),
    [anon_sym_u2282] = ACTIONS(239),
    [anon_sym_u2284] = ACTIONS(239),
    [anon_sym_AT_AT] = ACTIONS(239),
  },
  [72] = {
    [sym_filter] = STATE(64),
    [sym_path_element] = STATE(82),
    [sym_graph_path] = STATE(64),
    [sym_subscript] = STATE(64),
    [aux_sym_path_repeat1] = STATE(82),
    [ts_builtin_sym_end] = ACTIONS(59),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(59),
    [sym_keyword_value] = ACTIONS(59),
    [sym_keyword_explain] = ACTIONS(59),
    [sym_keyword_parallel] = ACTIONS(59),
    [sym_keyword_timeout] = ACTIONS(59),
    [sym_keyword_fetch] = ACTIONS(59),
    [sym_keyword_limit] = ACTIONS(59),
    [sym_keyword_rand] = ACTIONS(59),
    [sym_keyword_collate] = ACTIONS(59),
    [sym_keyword_numeric] = ACTIONS(59),
    [sym_keyword_asc] = ACTIONS(59),
    [sym_keyword_desc] = ACTIONS(59),
    [sym_keyword_and] = ACTIONS(59),
    [sym_keyword_or] = ACTIONS(59),
    [sym_keyword_is] = ACTIONS(59),
    [sym_keyword_not] = ACTIONS(61),
    [sym_keyword_contains] = ACTIONS(59),
    [sym_keyword_contains_not] = ACTIONS(59),
    [sym_keyword_contains_all] = ACTIONS(59),
    [sym_keyword_contains_any] = ACTIONS(59),
    [sym_keyword_contains_none] = ACTIONS(59),
    [sym_keyword_inside] = ACTIONS(59),
    [sym_keyword_in] = ACTIONS(61),
    [sym_keyword_not_inside] = ACTIONS(59),
    [sym_keyword_all_inside] = ACTIONS(59),
    [sym_keyword_any_inside] = ACTIONS(59),
    [sym_keyword_none_inside] = ACTIONS(59),
    [sym_keyword_outside] = ACTIONS(59),
    [sym_keyword_intersects] = ACTIONS(59),
    [sym_keyword_flexible] = ACTIONS(59),
    [sym_keyword_readonly] = ACTIONS(59),
    [sym_keyword_type] = ACTIONS(59),
    [sym_keyword_default] = ACTIONS(59),
    [sym_keyword_assert] = ACTIONS(59),
    [sym_keyword_permissions] = ACTIONS(59),
    [sym_keyword_for] = ACTIONS(59),
    [sym_keyword_comment] = ACTIONS(59),
    [anon_sym_COMMA] = ACTIONS(59),
    [anon_sym_DASH_GT] = ACTIONS(243),
    [anon_sym_LBRACK] = ACTIONS(245),
    [anon_sym_LT_DASH] = ACTIONS(247),
    [anon_sym_LT_DASH_GT] = ACTIONS(243),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_DOT] = ACTIONS(249),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(61),
    [anon_sym_LT_PIPE] = ACTIONS(59),
    [anon_sym_AMP_AMP] = ACTIONS(59),
    [anon_sym_PIPE_PIPE] = ACTIONS(59),
    [anon_sym_QMARK_QMARK] = ACTIONS(59),
    [anon_sym_QMARK_COLON] = ACTIONS(59),
    [anon_sym_BANG_EQ] = ACTIONS(59),
    [anon_sym_EQ_EQ] = ACTIONS(59),
    [anon_sym_QMARK_EQ] = ACTIONS(59),
    [anon_sym_STAR_EQ] = ACTIONS(59),
    [anon_sym_TILDE] = ACTIONS(59),
    [anon_sym_BANG_TILDE] = ACTIONS(59),
    [anon_sym_STAR_TILDE] = ACTIONS(59),
    [anon_sym_LT_EQ] = ACTIONS(59),
    [anon_sym_GT_EQ] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_PLUS_EQ] = ACTIONS(59),
    [anon_sym_DASH_EQ] = ACTIONS(59),
    [anon_sym_u00d7] = ACTIONS(59),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_u00f7] = ACTIONS(59),
    [anon_sym_STAR_STAR] = ACTIONS(59),
    [anon_sym_u220b] = ACTIONS(59),
    [anon_sym_u220c] = ACTIONS(59),
    [anon_sym_u2287] = ACTIONS(59),
    [anon_sym_u2283] = ACTIONS(59),
    [anon_sym_u2285] = ACTIONS(59),
    [anon_sym_u2208] = ACTIONS(59),
    [anon_sym_u2209] = ACTIONS(59),
    [anon_sym_u2286] = ACTIONS(59),
    [anon_sym_u2282] = ACTIONS(59),
    [anon_sym_u2284] = ACTIONS(59),
    [anon_sym_AT_AT] = ACTIONS(59),
  },
  [73] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(150),
    [sym_keyword_return] = ACTIONS(150),
    [sym_keyword_from] = ACTIONS(150),
    [sym_keyword_as] = ACTIONS(150),
    [sym_keyword_parallel] = ACTIONS(150),
    [sym_keyword_timeout] = ACTIONS(150),
    [sym_keyword_where] = ACTIONS(150),
    [sym_keyword_group] = ACTIONS(150),
    [sym_keyword_and] = ACTIONS(150),
    [sym_keyword_or] = ACTIONS(150),
    [sym_keyword_is] = ACTIONS(150),
    [sym_keyword_not] = ACTIONS(152),
    [sym_keyword_contains] = ACTIONS(150),
    [sym_keyword_contains_not] = ACTIONS(150),
    [sym_keyword_contains_all] = ACTIONS(150),
    [sym_keyword_contains_any] = ACTIONS(150),
    [sym_keyword_contains_none] = ACTIONS(150),
    [sym_keyword_inside] = ACTIONS(150),
    [sym_keyword_in] = ACTIONS(152),
    [sym_keyword_not_inside] = ACTIONS(150),
    [sym_keyword_all_inside] = ACTIONS(150),
    [sym_keyword_any_inside] = ACTIONS(150),
    [sym_keyword_none_inside] = ACTIONS(150),
    [sym_keyword_outside] = ACTIONS(150),
    [sym_keyword_intersects] = ACTIONS(150),
    [sym_keyword_drop] = ACTIONS(150),
    [sym_keyword_schemafull] = ACTIONS(150),
    [sym_keyword_schemaless] = ACTIONS(150),
    [sym_keyword_changefeed] = ACTIONS(150),
    [sym_keyword_content] = ACTIONS(150),
    [sym_keyword_merge] = ACTIONS(150),
    [sym_keyword_patch] = ACTIONS(150),
    [sym_keyword_then] = ACTIONS(150),
    [sym_keyword_type] = ACTIONS(150),
    [sym_keyword_permissions] = ACTIONS(150),
    [sym_keyword_for] = ACTIONS(150),
    [sym_keyword_comment] = ACTIONS(150),
    [sym_keyword_if] = ACTIONS(150),
    [sym_keyword_set] = ACTIONS(150),
    [sym_keyword_unset] = ACTIONS(150),
    [anon_sym_COMMA] = ACTIONS(150),
    [anon_sym_RBRACK] = ACTIONS(150),
    [anon_sym_LPAREN] = ACTIONS(150),
    [anon_sym_RPAREN] = ACTIONS(150),
    [anon_sym_QMARK] = ACTIONS(152),
    [anon_sym_LBRACE] = ACTIONS(150),
    [anon_sym_RBRACE] = ACTIONS(150),
    [anon_sym_STAR] = ACTIONS(152),
    [anon_sym_LT] = ACTIONS(152),
    [anon_sym_GT] = ACTIONS(152),
    [sym_variable_name] = ACTIONS(150),
    [sym_custom_function_name] = ACTIONS(150),
    [anon_sym_EQ] = ACTIONS(152),
    [anon_sym_DASH] = ACTIONS(152),
    [anon_sym_AT] = ACTIONS(152),
    [anon_sym_LT_PIPE] = ACTIONS(150),
    [anon_sym_AMP_AMP] = ACTIONS(150),
    [anon_sym_PIPE_PIPE] = ACTIONS(150),
    [anon_sym_QMARK_QMARK] = ACTIONS(150),
    [anon_sym_QMARK_COLON] = ACTIONS(150),
    [anon_sym_BANG_EQ] = ACTIONS(150),
    [anon_sym_EQ_EQ] = ACTIONS(150),
    [anon_sym_QMARK_EQ] = ACTIONS(150),
    [anon_sym_STAR_EQ] = ACTIONS(150),
    [anon_sym_TILDE] = ACTIONS(150),
    [anon_sym_BANG_TILDE] = ACTIONS(150),
    [anon_sym_STAR_TILDE] = ACTIONS(150),
    [anon_sym_LT_EQ] = ACTIONS(150),
    [anon_sym_GT_EQ] = ACTIONS(150),
    [anon_sym_PLUS] = ACTIONS(152),
    [anon_sym_PLUS_EQ] = ACTIONS(150),
    [anon_sym_DASH_EQ] = ACTIONS(150),
    [anon_sym_u00d7] = ACTIONS(150),
    [anon_sym_SLASH] = ACTIONS(152),
    [anon_sym_u00f7] = ACTIONS(150),
    [anon_sym_STAR_STAR] = ACTIONS(150),
    [anon_sym_u220b] = ACTIONS(150),
    [anon_sym_u220c] = ACTIONS(150),
    [anon_sym_u2287] = ACTIONS(150),
    [anon_sym_u2283] = ACTIONS(150),
    [anon_sym_u2285] = ACTIONS(150),
    [anon_sym_u2208] = ACTIONS(150),
    [anon_sym_u2209] = ACTIONS(150),
    [anon_sym_u2286] = ACTIONS(150),
    [anon_sym_u2282] = ACTIONS(150),
    [anon_sym_u2284] = ACTIONS(150),
    [anon_sym_AT_AT] = ACTIONS(150),
  },
  [74] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(251),
    [sym_keyword_return] = ACTIONS(251),
    [sym_keyword_from] = ACTIONS(251),
    [sym_keyword_as] = ACTIONS(251),
    [sym_keyword_parallel] = ACTIONS(251),
    [sym_keyword_timeout] = ACTIONS(251),
    [sym_keyword_where] = ACTIONS(251),
    [sym_keyword_group] = ACTIONS(251),
    [sym_keyword_and] = ACTIONS(251),
    [sym_keyword_or] = ACTIONS(251),
    [sym_keyword_is] = ACTIONS(251),
    [sym_keyword_not] = ACTIONS(253),
    [sym_keyword_contains] = ACTIONS(251),
    [sym_keyword_contains_not] = ACTIONS(251),
    [sym_keyword_contains_all] = ACTIONS(251),
    [sym_keyword_contains_any] = ACTIONS(251),
    [sym_keyword_contains_none] = ACTIONS(251),
    [sym_keyword_inside] = ACTIONS(251),
    [sym_keyword_in] = ACTIONS(253),
    [sym_keyword_not_inside] = ACTIONS(251),
    [sym_keyword_all_inside] = ACTIONS(251),
    [sym_keyword_any_inside] = ACTIONS(251),
    [sym_keyword_none_inside] = ACTIONS(251),
    [sym_keyword_outside] = ACTIONS(251),
    [sym_keyword_intersects] = ACTIONS(251),
    [sym_keyword_drop] = ACTIONS(251),
    [sym_keyword_schemafull] = ACTIONS(251),
    [sym_keyword_schemaless] = ACTIONS(251),
    [sym_keyword_changefeed] = ACTIONS(251),
    [sym_keyword_content] = ACTIONS(251),
    [sym_keyword_merge] = ACTIONS(251),
    [sym_keyword_patch] = ACTIONS(251),
    [sym_keyword_then] = ACTIONS(251),
    [sym_keyword_type] = ACTIONS(251),
    [sym_keyword_permissions] = ACTIONS(251),
    [sym_keyword_for] = ACTIONS(251),
    [sym_keyword_comment] = ACTIONS(251),
    [sym_keyword_if] = ACTIONS(251),
    [sym_keyword_set] = ACTIONS(251),
    [sym_keyword_unset] = ACTIONS(251),
    [anon_sym_COMMA] = ACTIONS(251),
    [anon_sym_RBRACK] = ACTIONS(251),
    [anon_sym_LPAREN] = ACTIONS(251),
    [anon_sym_RPAREN] = ACTIONS(251),
    [anon_sym_QMARK] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(251),
    [anon_sym_RBRACE] = ACTIONS(251),
    [anon_sym_STAR] = ACTIONS(253),
    [anon_sym_LT] = ACTIONS(253),
    [anon_sym_GT] = ACTIONS(253),
    [sym_variable_name] = ACTIONS(251),
    [sym_custom_function_name] = ACTIONS(251),
    [anon_sym_EQ] = ACTIONS(253),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_AT] = ACTIONS(253),
    [anon_sym_LT_PIPE] = ACTIONS(251),
    [anon_sym_AMP_AMP] = ACTIONS(251),
    [anon_sym_PIPE_PIPE] = ACTIONS(251),
    [anon_sym_QMARK_QMARK] = ACTIONS(251),
    [anon_sym_QMARK_COLON] = ACTIONS(251),
    [anon_sym_BANG_EQ] = ACTIONS(251),
    [anon_sym_EQ_EQ] = ACTIONS(251),
    [anon_sym_QMARK_EQ] = ACTIONS(251),
    [anon_sym_STAR_EQ] = ACTIONS(251),
    [anon_sym_TILDE] = ACTIONS(251),
    [anon_sym_BANG_TILDE] = ACTIONS(251),
    [anon_sym_STAR_TILDE] = ACTIONS(251),
    [anon_sym_LT_EQ] = ACTIONS(251),
    [anon_sym_GT_EQ] = ACTIONS(251),
    [anon_sym_PLUS] = ACTIONS(253),
    [anon_sym_PLUS_EQ] = ACTIONS(251),
    [anon_sym_DASH_EQ] = ACTIONS(251),
    [anon_sym_u00d7] = ACTIONS(251),
    [anon_sym_SLASH] = ACTIONS(253),
    [anon_sym_u00f7] = ACTIONS(251),
    [anon_sym_STAR_STAR] = ACTIONS(251),
    [anon_sym_u220b] = ACTIONS(251),
    [anon_sym_u220c] = ACTIONS(251),
    [anon_sym_u2287] = ACTIONS(251),
    [anon_sym_u2283] = ACTIONS(251),
    [anon_sym_u2285] = ACTIONS(251),
    [anon_sym_u2208] = ACTIONS(251),
    [anon_sym_u2209] = ACTIONS(251),
    [anon_sym_u2286] = ACTIONS(251),
    [anon_sym_u2282] = ACTIONS(251),
    [anon_sym_u2284] = ACTIONS(251),
    [anon_sym_AT_AT] = ACTIONS(251),
  },
  [75] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(255),
    [sym_keyword_return] = ACTIONS(255),
    [sym_keyword_from] = ACTIONS(255),
    [sym_keyword_as] = ACTIONS(255),
    [sym_keyword_parallel] = ACTIONS(255),
    [sym_keyword_timeout] = ACTIONS(255),
    [sym_keyword_where] = ACTIONS(255),
    [sym_keyword_group] = ACTIONS(255),
    [sym_keyword_and] = ACTIONS(255),
    [sym_keyword_or] = ACTIONS(255),
    [sym_keyword_is] = ACTIONS(255),
    [sym_keyword_not] = ACTIONS(257),
    [sym_keyword_contains] = ACTIONS(255),
    [sym_keyword_contains_not] = ACTIONS(255),
    [sym_keyword_contains_all] = ACTIONS(255),
    [sym_keyword_contains_any] = ACTIONS(255),
    [sym_keyword_contains_none] = ACTIONS(255),
    [sym_keyword_inside] = ACTIONS(255),
    [sym_keyword_in] = ACTIONS(257),
    [sym_keyword_not_inside] = ACTIONS(255),
    [sym_keyword_all_inside] = ACTIONS(255),
    [sym_keyword_any_inside] = ACTIONS(255),
    [sym_keyword_none_inside] = ACTIONS(255),
    [sym_keyword_outside] = ACTIONS(255),
    [sym_keyword_intersects] = ACTIONS(255),
    [sym_keyword_drop] = ACTIONS(255),
    [sym_keyword_schemafull] = ACTIONS(255),
    [sym_keyword_schemaless] = ACTIONS(255),
    [sym_keyword_changefeed] = ACTIONS(255),
    [sym_keyword_content] = ACTIONS(255),
    [sym_keyword_merge] = ACTIONS(255),
    [sym_keyword_patch] = ACTIONS(255),
    [sym_keyword_then] = ACTIONS(255),
    [sym_keyword_type] = ACTIONS(255),
    [sym_keyword_permissions] = ACTIONS(255),
    [sym_keyword_for] = ACTIONS(255),
    [sym_keyword_comment] = ACTIONS(255),
    [sym_keyword_if] = ACTIONS(255),
    [sym_keyword_set] = ACTIONS(255),
    [sym_keyword_unset] = ACTIONS(255),
    [anon_sym_COMMA] = ACTIONS(255),
    [anon_sym_RBRACK] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(255),
    [anon_sym_RPAREN] = ACTIONS(255),
    [anon_sym_QMARK] = ACTIONS(257),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_RBRACE] = ACTIONS(255),
    [anon_sym_STAR] = ACTIONS(257),
    [anon_sym_LT] = ACTIONS(257),
    [anon_sym_GT] = ACTIONS(257),
    [sym_variable_name] = ACTIONS(255),
    [sym_custom_function_name] = ACTIONS(255),
    [anon_sym_EQ] = ACTIONS(257),
    [anon_sym_DASH] = ACTIONS(257),
    [anon_sym_AT] = ACTIONS(257),
    [anon_sym_LT_PIPE] = ACTIONS(255),
    [anon_sym_AMP_AMP] = ACTIONS(255),
    [anon_sym_PIPE_PIPE] = ACTIONS(255),
    [anon_sym_QMARK_QMARK] = ACTIONS(255),
    [anon_sym_QMARK_COLON] = ACTIONS(255),
    [anon_sym_BANG_EQ] = ACTIONS(255),
    [anon_sym_EQ_EQ] = ACTIONS(255),
    [anon_sym_QMARK_EQ] = ACTIONS(255),
    [anon_sym_STAR_EQ] = ACTIONS(255),
    [anon_sym_TILDE] = ACTIONS(255),
    [anon_sym_BANG_TILDE] = ACTIONS(255),
    [anon_sym_STAR_TILDE] = ACTIONS(255),
    [anon_sym_LT_EQ] = ACTIONS(255),
    [anon_sym_GT_EQ] = ACTIONS(255),
    [anon_sym_PLUS] = ACTIONS(257),
    [anon_sym_PLUS_EQ] = ACTIONS(255),
    [anon_sym_DASH_EQ] = ACTIONS(255),
    [anon_sym_u00d7] = ACTIONS(255),
    [anon_sym_SLASH] = ACTIONS(257),
    [anon_sym_u00f7] = ACTIONS(255),
    [anon_sym_STAR_STAR] = ACTIONS(255),
    [anon_sym_u220b] = ACTIONS(255),
    [anon_sym_u220c] = ACTIONS(255),
    [anon_sym_u2287] = ACTIONS(255),
    [anon_sym_u2283] = ACTIONS(255),
    [anon_sym_u2285] = ACTIONS(255),
    [anon_sym_u2208] = ACTIONS(255),
    [anon_sym_u2209] = ACTIONS(255),
    [anon_sym_u2286] = ACTIONS(255),
    [anon_sym_u2282] = ACTIONS(255),
    [anon_sym_u2284] = ACTIONS(255),
    [anon_sym_AT_AT] = ACTIONS(255),
  },
  [76] = {
    [ts_builtin_sym_end] = ACTIONS(259),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(259),
    [sym_keyword_return] = ACTIONS(259),
    [sym_keyword_value] = ACTIONS(259),
    [sym_keyword_explain] = ACTIONS(259),
    [sym_keyword_parallel] = ACTIONS(259),
    [sym_keyword_timeout] = ACTIONS(259),
    [sym_keyword_fetch] = ACTIONS(259),
    [sym_keyword_limit] = ACTIONS(259),
    [sym_keyword_rand] = ACTIONS(259),
    [sym_keyword_collate] = ACTIONS(259),
    [sym_keyword_numeric] = ACTIONS(259),
    [sym_keyword_asc] = ACTIONS(259),
    [sym_keyword_desc] = ACTIONS(259),
    [sym_keyword_where] = ACTIONS(259),
    [sym_keyword_and] = ACTIONS(259),
    [sym_keyword_or] = ACTIONS(259),
    [sym_keyword_is] = ACTIONS(259),
    [sym_keyword_not] = ACTIONS(261),
    [sym_keyword_contains] = ACTIONS(259),
    [sym_keyword_contains_not] = ACTIONS(259),
    [sym_keyword_contains_all] = ACTIONS(259),
    [sym_keyword_contains_any] = ACTIONS(259),
    [sym_keyword_contains_none] = ACTIONS(259),
    [sym_keyword_inside] = ACTIONS(259),
    [sym_keyword_in] = ACTIONS(261),
    [sym_keyword_not_inside] = ACTIONS(259),
    [sym_keyword_all_inside] = ACTIONS(259),
    [sym_keyword_any_inside] = ACTIONS(259),
    [sym_keyword_none_inside] = ACTIONS(259),
    [sym_keyword_outside] = ACTIONS(259),
    [sym_keyword_intersects] = ACTIONS(259),
    [sym_keyword_flexible] = ACTIONS(259),
    [sym_keyword_readonly] = ACTIONS(259),
    [sym_keyword_content] = ACTIONS(259),
    [sym_keyword_merge] = ACTIONS(259),
    [sym_keyword_patch] = ACTIONS(259),
    [sym_keyword_type] = ACTIONS(259),
    [sym_keyword_default] = ACTIONS(259),
    [sym_keyword_assert] = ACTIONS(259),
    [sym_keyword_permissions] = ACTIONS(259),
    [sym_keyword_for] = ACTIONS(259),
    [sym_keyword_comment] = ACTIONS(259),
    [sym_keyword_set] = ACTIONS(259),
    [sym_keyword_unset] = ACTIONS(259),
    [anon_sym_COMMA] = ACTIONS(259),
    [anon_sym_DASH_GT] = ACTIONS(259),
    [anon_sym_RPAREN] = ACTIONS(259),
    [anon_sym_RBRACE] = ACTIONS(259),
    [anon_sym_STAR] = ACTIONS(261),
    [anon_sym_LT] = ACTIONS(261),
    [anon_sym_GT] = ACTIONS(261),
    [anon_sym_EQ] = ACTIONS(261),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_AT] = ACTIONS(261),
    [anon_sym_LT_PIPE] = ACTIONS(259),
    [anon_sym_AMP_AMP] = ACTIONS(259),
    [anon_sym_PIPE_PIPE] = ACTIONS(259),
    [anon_sym_QMARK_QMARK] = ACTIONS(259),
    [anon_sym_QMARK_COLON] = ACTIONS(259),
    [anon_sym_BANG_EQ] = ACTIONS(259),
    [anon_sym_EQ_EQ] = ACTIONS(259),
    [anon_sym_QMARK_EQ] = ACTIONS(259),
    [anon_sym_STAR_EQ] = ACTIONS(259),
    [anon_sym_TILDE] = ACTIONS(259),
    [anon_sym_BANG_TILDE] = ACTIONS(259),
    [anon_sym_STAR_TILDE] = ACTIONS(259),
    [anon_sym_LT_EQ] = ACTIONS(259),
    [anon_sym_GT_EQ] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(261),
    [anon_sym_PLUS_EQ] = ACTIONS(259),
    [anon_sym_DASH_EQ] = ACTIONS(259),
    [anon_sym_u00d7] = ACTIONS(259),
    [anon_sym_SLASH] = ACTIONS(261),
    [anon_sym_u00f7] = ACTIONS(259),
    [anon_sym_STAR_STAR] = ACTIONS(259),
    [anon_sym_u220b] = ACTIONS(259),
    [anon_sym_u220c] = ACTIONS(259),
    [anon_sym_u2287] = ACTIONS(259),
    [anon_sym_u2283] = ACTIONS(259),
    [anon_sym_u2285] = ACTIONS(259),
    [anon_sym_u2208] = ACTIONS(259),
    [anon_sym_u2209] = ACTIONS(259),
    [anon_sym_u2286] = ACTIONS(259),
    [anon_sym_u2282] = ACTIONS(259),
    [anon_sym_u2284] = ACTIONS(259),
    [anon_sym_AT_AT] = ACTIONS(259),
  },
  [77] = {
    [ts_builtin_sym_end] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(251),
    [sym_keyword_return] = ACTIONS(251),
    [sym_keyword_value] = ACTIONS(251),
    [sym_keyword_explain] = ACTIONS(251),
    [sym_keyword_parallel] = ACTIONS(251),
    [sym_keyword_timeout] = ACTIONS(251),
    [sym_keyword_fetch] = ACTIONS(251),
    [sym_keyword_limit] = ACTIONS(251),
    [sym_keyword_rand] = ACTIONS(251),
    [sym_keyword_collate] = ACTIONS(251),
    [sym_keyword_numeric] = ACTIONS(251),
    [sym_keyword_asc] = ACTIONS(251),
    [sym_keyword_desc] = ACTIONS(251),
    [sym_keyword_where] = ACTIONS(251),
    [sym_keyword_and] = ACTIONS(251),
    [sym_keyword_or] = ACTIONS(251),
    [sym_keyword_is] = ACTIONS(251),
    [sym_keyword_not] = ACTIONS(253),
    [sym_keyword_contains] = ACTIONS(251),
    [sym_keyword_contains_not] = ACTIONS(251),
    [sym_keyword_contains_all] = ACTIONS(251),
    [sym_keyword_contains_any] = ACTIONS(251),
    [sym_keyword_contains_none] = ACTIONS(251),
    [sym_keyword_inside] = ACTIONS(251),
    [sym_keyword_in] = ACTIONS(253),
    [sym_keyword_not_inside] = ACTIONS(251),
    [sym_keyword_all_inside] = ACTIONS(251),
    [sym_keyword_any_inside] = ACTIONS(251),
    [sym_keyword_none_inside] = ACTIONS(251),
    [sym_keyword_outside] = ACTIONS(251),
    [sym_keyword_intersects] = ACTIONS(251),
    [sym_keyword_flexible] = ACTIONS(251),
    [sym_keyword_readonly] = ACTIONS(251),
    [sym_keyword_content] = ACTIONS(251),
    [sym_keyword_merge] = ACTIONS(251),
    [sym_keyword_patch] = ACTIONS(251),
    [sym_keyword_type] = ACTIONS(251),
    [sym_keyword_default] = ACTIONS(251),
    [sym_keyword_assert] = ACTIONS(251),
    [sym_keyword_permissions] = ACTIONS(251),
    [sym_keyword_for] = ACTIONS(251),
    [sym_keyword_comment] = ACTIONS(251),
    [sym_keyword_set] = ACTIONS(251),
    [sym_keyword_unset] = ACTIONS(251),
    [anon_sym_COMMA] = ACTIONS(251),
    [anon_sym_DASH_GT] = ACTIONS(251),
    [anon_sym_RPAREN] = ACTIONS(251),
    [anon_sym_RBRACE] = ACTIONS(251),
    [anon_sym_STAR] = ACTIONS(253),
    [anon_sym_LT] = ACTIONS(253),
    [anon_sym_GT] = ACTIONS(253),
    [anon_sym_EQ] = ACTIONS(253),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_AT] = ACTIONS(253),
    [anon_sym_LT_PIPE] = ACTIONS(251),
    [anon_sym_AMP_AMP] = ACTIONS(251),
    [anon_sym_PIPE_PIPE] = ACTIONS(251),
    [anon_sym_QMARK_QMARK] = ACTIONS(251),
    [anon_sym_QMARK_COLON] = ACTIONS(251),
    [anon_sym_BANG_EQ] = ACTIONS(251),
    [anon_sym_EQ_EQ] = ACTIONS(251),
    [anon_sym_QMARK_EQ] = ACTIONS(251),
    [anon_sym_STAR_EQ] = ACTIONS(251),
    [anon_sym_TILDE] = ACTIONS(251),
    [anon_sym_BANG_TILDE] = ACTIONS(251),
    [anon_sym_STAR_TILDE] = ACTIONS(251),
    [anon_sym_LT_EQ] = ACTIONS(251),
    [anon_sym_GT_EQ] = ACTIONS(251),
    [anon_sym_PLUS] = ACTIONS(253),
    [anon_sym_PLUS_EQ] = ACTIONS(251),
    [anon_sym_DASH_EQ] = ACTIONS(251),
    [anon_sym_u00d7] = ACTIONS(251),
    [anon_sym_SLASH] = ACTIONS(253),
    [anon_sym_u00f7] = ACTIONS(251),
    [anon_sym_STAR_STAR] = ACTIONS(251),
    [anon_sym_u220b] = ACTIONS(251),
    [anon_sym_u220c] = ACTIONS(251),
    [anon_sym_u2287] = ACTIONS(251),
    [anon_sym_u2283] = ACTIONS(251),
    [anon_sym_u2285] = ACTIONS(251),
    [anon_sym_u2208] = ACTIONS(251),
    [anon_sym_u2209] = ACTIONS(251),
    [anon_sym_u2286] = ACTIONS(251),
    [anon_sym_u2282] = ACTIONS(251),
    [anon_sym_u2284] = ACTIONS(251),
    [anon_sym_AT_AT] = ACTIONS(251),
  },
  [78] = {
    [sym_filter] = STATE(64),
    [sym_path_element] = STATE(78),
    [sym_graph_path] = STATE(64),
    [sym_subscript] = STATE(64),
    [aux_sym_path_repeat1] = STATE(78),
    [ts_builtin_sym_end] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(75),
    [sym_keyword_value] = ACTIONS(75),
    [sym_keyword_explain] = ACTIONS(75),
    [sym_keyword_parallel] = ACTIONS(75),
    [sym_keyword_timeout] = ACTIONS(75),
    [sym_keyword_fetch] = ACTIONS(75),
    [sym_keyword_limit] = ACTIONS(75),
    [sym_keyword_rand] = ACTIONS(75),
    [sym_keyword_collate] = ACTIONS(75),
    [sym_keyword_numeric] = ACTIONS(75),
    [sym_keyword_asc] = ACTIONS(75),
    [sym_keyword_desc] = ACTIONS(75),
    [sym_keyword_and] = ACTIONS(75),
    [sym_keyword_or] = ACTIONS(75),
    [sym_keyword_is] = ACTIONS(75),
    [sym_keyword_not] = ACTIONS(77),
    [sym_keyword_contains] = ACTIONS(75),
    [sym_keyword_contains_not] = ACTIONS(75),
    [sym_keyword_contains_all] = ACTIONS(75),
    [sym_keyword_contains_any] = ACTIONS(75),
    [sym_keyword_contains_none] = ACTIONS(75),
    [sym_keyword_inside] = ACTIONS(75),
    [sym_keyword_in] = ACTIONS(77),
    [sym_keyword_not_inside] = ACTIONS(75),
    [sym_keyword_all_inside] = ACTIONS(75),
    [sym_keyword_any_inside] = ACTIONS(75),
    [sym_keyword_none_inside] = ACTIONS(75),
    [sym_keyword_outside] = ACTIONS(75),
    [sym_keyword_intersects] = ACTIONS(75),
    [sym_keyword_flexible] = ACTIONS(75),
    [sym_keyword_readonly] = ACTIONS(75),
    [sym_keyword_type] = ACTIONS(75),
    [sym_keyword_default] = ACTIONS(75),
    [sym_keyword_assert] = ACTIONS(75),
    [sym_keyword_permissions] = ACTIONS(75),
    [sym_keyword_for] = ACTIONS(75),
    [sym_keyword_comment] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(75),
    [anon_sym_DASH_GT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(266),
    [anon_sym_LT_DASH] = ACTIONS(269),
    [anon_sym_LT_DASH_GT] = ACTIONS(263),
    [anon_sym_STAR] = ACTIONS(77),
    [anon_sym_DOT] = ACTIONS(272),
    [anon_sym_LT] = ACTIONS(77),
    [anon_sym_GT] = ACTIONS(77),
    [anon_sym_EQ] = ACTIONS(77),
    [anon_sym_DASH] = ACTIONS(77),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LT_PIPE] = ACTIONS(75),
    [anon_sym_AMP_AMP] = ACTIONS(75),
    [anon_sym_PIPE_PIPE] = ACTIONS(75),
    [anon_sym_QMARK_QMARK] = ACTIONS(75),
    [anon_sym_QMARK_COLON] = ACTIONS(75),
    [anon_sym_BANG_EQ] = ACTIONS(75),
    [anon_sym_EQ_EQ] = ACTIONS(75),
    [anon_sym_QMARK_EQ] = ACTIONS(75),
    [anon_sym_STAR_EQ] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_BANG_TILDE] = ACTIONS(75),
    [anon_sym_STAR_TILDE] = ACTIONS(75),
    [anon_sym_LT_EQ] = ACTIONS(75),
    [anon_sym_GT_EQ] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(77),
    [anon_sym_PLUS_EQ] = ACTIONS(75),
    [anon_sym_DASH_EQ] = ACTIONS(75),
    [anon_sym_u00d7] = ACTIONS(75),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_u00f7] = ACTIONS(75),
    [anon_sym_STAR_STAR] = ACTIONS(75),
    [anon_sym_u220b] = ACTIONS(75),
    [anon_sym_u220c] = ACTIONS(75),
    [anon_sym_u2287] = ACTIONS(75),
    [anon_sym_u2283] = ACTIONS(75),
    [anon_sym_u2285] = ACTIONS(75),
    [anon_sym_u2208] = ACTIONS(75),
    [anon_sym_u2209] = ACTIONS(75),
    [anon_sym_u2286] = ACTIONS(75),
    [anon_sym_u2282] = ACTIONS(75),
    [anon_sym_u2284] = ACTIONS(75),
    [anon_sym_AT_AT] = ACTIONS(75),
  },
  [79] = {
    [ts_builtin_sym_end] = ACTIONS(150),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(150),
    [sym_keyword_return] = ACTIONS(150),
    [sym_keyword_value] = ACTIONS(150),
    [sym_keyword_explain] = ACTIONS(150),
    [sym_keyword_parallel] = ACTIONS(150),
    [sym_keyword_timeout] = ACTIONS(150),
    [sym_keyword_fetch] = ACTIONS(150),
    [sym_keyword_limit] = ACTIONS(150),
    [sym_keyword_rand] = ACTIONS(150),
    [sym_keyword_collate] = ACTIONS(150),
    [sym_keyword_numeric] = ACTIONS(150),
    [sym_keyword_asc] = ACTIONS(150),
    [sym_keyword_desc] = ACTIONS(150),
    [sym_keyword_where] = ACTIONS(150),
    [sym_keyword_and] = ACTIONS(150),
    [sym_keyword_or] = ACTIONS(150),
    [sym_keyword_is] = ACTIONS(150),
    [sym_keyword_not] = ACTIONS(152),
    [sym_keyword_contains] = ACTIONS(150),
    [sym_keyword_contains_not] = ACTIONS(150),
    [sym_keyword_contains_all] = ACTIONS(150),
    [sym_keyword_contains_any] = ACTIONS(150),
    [sym_keyword_contains_none] = ACTIONS(150),
    [sym_keyword_inside] = ACTIONS(150),
    [sym_keyword_in] = ACTIONS(152),
    [sym_keyword_not_inside] = ACTIONS(150),
    [sym_keyword_all_inside] = ACTIONS(150),
    [sym_keyword_any_inside] = ACTIONS(150),
    [sym_keyword_none_inside] = ACTIONS(150),
    [sym_keyword_outside] = ACTIONS(150),
    [sym_keyword_intersects] = ACTIONS(150),
    [sym_keyword_flexible] = ACTIONS(150),
    [sym_keyword_readonly] = ACTIONS(150),
    [sym_keyword_content] = ACTIONS(150),
    [sym_keyword_merge] = ACTIONS(150),
    [sym_keyword_patch] = ACTIONS(150),
    [sym_keyword_type] = ACTIONS(150),
    [sym_keyword_default] = ACTIONS(150),
    [sym_keyword_assert] = ACTIONS(150),
    [sym_keyword_permissions] = ACTIONS(150),
    [sym_keyword_for] = ACTIONS(150),
    [sym_keyword_comment] = ACTIONS(150),
    [sym_keyword_set] = ACTIONS(150),
    [sym_keyword_unset] = ACTIONS(150),
    [anon_sym_COMMA] = ACTIONS(150),
    [anon_sym_DASH_GT] = ACTIONS(150),
    [anon_sym_RPAREN] = ACTIONS(150),
    [anon_sym_RBRACE] = ACTIONS(150),
    [anon_sym_STAR] = ACTIONS(152),
    [anon_sym_LT] = ACTIONS(152),
    [anon_sym_GT] = ACTIONS(152),
    [anon_sym_EQ] = ACTIONS(152),
    [anon_sym_DASH] = ACTIONS(152),
    [anon_sym_AT] = ACTIONS(152),
    [anon_sym_LT_PIPE] = ACTIONS(150),
    [anon_sym_AMP_AMP] = ACTIONS(150),
    [anon_sym_PIPE_PIPE] = ACTIONS(150),
    [anon_sym_QMARK_QMARK] = ACTIONS(150),
    [anon_sym_QMARK_COLON] = ACTIONS(150),
    [anon_sym_BANG_EQ] = ACTIONS(150),
    [anon_sym_EQ_EQ] = ACTIONS(150),
    [anon_sym_QMARK_EQ] = ACTIONS(150),
    [anon_sym_STAR_EQ] = ACTIONS(150),
    [anon_sym_TILDE] = ACTIONS(150),
    [anon_sym_BANG_TILDE] = ACTIONS(150),
    [anon_sym_STAR_TILDE] = ACTIONS(150),
    [anon_sym_LT_EQ] = ACTIONS(150),
    [anon_sym_GT_EQ] = ACTIONS(150),
    [anon_sym_PLUS] = ACTIONS(152),
    [anon_sym_PLUS_EQ] = ACTIONS(150),
    [anon_sym_DASH_EQ] = ACTIONS(150),
    [anon_sym_u00d7] = ACTIONS(150),
    [anon_sym_SLASH] = ACTIONS(152),
    [anon_sym_u00f7] = ACTIONS(150),
    [anon_sym_STAR_STAR] = ACTIONS(150),
    [anon_sym_u220b] = ACTIONS(150),
    [anon_sym_u220c] = ACTIONS(150),
    [anon_sym_u2287] = ACTIONS(150),
    [anon_sym_u2283] = ACTIONS(150),
    [anon_sym_u2285] = ACTIONS(150),
    [anon_sym_u2208] = ACTIONS(150),
    [anon_sym_u2209] = ACTIONS(150),
    [anon_sym_u2286] = ACTIONS(150),
    [anon_sym_u2282] = ACTIONS(150),
    [anon_sym_u2284] = ACTIONS(150),
    [anon_sym_AT_AT] = ACTIONS(150),
  },
  [80] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(198),
    [sym_keyword_return] = ACTIONS(198),
    [sym_keyword_from] = ACTIONS(198),
    [sym_keyword_as] = ACTIONS(198),
    [sym_keyword_parallel] = ACTIONS(198),
    [sym_keyword_timeout] = ACTIONS(198),
    [sym_keyword_where] = ACTIONS(198),
    [sym_keyword_group] = ACTIONS(198),
    [sym_keyword_and] = ACTIONS(198),
    [sym_keyword_or] = ACTIONS(198),
    [sym_keyword_is] = ACTIONS(198),
    [sym_keyword_not] = ACTIONS(200),
    [sym_keyword_contains] = ACTIONS(198),
    [sym_keyword_contains_not] = ACTIONS(198),
    [sym_keyword_contains_all] = ACTIONS(198),
    [sym_keyword_contains_any] = ACTIONS(198),
    [sym_keyword_contains_none] = ACTIONS(198),
    [sym_keyword_inside] = ACTIONS(198),
    [sym_keyword_in] = ACTIONS(200),
    [sym_keyword_not_inside] = ACTIONS(198),
    [sym_keyword_all_inside] = ACTIONS(198),
    [sym_keyword_any_inside] = ACTIONS(198),
    [sym_keyword_none_inside] = ACTIONS(198),
    [sym_keyword_outside] = ACTIONS(198),
    [sym_keyword_intersects] = ACTIONS(198),
    [sym_keyword_drop] = ACTIONS(198),
    [sym_keyword_schemafull] = ACTIONS(198),
    [sym_keyword_schemaless] = ACTIONS(198),
    [sym_keyword_changefeed] = ACTIONS(198),
    [sym_keyword_content] = ACTIONS(198),
    [sym_keyword_merge] = ACTIONS(198),
    [sym_keyword_patch] = ACTIONS(198),
    [sym_keyword_then] = ACTIONS(198),
    [sym_keyword_type] = ACTIONS(198),
    [sym_keyword_permissions] = ACTIONS(198),
    [sym_keyword_for] = ACTIONS(198),
    [sym_keyword_comment] = ACTIONS(198),
    [sym_keyword_if] = ACTIONS(198),
    [sym_keyword_set] = ACTIONS(198),
    [sym_keyword_unset] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(198),
    [anon_sym_RBRACK] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(198),
    [anon_sym_RPAREN] = ACTIONS(198),
    [anon_sym_QMARK] = ACTIONS(200),
    [anon_sym_LBRACE] = ACTIONS(198),
    [anon_sym_RBRACE] = ACTIONS(198),
    [anon_sym_STAR] = ACTIONS(200),
    [anon_sym_LT] = ACTIONS(200),
    [anon_sym_GT] = ACTIONS(200),
    [sym_variable_name] = ACTIONS(198),
    [sym_custom_function_name] = ACTIONS(198),
    [anon_sym_EQ] = ACTIONS(200),
    [anon_sym_DASH] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(200),
    [anon_sym_LT_PIPE] = ACTIONS(198),
    [anon_sym_AMP_AMP] = ACTIONS(198),
    [anon_sym_PIPE_PIPE] = ACTIONS(198),
    [anon_sym_QMARK_QMARK] = ACTIONS(198),
    [anon_sym_QMARK_COLON] = ACTIONS(198),
    [anon_sym_BANG_EQ] = ACTIONS(198),
    [anon_sym_EQ_EQ] = ACTIONS(198),
    [anon_sym_QMARK_EQ] = ACTIONS(198),
    [anon_sym_STAR_EQ] = ACTIONS(198),
    [anon_sym_TILDE] = ACTIONS(198),
    [anon_sym_BANG_TILDE] = ACTIONS(198),
    [anon_sym_STAR_TILDE] = ACTIONS(198),
    [anon_sym_LT_EQ] = ACTIONS(198),
    [anon_sym_GT_EQ] = ACTIONS(198),
    [anon_sym_PLUS] = ACTIONS(200),
    [anon_sym_PLUS_EQ] = ACTIONS(198),
    [anon_sym_DASH_EQ] = ACTIONS(198),
    [anon_sym_u00d7] = ACTIONS(198),
    [anon_sym_SLASH] = ACTIONS(200),
    [anon_sym_u00f7] = ACTIONS(198),
    [anon_sym_STAR_STAR] = ACTIONS(198),
    [anon_sym_u220b] = ACTIONS(198),
    [anon_sym_u220c] = ACTIONS(198),
    [anon_sym_u2287] = ACTIONS(198),
    [anon_sym_u2283] = ACTIONS(198),
    [anon_sym_u2285] = ACTIONS(198),
    [anon_sym_u2208] = ACTIONS(198),
    [anon_sym_u2209] = ACTIONS(198),
    [anon_sym_u2286] = ACTIONS(198),
    [anon_sym_u2282] = ACTIONS(198),
    [anon_sym_u2284] = ACTIONS(198),
    [anon_sym_AT_AT] = ACTIONS(198),
  },
  [81] = {
    [sym_filter] = STATE(64),
    [sym_path_element] = STATE(82),
    [sym_graph_path] = STATE(64),
    [sym_subscript] = STATE(64),
    [aux_sym_path_repeat1] = STATE(82),
    [ts_builtin_sym_end] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(71),
    [sym_keyword_value] = ACTIONS(71),
    [sym_keyword_explain] = ACTIONS(71),
    [sym_keyword_parallel] = ACTIONS(71),
    [sym_keyword_timeout] = ACTIONS(71),
    [sym_keyword_fetch] = ACTIONS(71),
    [sym_keyword_limit] = ACTIONS(71),
    [sym_keyword_rand] = ACTIONS(71),
    [sym_keyword_collate] = ACTIONS(71),
    [sym_keyword_numeric] = ACTIONS(71),
    [sym_keyword_asc] = ACTIONS(71),
    [sym_keyword_desc] = ACTIONS(71),
    [sym_keyword_and] = ACTIONS(71),
    [sym_keyword_or] = ACTIONS(71),
    [sym_keyword_is] = ACTIONS(71),
    [sym_keyword_not] = ACTIONS(73),
    [sym_keyword_contains] = ACTIONS(71),
    [sym_keyword_contains_not] = ACTIONS(71),
    [sym_keyword_contains_all] = ACTIONS(71),
    [sym_keyword_contains_any] = ACTIONS(71),
    [sym_keyword_contains_none] = ACTIONS(71),
    [sym_keyword_inside] = ACTIONS(71),
    [sym_keyword_in] = ACTIONS(73),
    [sym_keyword_not_inside] = ACTIONS(71),
    [sym_keyword_all_inside] = ACTIONS(71),
    [sym_keyword_any_inside] = ACTIONS(71),
    [sym_keyword_none_inside] = ACTIONS(71),
    [sym_keyword_outside] = ACTIONS(71),
    [sym_keyword_intersects] = ACTIONS(71),
    [sym_keyword_flexible] = ACTIONS(71),
    [sym_keyword_readonly] = ACTIONS(71),
    [sym_keyword_type] = ACTIONS(71),
    [sym_keyword_default] = ACTIONS(71),
    [sym_keyword_assert] = ACTIONS(71),
    [sym_keyword_permissions] = ACTIONS(71),
    [sym_keyword_for] = ACTIONS(71),
    [sym_keyword_comment] = ACTIONS(71),
    [anon_sym_COMMA] = ACTIONS(71),
    [anon_sym_DASH_GT] = ACTIONS(243),
    [anon_sym_LBRACK] = ACTIONS(245),
    [anon_sym_LT_DASH] = ACTIONS(247),
    [anon_sym_LT_DASH_GT] = ACTIONS(243),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_DOT] = ACTIONS(249),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(73),
    [anon_sym_LT_PIPE] = ACTIONS(71),
    [anon_sym_AMP_AMP] = ACTIONS(71),
    [anon_sym_PIPE_PIPE] = ACTIONS(71),
    [anon_sym_QMARK_QMARK] = ACTIONS(71),
    [anon_sym_QMARK_COLON] = ACTIONS(71),
    [anon_sym_BANG_EQ] = ACTIONS(71),
    [anon_sym_EQ_EQ] = ACTIONS(71),
    [anon_sym_QMARK_EQ] = ACTIONS(71),
    [anon_sym_STAR_EQ] = ACTIONS(71),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_BANG_TILDE] = ACTIONS(71),
    [anon_sym_STAR_TILDE] = ACTIONS(71),
    [anon_sym_LT_EQ] = ACTIONS(71),
    [anon_sym_GT_EQ] = ACTIONS(71),
    [anon_sym_PLUS] = ACTIONS(73),
    [anon_sym_PLUS_EQ] = ACTIONS(71),
    [anon_sym_DASH_EQ] = ACTIONS(71),
    [anon_sym_u00d7] = ACTIONS(71),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_u00f7] = ACTIONS(71),
    [anon_sym_STAR_STAR] = ACTIONS(71),
    [anon_sym_u220b] = ACTIONS(71),
    [anon_sym_u220c] = ACTIONS(71),
    [anon_sym_u2287] = ACTIONS(71),
    [anon_sym_u2283] = ACTIONS(71),
    [anon_sym_u2285] = ACTIONS(71),
    [anon_sym_u2208] = ACTIONS(71),
    [anon_sym_u2209] = ACTIONS(71),
    [anon_sym_u2286] = ACTIONS(71),
    [anon_sym_u2282] = ACTIONS(71),
    [anon_sym_u2284] = ACTIONS(71),
    [anon_sym_AT_AT] = ACTIONS(71),
  },
  [82] = {
    [sym_filter] = STATE(64),
    [sym_path_element] = STATE(78),
    [sym_graph_path] = STATE(64),
    [sym_subscript] = STATE(64),
    [aux_sym_path_repeat1] = STATE(78),
    [ts_builtin_sym_end] = ACTIONS(91),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(91),
    [sym_keyword_value] = ACTIONS(91),
    [sym_keyword_explain] = ACTIONS(91),
    [sym_keyword_parallel] = ACTIONS(91),
    [sym_keyword_timeout] = ACTIONS(91),
    [sym_keyword_fetch] = ACTIONS(91),
    [sym_keyword_limit] = ACTIONS(91),
    [sym_keyword_rand] = ACTIONS(91),
    [sym_keyword_collate] = ACTIONS(91),
    [sym_keyword_numeric] = ACTIONS(91),
    [sym_keyword_asc] = ACTIONS(91),
    [sym_keyword_desc] = ACTIONS(91),
    [sym_keyword_and] = ACTIONS(91),
    [sym_keyword_or] = ACTIONS(91),
    [sym_keyword_is] = ACTIONS(91),
    [sym_keyword_not] = ACTIONS(93),
    [sym_keyword_contains] = ACTIONS(91),
    [sym_keyword_contains_not] = ACTIONS(91),
    [sym_keyword_contains_all] = ACTIONS(91),
    [sym_keyword_contains_any] = ACTIONS(91),
    [sym_keyword_contains_none] = ACTIONS(91),
    [sym_keyword_inside] = ACTIONS(91),
    [sym_keyword_in] = ACTIONS(93),
    [sym_keyword_not_inside] = ACTIONS(91),
    [sym_keyword_all_inside] = ACTIONS(91),
    [sym_keyword_any_inside] = ACTIONS(91),
    [sym_keyword_none_inside] = ACTIONS(91),
    [sym_keyword_outside] = ACTIONS(91),
    [sym_keyword_intersects] = ACTIONS(91),
    [sym_keyword_flexible] = ACTIONS(91),
    [sym_keyword_readonly] = ACTIONS(91),
    [sym_keyword_type] = ACTIONS(91),
    [sym_keyword_default] = ACTIONS(91),
    [sym_keyword_assert] = ACTIONS(91),
    [sym_keyword_permissions] = ACTIONS(91),
    [sym_keyword_for] = ACTIONS(91),
    [sym_keyword_comment] = ACTIONS(91),
    [anon_sym_COMMA] = ACTIONS(91),
    [anon_sym_DASH_GT] = ACTIONS(243),
    [anon_sym_LBRACK] = ACTIONS(245),
    [anon_sym_LT_DASH] = ACTIONS(247),
    [anon_sym_LT_DASH_GT] = ACTIONS(243),
    [anon_sym_STAR] = ACTIONS(93),
    [anon_sym_DOT] = ACTIONS(249),
    [anon_sym_LT] = ACTIONS(93),
    [anon_sym_GT] = ACTIONS(93),
    [anon_sym_EQ] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(93),
    [anon_sym_AT] = ACTIONS(93),
    [anon_sym_LT_PIPE] = ACTIONS(91),
    [anon_sym_AMP_AMP] = ACTIONS(91),
    [anon_sym_PIPE_PIPE] = ACTIONS(91),
    [anon_sym_QMARK_QMARK] = ACTIONS(91),
    [anon_sym_QMARK_COLON] = ACTIONS(91),
    [anon_sym_BANG_EQ] = ACTIONS(91),
    [anon_sym_EQ_EQ] = ACTIONS(91),
    [anon_sym_QMARK_EQ] = ACTIONS(91),
    [anon_sym_STAR_EQ] = ACTIONS(91),
    [anon_sym_TILDE] = ACTIONS(91),
    [anon_sym_BANG_TILDE] = ACTIONS(91),
    [anon_sym_STAR_TILDE] = ACTIONS(91),
    [anon_sym_LT_EQ] = ACTIONS(91),
    [anon_sym_GT_EQ] = ACTIONS(91),
    [anon_sym_PLUS] = ACTIONS(93),
    [anon_sym_PLUS_EQ] = ACTIONS(91),
    [anon_sym_DASH_EQ] = ACTIONS(91),
    [anon_sym_u00d7] = ACTIONS(91),
    [anon_sym_SLASH] = ACTIONS(93),
    [anon_sym_u00f7] = ACTIONS(91),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_u220b] = ACTIONS(91),
    [anon_sym_u220c] = ACTIONS(91),
    [anon_sym_u2287] = ACTIONS(91),
    [anon_sym_u2283] = ACTIONS(91),
    [anon_sym_u2285] = ACTIONS(91),
    [anon_sym_u2208] = ACTIONS(91),
    [anon_sym_u2209] = ACTIONS(91),
    [anon_sym_u2286] = ACTIONS(91),
    [anon_sym_u2282] = ACTIONS(91),
    [anon_sym_u2284] = ACTIONS(91),
    [anon_sym_AT_AT] = ACTIONS(91),
  },
  [83] = {
    [ts_builtin_sym_end] = ACTIONS(239),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(239),
    [sym_keyword_return] = ACTIONS(239),
    [sym_keyword_value] = ACTIONS(239),
    [sym_keyword_explain] = ACTIONS(239),
    [sym_keyword_parallel] = ACTIONS(239),
    [sym_keyword_timeout] = ACTIONS(239),
    [sym_keyword_fetch] = ACTIONS(239),
    [sym_keyword_limit] = ACTIONS(239),
    [sym_keyword_rand] = ACTIONS(239),
    [sym_keyword_collate] = ACTIONS(239),
    [sym_keyword_numeric] = ACTIONS(239),
    [sym_keyword_asc] = ACTIONS(239),
    [sym_keyword_desc] = ACTIONS(239),
    [sym_keyword_where] = ACTIONS(239),
    [sym_keyword_and] = ACTIONS(239),
    [sym_keyword_or] = ACTIONS(239),
    [sym_keyword_is] = ACTIONS(239),
    [sym_keyword_not] = ACTIONS(241),
    [sym_keyword_contains] = ACTIONS(239),
    [sym_keyword_contains_not] = ACTIONS(239),
    [sym_keyword_contains_all] = ACTIONS(239),
    [sym_keyword_contains_any] = ACTIONS(239),
    [sym_keyword_contains_none] = ACTIONS(239),
    [sym_keyword_inside] = ACTIONS(239),
    [sym_keyword_in] = ACTIONS(241),
    [sym_keyword_not_inside] = ACTIONS(239),
    [sym_keyword_all_inside] = ACTIONS(239),
    [sym_keyword_any_inside] = ACTIONS(239),
    [sym_keyword_none_inside] = ACTIONS(239),
    [sym_keyword_outside] = ACTIONS(239),
    [sym_keyword_intersects] = ACTIONS(239),
    [sym_keyword_flexible] = ACTIONS(239),
    [sym_keyword_readonly] = ACTIONS(239),
    [sym_keyword_content] = ACTIONS(239),
    [sym_keyword_merge] = ACTIONS(239),
    [sym_keyword_patch] = ACTIONS(239),
    [sym_keyword_type] = ACTIONS(239),
    [sym_keyword_default] = ACTIONS(239),
    [sym_keyword_assert] = ACTIONS(239),
    [sym_keyword_permissions] = ACTIONS(239),
    [sym_keyword_for] = ACTIONS(239),
    [sym_keyword_comment] = ACTIONS(239),
    [sym_keyword_set] = ACTIONS(239),
    [sym_keyword_unset] = ACTIONS(239),
    [anon_sym_COMMA] = ACTIONS(239),
    [anon_sym_DASH_GT] = ACTIONS(239),
    [anon_sym_RPAREN] = ACTIONS(239),
    [anon_sym_RBRACE] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(241),
    [anon_sym_LT] = ACTIONS(241),
    [anon_sym_GT] = ACTIONS(241),
    [anon_sym_EQ] = ACTIONS(241),
    [anon_sym_DASH] = ACTIONS(241),
    [anon_sym_AT] = ACTIONS(241),
    [anon_sym_LT_PIPE] = ACTIONS(239),
    [anon_sym_AMP_AMP] = ACTIONS(239),
    [anon_sym_PIPE_PIPE] = ACTIONS(239),
    [anon_sym_QMARK_QMARK] = ACTIONS(239),
    [anon_sym_QMARK_COLON] = ACTIONS(239),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(239),
    [anon_sym_QMARK_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_TILDE] = ACTIONS(239),
    [anon_sym_BANG_TILDE] = ACTIONS(239),
    [anon_sym_STAR_TILDE] = ACTIONS(239),
    [anon_sym_LT_EQ] = ACTIONS(239),
    [anon_sym_GT_EQ] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(241),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_u00d7] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(241),
    [anon_sym_u00f7] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_u220b] = ACTIONS(239),
    [anon_sym_u220c] = ACTIONS(239),
    [anon_sym_u2287] = ACTIONS(239),
    [anon_sym_u2283] = ACTIONS(239),
    [anon_sym_u2285] = ACTIONS(239),
    [anon_sym_u2208] = ACTIONS(239),
    [anon_sym_u2209] = ACTIONS(239),
    [anon_sym_u2286] = ACTIONS(239),
    [anon_sym_u2282] = ACTIONS(239),
    [anon_sym_u2284] = ACTIONS(239),
    [anon_sym_AT_AT] = ACTIONS(239),
  },
  [84] = {
    [ts_builtin_sym_end] = ACTIONS(275),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(275),
    [sym_keyword_return] = ACTIONS(275),
    [sym_keyword_value] = ACTIONS(275),
    [sym_keyword_explain] = ACTIONS(275),
    [sym_keyword_parallel] = ACTIONS(275),
    [sym_keyword_timeout] = ACTIONS(275),
    [sym_keyword_fetch] = ACTIONS(275),
    [sym_keyword_limit] = ACTIONS(275),
    [sym_keyword_rand] = ACTIONS(275),
    [sym_keyword_collate] = ACTIONS(275),
    [sym_keyword_numeric] = ACTIONS(275),
    [sym_keyword_asc] = ACTIONS(275),
    [sym_keyword_desc] = ACTIONS(275),
    [sym_keyword_where] = ACTIONS(275),
    [sym_keyword_and] = ACTIONS(275),
    [sym_keyword_or] = ACTIONS(275),
    [sym_keyword_is] = ACTIONS(275),
    [sym_keyword_not] = ACTIONS(277),
    [sym_keyword_contains] = ACTIONS(275),
    [sym_keyword_contains_not] = ACTIONS(275),
    [sym_keyword_contains_all] = ACTIONS(275),
    [sym_keyword_contains_any] = ACTIONS(275),
    [sym_keyword_contains_none] = ACTIONS(275),
    [sym_keyword_inside] = ACTIONS(275),
    [sym_keyword_in] = ACTIONS(277),
    [sym_keyword_not_inside] = ACTIONS(275),
    [sym_keyword_all_inside] = ACTIONS(275),
    [sym_keyword_any_inside] = ACTIONS(275),
    [sym_keyword_none_inside] = ACTIONS(275),
    [sym_keyword_outside] = ACTIONS(275),
    [sym_keyword_intersects] = ACTIONS(275),
    [sym_keyword_flexible] = ACTIONS(275),
    [sym_keyword_readonly] = ACTIONS(275),
    [sym_keyword_content] = ACTIONS(275),
    [sym_keyword_merge] = ACTIONS(275),
    [sym_keyword_patch] = ACTIONS(275),
    [sym_keyword_type] = ACTIONS(275),
    [sym_keyword_default] = ACTIONS(275),
    [sym_keyword_assert] = ACTIONS(275),
    [sym_keyword_permissions] = ACTIONS(275),
    [sym_keyword_for] = ACTIONS(275),
    [sym_keyword_comment] = ACTIONS(275),
    [sym_keyword_set] = ACTIONS(275),
    [sym_keyword_unset] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(275),
    [anon_sym_DASH_GT] = ACTIONS(275),
    [anon_sym_RPAREN] = ACTIONS(275),
    [anon_sym_RBRACE] = ACTIONS(275),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LT] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(277),
    [anon_sym_EQ] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_LT_PIPE] = ACTIONS(275),
    [anon_sym_AMP_AMP] = ACTIONS(275),
    [anon_sym_PIPE_PIPE] = ACTIONS(275),
    [anon_sym_QMARK_QMARK] = ACTIONS(275),
    [anon_sym_QMARK_COLON] = ACTIONS(275),
    [anon_sym_BANG_EQ] = ACTIONS(275),
    [anon_sym_EQ_EQ] = ACTIONS(275),
    [anon_sym_QMARK_EQ] = ACTIONS(275),
    [anon_sym_STAR_EQ] = ACTIONS(275),
    [anon_sym_TILDE] = ACTIONS(275),
    [anon_sym_BANG_TILDE] = ACTIONS(275),
    [anon_sym_STAR_TILDE] = ACTIONS(275),
    [anon_sym_LT_EQ] = ACTIONS(275),
    [anon_sym_GT_EQ] = ACTIONS(275),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_PLUS_EQ] = ACTIONS(275),
    [anon_sym_DASH_EQ] = ACTIONS(275),
    [anon_sym_u00d7] = ACTIONS(275),
    [anon_sym_SLASH] = ACTIONS(277),
    [anon_sym_u00f7] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(275),
    [anon_sym_u220b] = ACTIONS(275),
    [anon_sym_u220c] = ACTIONS(275),
    [anon_sym_u2287] = ACTIONS(275),
    [anon_sym_u2283] = ACTIONS(275),
    [anon_sym_u2285] = ACTIONS(275),
    [anon_sym_u2208] = ACTIONS(275),
    [anon_sym_u2209] = ACTIONS(275),
    [anon_sym_u2286] = ACTIONS(275),
    [anon_sym_u2282] = ACTIONS(275),
    [anon_sym_u2284] = ACTIONS(275),
    [anon_sym_AT_AT] = ACTIONS(275),
  },
  [85] = {
    [ts_builtin_sym_end] = ACTIONS(198),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(198),
    [sym_keyword_return] = ACTIONS(198),
    [sym_keyword_value] = ACTIONS(198),
    [sym_keyword_explain] = ACTIONS(198),
    [sym_keyword_parallel] = ACTIONS(198),
    [sym_keyword_timeout] = ACTIONS(198),
    [sym_keyword_fetch] = ACTIONS(198),
    [sym_keyword_limit] = ACTIONS(198),
    [sym_keyword_rand] = ACTIONS(198),
    [sym_keyword_collate] = ACTIONS(198),
    [sym_keyword_numeric] = ACTIONS(198),
    [sym_keyword_asc] = ACTIONS(198),
    [sym_keyword_desc] = ACTIONS(198),
    [sym_keyword_where] = ACTIONS(198),
    [sym_keyword_and] = ACTIONS(198),
    [sym_keyword_or] = ACTIONS(198),
    [sym_keyword_is] = ACTIONS(198),
    [sym_keyword_not] = ACTIONS(200),
    [sym_keyword_contains] = ACTIONS(198),
    [sym_keyword_contains_not] = ACTIONS(198),
    [sym_keyword_contains_all] = ACTIONS(198),
    [sym_keyword_contains_any] = ACTIONS(198),
    [sym_keyword_contains_none] = ACTIONS(198),
    [sym_keyword_inside] = ACTIONS(198),
    [sym_keyword_in] = ACTIONS(200),
    [sym_keyword_not_inside] = ACTIONS(198),
    [sym_keyword_all_inside] = ACTIONS(198),
    [sym_keyword_any_inside] = ACTIONS(198),
    [sym_keyword_none_inside] = ACTIONS(198),
    [sym_keyword_outside] = ACTIONS(198),
    [sym_keyword_intersects] = ACTIONS(198),
    [sym_keyword_flexible] = ACTIONS(198),
    [sym_keyword_readonly] = ACTIONS(198),
    [sym_keyword_content] = ACTIONS(198),
    [sym_keyword_merge] = ACTIONS(198),
    [sym_keyword_patch] = ACTIONS(198),
    [sym_keyword_type] = ACTIONS(198),
    [sym_keyword_default] = ACTIONS(198),
    [sym_keyword_assert] = ACTIONS(198),
    [sym_keyword_permissions] = ACTIONS(198),
    [sym_keyword_for] = ACTIONS(198),
    [sym_keyword_comment] = ACTIONS(198),
    [sym_keyword_set] = ACTIONS(198),
    [sym_keyword_unset] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(198),
    [anon_sym_DASH_GT] = ACTIONS(198),
    [anon_sym_RPAREN] = ACTIONS(198),
    [anon_sym_RBRACE] = ACTIONS(198),
    [anon_sym_STAR] = ACTIONS(200),
    [anon_sym_LT] = ACTIONS(200),
    [anon_sym_GT] = ACTIONS(200),
    [anon_sym_EQ] = ACTIONS(200),
    [anon_sym_DASH] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(200),
    [anon_sym_LT_PIPE] = ACTIONS(198),
    [anon_sym_AMP_AMP] = ACTIONS(198),
    [anon_sym_PIPE_PIPE] = ACTIONS(198),
    [anon_sym_QMARK_QMARK] = ACTIONS(198),
    [anon_sym_QMARK_COLON] = ACTIONS(198),
    [anon_sym_BANG_EQ] = ACTIONS(198),
    [anon_sym_EQ_EQ] = ACTIONS(198),
    [anon_sym_QMARK_EQ] = ACTIONS(198),
    [anon_sym_STAR_EQ] = ACTIONS(198),
    [anon_sym_TILDE] = ACTIONS(198),
    [anon_sym_BANG_TILDE] = ACTIONS(198),
    [anon_sym_STAR_TILDE] = ACTIONS(198),
    [anon_sym_LT_EQ] = ACTIONS(198),
    [anon_sym_GT_EQ] = ACTIONS(198),
    [anon_sym_PLUS] = ACTIONS(200),
    [anon_sym_PLUS_EQ] = ACTIONS(198),
    [anon_sym_DASH_EQ] = ACTIONS(198),
    [anon_sym_u00d7] = ACTIONS(198),
    [anon_sym_SLASH] = ACTIONS(200),
    [anon_sym_u00f7] = ACTIONS(198),
    [anon_sym_STAR_STAR] = ACTIONS(198),
    [anon_sym_u220b] = ACTIONS(198),
    [anon_sym_u220c] = ACTIONS(198),
    [anon_sym_u2287] = ACTIONS(198),
    [anon_sym_u2283] = ACTIONS(198),
    [anon_sym_u2285] = ACTIONS(198),
    [anon_sym_u2208] = ACTIONS(198),
    [anon_sym_u2209] = ACTIONS(198),
    [anon_sym_u2286] = ACTIONS(198),
    [anon_sym_u2282] = ACTIONS(198),
    [anon_sym_u2284] = ACTIONS(198),
    [anon_sym_AT_AT] = ACTIONS(198),
  },
  [86] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(59),
    [sym_keyword_return] = ACTIONS(59),
    [sym_keyword_from] = ACTIONS(59),
    [sym_keyword_as] = ACTIONS(59),
    [sym_keyword_parallel] = ACTIONS(59),
    [sym_keyword_timeout] = ACTIONS(59),
    [sym_keyword_where] = ACTIONS(59),
    [sym_keyword_group] = ACTIONS(59),
    [sym_keyword_and] = ACTIONS(59),
    [sym_keyword_or] = ACTIONS(59),
    [sym_keyword_is] = ACTIONS(59),
    [sym_keyword_not] = ACTIONS(61),
    [sym_keyword_contains] = ACTIONS(59),
    [sym_keyword_contains_not] = ACTIONS(59),
    [sym_keyword_contains_all] = ACTIONS(59),
    [sym_keyword_contains_any] = ACTIONS(59),
    [sym_keyword_contains_none] = ACTIONS(59),
    [sym_keyword_inside] = ACTIONS(59),
    [sym_keyword_in] = ACTIONS(61),
    [sym_keyword_not_inside] = ACTIONS(59),
    [sym_keyword_all_inside] = ACTIONS(59),
    [sym_keyword_any_inside] = ACTIONS(59),
    [sym_keyword_none_inside] = ACTIONS(59),
    [sym_keyword_outside] = ACTIONS(59),
    [sym_keyword_intersects] = ACTIONS(59),
    [sym_keyword_drop] = ACTIONS(59),
    [sym_keyword_schemafull] = ACTIONS(59),
    [sym_keyword_schemaless] = ACTIONS(59),
    [sym_keyword_changefeed] = ACTIONS(59),
    [sym_keyword_content] = ACTIONS(59),
    [sym_keyword_merge] = ACTIONS(59),
    [sym_keyword_patch] = ACTIONS(59),
    [sym_keyword_then] = ACTIONS(59),
    [sym_keyword_type] = ACTIONS(59),
    [sym_keyword_permissions] = ACTIONS(59),
    [sym_keyword_for] = ACTIONS(59),
    [sym_keyword_comment] = ACTIONS(59),
    [sym_keyword_if] = ACTIONS(59),
    [sym_keyword_set] = ACTIONS(59),
    [sym_keyword_unset] = ACTIONS(59),
    [anon_sym_COMMA] = ACTIONS(59),
    [anon_sym_RBRACK] = ACTIONS(59),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_RPAREN] = ACTIONS(59),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(59),
    [anon_sym_RBRACE] = ACTIONS(59),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [sym_variable_name] = ACTIONS(59),
    [sym_custom_function_name] = ACTIONS(59),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(61),
    [anon_sym_LT_PIPE] = ACTIONS(59),
    [anon_sym_AMP_AMP] = ACTIONS(59),
    [anon_sym_PIPE_PIPE] = ACTIONS(59),
    [anon_sym_QMARK_QMARK] = ACTIONS(59),
    [anon_sym_QMARK_COLON] = ACTIONS(59),
    [anon_sym_BANG_EQ] = ACTIONS(59),
    [anon_sym_EQ_EQ] = ACTIONS(59),
    [anon_sym_QMARK_EQ] = ACTIONS(59),
    [anon_sym_STAR_EQ] = ACTIONS(59),
    [anon_sym_TILDE] = ACTIONS(59),
    [anon_sym_BANG_TILDE] = ACTIONS(59),
    [anon_sym_STAR_TILDE] = ACTIONS(59),
    [anon_sym_LT_EQ] = ACTIONS(59),
    [anon_sym_GT_EQ] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_PLUS_EQ] = ACTIONS(59),
    [anon_sym_DASH_EQ] = ACTIONS(59),
    [anon_sym_u00d7] = ACTIONS(59),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_u00f7] = ACTIONS(59),
    [anon_sym_STAR_STAR] = ACTIONS(59),
    [anon_sym_u220b] = ACTIONS(59),
    [anon_sym_u220c] = ACTIONS(59),
    [anon_sym_u2287] = ACTIONS(59),
    [anon_sym_u2283] = ACTIONS(59),
    [anon_sym_u2285] = ACTIONS(59),
    [anon_sym_u2208] = ACTIONS(59),
    [anon_sym_u2209] = ACTIONS(59),
    [anon_sym_u2286] = ACTIONS(59),
    [anon_sym_u2282] = ACTIONS(59),
    [anon_sym_u2284] = ACTIONS(59),
    [anon_sym_AT_AT] = ACTIONS(59),
  },
  [87] = {
    [ts_builtin_sym_end] = ACTIONS(255),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(255),
    [sym_keyword_return] = ACTIONS(255),
    [sym_keyword_value] = ACTIONS(255),
    [sym_keyword_explain] = ACTIONS(255),
    [sym_keyword_parallel] = ACTIONS(255),
    [sym_keyword_timeout] = ACTIONS(255),
    [sym_keyword_fetch] = ACTIONS(255),
    [sym_keyword_limit] = ACTIONS(255),
    [sym_keyword_rand] = ACTIONS(255),
    [sym_keyword_collate] = ACTIONS(255),
    [sym_keyword_numeric] = ACTIONS(255),
    [sym_keyword_asc] = ACTIONS(255),
    [sym_keyword_desc] = ACTIONS(255),
    [sym_keyword_where] = ACTIONS(255),
    [sym_keyword_and] = ACTIONS(255),
    [sym_keyword_or] = ACTIONS(255),
    [sym_keyword_is] = ACTIONS(255),
    [sym_keyword_not] = ACTIONS(257),
    [sym_keyword_contains] = ACTIONS(255),
    [sym_keyword_contains_not] = ACTIONS(255),
    [sym_keyword_contains_all] = ACTIONS(255),
    [sym_keyword_contains_any] = ACTIONS(255),
    [sym_keyword_contains_none] = ACTIONS(255),
    [sym_keyword_inside] = ACTIONS(255),
    [sym_keyword_in] = ACTIONS(257),
    [sym_keyword_not_inside] = ACTIONS(255),
    [sym_keyword_all_inside] = ACTIONS(255),
    [sym_keyword_any_inside] = ACTIONS(255),
    [sym_keyword_none_inside] = ACTIONS(255),
    [sym_keyword_outside] = ACTIONS(255),
    [sym_keyword_intersects] = ACTIONS(255),
    [sym_keyword_flexible] = ACTIONS(255),
    [sym_keyword_readonly] = ACTIONS(255),
    [sym_keyword_content] = ACTIONS(255),
    [sym_keyword_merge] = ACTIONS(255),
    [sym_keyword_patch] = ACTIONS(255),
    [sym_keyword_type] = ACTIONS(255),
    [sym_keyword_default] = ACTIONS(255),
    [sym_keyword_assert] = ACTIONS(255),
    [sym_keyword_permissions] = ACTIONS(255),
    [sym_keyword_for] = ACTIONS(255),
    [sym_keyword_comment] = ACTIONS(255),
    [sym_keyword_set] = ACTIONS(255),
    [sym_keyword_unset] = ACTIONS(255),
    [anon_sym_COMMA] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(255),
    [anon_sym_RPAREN] = ACTIONS(255),
    [anon_sym_RBRACE] = ACTIONS(255),
    [anon_sym_STAR] = ACTIONS(257),
    [anon_sym_LT] = ACTIONS(257),
    [anon_sym_GT] = ACTIONS(257),
    [anon_sym_EQ] = ACTIONS(257),
    [anon_sym_DASH] = ACTIONS(257),
    [anon_sym_AT] = ACTIONS(257),
    [anon_sym_LT_PIPE] = ACTIONS(255),
    [anon_sym_AMP_AMP] = ACTIONS(255),
    [anon_sym_PIPE_PIPE] = ACTIONS(255),
    [anon_sym_QMARK_QMARK] = ACTIONS(255),
    [anon_sym_QMARK_COLON] = ACTIONS(255),
    [anon_sym_BANG_EQ] = ACTIONS(255),
    [anon_sym_EQ_EQ] = ACTIONS(255),
    [anon_sym_QMARK_EQ] = ACTIONS(255),
    [anon_sym_STAR_EQ] = ACTIONS(255),
    [anon_sym_TILDE] = ACTIONS(255),
    [anon_sym_BANG_TILDE] = ACTIONS(255),
    [anon_sym_STAR_TILDE] = ACTIONS(255),
    [anon_sym_LT_EQ] = ACTIONS(255),
    [anon_sym_GT_EQ] = ACTIONS(255),
    [anon_sym_PLUS] = ACTIONS(257),
    [anon_sym_PLUS_EQ] = ACTIONS(255),
    [anon_sym_DASH_EQ] = ACTIONS(255),
    [anon_sym_u00d7] = ACTIONS(255),
    [anon_sym_SLASH] = ACTIONS(257),
    [anon_sym_u00f7] = ACTIONS(255),
    [anon_sym_STAR_STAR] = ACTIONS(255),
    [anon_sym_u220b] = ACTIONS(255),
    [anon_sym_u220c] = ACTIONS(255),
    [anon_sym_u2287] = ACTIONS(255),
    [anon_sym_u2283] = ACTIONS(255),
    [anon_sym_u2285] = ACTIONS(255),
    [anon_sym_u2208] = ACTIONS(255),
    [anon_sym_u2209] = ACTIONS(255),
    [anon_sym_u2286] = ACTIONS(255),
    [anon_sym_u2282] = ACTIONS(255),
    [anon_sym_u2284] = ACTIONS(255),
    [anon_sym_AT_AT] = ACTIONS(255),
  },
  [88] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(275),
    [sym_keyword_return] = ACTIONS(275),
    [sym_keyword_from] = ACTIONS(275),
    [sym_keyword_as] = ACTIONS(275),
    [sym_keyword_parallel] = ACTIONS(275),
    [sym_keyword_timeout] = ACTIONS(275),
    [sym_keyword_where] = ACTIONS(275),
    [sym_keyword_group] = ACTIONS(275),
    [sym_keyword_and] = ACTIONS(275),
    [sym_keyword_or] = ACTIONS(275),
    [sym_keyword_is] = ACTIONS(275),
    [sym_keyword_not] = ACTIONS(277),
    [sym_keyword_contains] = ACTIONS(275),
    [sym_keyword_contains_not] = ACTIONS(275),
    [sym_keyword_contains_all] = ACTIONS(275),
    [sym_keyword_contains_any] = ACTIONS(275),
    [sym_keyword_contains_none] = ACTIONS(275),
    [sym_keyword_inside] = ACTIONS(275),
    [sym_keyword_in] = ACTIONS(277),
    [sym_keyword_not_inside] = ACTIONS(275),
    [sym_keyword_all_inside] = ACTIONS(275),
    [sym_keyword_any_inside] = ACTIONS(275),
    [sym_keyword_none_inside] = ACTIONS(275),
    [sym_keyword_outside] = ACTIONS(275),
    [sym_keyword_intersects] = ACTIONS(275),
    [sym_keyword_drop] = ACTIONS(275),
    [sym_keyword_schemafull] = ACTIONS(275),
    [sym_keyword_schemaless] = ACTIONS(275),
    [sym_keyword_changefeed] = ACTIONS(275),
    [sym_keyword_content] = ACTIONS(275),
    [sym_keyword_merge] = ACTIONS(275),
    [sym_keyword_patch] = ACTIONS(275),
    [sym_keyword_then] = ACTIONS(275),
    [sym_keyword_type] = ACTIONS(275),
    [sym_keyword_permissions] = ACTIONS(275),
    [sym_keyword_for] = ACTIONS(275),
    [sym_keyword_comment] = ACTIONS(275),
    [sym_keyword_if] = ACTIONS(275),
    [sym_keyword_set] = ACTIONS(275),
    [sym_keyword_unset] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(275),
    [anon_sym_RBRACK] = ACTIONS(275),
    [anon_sym_LPAREN] = ACTIONS(275),
    [anon_sym_RPAREN] = ACTIONS(275),
    [anon_sym_QMARK] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(275),
    [anon_sym_RBRACE] = ACTIONS(275),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LT] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(277),
    [sym_variable_name] = ACTIONS(275),
    [sym_custom_function_name] = ACTIONS(275),
    [anon_sym_EQ] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_LT_PIPE] = ACTIONS(275),
    [anon_sym_AMP_AMP] = ACTIONS(275),
    [anon_sym_PIPE_PIPE] = ACTIONS(275),
    [anon_sym_QMARK_QMARK] = ACTIONS(275),
    [anon_sym_QMARK_COLON] = ACTIONS(275),
    [anon_sym_BANG_EQ] = ACTIONS(275),
    [anon_sym_EQ_EQ] = ACTIONS(275),
    [anon_sym_QMARK_EQ] = ACTIONS(275),
    [anon_sym_STAR_EQ] = ACTIONS(275),
    [anon_sym_TILDE] = ACTIONS(275),
    [anon_sym_BANG_TILDE] = ACTIONS(275),
    [anon_sym_STAR_TILDE] = ACTIONS(275),
    [anon_sym_LT_EQ] = ACTIONS(275),
    [anon_sym_GT_EQ] = ACTIONS(275),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_PLUS_EQ] = ACTIONS(275),
    [anon_sym_DASH_EQ] = ACTIONS(275),
    [anon_sym_u00d7] = ACTIONS(275),
    [anon_sym_SLASH] = ACTIONS(277),
    [anon_sym_u00f7] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(275),
    [anon_sym_u220b] = ACTIONS(275),
    [anon_sym_u220c] = ACTIONS(275),
    [anon_sym_u2287] = ACTIONS(275),
    [anon_sym_u2283] = ACTIONS(275),
    [anon_sym_u2285] = ACTIONS(275),
    [anon_sym_u2208] = ACTIONS(275),
    [anon_sym_u2209] = ACTIONS(275),
    [anon_sym_u2286] = ACTIONS(275),
    [anon_sym_u2282] = ACTIONS(275),
    [anon_sym_u2284] = ACTIONS(275),
    [anon_sym_AT_AT] = ACTIONS(275),
  },
  [89] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(138),
    [sym_keyword_return] = ACTIONS(138),
    [sym_keyword_from] = ACTIONS(138),
    [sym_keyword_as] = ACTIONS(138),
    [sym_keyword_parallel] = ACTIONS(138),
    [sym_keyword_timeout] = ACTIONS(138),
    [sym_keyword_where] = ACTIONS(138),
    [sym_keyword_group] = ACTIONS(138),
    [sym_keyword_and] = ACTIONS(138),
    [sym_keyword_or] = ACTIONS(138),
    [sym_keyword_is] = ACTIONS(138),
    [sym_keyword_not] = ACTIONS(140),
    [sym_keyword_contains] = ACTIONS(138),
    [sym_keyword_contains_not] = ACTIONS(138),
    [sym_keyword_contains_all] = ACTIONS(138),
    [sym_keyword_contains_any] = ACTIONS(138),
    [sym_keyword_contains_none] = ACTIONS(138),
    [sym_keyword_inside] = ACTIONS(138),
    [sym_keyword_in] = ACTIONS(140),
    [sym_keyword_not_inside] = ACTIONS(138),
    [sym_keyword_all_inside] = ACTIONS(138),
    [sym_keyword_any_inside] = ACTIONS(138),
    [sym_keyword_none_inside] = ACTIONS(138),
    [sym_keyword_outside] = ACTIONS(138),
    [sym_keyword_intersects] = ACTIONS(138),
    [sym_keyword_drop] = ACTIONS(138),
    [sym_keyword_schemafull] = ACTIONS(138),
    [sym_keyword_schemaless] = ACTIONS(138),
    [sym_keyword_changefeed] = ACTIONS(138),
    [sym_keyword_content] = ACTIONS(138),
    [sym_keyword_merge] = ACTIONS(138),
    [sym_keyword_patch] = ACTIONS(138),
    [sym_keyword_then] = ACTIONS(138),
    [sym_keyword_type] = ACTIONS(138),
    [sym_keyword_permissions] = ACTIONS(138),
    [sym_keyword_for] = ACTIONS(138),
    [sym_keyword_comment] = ACTIONS(138),
    [sym_keyword_if] = ACTIONS(138),
    [sym_keyword_set] = ACTIONS(138),
    [sym_keyword_unset] = ACTIONS(138),
    [anon_sym_COMMA] = ACTIONS(138),
    [anon_sym_RBRACK] = ACTIONS(138),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_RPAREN] = ACTIONS(138),
    [anon_sym_QMARK] = ACTIONS(140),
    [anon_sym_LBRACE] = ACTIONS(138),
    [anon_sym_RBRACE] = ACTIONS(138),
    [anon_sym_STAR] = ACTIONS(140),
    [anon_sym_LT] = ACTIONS(140),
    [anon_sym_GT] = ACTIONS(140),
    [sym_variable_name] = ACTIONS(138),
    [sym_custom_function_name] = ACTIONS(138),
    [anon_sym_EQ] = ACTIONS(140),
    [anon_sym_DASH] = ACTIONS(140),
    [anon_sym_AT] = ACTIONS(140),
    [anon_sym_LT_PIPE] = ACTIONS(138),
    [anon_sym_AMP_AMP] = ACTIONS(138),
    [anon_sym_PIPE_PIPE] = ACTIONS(138),
    [anon_sym_QMARK_QMARK] = ACTIONS(138),
    [anon_sym_QMARK_COLON] = ACTIONS(138),
    [anon_sym_BANG_EQ] = ACTIONS(138),
    [anon_sym_EQ_EQ] = ACTIONS(138),
    [anon_sym_QMARK_EQ] = ACTIONS(138),
    [anon_sym_STAR_EQ] = ACTIONS(138),
    [anon_sym_TILDE] = ACTIONS(138),
    [anon_sym_BANG_TILDE] = ACTIONS(138),
    [anon_sym_STAR_TILDE] = ACTIONS(138),
    [anon_sym_LT_EQ] = ACTIONS(138),
    [anon_sym_GT_EQ] = ACTIONS(138),
    [anon_sym_PLUS] = ACTIONS(140),
    [anon_sym_PLUS_EQ] = ACTIONS(138),
    [anon_sym_DASH_EQ] = ACTIONS(138),
    [anon_sym_u00d7] = ACTIONS(138),
    [anon_sym_SLASH] = ACTIONS(140),
    [anon_sym_u00f7] = ACTIONS(138),
    [anon_sym_STAR_STAR] = ACTIONS(138),
    [anon_sym_u220b] = ACTIONS(138),
    [anon_sym_u220c] = ACTIONS(138),
    [anon_sym_u2287] = ACTIONS(138),
    [anon_sym_u2283] = ACTIONS(138),
    [anon_sym_u2285] = ACTIONS(138),
    [anon_sym_u2208] = ACTIONS(138),
    [anon_sym_u2209] = ACTIONS(138),
    [anon_sym_u2286] = ACTIONS(138),
    [anon_sym_u2282] = ACTIONS(138),
    [anon_sym_u2284] = ACTIONS(138),
    [anon_sym_AT_AT] = ACTIONS(138),
  },
  [90] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(259),
    [sym_keyword_return] = ACTIONS(259),
    [sym_keyword_from] = ACTIONS(259),
    [sym_keyword_as] = ACTIONS(259),
    [sym_keyword_parallel] = ACTIONS(259),
    [sym_keyword_timeout] = ACTIONS(259),
    [sym_keyword_where] = ACTIONS(259),
    [sym_keyword_group] = ACTIONS(259),
    [sym_keyword_and] = ACTIONS(259),
    [sym_keyword_or] = ACTIONS(259),
    [sym_keyword_is] = ACTIONS(259),
    [sym_keyword_not] = ACTIONS(261),
    [sym_keyword_contains] = ACTIONS(259),
    [sym_keyword_contains_not] = ACTIONS(259),
    [sym_keyword_contains_all] = ACTIONS(259),
    [sym_keyword_contains_any] = ACTIONS(259),
    [sym_keyword_contains_none] = ACTIONS(259),
    [sym_keyword_inside] = ACTIONS(259),
    [sym_keyword_in] = ACTIONS(261),
    [sym_keyword_not_inside] = ACTIONS(259),
    [sym_keyword_all_inside] = ACTIONS(259),
    [sym_keyword_any_inside] = ACTIONS(259),
    [sym_keyword_none_inside] = ACTIONS(259),
    [sym_keyword_outside] = ACTIONS(259),
    [sym_keyword_intersects] = ACTIONS(259),
    [sym_keyword_drop] = ACTIONS(259),
    [sym_keyword_schemafull] = ACTIONS(259),
    [sym_keyword_schemaless] = ACTIONS(259),
    [sym_keyword_changefeed] = ACTIONS(259),
    [sym_keyword_content] = ACTIONS(259),
    [sym_keyword_merge] = ACTIONS(259),
    [sym_keyword_patch] = ACTIONS(259),
    [sym_keyword_then] = ACTIONS(259),
    [sym_keyword_type] = ACTIONS(259),
    [sym_keyword_permissions] = ACTIONS(259),
    [sym_keyword_for] = ACTIONS(259),
    [sym_keyword_comment] = ACTIONS(259),
    [sym_keyword_if] = ACTIONS(259),
    [sym_keyword_set] = ACTIONS(259),
    [sym_keyword_unset] = ACTIONS(259),
    [anon_sym_COMMA] = ACTIONS(259),
    [anon_sym_RBRACK] = ACTIONS(259),
    [anon_sym_LPAREN] = ACTIONS(259),
    [anon_sym_RPAREN] = ACTIONS(259),
    [anon_sym_QMARK] = ACTIONS(261),
    [anon_sym_LBRACE] = ACTIONS(259),
    [anon_sym_RBRACE] = ACTIONS(259),
    [anon_sym_STAR] = ACTIONS(261),
    [anon_sym_LT] = ACTIONS(261),
    [anon_sym_GT] = ACTIONS(261),
    [sym_variable_name] = ACTIONS(259),
    [sym_custom_function_name] = ACTIONS(259),
    [anon_sym_EQ] = ACTIONS(261),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_AT] = ACTIONS(261),
    [anon_sym_LT_PIPE] = ACTIONS(259),
    [anon_sym_AMP_AMP] = ACTIONS(259),
    [anon_sym_PIPE_PIPE] = ACTIONS(259),
    [anon_sym_QMARK_QMARK] = ACTIONS(259),
    [anon_sym_QMARK_COLON] = ACTIONS(259),
    [anon_sym_BANG_EQ] = ACTIONS(259),
    [anon_sym_EQ_EQ] = ACTIONS(259),
    [anon_sym_QMARK_EQ] = ACTIONS(259),
    [anon_sym_STAR_EQ] = ACTIONS(259),
    [anon_sym_TILDE] = ACTIONS(259),
    [anon_sym_BANG_TILDE] = ACTIONS(259),
    [anon_sym_STAR_TILDE] = ACTIONS(259),
    [anon_sym_LT_EQ] = ACTIONS(259),
    [anon_sym_GT_EQ] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(261),
    [anon_sym_PLUS_EQ] = ACTIONS(259),
    [anon_sym_DASH_EQ] = ACTIONS(259),
    [anon_sym_u00d7] = ACTIONS(259),
    [anon_sym_SLASH] = ACTIONS(261),
    [anon_sym_u00f7] = ACTIONS(259),
    [anon_sym_STAR_STAR] = ACTIONS(259),
    [anon_sym_u220b] = ACTIONS(259),
    [anon_sym_u220c] = ACTIONS(259),
    [anon_sym_u2287] = ACTIONS(259),
    [anon_sym_u2283] = ACTIONS(259),
    [anon_sym_u2285] = ACTIONS(259),
    [anon_sym_u2208] = ACTIONS(259),
    [anon_sym_u2209] = ACTIONS(259),
    [anon_sym_u2286] = ACTIONS(259),
    [anon_sym_u2282] = ACTIONS(259),
    [anon_sym_u2284] = ACTIONS(259),
    [anon_sym_AT_AT] = ACTIONS(259),
  },
  [91] = {
    [aux_sym_duration_repeat1] = STATE(91),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(105),
    [sym_keyword_value] = ACTIONS(105),
    [sym_keyword_explain] = ACTIONS(105),
    [sym_keyword_parallel] = ACTIONS(105),
    [sym_keyword_timeout] = ACTIONS(105),
    [sym_keyword_fetch] = ACTIONS(105),
    [sym_keyword_limit] = ACTIONS(105),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_collate] = ACTIONS(105),
    [sym_keyword_numeric] = ACTIONS(105),
    [sym_keyword_asc] = ACTIONS(105),
    [sym_keyword_desc] = ACTIONS(105),
    [sym_keyword_and] = ACTIONS(105),
    [sym_keyword_or] = ACTIONS(105),
    [sym_keyword_is] = ACTIONS(105),
    [sym_keyword_not] = ACTIONS(107),
    [sym_keyword_contains] = ACTIONS(105),
    [sym_keyword_contains_not] = ACTIONS(105),
    [sym_keyword_contains_all] = ACTIONS(105),
    [sym_keyword_contains_any] = ACTIONS(105),
    [sym_keyword_contains_none] = ACTIONS(105),
    [sym_keyword_inside] = ACTIONS(105),
    [sym_keyword_in] = ACTIONS(107),
    [sym_keyword_not_inside] = ACTIONS(105),
    [sym_keyword_all_inside] = ACTIONS(105),
    [sym_keyword_any_inside] = ACTIONS(105),
    [sym_keyword_none_inside] = ACTIONS(105),
    [sym_keyword_outside] = ACTIONS(105),
    [sym_keyword_intersects] = ACTIONS(105),
    [sym_keyword_flexible] = ACTIONS(105),
    [sym_keyword_readonly] = ACTIONS(105),
    [sym_keyword_type] = ACTIONS(105),
    [sym_keyword_default] = ACTIONS(105),
    [sym_keyword_assert] = ACTIONS(105),
    [sym_keyword_permissions] = ACTIONS(105),
    [sym_keyword_for] = ACTIONS(105),
    [sym_keyword_comment] = ACTIONS(105),
    [anon_sym_COMMA] = ACTIONS(105),
    [anon_sym_DASH_GT] = ACTIONS(105),
    [anon_sym_LBRACK] = ACTIONS(105),
    [anon_sym_RPAREN] = ACTIONS(105),
    [anon_sym_RBRACE] = ACTIONS(105),
    [anon_sym_LT_DASH] = ACTIONS(107),
    [anon_sym_LT_DASH_GT] = ACTIONS(105),
    [anon_sym_STAR] = ACTIONS(107),
    [anon_sym_DOT] = ACTIONS(105),
    [anon_sym_LT] = ACTIONS(107),
    [anon_sym_GT] = ACTIONS(107),
    [anon_sym_EQ] = ACTIONS(107),
    [sym_duration_part] = ACTIONS(279),
    [anon_sym_DASH] = ACTIONS(107),
    [anon_sym_AT] = ACTIONS(107),
    [anon_sym_LT_PIPE] = ACTIONS(105),
    [anon_sym_AMP_AMP] = ACTIONS(105),
    [anon_sym_PIPE_PIPE] = ACTIONS(105),
    [anon_sym_QMARK_QMARK] = ACTIONS(105),
    [anon_sym_QMARK_COLON] = ACTIONS(105),
    [anon_sym_BANG_EQ] = ACTIONS(105),
    [anon_sym_EQ_EQ] = ACTIONS(105),
    [anon_sym_QMARK_EQ] = ACTIONS(105),
    [anon_sym_STAR_EQ] = ACTIONS(105),
    [anon_sym_TILDE] = ACTIONS(105),
    [anon_sym_BANG_TILDE] = ACTIONS(105),
    [anon_sym_STAR_TILDE] = ACTIONS(105),
    [anon_sym_LT_EQ] = ACTIONS(105),
    [anon_sym_GT_EQ] = ACTIONS(105),
    [anon_sym_PLUS] = ACTIONS(107),
    [anon_sym_PLUS_EQ] = ACTIONS(105),
    [anon_sym_DASH_EQ] = ACTIONS(105),
    [anon_sym_u00d7] = ACTIONS(105),
    [anon_sym_SLASH] = ACTIONS(107),
    [anon_sym_u00f7] = ACTIONS(105),
    [anon_sym_STAR_STAR] = ACTIONS(105),
    [anon_sym_u220b] = ACTIONS(105),
    [anon_sym_u220c] = ACTIONS(105),
    [anon_sym_u2287] = ACTIONS(105),
    [anon_sym_u2283] = ACTIONS(105),
    [anon_sym_u2285] = ACTIONS(105),
    [anon_sym_u2208] = ACTIONS(105),
    [anon_sym_u2209] = ACTIONS(105),
    [anon_sym_u2286] = ACTIONS(105),
    [anon_sym_u2282] = ACTIONS(105),
    [anon_sym_u2284] = ACTIONS(105),
    [anon_sym_AT_AT] = ACTIONS(105),
  },
  [92] = {
    [aux_sym_duration_repeat1] = STATE(91),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(99),
    [sym_keyword_value] = ACTIONS(99),
    [sym_keyword_explain] = ACTIONS(99),
    [sym_keyword_parallel] = ACTIONS(99),
    [sym_keyword_timeout] = ACTIONS(99),
    [sym_keyword_fetch] = ACTIONS(99),
    [sym_keyword_limit] = ACTIONS(99),
    [sym_keyword_rand] = ACTIONS(99),
    [sym_keyword_collate] = ACTIONS(99),
    [sym_keyword_numeric] = ACTIONS(99),
    [sym_keyword_asc] = ACTIONS(99),
    [sym_keyword_desc] = ACTIONS(99),
    [sym_keyword_and] = ACTIONS(99),
    [sym_keyword_or] = ACTIONS(99),
    [sym_keyword_is] = ACTIONS(99),
    [sym_keyword_not] = ACTIONS(101),
    [sym_keyword_contains] = ACTIONS(99),
    [sym_keyword_contains_not] = ACTIONS(99),
    [sym_keyword_contains_all] = ACTIONS(99),
    [sym_keyword_contains_any] = ACTIONS(99),
    [sym_keyword_contains_none] = ACTIONS(99),
    [sym_keyword_inside] = ACTIONS(99),
    [sym_keyword_in] = ACTIONS(101),
    [sym_keyword_not_inside] = ACTIONS(99),
    [sym_keyword_all_inside] = ACTIONS(99),
    [sym_keyword_any_inside] = ACTIONS(99),
    [sym_keyword_none_inside] = ACTIONS(99),
    [sym_keyword_outside] = ACTIONS(99),
    [sym_keyword_intersects] = ACTIONS(99),
    [sym_keyword_flexible] = ACTIONS(99),
    [sym_keyword_readonly] = ACTIONS(99),
    [sym_keyword_type] = ACTIONS(99),
    [sym_keyword_default] = ACTIONS(99),
    [sym_keyword_assert] = ACTIONS(99),
    [sym_keyword_permissions] = ACTIONS(99),
    [sym_keyword_for] = ACTIONS(99),
    [sym_keyword_comment] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_DASH_GT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(99),
    [anon_sym_RPAREN] = ACTIONS(99),
    [anon_sym_RBRACE] = ACTIONS(99),
    [anon_sym_LT_DASH] = ACTIONS(101),
    [anon_sym_LT_DASH_GT] = ACTIONS(99),
    [anon_sym_STAR] = ACTIONS(101),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LT] = ACTIONS(101),
    [anon_sym_GT] = ACTIONS(101),
    [anon_sym_EQ] = ACTIONS(101),
    [sym_duration_part] = ACTIONS(282),
    [anon_sym_DASH] = ACTIONS(101),
    [anon_sym_AT] = ACTIONS(101),
    [anon_sym_LT_PIPE] = ACTIONS(99),
    [anon_sym_AMP_AMP] = ACTIONS(99),
    [anon_sym_PIPE_PIPE] = ACTIONS(99),
    [anon_sym_QMARK_QMARK] = ACTIONS(99),
    [anon_sym_QMARK_COLON] = ACTIONS(99),
    [anon_sym_BANG_EQ] = ACTIONS(99),
    [anon_sym_EQ_EQ] = ACTIONS(99),
    [anon_sym_QMARK_EQ] = ACTIONS(99),
    [anon_sym_STAR_EQ] = ACTIONS(99),
    [anon_sym_TILDE] = ACTIONS(99),
    [anon_sym_BANG_TILDE] = ACTIONS(99),
    [anon_sym_STAR_TILDE] = ACTIONS(99),
    [anon_sym_LT_EQ] = ACTIONS(99),
    [anon_sym_GT_EQ] = ACTIONS(99),
    [anon_sym_PLUS] = ACTIONS(101),
    [anon_sym_PLUS_EQ] = ACTIONS(99),
    [anon_sym_DASH_EQ] = ACTIONS(99),
    [anon_sym_u00d7] = ACTIONS(99),
    [anon_sym_SLASH] = ACTIONS(101),
    [anon_sym_u00f7] = ACTIONS(99),
    [anon_sym_STAR_STAR] = ACTIONS(99),
    [anon_sym_u220b] = ACTIONS(99),
    [anon_sym_u220c] = ACTIONS(99),
    [anon_sym_u2287] = ACTIONS(99),
    [anon_sym_u2283] = ACTIONS(99),
    [anon_sym_u2285] = ACTIONS(99),
    [anon_sym_u2208] = ACTIONS(99),
    [anon_sym_u2209] = ACTIONS(99),
    [anon_sym_u2286] = ACTIONS(99),
    [anon_sym_u2282] = ACTIONS(99),
    [anon_sym_u2284] = ACTIONS(99),
    [anon_sym_AT_AT] = ACTIONS(99),
  },
  [93] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(130),
    [sym_keyword_value] = ACTIONS(130),
    [sym_keyword_explain] = ACTIONS(130),
    [sym_keyword_parallel] = ACTIONS(130),
    [sym_keyword_timeout] = ACTIONS(130),
    [sym_keyword_fetch] = ACTIONS(130),
    [sym_keyword_limit] = ACTIONS(130),
    [sym_keyword_rand] = ACTIONS(130),
    [sym_keyword_collate] = ACTIONS(130),
    [sym_keyword_numeric] = ACTIONS(130),
    [sym_keyword_asc] = ACTIONS(130),
    [sym_keyword_desc] = ACTIONS(130),
    [sym_keyword_and] = ACTIONS(130),
    [sym_keyword_or] = ACTIONS(130),
    [sym_keyword_is] = ACTIONS(130),
    [sym_keyword_not] = ACTIONS(132),
    [sym_keyword_contains] = ACTIONS(130),
    [sym_keyword_contains_not] = ACTIONS(130),
    [sym_keyword_contains_all] = ACTIONS(130),
    [sym_keyword_contains_any] = ACTIONS(130),
    [sym_keyword_contains_none] = ACTIONS(130),
    [sym_keyword_inside] = ACTIONS(130),
    [sym_keyword_in] = ACTIONS(132),
    [sym_keyword_not_inside] = ACTIONS(130),
    [sym_keyword_all_inside] = ACTIONS(130),
    [sym_keyword_any_inside] = ACTIONS(130),
    [sym_keyword_none_inside] = ACTIONS(130),
    [sym_keyword_outside] = ACTIONS(130),
    [sym_keyword_intersects] = ACTIONS(130),
    [sym_keyword_flexible] = ACTIONS(130),
    [sym_keyword_readonly] = ACTIONS(130),
    [sym_keyword_type] = ACTIONS(130),
    [sym_keyword_default] = ACTIONS(130),
    [sym_keyword_assert] = ACTIONS(130),
    [sym_keyword_permissions] = ACTIONS(130),
    [sym_keyword_for] = ACTIONS(130),
    [sym_keyword_comment] = ACTIONS(130),
    [anon_sym_COMMA] = ACTIONS(130),
    [anon_sym_DASH_GT] = ACTIONS(130),
    [anon_sym_LBRACK] = ACTIONS(130),
    [anon_sym_RPAREN] = ACTIONS(130),
    [anon_sym_RBRACE] = ACTIONS(130),
    [anon_sym_LT_DASH] = ACTIONS(132),
    [anon_sym_LT_DASH_GT] = ACTIONS(130),
    [anon_sym_STAR] = ACTIONS(132),
    [anon_sym_DOT] = ACTIONS(132),
    [anon_sym_LT] = ACTIONS(132),
    [anon_sym_GT] = ACTIONS(132),
    [anon_sym_DOT_DOT] = ACTIONS(130),
    [anon_sym_EQ] = ACTIONS(132),
    [anon_sym_DASH] = ACTIONS(132),
    [anon_sym_AT] = ACTIONS(132),
    [anon_sym_LT_PIPE] = ACTIONS(130),
    [anon_sym_AMP_AMP] = ACTIONS(130),
    [anon_sym_PIPE_PIPE] = ACTIONS(130),
    [anon_sym_QMARK_QMARK] = ACTIONS(130),
    [anon_sym_QMARK_COLON] = ACTIONS(130),
    [anon_sym_BANG_EQ] = ACTIONS(130),
    [anon_sym_EQ_EQ] = ACTIONS(130),
    [anon_sym_QMARK_EQ] = ACTIONS(130),
    [anon_sym_STAR_EQ] = ACTIONS(130),
    [anon_sym_TILDE] = ACTIONS(130),
    [anon_sym_BANG_TILDE] = ACTIONS(130),
    [anon_sym_STAR_TILDE] = ACTIONS(130),
    [anon_sym_LT_EQ] = ACTIONS(130),
    [anon_sym_GT_EQ] = ACTIONS(130),
    [anon_sym_PLUS] = ACTIONS(132),
    [anon_sym_PLUS_EQ] = ACTIONS(130),
    [anon_sym_DASH_EQ] = ACTIONS(130),
    [anon_sym_u00d7] = ACTIONS(130),
    [anon_sym_SLASH] = ACTIONS(132),
    [anon_sym_u00f7] = ACTIONS(130),
    [anon_sym_STAR_STAR] = ACTIONS(130),
    [anon_sym_u220b] = ACTIONS(130),
    [anon_sym_u220c] = ACTIONS(130),
    [anon_sym_u2287] = ACTIONS(130),
    [anon_sym_u2283] = ACTIONS(130),
    [anon_sym_u2285] = ACTIONS(130),
    [anon_sym_u2208] = ACTIONS(130),
    [anon_sym_u2209] = ACTIONS(130),
    [anon_sym_u2286] = ACTIONS(130),
    [anon_sym_u2282] = ACTIONS(130),
    [anon_sym_u2284] = ACTIONS(130),
    [anon_sym_AT_AT] = ACTIONS(130),
  },
  [94] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(116),
    [sym_keyword_value] = ACTIONS(116),
    [sym_keyword_explain] = ACTIONS(116),
    [sym_keyword_parallel] = ACTIONS(116),
    [sym_keyword_timeout] = ACTIONS(116),
    [sym_keyword_fetch] = ACTIONS(116),
    [sym_keyword_limit] = ACTIONS(116),
    [sym_keyword_rand] = ACTIONS(116),
    [sym_keyword_collate] = ACTIONS(116),
    [sym_keyword_numeric] = ACTIONS(116),
    [sym_keyword_asc] = ACTIONS(116),
    [sym_keyword_desc] = ACTIONS(116),
    [sym_keyword_and] = ACTIONS(116),
    [sym_keyword_or] = ACTIONS(116),
    [sym_keyword_is] = ACTIONS(116),
    [sym_keyword_not] = ACTIONS(118),
    [sym_keyword_contains] = ACTIONS(116),
    [sym_keyword_contains_not] = ACTIONS(116),
    [sym_keyword_contains_all] = ACTIONS(116),
    [sym_keyword_contains_any] = ACTIONS(116),
    [sym_keyword_contains_none] = ACTIONS(116),
    [sym_keyword_inside] = ACTIONS(116),
    [sym_keyword_in] = ACTIONS(118),
    [sym_keyword_not_inside] = ACTIONS(116),
    [sym_keyword_all_inside] = ACTIONS(116),
    [sym_keyword_any_inside] = ACTIONS(116),
    [sym_keyword_none_inside] = ACTIONS(116),
    [sym_keyword_outside] = ACTIONS(116),
    [sym_keyword_intersects] = ACTIONS(116),
    [sym_keyword_flexible] = ACTIONS(116),
    [sym_keyword_readonly] = ACTIONS(116),
    [sym_keyword_type] = ACTIONS(116),
    [sym_keyword_default] = ACTIONS(116),
    [sym_keyword_assert] = ACTIONS(116),
    [sym_keyword_permissions] = ACTIONS(116),
    [sym_keyword_for] = ACTIONS(116),
    [sym_keyword_comment] = ACTIONS(116),
    [anon_sym_COMMA] = ACTIONS(116),
    [anon_sym_DASH_GT] = ACTIONS(116),
    [anon_sym_LBRACK] = ACTIONS(116),
    [anon_sym_RPAREN] = ACTIONS(116),
    [anon_sym_RBRACE] = ACTIONS(116),
    [anon_sym_LT_DASH] = ACTIONS(118),
    [anon_sym_LT_DASH_GT] = ACTIONS(116),
    [anon_sym_STAR] = ACTIONS(118),
    [anon_sym_DOT] = ACTIONS(118),
    [anon_sym_LT] = ACTIONS(118),
    [anon_sym_GT] = ACTIONS(118),
    [anon_sym_DOT_DOT] = ACTIONS(116),
    [anon_sym_EQ] = ACTIONS(118),
    [anon_sym_DASH] = ACTIONS(118),
    [anon_sym_AT] = ACTIONS(118),
    [anon_sym_LT_PIPE] = ACTIONS(116),
    [anon_sym_AMP_AMP] = ACTIONS(116),
    [anon_sym_PIPE_PIPE] = ACTIONS(116),
    [anon_sym_QMARK_QMARK] = ACTIONS(116),
    [anon_sym_QMARK_COLON] = ACTIONS(116),
    [anon_sym_BANG_EQ] = ACTIONS(116),
    [anon_sym_EQ_EQ] = ACTIONS(116),
    [anon_sym_QMARK_EQ] = ACTIONS(116),
    [anon_sym_STAR_EQ] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(116),
    [anon_sym_BANG_TILDE] = ACTIONS(116),
    [anon_sym_STAR_TILDE] = ACTIONS(116),
    [anon_sym_LT_EQ] = ACTIONS(116),
    [anon_sym_GT_EQ] = ACTIONS(116),
    [anon_sym_PLUS] = ACTIONS(118),
    [anon_sym_PLUS_EQ] = ACTIONS(116),
    [anon_sym_DASH_EQ] = ACTIONS(116),
    [anon_sym_u00d7] = ACTIONS(116),
    [anon_sym_SLASH] = ACTIONS(118),
    [anon_sym_u00f7] = ACTIONS(116),
    [anon_sym_STAR_STAR] = ACTIONS(116),
    [anon_sym_u220b] = ACTIONS(116),
    [anon_sym_u220c] = ACTIONS(116),
    [anon_sym_u2287] = ACTIONS(116),
    [anon_sym_u2283] = ACTIONS(116),
    [anon_sym_u2285] = ACTIONS(116),
    [anon_sym_u2208] = ACTIONS(116),
    [anon_sym_u2209] = ACTIONS(116),
    [anon_sym_u2286] = ACTIONS(116),
    [anon_sym_u2282] = ACTIONS(116),
    [anon_sym_u2284] = ACTIONS(116),
    [anon_sym_AT_AT] = ACTIONS(116),
  },
  [95] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(55),
    [sym_keyword_value] = ACTIONS(55),
    [sym_keyword_explain] = ACTIONS(55),
    [sym_keyword_parallel] = ACTIONS(55),
    [sym_keyword_timeout] = ACTIONS(55),
    [sym_keyword_fetch] = ACTIONS(55),
    [sym_keyword_limit] = ACTIONS(55),
    [sym_keyword_rand] = ACTIONS(55),
    [sym_keyword_collate] = ACTIONS(55),
    [sym_keyword_numeric] = ACTIONS(55),
    [sym_keyword_asc] = ACTIONS(55),
    [sym_keyword_desc] = ACTIONS(55),
    [sym_keyword_and] = ACTIONS(55),
    [sym_keyword_or] = ACTIONS(55),
    [sym_keyword_is] = ACTIONS(55),
    [sym_keyword_not] = ACTIONS(57),
    [sym_keyword_contains] = ACTIONS(55),
    [sym_keyword_contains_not] = ACTIONS(55),
    [sym_keyword_contains_all] = ACTIONS(55),
    [sym_keyword_contains_any] = ACTIONS(55),
    [sym_keyword_contains_none] = ACTIONS(55),
    [sym_keyword_inside] = ACTIONS(55),
    [sym_keyword_in] = ACTIONS(57),
    [sym_keyword_not_inside] = ACTIONS(55),
    [sym_keyword_all_inside] = ACTIONS(55),
    [sym_keyword_any_inside] = ACTIONS(55),
    [sym_keyword_none_inside] = ACTIONS(55),
    [sym_keyword_outside] = ACTIONS(55),
    [sym_keyword_intersects] = ACTIONS(55),
    [sym_keyword_flexible] = ACTIONS(55),
    [sym_keyword_readonly] = ACTIONS(55),
    [sym_keyword_type] = ACTIONS(55),
    [sym_keyword_default] = ACTIONS(55),
    [sym_keyword_assert] = ACTIONS(55),
    [sym_keyword_permissions] = ACTIONS(55),
    [sym_keyword_for] = ACTIONS(55),
    [sym_keyword_comment] = ACTIONS(55),
    [anon_sym_COMMA] = ACTIONS(55),
    [anon_sym_DASH_GT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(55),
    [anon_sym_RPAREN] = ACTIONS(55),
    [anon_sym_COLON] = ACTIONS(120),
    [anon_sym_RBRACE] = ACTIONS(55),
    [anon_sym_LT_DASH] = ACTIONS(57),
    [anon_sym_LT_DASH_GT] = ACTIONS(55),
    [anon_sym_STAR] = ACTIONS(57),
    [anon_sym_DOT] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(57),
    [anon_sym_GT] = ACTIONS(57),
    [anon_sym_EQ] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(57),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LT_PIPE] = ACTIONS(55),
    [anon_sym_AMP_AMP] = ACTIONS(55),
    [anon_sym_PIPE_PIPE] = ACTIONS(55),
    [anon_sym_QMARK_QMARK] = ACTIONS(55),
    [anon_sym_QMARK_COLON] = ACTIONS(55),
    [anon_sym_BANG_EQ] = ACTIONS(55),
    [anon_sym_EQ_EQ] = ACTIONS(55),
    [anon_sym_QMARK_EQ] = ACTIONS(55),
    [anon_sym_STAR_EQ] = ACTIONS(55),
    [anon_sym_TILDE] = ACTIONS(55),
    [anon_sym_BANG_TILDE] = ACTIONS(55),
    [anon_sym_STAR_TILDE] = ACTIONS(55),
    [anon_sym_LT_EQ] = ACTIONS(55),
    [anon_sym_GT_EQ] = ACTIONS(55),
    [anon_sym_PLUS] = ACTIONS(57),
    [anon_sym_PLUS_EQ] = ACTIONS(55),
    [anon_sym_DASH_EQ] = ACTIONS(55),
    [anon_sym_u00d7] = ACTIONS(55),
    [anon_sym_SLASH] = ACTIONS(57),
    [anon_sym_u00f7] = ACTIONS(55),
    [anon_sym_STAR_STAR] = ACTIONS(55),
    [anon_sym_u220b] = ACTIONS(55),
    [anon_sym_u220c] = ACTIONS(55),
    [anon_sym_u2287] = ACTIONS(55),
    [anon_sym_u2283] = ACTIONS(55),
    [anon_sym_u2285] = ACTIONS(55),
    [anon_sym_u2208] = ACTIONS(55),
    [anon_sym_u2209] = ACTIONS(55),
    [anon_sym_u2286] = ACTIONS(55),
    [anon_sym_u2282] = ACTIONS(55),
    [anon_sym_u2284] = ACTIONS(55),
    [anon_sym_AT_AT] = ACTIONS(55),
  },
  [96] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(126),
    [sym_keyword_value] = ACTIONS(126),
    [sym_keyword_explain] = ACTIONS(126),
    [sym_keyword_parallel] = ACTIONS(126),
    [sym_keyword_timeout] = ACTIONS(126),
    [sym_keyword_fetch] = ACTIONS(126),
    [sym_keyword_limit] = ACTIONS(126),
    [sym_keyword_rand] = ACTIONS(126),
    [sym_keyword_collate] = ACTIONS(126),
    [sym_keyword_numeric] = ACTIONS(126),
    [sym_keyword_asc] = ACTIONS(126),
    [sym_keyword_desc] = ACTIONS(126),
    [sym_keyword_and] = ACTIONS(126),
    [sym_keyword_or] = ACTIONS(126),
    [sym_keyword_is] = ACTIONS(126),
    [sym_keyword_not] = ACTIONS(128),
    [sym_keyword_contains] = ACTIONS(126),
    [sym_keyword_contains_not] = ACTIONS(126),
    [sym_keyword_contains_all] = ACTIONS(126),
    [sym_keyword_contains_any] = ACTIONS(126),
    [sym_keyword_contains_none] = ACTIONS(126),
    [sym_keyword_inside] = ACTIONS(126),
    [sym_keyword_in] = ACTIONS(128),
    [sym_keyword_not_inside] = ACTIONS(126),
    [sym_keyword_all_inside] = ACTIONS(126),
    [sym_keyword_any_inside] = ACTIONS(126),
    [sym_keyword_none_inside] = ACTIONS(126),
    [sym_keyword_outside] = ACTIONS(126),
    [sym_keyword_intersects] = ACTIONS(126),
    [sym_keyword_flexible] = ACTIONS(126),
    [sym_keyword_readonly] = ACTIONS(126),
    [sym_keyword_type] = ACTIONS(126),
    [sym_keyword_default] = ACTIONS(126),
    [sym_keyword_assert] = ACTIONS(126),
    [sym_keyword_permissions] = ACTIONS(126),
    [sym_keyword_for] = ACTIONS(126),
    [sym_keyword_comment] = ACTIONS(126),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_DASH_GT] = ACTIONS(126),
    [anon_sym_LBRACK] = ACTIONS(126),
    [anon_sym_RPAREN] = ACTIONS(126),
    [anon_sym_RBRACE] = ACTIONS(126),
    [anon_sym_LT_DASH] = ACTIONS(128),
    [anon_sym_LT_DASH_GT] = ACTIONS(126),
    [anon_sym_STAR] = ACTIONS(128),
    [anon_sym_DOT] = ACTIONS(128),
    [anon_sym_LT] = ACTIONS(128),
    [anon_sym_GT] = ACTIONS(128),
    [anon_sym_DOT_DOT] = ACTIONS(126),
    [anon_sym_EQ] = ACTIONS(128),
    [anon_sym_DASH] = ACTIONS(128),
    [anon_sym_AT] = ACTIONS(128),
    [anon_sym_LT_PIPE] = ACTIONS(126),
    [anon_sym_AMP_AMP] = ACTIONS(126),
    [anon_sym_PIPE_PIPE] = ACTIONS(126),
    [anon_sym_QMARK_QMARK] = ACTIONS(126),
    [anon_sym_QMARK_COLON] = ACTIONS(126),
    [anon_sym_BANG_EQ] = ACTIONS(126),
    [anon_sym_EQ_EQ] = ACTIONS(126),
    [anon_sym_QMARK_EQ] = ACTIONS(126),
    [anon_sym_STAR_EQ] = ACTIONS(126),
    [anon_sym_TILDE] = ACTIONS(126),
    [anon_sym_BANG_TILDE] = ACTIONS(126),
    [anon_sym_STAR_TILDE] = ACTIONS(126),
    [anon_sym_LT_EQ] = ACTIONS(126),
    [anon_sym_GT_EQ] = ACTIONS(126),
    [anon_sym_PLUS] = ACTIONS(128),
    [anon_sym_PLUS_EQ] = ACTIONS(126),
    [anon_sym_DASH_EQ] = ACTIONS(126),
    [anon_sym_u00d7] = ACTIONS(126),
    [anon_sym_SLASH] = ACTIONS(128),
    [anon_sym_u00f7] = ACTIONS(126),
    [anon_sym_STAR_STAR] = ACTIONS(126),
    [anon_sym_u220b] = ACTIONS(126),
    [anon_sym_u220c] = ACTIONS(126),
    [anon_sym_u2287] = ACTIONS(126),
    [anon_sym_u2283] = ACTIONS(126),
    [anon_sym_u2285] = ACTIONS(126),
    [anon_sym_u2208] = ACTIONS(126),
    [anon_sym_u2209] = ACTIONS(126),
    [anon_sym_u2286] = ACTIONS(126),
    [anon_sym_u2282] = ACTIONS(126),
    [anon_sym_u2284] = ACTIONS(126),
    [anon_sym_AT_AT] = ACTIONS(126),
  },
  [97] = {
    [aux_sym_duration_repeat1] = STATE(97),
    [ts_builtin_sym_end] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(105),
    [sym_keyword_value] = ACTIONS(105),
    [sym_keyword_explain] = ACTIONS(105),
    [sym_keyword_parallel] = ACTIONS(105),
    [sym_keyword_timeout] = ACTIONS(105),
    [sym_keyword_fetch] = ACTIONS(105),
    [sym_keyword_limit] = ACTIONS(105),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_collate] = ACTIONS(105),
    [sym_keyword_numeric] = ACTIONS(105),
    [sym_keyword_asc] = ACTIONS(105),
    [sym_keyword_desc] = ACTIONS(105),
    [sym_keyword_and] = ACTIONS(105),
    [sym_keyword_or] = ACTIONS(105),
    [sym_keyword_is] = ACTIONS(105),
    [sym_keyword_not] = ACTIONS(107),
    [sym_keyword_contains] = ACTIONS(105),
    [sym_keyword_contains_not] = ACTIONS(105),
    [sym_keyword_contains_all] = ACTIONS(105),
    [sym_keyword_contains_any] = ACTIONS(105),
    [sym_keyword_contains_none] = ACTIONS(105),
    [sym_keyword_inside] = ACTIONS(105),
    [sym_keyword_in] = ACTIONS(107),
    [sym_keyword_not_inside] = ACTIONS(105),
    [sym_keyword_all_inside] = ACTIONS(105),
    [sym_keyword_any_inside] = ACTIONS(105),
    [sym_keyword_none_inside] = ACTIONS(105),
    [sym_keyword_outside] = ACTIONS(105),
    [sym_keyword_intersects] = ACTIONS(105),
    [sym_keyword_flexible] = ACTIONS(105),
    [sym_keyword_readonly] = ACTIONS(105),
    [sym_keyword_type] = ACTIONS(105),
    [sym_keyword_default] = ACTIONS(105),
    [sym_keyword_assert] = ACTIONS(105),
    [sym_keyword_permissions] = ACTIONS(105),
    [sym_keyword_for] = ACTIONS(105),
    [sym_keyword_comment] = ACTIONS(105),
    [anon_sym_COMMA] = ACTIONS(105),
    [anon_sym_DASH_GT] = ACTIONS(105),
    [anon_sym_LBRACK] = ACTIONS(105),
    [anon_sym_LT_DASH] = ACTIONS(107),
    [anon_sym_LT_DASH_GT] = ACTIONS(105),
    [anon_sym_STAR] = ACTIONS(107),
    [anon_sym_DOT] = ACTIONS(105),
    [anon_sym_LT] = ACTIONS(107),
    [anon_sym_GT] = ACTIONS(107),
    [anon_sym_EQ] = ACTIONS(107),
    [sym_duration_part] = ACTIONS(284),
    [anon_sym_DASH] = ACTIONS(107),
    [anon_sym_AT] = ACTIONS(107),
    [anon_sym_LT_PIPE] = ACTIONS(105),
    [anon_sym_AMP_AMP] = ACTIONS(105),
    [anon_sym_PIPE_PIPE] = ACTIONS(105),
    [anon_sym_QMARK_QMARK] = ACTIONS(105),
    [anon_sym_QMARK_COLON] = ACTIONS(105),
    [anon_sym_BANG_EQ] = ACTIONS(105),
    [anon_sym_EQ_EQ] = ACTIONS(105),
    [anon_sym_QMARK_EQ] = ACTIONS(105),
    [anon_sym_STAR_EQ] = ACTIONS(105),
    [anon_sym_TILDE] = ACTIONS(105),
    [anon_sym_BANG_TILDE] = ACTIONS(105),
    [anon_sym_STAR_TILDE] = ACTIONS(105),
    [anon_sym_LT_EQ] = ACTIONS(105),
    [anon_sym_GT_EQ] = ACTIONS(105),
    [anon_sym_PLUS] = ACTIONS(107),
    [anon_sym_PLUS_EQ] = ACTIONS(105),
    [anon_sym_DASH_EQ] = ACTIONS(105),
    [anon_sym_u00d7] = ACTIONS(105),
    [anon_sym_SLASH] = ACTIONS(107),
    [anon_sym_u00f7] = ACTIONS(105),
    [anon_sym_STAR_STAR] = ACTIONS(105),
    [anon_sym_u220b] = ACTIONS(105),
    [anon_sym_u220c] = ACTIONS(105),
    [anon_sym_u2287] = ACTIONS(105),
    [anon_sym_u2283] = ACTIONS(105),
    [anon_sym_u2285] = ACTIONS(105),
    [anon_sym_u2208] = ACTIONS(105),
    [anon_sym_u2209] = ACTIONS(105),
    [anon_sym_u2286] = ACTIONS(105),
    [anon_sym_u2282] = ACTIONS(105),
    [anon_sym_u2284] = ACTIONS(105),
    [anon_sym_AT_AT] = ACTIONS(105),
  },
  [98] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(122),
    [sym_keyword_value] = ACTIONS(122),
    [sym_keyword_explain] = ACTIONS(122),
    [sym_keyword_parallel] = ACTIONS(122),
    [sym_keyword_timeout] = ACTIONS(122),
    [sym_keyword_fetch] = ACTIONS(122),
    [sym_keyword_limit] = ACTIONS(122),
    [sym_keyword_rand] = ACTIONS(122),
    [sym_keyword_collate] = ACTIONS(122),
    [sym_keyword_numeric] = ACTIONS(122),
    [sym_keyword_asc] = ACTIONS(122),
    [sym_keyword_desc] = ACTIONS(122),
    [sym_keyword_and] = ACTIONS(122),
    [sym_keyword_or] = ACTIONS(122),
    [sym_keyword_is] = ACTIONS(122),
    [sym_keyword_not] = ACTIONS(124),
    [sym_keyword_contains] = ACTIONS(122),
    [sym_keyword_contains_not] = ACTIONS(122),
    [sym_keyword_contains_all] = ACTIONS(122),
    [sym_keyword_contains_any] = ACTIONS(122),
    [sym_keyword_contains_none] = ACTIONS(122),
    [sym_keyword_inside] = ACTIONS(122),
    [sym_keyword_in] = ACTIONS(124),
    [sym_keyword_not_inside] = ACTIONS(122),
    [sym_keyword_all_inside] = ACTIONS(122),
    [sym_keyword_any_inside] = ACTIONS(122),
    [sym_keyword_none_inside] = ACTIONS(122),
    [sym_keyword_outside] = ACTIONS(122),
    [sym_keyword_intersects] = ACTIONS(122),
    [sym_keyword_flexible] = ACTIONS(122),
    [sym_keyword_readonly] = ACTIONS(122),
    [sym_keyword_type] = ACTIONS(122),
    [sym_keyword_default] = ACTIONS(122),
    [sym_keyword_assert] = ACTIONS(122),
    [sym_keyword_permissions] = ACTIONS(122),
    [sym_keyword_for] = ACTIONS(122),
    [sym_keyword_comment] = ACTIONS(122),
    [anon_sym_COMMA] = ACTIONS(122),
    [anon_sym_DASH_GT] = ACTIONS(122),
    [anon_sym_LBRACK] = ACTIONS(122),
    [anon_sym_RPAREN] = ACTIONS(122),
    [anon_sym_RBRACE] = ACTIONS(122),
    [anon_sym_LT_DASH] = ACTIONS(124),
    [anon_sym_LT_DASH_GT] = ACTIONS(122),
    [anon_sym_STAR] = ACTIONS(124),
    [anon_sym_DOT] = ACTIONS(124),
    [anon_sym_LT] = ACTIONS(124),
    [anon_sym_GT] = ACTIONS(124),
    [anon_sym_DOT_DOT] = ACTIONS(122),
    [anon_sym_EQ] = ACTIONS(124),
    [anon_sym_DASH] = ACTIONS(124),
    [anon_sym_AT] = ACTIONS(124),
    [anon_sym_LT_PIPE] = ACTIONS(122),
    [anon_sym_AMP_AMP] = ACTIONS(122),
    [anon_sym_PIPE_PIPE] = ACTIONS(122),
    [anon_sym_QMARK_QMARK] = ACTIONS(122),
    [anon_sym_QMARK_COLON] = ACTIONS(122),
    [anon_sym_BANG_EQ] = ACTIONS(122),
    [anon_sym_EQ_EQ] = ACTIONS(122),
    [anon_sym_QMARK_EQ] = ACTIONS(122),
    [anon_sym_STAR_EQ] = ACTIONS(122),
    [anon_sym_TILDE] = ACTIONS(122),
    [anon_sym_BANG_TILDE] = ACTIONS(122),
    [anon_sym_STAR_TILDE] = ACTIONS(122),
    [anon_sym_LT_EQ] = ACTIONS(122),
    [anon_sym_GT_EQ] = ACTIONS(122),
    [anon_sym_PLUS] = ACTIONS(124),
    [anon_sym_PLUS_EQ] = ACTIONS(122),
    [anon_sym_DASH_EQ] = ACTIONS(122),
    [anon_sym_u00d7] = ACTIONS(122),
    [anon_sym_SLASH] = ACTIONS(124),
    [anon_sym_u00f7] = ACTIONS(122),
    [anon_sym_STAR_STAR] = ACTIONS(122),
    [anon_sym_u220b] = ACTIONS(122),
    [anon_sym_u220c] = ACTIONS(122),
    [anon_sym_u2287] = ACTIONS(122),
    [anon_sym_u2283] = ACTIONS(122),
    [anon_sym_u2285] = ACTIONS(122),
    [anon_sym_u2208] = ACTIONS(122),
    [anon_sym_u2209] = ACTIONS(122),
    [anon_sym_u2286] = ACTIONS(122),
    [anon_sym_u2282] = ACTIONS(122),
    [anon_sym_u2284] = ACTIONS(122),
    [anon_sym_AT_AT] = ACTIONS(122),
  },
  [99] = {
    [ts_builtin_sym_end] = ACTIONS(59),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(59),
    [sym_keyword_return] = ACTIONS(59),
    [sym_keyword_value] = ACTIONS(59),
    [sym_keyword_explain] = ACTIONS(59),
    [sym_keyword_parallel] = ACTIONS(59),
    [sym_keyword_timeout] = ACTIONS(59),
    [sym_keyword_fetch] = ACTIONS(59),
    [sym_keyword_limit] = ACTIONS(59),
    [sym_keyword_rand] = ACTIONS(59),
    [sym_keyword_collate] = ACTIONS(59),
    [sym_keyword_numeric] = ACTIONS(59),
    [sym_keyword_asc] = ACTIONS(59),
    [sym_keyword_desc] = ACTIONS(59),
    [sym_keyword_where] = ACTIONS(59),
    [sym_keyword_and] = ACTIONS(59),
    [sym_keyword_or] = ACTIONS(59),
    [sym_keyword_is] = ACTIONS(59),
    [sym_keyword_not] = ACTIONS(61),
    [sym_keyword_contains] = ACTIONS(59),
    [sym_keyword_contains_not] = ACTIONS(59),
    [sym_keyword_contains_all] = ACTIONS(59),
    [sym_keyword_contains_any] = ACTIONS(59),
    [sym_keyword_contains_none] = ACTIONS(59),
    [sym_keyword_inside] = ACTIONS(59),
    [sym_keyword_in] = ACTIONS(61),
    [sym_keyword_not_inside] = ACTIONS(59),
    [sym_keyword_all_inside] = ACTIONS(59),
    [sym_keyword_any_inside] = ACTIONS(59),
    [sym_keyword_none_inside] = ACTIONS(59),
    [sym_keyword_outside] = ACTIONS(59),
    [sym_keyword_intersects] = ACTIONS(59),
    [sym_keyword_flexible] = ACTIONS(59),
    [sym_keyword_readonly] = ACTIONS(59),
    [sym_keyword_content] = ACTIONS(59),
    [sym_keyword_merge] = ACTIONS(59),
    [sym_keyword_patch] = ACTIONS(59),
    [sym_keyword_type] = ACTIONS(59),
    [sym_keyword_default] = ACTIONS(59),
    [sym_keyword_assert] = ACTIONS(59),
    [sym_keyword_permissions] = ACTIONS(59),
    [sym_keyword_for] = ACTIONS(59),
    [sym_keyword_comment] = ACTIONS(59),
    [sym_keyword_set] = ACTIONS(59),
    [sym_keyword_unset] = ACTIONS(59),
    [anon_sym_COMMA] = ACTIONS(59),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(61),
    [anon_sym_LT_PIPE] = ACTIONS(59),
    [anon_sym_AMP_AMP] = ACTIONS(59),
    [anon_sym_PIPE_PIPE] = ACTIONS(59),
    [anon_sym_QMARK_QMARK] = ACTIONS(59),
    [anon_sym_QMARK_COLON] = ACTIONS(59),
    [anon_sym_BANG_EQ] = ACTIONS(59),
    [anon_sym_EQ_EQ] = ACTIONS(59),
    [anon_sym_QMARK_EQ] = ACTIONS(59),
    [anon_sym_STAR_EQ] = ACTIONS(59),
    [anon_sym_TILDE] = ACTIONS(59),
    [anon_sym_BANG_TILDE] = ACTIONS(59),
    [anon_sym_STAR_TILDE] = ACTIONS(59),
    [anon_sym_LT_EQ] = ACTIONS(59),
    [anon_sym_GT_EQ] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_PLUS_EQ] = ACTIONS(59),
    [anon_sym_DASH_EQ] = ACTIONS(59),
    [anon_sym_u00d7] = ACTIONS(59),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_u00f7] = ACTIONS(59),
    [anon_sym_STAR_STAR] = ACTIONS(59),
    [anon_sym_u220b] = ACTIONS(59),
    [anon_sym_u220c] = ACTIONS(59),
    [anon_sym_u2287] = ACTIONS(59),
    [anon_sym_u2283] = ACTIONS(59),
    [anon_sym_u2285] = ACTIONS(59),
    [anon_sym_u2208] = ACTIONS(59),
    [anon_sym_u2209] = ACTIONS(59),
    [anon_sym_u2286] = ACTIONS(59),
    [anon_sym_u2282] = ACTIONS(59),
    [anon_sym_u2284] = ACTIONS(59),
    [anon_sym_AT_AT] = ACTIONS(59),
  },
  [100] = {
    [aux_sym_duration_repeat1] = STATE(97),
    [ts_builtin_sym_end] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(99),
    [sym_keyword_value] = ACTIONS(99),
    [sym_keyword_explain] = ACTIONS(99),
    [sym_keyword_parallel] = ACTIONS(99),
    [sym_keyword_timeout] = ACTIONS(99),
    [sym_keyword_fetch] = ACTIONS(99),
    [sym_keyword_limit] = ACTIONS(99),
    [sym_keyword_rand] = ACTIONS(99),
    [sym_keyword_collate] = ACTIONS(99),
    [sym_keyword_numeric] = ACTIONS(99),
    [sym_keyword_asc] = ACTIONS(99),
    [sym_keyword_desc] = ACTIONS(99),
    [sym_keyword_and] = ACTIONS(99),
    [sym_keyword_or] = ACTIONS(99),
    [sym_keyword_is] = ACTIONS(99),
    [sym_keyword_not] = ACTIONS(101),
    [sym_keyword_contains] = ACTIONS(99),
    [sym_keyword_contains_not] = ACTIONS(99),
    [sym_keyword_contains_all] = ACTIONS(99),
    [sym_keyword_contains_any] = ACTIONS(99),
    [sym_keyword_contains_none] = ACTIONS(99),
    [sym_keyword_inside] = ACTIONS(99),
    [sym_keyword_in] = ACTIONS(101),
    [sym_keyword_not_inside] = ACTIONS(99),
    [sym_keyword_all_inside] = ACTIONS(99),
    [sym_keyword_any_inside] = ACTIONS(99),
    [sym_keyword_none_inside] = ACTIONS(99),
    [sym_keyword_outside] = ACTIONS(99),
    [sym_keyword_intersects] = ACTIONS(99),
    [sym_keyword_flexible] = ACTIONS(99),
    [sym_keyword_readonly] = ACTIONS(99),
    [sym_keyword_type] = ACTIONS(99),
    [sym_keyword_default] = ACTIONS(99),
    [sym_keyword_assert] = ACTIONS(99),
    [sym_keyword_permissions] = ACTIONS(99),
    [sym_keyword_for] = ACTIONS(99),
    [sym_keyword_comment] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_DASH_GT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(99),
    [anon_sym_LT_DASH] = ACTIONS(101),
    [anon_sym_LT_DASH_GT] = ACTIONS(99),
    [anon_sym_STAR] = ACTIONS(101),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LT] = ACTIONS(101),
    [anon_sym_GT] = ACTIONS(101),
    [anon_sym_EQ] = ACTIONS(101),
    [sym_duration_part] = ACTIONS(287),
    [anon_sym_DASH] = ACTIONS(101),
    [anon_sym_AT] = ACTIONS(101),
    [anon_sym_LT_PIPE] = ACTIONS(99),
    [anon_sym_AMP_AMP] = ACTIONS(99),
    [anon_sym_PIPE_PIPE] = ACTIONS(99),
    [anon_sym_QMARK_QMARK] = ACTIONS(99),
    [anon_sym_QMARK_COLON] = ACTIONS(99),
    [anon_sym_BANG_EQ] = ACTIONS(99),
    [anon_sym_EQ_EQ] = ACTIONS(99),
    [anon_sym_QMARK_EQ] = ACTIONS(99),
    [anon_sym_STAR_EQ] = ACTIONS(99),
    [anon_sym_TILDE] = ACTIONS(99),
    [anon_sym_BANG_TILDE] = ACTIONS(99),
    [anon_sym_STAR_TILDE] = ACTIONS(99),
    [anon_sym_LT_EQ] = ACTIONS(99),
    [anon_sym_GT_EQ] = ACTIONS(99),
    [anon_sym_PLUS] = ACTIONS(101),
    [anon_sym_PLUS_EQ] = ACTIONS(99),
    [anon_sym_DASH_EQ] = ACTIONS(99),
    [anon_sym_u00d7] = ACTIONS(99),
    [anon_sym_SLASH] = ACTIONS(101),
    [anon_sym_u00f7] = ACTIONS(99),
    [anon_sym_STAR_STAR] = ACTIONS(99),
    [anon_sym_u220b] = ACTIONS(99),
    [anon_sym_u220c] = ACTIONS(99),
    [anon_sym_u2287] = ACTIONS(99),
    [anon_sym_u2283] = ACTIONS(99),
    [anon_sym_u2285] = ACTIONS(99),
    [anon_sym_u2208] = ACTIONS(99),
    [anon_sym_u2209] = ACTIONS(99),
    [anon_sym_u2286] = ACTIONS(99),
    [anon_sym_u2282] = ACTIONS(99),
    [anon_sym_u2284] = ACTIONS(99),
    [anon_sym_AT_AT] = ACTIONS(99),
  },
  [101] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(134),
    [sym_keyword_value] = ACTIONS(134),
    [sym_keyword_explain] = ACTIONS(134),
    [sym_keyword_parallel] = ACTIONS(134),
    [sym_keyword_timeout] = ACTIONS(134),
    [sym_keyword_fetch] = ACTIONS(134),
    [sym_keyword_limit] = ACTIONS(134),
    [sym_keyword_rand] = ACTIONS(134),
    [sym_keyword_collate] = ACTIONS(134),
    [sym_keyword_numeric] = ACTIONS(134),
    [sym_keyword_asc] = ACTIONS(134),
    [sym_keyword_desc] = ACTIONS(134),
    [sym_keyword_and] = ACTIONS(134),
    [sym_keyword_or] = ACTIONS(134),
    [sym_keyword_is] = ACTIONS(134),
    [sym_keyword_not] = ACTIONS(136),
    [sym_keyword_contains] = ACTIONS(134),
    [sym_keyword_contains_not] = ACTIONS(134),
    [sym_keyword_contains_all] = ACTIONS(134),
    [sym_keyword_contains_any] = ACTIONS(134),
    [sym_keyword_contains_none] = ACTIONS(134),
    [sym_keyword_inside] = ACTIONS(134),
    [sym_keyword_in] = ACTIONS(136),
    [sym_keyword_not_inside] = ACTIONS(134),
    [sym_keyword_all_inside] = ACTIONS(134),
    [sym_keyword_any_inside] = ACTIONS(134),
    [sym_keyword_none_inside] = ACTIONS(134),
    [sym_keyword_outside] = ACTIONS(134),
    [sym_keyword_intersects] = ACTIONS(134),
    [sym_keyword_flexible] = ACTIONS(134),
    [sym_keyword_readonly] = ACTIONS(134),
    [sym_keyword_type] = ACTIONS(134),
    [sym_keyword_default] = ACTIONS(134),
    [sym_keyword_assert] = ACTIONS(134),
    [sym_keyword_permissions] = ACTIONS(134),
    [sym_keyword_for] = ACTIONS(134),
    [sym_keyword_comment] = ACTIONS(134),
    [anon_sym_COMMA] = ACTIONS(134),
    [anon_sym_DASH_GT] = ACTIONS(134),
    [anon_sym_LBRACK] = ACTIONS(134),
    [anon_sym_RPAREN] = ACTIONS(134),
    [anon_sym_RBRACE] = ACTIONS(134),
    [anon_sym_LT_DASH] = ACTIONS(136),
    [anon_sym_LT_DASH_GT] = ACTIONS(134),
    [anon_sym_STAR] = ACTIONS(136),
    [anon_sym_DOT] = ACTIONS(136),
    [anon_sym_LT] = ACTIONS(136),
    [anon_sym_GT] = ACTIONS(136),
    [anon_sym_DOT_DOT] = ACTIONS(134),
    [anon_sym_EQ] = ACTIONS(136),
    [anon_sym_DASH] = ACTIONS(136),
    [anon_sym_AT] = ACTIONS(136),
    [anon_sym_LT_PIPE] = ACTIONS(134),
    [anon_sym_AMP_AMP] = ACTIONS(134),
    [anon_sym_PIPE_PIPE] = ACTIONS(134),
    [anon_sym_QMARK_QMARK] = ACTIONS(134),
    [anon_sym_QMARK_COLON] = ACTIONS(134),
    [anon_sym_BANG_EQ] = ACTIONS(134),
    [anon_sym_EQ_EQ] = ACTIONS(134),
    [anon_sym_QMARK_EQ] = ACTIONS(134),
    [anon_sym_STAR_EQ] = ACTIONS(134),
    [anon_sym_TILDE] = ACTIONS(134),
    [anon_sym_BANG_TILDE] = ACTIONS(134),
    [anon_sym_STAR_TILDE] = ACTIONS(134),
    [anon_sym_LT_EQ] = ACTIONS(134),
    [anon_sym_GT_EQ] = ACTIONS(134),
    [anon_sym_PLUS] = ACTIONS(136),
    [anon_sym_PLUS_EQ] = ACTIONS(134),
    [anon_sym_DASH_EQ] = ACTIONS(134),
    [anon_sym_u00d7] = ACTIONS(134),
    [anon_sym_SLASH] = ACTIONS(136),
    [anon_sym_u00f7] = ACTIONS(134),
    [anon_sym_STAR_STAR] = ACTIONS(134),
    [anon_sym_u220b] = ACTIONS(134),
    [anon_sym_u220c] = ACTIONS(134),
    [anon_sym_u2287] = ACTIONS(134),
    [anon_sym_u2283] = ACTIONS(134),
    [anon_sym_u2285] = ACTIONS(134),
    [anon_sym_u2208] = ACTIONS(134),
    [anon_sym_u2209] = ACTIONS(134),
    [anon_sym_u2286] = ACTIONS(134),
    [anon_sym_u2282] = ACTIONS(134),
    [anon_sym_u2284] = ACTIONS(134),
    [anon_sym_AT_AT] = ACTIONS(134),
  },
  [102] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(112),
    [sym_keyword_value] = ACTIONS(112),
    [sym_keyword_explain] = ACTIONS(112),
    [sym_keyword_parallel] = ACTIONS(112),
    [sym_keyword_timeout] = ACTIONS(112),
    [sym_keyword_fetch] = ACTIONS(112),
    [sym_keyword_limit] = ACTIONS(112),
    [sym_keyword_rand] = ACTIONS(112),
    [sym_keyword_collate] = ACTIONS(112),
    [sym_keyword_numeric] = ACTIONS(112),
    [sym_keyword_asc] = ACTIONS(112),
    [sym_keyword_desc] = ACTIONS(112),
    [sym_keyword_and] = ACTIONS(112),
    [sym_keyword_or] = ACTIONS(112),
    [sym_keyword_is] = ACTIONS(112),
    [sym_keyword_not] = ACTIONS(114),
    [sym_keyword_contains] = ACTIONS(112),
    [sym_keyword_contains_not] = ACTIONS(112),
    [sym_keyword_contains_all] = ACTIONS(112),
    [sym_keyword_contains_any] = ACTIONS(112),
    [sym_keyword_contains_none] = ACTIONS(112),
    [sym_keyword_inside] = ACTIONS(112),
    [sym_keyword_in] = ACTIONS(114),
    [sym_keyword_not_inside] = ACTIONS(112),
    [sym_keyword_all_inside] = ACTIONS(112),
    [sym_keyword_any_inside] = ACTIONS(112),
    [sym_keyword_none_inside] = ACTIONS(112),
    [sym_keyword_outside] = ACTIONS(112),
    [sym_keyword_intersects] = ACTIONS(112),
    [sym_keyword_flexible] = ACTIONS(112),
    [sym_keyword_readonly] = ACTIONS(112),
    [sym_keyword_type] = ACTIONS(112),
    [sym_keyword_default] = ACTIONS(112),
    [sym_keyword_assert] = ACTIONS(112),
    [sym_keyword_permissions] = ACTIONS(112),
    [sym_keyword_for] = ACTIONS(112),
    [sym_keyword_comment] = ACTIONS(112),
    [anon_sym_COMMA] = ACTIONS(112),
    [anon_sym_DASH_GT] = ACTIONS(112),
    [anon_sym_LBRACK] = ACTIONS(112),
    [anon_sym_RPAREN] = ACTIONS(112),
    [anon_sym_RBRACE] = ACTIONS(112),
    [anon_sym_LT_DASH] = ACTIONS(114),
    [anon_sym_LT_DASH_GT] = ACTIONS(112),
    [anon_sym_STAR] = ACTIONS(114),
    [anon_sym_DOT] = ACTIONS(114),
    [anon_sym_LT] = ACTIONS(114),
    [anon_sym_GT] = ACTIONS(114),
    [anon_sym_DOT_DOT] = ACTIONS(112),
    [anon_sym_EQ] = ACTIONS(114),
    [anon_sym_DASH] = ACTIONS(114),
    [anon_sym_AT] = ACTIONS(114),
    [anon_sym_LT_PIPE] = ACTIONS(112),
    [anon_sym_AMP_AMP] = ACTIONS(112),
    [anon_sym_PIPE_PIPE] = ACTIONS(112),
    [anon_sym_QMARK_QMARK] = ACTIONS(112),
    [anon_sym_QMARK_COLON] = ACTIONS(112),
    [anon_sym_BANG_EQ] = ACTIONS(112),
    [anon_sym_EQ_EQ] = ACTIONS(112),
    [anon_sym_QMARK_EQ] = ACTIONS(112),
    [anon_sym_STAR_EQ] = ACTIONS(112),
    [anon_sym_TILDE] = ACTIONS(112),
    [anon_sym_BANG_TILDE] = ACTIONS(112),
    [anon_sym_STAR_TILDE] = ACTIONS(112),
    [anon_sym_LT_EQ] = ACTIONS(112),
    [anon_sym_GT_EQ] = ACTIONS(112),
    [anon_sym_PLUS] = ACTIONS(114),
    [anon_sym_PLUS_EQ] = ACTIONS(112),
    [anon_sym_DASH_EQ] = ACTIONS(112),
    [anon_sym_u00d7] = ACTIONS(112),
    [anon_sym_SLASH] = ACTIONS(114),
    [anon_sym_u00f7] = ACTIONS(112),
    [anon_sym_STAR_STAR] = ACTIONS(112),
    [anon_sym_u220b] = ACTIONS(112),
    [anon_sym_u220c] = ACTIONS(112),
    [anon_sym_u2287] = ACTIONS(112),
    [anon_sym_u2283] = ACTIONS(112),
    [anon_sym_u2285] = ACTIONS(112),
    [anon_sym_u2208] = ACTIONS(112),
    [anon_sym_u2209] = ACTIONS(112),
    [anon_sym_u2286] = ACTIONS(112),
    [anon_sym_u2282] = ACTIONS(112),
    [anon_sym_u2284] = ACTIONS(112),
    [anon_sym_AT_AT] = ACTIONS(112),
  },
  [103] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_value] = ACTIONS(210),
    [sym_keyword_explain] = ACTIONS(210),
    [sym_keyword_parallel] = ACTIONS(210),
    [sym_keyword_timeout] = ACTIONS(210),
    [sym_keyword_fetch] = ACTIONS(210),
    [sym_keyword_limit] = ACTIONS(210),
    [sym_keyword_rand] = ACTIONS(210),
    [sym_keyword_collate] = ACTIONS(210),
    [sym_keyword_numeric] = ACTIONS(210),
    [sym_keyword_asc] = ACTIONS(210),
    [sym_keyword_desc] = ACTIONS(210),
    [sym_keyword_and] = ACTIONS(210),
    [sym_keyword_or] = ACTIONS(210),
    [sym_keyword_is] = ACTIONS(210),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(210),
    [sym_keyword_contains_not] = ACTIONS(210),
    [sym_keyword_contains_all] = ACTIONS(210),
    [sym_keyword_contains_any] = ACTIONS(210),
    [sym_keyword_contains_none] = ACTIONS(210),
    [sym_keyword_inside] = ACTIONS(210),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(210),
    [sym_keyword_all_inside] = ACTIONS(210),
    [sym_keyword_any_inside] = ACTIONS(210),
    [sym_keyword_none_inside] = ACTIONS(210),
    [sym_keyword_outside] = ACTIONS(210),
    [sym_keyword_intersects] = ACTIONS(210),
    [sym_keyword_flexible] = ACTIONS(210),
    [sym_keyword_readonly] = ACTIONS(210),
    [sym_keyword_type] = ACTIONS(210),
    [sym_keyword_default] = ACTIONS(210),
    [sym_keyword_assert] = ACTIONS(210),
    [sym_keyword_permissions] = ACTIONS(210),
    [sym_keyword_for] = ACTIONS(210),
    [sym_keyword_comment] = ACTIONS(210),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [104] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(146),
    [sym_keyword_value] = ACTIONS(146),
    [sym_keyword_explain] = ACTIONS(146),
    [sym_keyword_parallel] = ACTIONS(146),
    [sym_keyword_timeout] = ACTIONS(146),
    [sym_keyword_fetch] = ACTIONS(146),
    [sym_keyword_limit] = ACTIONS(146),
    [sym_keyword_rand] = ACTIONS(146),
    [sym_keyword_collate] = ACTIONS(146),
    [sym_keyword_numeric] = ACTIONS(146),
    [sym_keyword_asc] = ACTIONS(146),
    [sym_keyword_desc] = ACTIONS(146),
    [sym_keyword_and] = ACTIONS(146),
    [sym_keyword_or] = ACTIONS(146),
    [sym_keyword_is] = ACTIONS(146),
    [sym_keyword_not] = ACTIONS(148),
    [sym_keyword_contains] = ACTIONS(146),
    [sym_keyword_contains_not] = ACTIONS(146),
    [sym_keyword_contains_all] = ACTIONS(146),
    [sym_keyword_contains_any] = ACTIONS(146),
    [sym_keyword_contains_none] = ACTIONS(146),
    [sym_keyword_inside] = ACTIONS(146),
    [sym_keyword_in] = ACTIONS(148),
    [sym_keyword_not_inside] = ACTIONS(146),
    [sym_keyword_all_inside] = ACTIONS(146),
    [sym_keyword_any_inside] = ACTIONS(146),
    [sym_keyword_none_inside] = ACTIONS(146),
    [sym_keyword_outside] = ACTIONS(146),
    [sym_keyword_intersects] = ACTIONS(146),
    [sym_keyword_flexible] = ACTIONS(146),
    [sym_keyword_readonly] = ACTIONS(146),
    [sym_keyword_type] = ACTIONS(146),
    [sym_keyword_default] = ACTIONS(146),
    [sym_keyword_assert] = ACTIONS(146),
    [sym_keyword_permissions] = ACTIONS(146),
    [sym_keyword_for] = ACTIONS(146),
    [sym_keyword_comment] = ACTIONS(146),
    [anon_sym_COMMA] = ACTIONS(146),
    [anon_sym_DASH_GT] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(146),
    [anon_sym_RPAREN] = ACTIONS(146),
    [anon_sym_RBRACE] = ACTIONS(146),
    [anon_sym_LT_DASH] = ACTIONS(148),
    [anon_sym_LT_DASH_GT] = ACTIONS(146),
    [anon_sym_STAR] = ACTIONS(148),
    [anon_sym_DOT] = ACTIONS(146),
    [anon_sym_LT] = ACTIONS(148),
    [anon_sym_GT] = ACTIONS(148),
    [anon_sym_EQ] = ACTIONS(148),
    [anon_sym_DASH] = ACTIONS(148),
    [anon_sym_AT] = ACTIONS(148),
    [anon_sym_LT_PIPE] = ACTIONS(146),
    [anon_sym_AMP_AMP] = ACTIONS(146),
    [anon_sym_PIPE_PIPE] = ACTIONS(146),
    [anon_sym_QMARK_QMARK] = ACTIONS(146),
    [anon_sym_QMARK_COLON] = ACTIONS(146),
    [anon_sym_BANG_EQ] = ACTIONS(146),
    [anon_sym_EQ_EQ] = ACTIONS(146),
    [anon_sym_QMARK_EQ] = ACTIONS(146),
    [anon_sym_STAR_EQ] = ACTIONS(146),
    [anon_sym_TILDE] = ACTIONS(146),
    [anon_sym_BANG_TILDE] = ACTIONS(146),
    [anon_sym_STAR_TILDE] = ACTIONS(146),
    [anon_sym_LT_EQ] = ACTIONS(146),
    [anon_sym_GT_EQ] = ACTIONS(146),
    [anon_sym_PLUS] = ACTIONS(148),
    [anon_sym_PLUS_EQ] = ACTIONS(146),
    [anon_sym_DASH_EQ] = ACTIONS(146),
    [anon_sym_u00d7] = ACTIONS(146),
    [anon_sym_SLASH] = ACTIONS(148),
    [anon_sym_u00f7] = ACTIONS(146),
    [anon_sym_STAR_STAR] = ACTIONS(146),
    [anon_sym_u220b] = ACTIONS(146),
    [anon_sym_u220c] = ACTIONS(146),
    [anon_sym_u2287] = ACTIONS(146),
    [anon_sym_u2283] = ACTIONS(146),
    [anon_sym_u2285] = ACTIONS(146),
    [anon_sym_u2208] = ACTIONS(146),
    [anon_sym_u2209] = ACTIONS(146),
    [anon_sym_u2286] = ACTIONS(146),
    [anon_sym_u2282] = ACTIONS(146),
    [anon_sym_u2284] = ACTIONS(146),
    [anon_sym_AT_AT] = ACTIONS(146),
  },
  [105] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(198),
    [sym_keyword_value] = ACTIONS(198),
    [sym_keyword_explain] = ACTIONS(198),
    [sym_keyword_parallel] = ACTIONS(198),
    [sym_keyword_timeout] = ACTIONS(198),
    [sym_keyword_fetch] = ACTIONS(198),
    [sym_keyword_limit] = ACTIONS(198),
    [sym_keyword_rand] = ACTIONS(198),
    [sym_keyword_collate] = ACTIONS(198),
    [sym_keyword_numeric] = ACTIONS(198),
    [sym_keyword_asc] = ACTIONS(198),
    [sym_keyword_desc] = ACTIONS(198),
    [sym_keyword_and] = ACTIONS(198),
    [sym_keyword_or] = ACTIONS(198),
    [sym_keyword_is] = ACTIONS(198),
    [sym_keyword_not] = ACTIONS(200),
    [sym_keyword_contains] = ACTIONS(198),
    [sym_keyword_contains_not] = ACTIONS(198),
    [sym_keyword_contains_all] = ACTIONS(198),
    [sym_keyword_contains_any] = ACTIONS(198),
    [sym_keyword_contains_none] = ACTIONS(198),
    [sym_keyword_inside] = ACTIONS(198),
    [sym_keyword_in] = ACTIONS(200),
    [sym_keyword_not_inside] = ACTIONS(198),
    [sym_keyword_all_inside] = ACTIONS(198),
    [sym_keyword_any_inside] = ACTIONS(198),
    [sym_keyword_none_inside] = ACTIONS(198),
    [sym_keyword_outside] = ACTIONS(198),
    [sym_keyword_intersects] = ACTIONS(198),
    [sym_keyword_flexible] = ACTIONS(198),
    [sym_keyword_readonly] = ACTIONS(198),
    [sym_keyword_type] = ACTIONS(198),
    [sym_keyword_default] = ACTIONS(198),
    [sym_keyword_assert] = ACTIONS(198),
    [sym_keyword_permissions] = ACTIONS(198),
    [sym_keyword_for] = ACTIONS(198),
    [sym_keyword_comment] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(198),
    [anon_sym_DASH_GT] = ACTIONS(198),
    [anon_sym_LBRACK] = ACTIONS(198),
    [anon_sym_RPAREN] = ACTIONS(198),
    [anon_sym_RBRACE] = ACTIONS(198),
    [anon_sym_LT_DASH] = ACTIONS(200),
    [anon_sym_LT_DASH_GT] = ACTIONS(198),
    [anon_sym_STAR] = ACTIONS(200),
    [anon_sym_DOT] = ACTIONS(198),
    [anon_sym_LT] = ACTIONS(200),
    [anon_sym_GT] = ACTIONS(200),
    [anon_sym_EQ] = ACTIONS(200),
    [anon_sym_DASH] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(200),
    [anon_sym_LT_PIPE] = ACTIONS(198),
    [anon_sym_AMP_AMP] = ACTIONS(198),
    [anon_sym_PIPE_PIPE] = ACTIONS(198),
    [anon_sym_QMARK_QMARK] = ACTIONS(198),
    [anon_sym_QMARK_COLON] = ACTIONS(198),
    [anon_sym_BANG_EQ] = ACTIONS(198),
    [anon_sym_EQ_EQ] = ACTIONS(198),
    [anon_sym_QMARK_EQ] = ACTIONS(198),
    [anon_sym_STAR_EQ] = ACTIONS(198),
    [anon_sym_TILDE] = ACTIONS(198),
    [anon_sym_BANG_TILDE] = ACTIONS(198),
    [anon_sym_STAR_TILDE] = ACTIONS(198),
    [anon_sym_LT_EQ] = ACTIONS(198),
    [anon_sym_GT_EQ] = ACTIONS(198),
    [anon_sym_PLUS] = ACTIONS(200),
    [anon_sym_PLUS_EQ] = ACTIONS(198),
    [anon_sym_DASH_EQ] = ACTIONS(198),
    [anon_sym_u00d7] = ACTIONS(198),
    [anon_sym_SLASH] = ACTIONS(200),
    [anon_sym_u00f7] = ACTIONS(198),
    [anon_sym_STAR_STAR] = ACTIONS(198),
    [anon_sym_u220b] = ACTIONS(198),
    [anon_sym_u220c] = ACTIONS(198),
    [anon_sym_u2287] = ACTIONS(198),
    [anon_sym_u2283] = ACTIONS(198),
    [anon_sym_u2285] = ACTIONS(198),
    [anon_sym_u2208] = ACTIONS(198),
    [anon_sym_u2209] = ACTIONS(198),
    [anon_sym_u2286] = ACTIONS(198),
    [anon_sym_u2282] = ACTIONS(198),
    [anon_sym_u2284] = ACTIONS(198),
    [anon_sym_AT_AT] = ACTIONS(198),
  },
  [106] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(95),
    [sym_keyword_value] = ACTIONS(95),
    [sym_keyword_explain] = ACTIONS(95),
    [sym_keyword_parallel] = ACTIONS(95),
    [sym_keyword_timeout] = ACTIONS(95),
    [sym_keyword_fetch] = ACTIONS(95),
    [sym_keyword_limit] = ACTIONS(95),
    [sym_keyword_rand] = ACTIONS(95),
    [sym_keyword_collate] = ACTIONS(95),
    [sym_keyword_numeric] = ACTIONS(95),
    [sym_keyword_asc] = ACTIONS(95),
    [sym_keyword_desc] = ACTIONS(95),
    [sym_keyword_and] = ACTIONS(95),
    [sym_keyword_or] = ACTIONS(95),
    [sym_keyword_is] = ACTIONS(95),
    [sym_keyword_not] = ACTIONS(97),
    [sym_keyword_contains] = ACTIONS(95),
    [sym_keyword_contains_not] = ACTIONS(95),
    [sym_keyword_contains_all] = ACTIONS(95),
    [sym_keyword_contains_any] = ACTIONS(95),
    [sym_keyword_contains_none] = ACTIONS(95),
    [sym_keyword_inside] = ACTIONS(95),
    [sym_keyword_in] = ACTIONS(97),
    [sym_keyword_not_inside] = ACTIONS(95),
    [sym_keyword_all_inside] = ACTIONS(95),
    [sym_keyword_any_inside] = ACTIONS(95),
    [sym_keyword_none_inside] = ACTIONS(95),
    [sym_keyword_outside] = ACTIONS(95),
    [sym_keyword_intersects] = ACTIONS(95),
    [sym_keyword_flexible] = ACTIONS(95),
    [sym_keyword_readonly] = ACTIONS(95),
    [sym_keyword_type] = ACTIONS(95),
    [sym_keyword_default] = ACTIONS(95),
    [sym_keyword_assert] = ACTIONS(95),
    [sym_keyword_permissions] = ACTIONS(95),
    [sym_keyword_for] = ACTIONS(95),
    [sym_keyword_comment] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(95),
    [anon_sym_DASH_GT] = ACTIONS(95),
    [anon_sym_LBRACK] = ACTIONS(95),
    [anon_sym_RPAREN] = ACTIONS(95),
    [anon_sym_RBRACE] = ACTIONS(95),
    [anon_sym_LT_DASH] = ACTIONS(97),
    [anon_sym_LT_DASH_GT] = ACTIONS(95),
    [anon_sym_STAR] = ACTIONS(97),
    [anon_sym_DOT] = ACTIONS(95),
    [anon_sym_LT] = ACTIONS(97),
    [anon_sym_GT] = ACTIONS(97),
    [anon_sym_EQ] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_LT_PIPE] = ACTIONS(95),
    [anon_sym_AMP_AMP] = ACTIONS(95),
    [anon_sym_PIPE_PIPE] = ACTIONS(95),
    [anon_sym_QMARK_QMARK] = ACTIONS(95),
    [anon_sym_QMARK_COLON] = ACTIONS(95),
    [anon_sym_BANG_EQ] = ACTIONS(95),
    [anon_sym_EQ_EQ] = ACTIONS(95),
    [anon_sym_QMARK_EQ] = ACTIONS(95),
    [anon_sym_STAR_EQ] = ACTIONS(95),
    [anon_sym_TILDE] = ACTIONS(95),
    [anon_sym_BANG_TILDE] = ACTIONS(95),
    [anon_sym_STAR_TILDE] = ACTIONS(95),
    [anon_sym_LT_EQ] = ACTIONS(95),
    [anon_sym_GT_EQ] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_PLUS_EQ] = ACTIONS(95),
    [anon_sym_DASH_EQ] = ACTIONS(95),
    [anon_sym_u00d7] = ACTIONS(95),
    [anon_sym_SLASH] = ACTIONS(97),
    [anon_sym_u00f7] = ACTIONS(95),
    [anon_sym_STAR_STAR] = ACTIONS(95),
    [anon_sym_u220b] = ACTIONS(95),
    [anon_sym_u220c] = ACTIONS(95),
    [anon_sym_u2287] = ACTIONS(95),
    [anon_sym_u2283] = ACTIONS(95),
    [anon_sym_u2285] = ACTIONS(95),
    [anon_sym_u2208] = ACTIONS(95),
    [anon_sym_u2209] = ACTIONS(95),
    [anon_sym_u2286] = ACTIONS(95),
    [anon_sym_u2282] = ACTIONS(95),
    [anon_sym_u2284] = ACTIONS(95),
    [anon_sym_AT_AT] = ACTIONS(95),
  },
  [107] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(166),
    [sym_keyword_value] = ACTIONS(166),
    [sym_keyword_explain] = ACTIONS(166),
    [sym_keyword_parallel] = ACTIONS(166),
    [sym_keyword_timeout] = ACTIONS(166),
    [sym_keyword_fetch] = ACTIONS(166),
    [sym_keyword_limit] = ACTIONS(166),
    [sym_keyword_rand] = ACTIONS(166),
    [sym_keyword_collate] = ACTIONS(166),
    [sym_keyword_numeric] = ACTIONS(166),
    [sym_keyword_asc] = ACTIONS(166),
    [sym_keyword_desc] = ACTIONS(166),
    [sym_keyword_and] = ACTIONS(166),
    [sym_keyword_or] = ACTIONS(166),
    [sym_keyword_is] = ACTIONS(166),
    [sym_keyword_not] = ACTIONS(168),
    [sym_keyword_contains] = ACTIONS(166),
    [sym_keyword_contains_not] = ACTIONS(166),
    [sym_keyword_contains_all] = ACTIONS(166),
    [sym_keyword_contains_any] = ACTIONS(166),
    [sym_keyword_contains_none] = ACTIONS(166),
    [sym_keyword_inside] = ACTIONS(166),
    [sym_keyword_in] = ACTIONS(168),
    [sym_keyword_not_inside] = ACTIONS(166),
    [sym_keyword_all_inside] = ACTIONS(166),
    [sym_keyword_any_inside] = ACTIONS(166),
    [sym_keyword_none_inside] = ACTIONS(166),
    [sym_keyword_outside] = ACTIONS(166),
    [sym_keyword_intersects] = ACTIONS(166),
    [sym_keyword_flexible] = ACTIONS(166),
    [sym_keyword_readonly] = ACTIONS(166),
    [sym_keyword_type] = ACTIONS(166),
    [sym_keyword_default] = ACTIONS(166),
    [sym_keyword_assert] = ACTIONS(166),
    [sym_keyword_permissions] = ACTIONS(166),
    [sym_keyword_for] = ACTIONS(166),
    [sym_keyword_comment] = ACTIONS(166),
    [anon_sym_COMMA] = ACTIONS(166),
    [anon_sym_DASH_GT] = ACTIONS(166),
    [anon_sym_LBRACK] = ACTIONS(166),
    [anon_sym_RPAREN] = ACTIONS(166),
    [anon_sym_RBRACE] = ACTIONS(166),
    [anon_sym_LT_DASH] = ACTIONS(168),
    [anon_sym_LT_DASH_GT] = ACTIONS(166),
    [anon_sym_STAR] = ACTIONS(168),
    [anon_sym_DOT] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [anon_sym_GT] = ACTIONS(168),
    [anon_sym_EQ] = ACTIONS(168),
    [anon_sym_DASH] = ACTIONS(168),
    [anon_sym_AT] = ACTIONS(168),
    [anon_sym_LT_PIPE] = ACTIONS(166),
    [anon_sym_AMP_AMP] = ACTIONS(166),
    [anon_sym_PIPE_PIPE] = ACTIONS(166),
    [anon_sym_QMARK_QMARK] = ACTIONS(166),
    [anon_sym_QMARK_COLON] = ACTIONS(166),
    [anon_sym_BANG_EQ] = ACTIONS(166),
    [anon_sym_EQ_EQ] = ACTIONS(166),
    [anon_sym_QMARK_EQ] = ACTIONS(166),
    [anon_sym_STAR_EQ] = ACTIONS(166),
    [anon_sym_TILDE] = ACTIONS(166),
    [anon_sym_BANG_TILDE] = ACTIONS(166),
    [anon_sym_STAR_TILDE] = ACTIONS(166),
    [anon_sym_LT_EQ] = ACTIONS(166),
    [anon_sym_GT_EQ] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(168),
    [anon_sym_PLUS_EQ] = ACTIONS(166),
    [anon_sym_DASH_EQ] = ACTIONS(166),
    [anon_sym_u00d7] = ACTIONS(166),
    [anon_sym_SLASH] = ACTIONS(168),
    [anon_sym_u00f7] = ACTIONS(166),
    [anon_sym_STAR_STAR] = ACTIONS(166),
    [anon_sym_u220b] = ACTIONS(166),
    [anon_sym_u220c] = ACTIONS(166),
    [anon_sym_u2287] = ACTIONS(166),
    [anon_sym_u2283] = ACTIONS(166),
    [anon_sym_u2285] = ACTIONS(166),
    [anon_sym_u2208] = ACTIONS(166),
    [anon_sym_u2209] = ACTIONS(166),
    [anon_sym_u2286] = ACTIONS(166),
    [anon_sym_u2282] = ACTIONS(166),
    [anon_sym_u2284] = ACTIONS(166),
    [anon_sym_AT_AT] = ACTIONS(166),
  },
  [108] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(55),
    [sym_keyword_value] = ACTIONS(55),
    [sym_keyword_explain] = ACTIONS(55),
    [sym_keyword_parallel] = ACTIONS(55),
    [sym_keyword_timeout] = ACTIONS(55),
    [sym_keyword_fetch] = ACTIONS(55),
    [sym_keyword_limit] = ACTIONS(55),
    [sym_keyword_rand] = ACTIONS(55),
    [sym_keyword_collate] = ACTIONS(55),
    [sym_keyword_numeric] = ACTIONS(55),
    [sym_keyword_asc] = ACTIONS(55),
    [sym_keyword_desc] = ACTIONS(55),
    [sym_keyword_and] = ACTIONS(55),
    [sym_keyword_or] = ACTIONS(55),
    [sym_keyword_is] = ACTIONS(55),
    [sym_keyword_not] = ACTIONS(57),
    [sym_keyword_contains] = ACTIONS(55),
    [sym_keyword_contains_not] = ACTIONS(55),
    [sym_keyword_contains_all] = ACTIONS(55),
    [sym_keyword_contains_any] = ACTIONS(55),
    [sym_keyword_contains_none] = ACTIONS(55),
    [sym_keyword_inside] = ACTIONS(55),
    [sym_keyword_in] = ACTIONS(57),
    [sym_keyword_not_inside] = ACTIONS(55),
    [sym_keyword_all_inside] = ACTIONS(55),
    [sym_keyword_any_inside] = ACTIONS(55),
    [sym_keyword_none_inside] = ACTIONS(55),
    [sym_keyword_outside] = ACTIONS(55),
    [sym_keyword_intersects] = ACTIONS(55),
    [sym_keyword_flexible] = ACTIONS(55),
    [sym_keyword_readonly] = ACTIONS(55),
    [sym_keyword_type] = ACTIONS(55),
    [sym_keyword_default] = ACTIONS(55),
    [sym_keyword_assert] = ACTIONS(55),
    [sym_keyword_permissions] = ACTIONS(55),
    [sym_keyword_for] = ACTIONS(55),
    [sym_keyword_comment] = ACTIONS(55),
    [anon_sym_COMMA] = ACTIONS(55),
    [anon_sym_DASH_GT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(55),
    [anon_sym_RPAREN] = ACTIONS(55),
    [anon_sym_RBRACE] = ACTIONS(55),
    [anon_sym_LT_DASH] = ACTIONS(57),
    [anon_sym_LT_DASH_GT] = ACTIONS(55),
    [anon_sym_STAR] = ACTIONS(57),
    [anon_sym_DOT] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(57),
    [anon_sym_GT] = ACTIONS(57),
    [anon_sym_EQ] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(57),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LT_PIPE] = ACTIONS(55),
    [anon_sym_AMP_AMP] = ACTIONS(55),
    [anon_sym_PIPE_PIPE] = ACTIONS(55),
    [anon_sym_QMARK_QMARK] = ACTIONS(55),
    [anon_sym_QMARK_COLON] = ACTIONS(55),
    [anon_sym_BANG_EQ] = ACTIONS(55),
    [anon_sym_EQ_EQ] = ACTIONS(55),
    [anon_sym_QMARK_EQ] = ACTIONS(55),
    [anon_sym_STAR_EQ] = ACTIONS(55),
    [anon_sym_TILDE] = ACTIONS(55),
    [anon_sym_BANG_TILDE] = ACTIONS(55),
    [anon_sym_STAR_TILDE] = ACTIONS(55),
    [anon_sym_LT_EQ] = ACTIONS(55),
    [anon_sym_GT_EQ] = ACTIONS(55),
    [anon_sym_PLUS] = ACTIONS(57),
    [anon_sym_PLUS_EQ] = ACTIONS(55),
    [anon_sym_DASH_EQ] = ACTIONS(55),
    [anon_sym_u00d7] = ACTIONS(55),
    [anon_sym_SLASH] = ACTIONS(57),
    [anon_sym_u00f7] = ACTIONS(55),
    [anon_sym_STAR_STAR] = ACTIONS(55),
    [anon_sym_u220b] = ACTIONS(55),
    [anon_sym_u220c] = ACTIONS(55),
    [anon_sym_u2287] = ACTIONS(55),
    [anon_sym_u2283] = ACTIONS(55),
    [anon_sym_u2285] = ACTIONS(55),
    [anon_sym_u2208] = ACTIONS(55),
    [anon_sym_u2209] = ACTIONS(55),
    [anon_sym_u2286] = ACTIONS(55),
    [anon_sym_u2282] = ACTIONS(55),
    [anon_sym_u2284] = ACTIONS(55),
    [anon_sym_AT_AT] = ACTIONS(55),
  },
  [109] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(150),
    [sym_keyword_value] = ACTIONS(150),
    [sym_keyword_explain] = ACTIONS(150),
    [sym_keyword_parallel] = ACTIONS(150),
    [sym_keyword_timeout] = ACTIONS(150),
    [sym_keyword_fetch] = ACTIONS(150),
    [sym_keyword_limit] = ACTIONS(150),
    [sym_keyword_rand] = ACTIONS(150),
    [sym_keyword_collate] = ACTIONS(150),
    [sym_keyword_numeric] = ACTIONS(150),
    [sym_keyword_asc] = ACTIONS(150),
    [sym_keyword_desc] = ACTIONS(150),
    [sym_keyword_and] = ACTIONS(150),
    [sym_keyword_or] = ACTIONS(150),
    [sym_keyword_is] = ACTIONS(150),
    [sym_keyword_not] = ACTIONS(152),
    [sym_keyword_contains] = ACTIONS(150),
    [sym_keyword_contains_not] = ACTIONS(150),
    [sym_keyword_contains_all] = ACTIONS(150),
    [sym_keyword_contains_any] = ACTIONS(150),
    [sym_keyword_contains_none] = ACTIONS(150),
    [sym_keyword_inside] = ACTIONS(150),
    [sym_keyword_in] = ACTIONS(152),
    [sym_keyword_not_inside] = ACTIONS(150),
    [sym_keyword_all_inside] = ACTIONS(150),
    [sym_keyword_any_inside] = ACTIONS(150),
    [sym_keyword_none_inside] = ACTIONS(150),
    [sym_keyword_outside] = ACTIONS(150),
    [sym_keyword_intersects] = ACTIONS(150),
    [sym_keyword_flexible] = ACTIONS(150),
    [sym_keyword_readonly] = ACTIONS(150),
    [sym_keyword_type] = ACTIONS(150),
    [sym_keyword_default] = ACTIONS(150),
    [sym_keyword_assert] = ACTIONS(150),
    [sym_keyword_permissions] = ACTIONS(150),
    [sym_keyword_for] = ACTIONS(150),
    [sym_keyword_comment] = ACTIONS(150),
    [anon_sym_COMMA] = ACTIONS(150),
    [anon_sym_DASH_GT] = ACTIONS(150),
    [anon_sym_LBRACK] = ACTIONS(150),
    [anon_sym_RPAREN] = ACTIONS(150),
    [anon_sym_RBRACE] = ACTIONS(150),
    [anon_sym_LT_DASH] = ACTIONS(152),
    [anon_sym_LT_DASH_GT] = ACTIONS(150),
    [anon_sym_STAR] = ACTIONS(152),
    [anon_sym_DOT] = ACTIONS(150),
    [anon_sym_LT] = ACTIONS(152),
    [anon_sym_GT] = ACTIONS(152),
    [anon_sym_EQ] = ACTIONS(152),
    [anon_sym_DASH] = ACTIONS(152),
    [anon_sym_AT] = ACTIONS(152),
    [anon_sym_LT_PIPE] = ACTIONS(150),
    [anon_sym_AMP_AMP] = ACTIONS(150),
    [anon_sym_PIPE_PIPE] = ACTIONS(150),
    [anon_sym_QMARK_QMARK] = ACTIONS(150),
    [anon_sym_QMARK_COLON] = ACTIONS(150),
    [anon_sym_BANG_EQ] = ACTIONS(150),
    [anon_sym_EQ_EQ] = ACTIONS(150),
    [anon_sym_QMARK_EQ] = ACTIONS(150),
    [anon_sym_STAR_EQ] = ACTIONS(150),
    [anon_sym_TILDE] = ACTIONS(150),
    [anon_sym_BANG_TILDE] = ACTIONS(150),
    [anon_sym_STAR_TILDE] = ACTIONS(150),
    [anon_sym_LT_EQ] = ACTIONS(150),
    [anon_sym_GT_EQ] = ACTIONS(150),
    [anon_sym_PLUS] = ACTIONS(152),
    [anon_sym_PLUS_EQ] = ACTIONS(150),
    [anon_sym_DASH_EQ] = ACTIONS(150),
    [anon_sym_u00d7] = ACTIONS(150),
    [anon_sym_SLASH] = ACTIONS(152),
    [anon_sym_u00f7] = ACTIONS(150),
    [anon_sym_STAR_STAR] = ACTIONS(150),
    [anon_sym_u220b] = ACTIONS(150),
    [anon_sym_u220c] = ACTIONS(150),
    [anon_sym_u2287] = ACTIONS(150),
    [anon_sym_u2283] = ACTIONS(150),
    [anon_sym_u2285] = ACTIONS(150),
    [anon_sym_u2208] = ACTIONS(150),
    [anon_sym_u2209] = ACTIONS(150),
    [anon_sym_u2286] = ACTIONS(150),
    [anon_sym_u2282] = ACTIONS(150),
    [anon_sym_u2284] = ACTIONS(150),
    [anon_sym_AT_AT] = ACTIONS(150),
  },
  [110] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(154),
    [sym_keyword_value] = ACTIONS(154),
    [sym_keyword_explain] = ACTIONS(154),
    [sym_keyword_parallel] = ACTIONS(154),
    [sym_keyword_timeout] = ACTIONS(154),
    [sym_keyword_fetch] = ACTIONS(154),
    [sym_keyword_limit] = ACTIONS(154),
    [sym_keyword_rand] = ACTIONS(154),
    [sym_keyword_collate] = ACTIONS(154),
    [sym_keyword_numeric] = ACTIONS(154),
    [sym_keyword_asc] = ACTIONS(154),
    [sym_keyword_desc] = ACTIONS(154),
    [sym_keyword_and] = ACTIONS(154),
    [sym_keyword_or] = ACTIONS(154),
    [sym_keyword_is] = ACTIONS(154),
    [sym_keyword_not] = ACTIONS(156),
    [sym_keyword_contains] = ACTIONS(154),
    [sym_keyword_contains_not] = ACTIONS(154),
    [sym_keyword_contains_all] = ACTIONS(154),
    [sym_keyword_contains_any] = ACTIONS(154),
    [sym_keyword_contains_none] = ACTIONS(154),
    [sym_keyword_inside] = ACTIONS(154),
    [sym_keyword_in] = ACTIONS(156),
    [sym_keyword_not_inside] = ACTIONS(154),
    [sym_keyword_all_inside] = ACTIONS(154),
    [sym_keyword_any_inside] = ACTIONS(154),
    [sym_keyword_none_inside] = ACTIONS(154),
    [sym_keyword_outside] = ACTIONS(154),
    [sym_keyword_intersects] = ACTIONS(154),
    [sym_keyword_flexible] = ACTIONS(154),
    [sym_keyword_readonly] = ACTIONS(154),
    [sym_keyword_type] = ACTIONS(154),
    [sym_keyword_default] = ACTIONS(154),
    [sym_keyword_assert] = ACTIONS(154),
    [sym_keyword_permissions] = ACTIONS(154),
    [sym_keyword_for] = ACTIONS(154),
    [sym_keyword_comment] = ACTIONS(154),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_DASH_GT] = ACTIONS(154),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_LT_DASH] = ACTIONS(156),
    [anon_sym_LT_DASH_GT] = ACTIONS(154),
    [anon_sym_STAR] = ACTIONS(156),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_LT] = ACTIONS(156),
    [anon_sym_GT] = ACTIONS(156),
    [anon_sym_EQ] = ACTIONS(156),
    [anon_sym_DASH] = ACTIONS(156),
    [anon_sym_AT] = ACTIONS(156),
    [anon_sym_LT_PIPE] = ACTIONS(154),
    [anon_sym_AMP_AMP] = ACTIONS(154),
    [anon_sym_PIPE_PIPE] = ACTIONS(154),
    [anon_sym_QMARK_QMARK] = ACTIONS(154),
    [anon_sym_QMARK_COLON] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(154),
    [anon_sym_QMARK_EQ] = ACTIONS(154),
    [anon_sym_STAR_EQ] = ACTIONS(154),
    [anon_sym_TILDE] = ACTIONS(154),
    [anon_sym_BANG_TILDE] = ACTIONS(154),
    [anon_sym_STAR_TILDE] = ACTIONS(154),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_PLUS] = ACTIONS(156),
    [anon_sym_PLUS_EQ] = ACTIONS(154),
    [anon_sym_DASH_EQ] = ACTIONS(154),
    [anon_sym_u00d7] = ACTIONS(154),
    [anon_sym_SLASH] = ACTIONS(156),
    [anon_sym_u00f7] = ACTIONS(154),
    [anon_sym_STAR_STAR] = ACTIONS(154),
    [anon_sym_u220b] = ACTIONS(154),
    [anon_sym_u220c] = ACTIONS(154),
    [anon_sym_u2287] = ACTIONS(154),
    [anon_sym_u2283] = ACTIONS(154),
    [anon_sym_u2285] = ACTIONS(154),
    [anon_sym_u2208] = ACTIONS(154),
    [anon_sym_u2209] = ACTIONS(154),
    [anon_sym_u2286] = ACTIONS(154),
    [anon_sym_u2282] = ACTIONS(154),
    [anon_sym_u2284] = ACTIONS(154),
    [anon_sym_AT_AT] = ACTIONS(154),
  },
  [111] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(158),
    [sym_keyword_value] = ACTIONS(158),
    [sym_keyword_explain] = ACTIONS(158),
    [sym_keyword_parallel] = ACTIONS(158),
    [sym_keyword_timeout] = ACTIONS(158),
    [sym_keyword_fetch] = ACTIONS(158),
    [sym_keyword_limit] = ACTIONS(158),
    [sym_keyword_rand] = ACTIONS(158),
    [sym_keyword_collate] = ACTIONS(158),
    [sym_keyword_numeric] = ACTIONS(158),
    [sym_keyword_asc] = ACTIONS(158),
    [sym_keyword_desc] = ACTIONS(158),
    [sym_keyword_and] = ACTIONS(158),
    [sym_keyword_or] = ACTIONS(158),
    [sym_keyword_is] = ACTIONS(158),
    [sym_keyword_not] = ACTIONS(160),
    [sym_keyword_contains] = ACTIONS(158),
    [sym_keyword_contains_not] = ACTIONS(158),
    [sym_keyword_contains_all] = ACTIONS(158),
    [sym_keyword_contains_any] = ACTIONS(158),
    [sym_keyword_contains_none] = ACTIONS(158),
    [sym_keyword_inside] = ACTIONS(158),
    [sym_keyword_in] = ACTIONS(160),
    [sym_keyword_not_inside] = ACTIONS(158),
    [sym_keyword_all_inside] = ACTIONS(158),
    [sym_keyword_any_inside] = ACTIONS(158),
    [sym_keyword_none_inside] = ACTIONS(158),
    [sym_keyword_outside] = ACTIONS(158),
    [sym_keyword_intersects] = ACTIONS(158),
    [sym_keyword_flexible] = ACTIONS(158),
    [sym_keyword_readonly] = ACTIONS(158),
    [sym_keyword_type] = ACTIONS(158),
    [sym_keyword_default] = ACTIONS(158),
    [sym_keyword_assert] = ACTIONS(158),
    [sym_keyword_permissions] = ACTIONS(158),
    [sym_keyword_for] = ACTIONS(158),
    [sym_keyword_comment] = ACTIONS(158),
    [anon_sym_COMMA] = ACTIONS(158),
    [anon_sym_DASH_GT] = ACTIONS(158),
    [anon_sym_LBRACK] = ACTIONS(158),
    [anon_sym_RPAREN] = ACTIONS(158),
    [anon_sym_RBRACE] = ACTIONS(158),
    [anon_sym_LT_DASH] = ACTIONS(160),
    [anon_sym_LT_DASH_GT] = ACTIONS(158),
    [anon_sym_STAR] = ACTIONS(160),
    [anon_sym_DOT] = ACTIONS(158),
    [anon_sym_LT] = ACTIONS(160),
    [anon_sym_GT] = ACTIONS(160),
    [anon_sym_EQ] = ACTIONS(160),
    [anon_sym_DASH] = ACTIONS(160),
    [anon_sym_AT] = ACTIONS(160),
    [anon_sym_LT_PIPE] = ACTIONS(158),
    [anon_sym_AMP_AMP] = ACTIONS(158),
    [anon_sym_PIPE_PIPE] = ACTIONS(158),
    [anon_sym_QMARK_QMARK] = ACTIONS(158),
    [anon_sym_QMARK_COLON] = ACTIONS(158),
    [anon_sym_BANG_EQ] = ACTIONS(158),
    [anon_sym_EQ_EQ] = ACTIONS(158),
    [anon_sym_QMARK_EQ] = ACTIONS(158),
    [anon_sym_STAR_EQ] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(158),
    [anon_sym_BANG_TILDE] = ACTIONS(158),
    [anon_sym_STAR_TILDE] = ACTIONS(158),
    [anon_sym_LT_EQ] = ACTIONS(158),
    [anon_sym_GT_EQ] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(160),
    [anon_sym_PLUS_EQ] = ACTIONS(158),
    [anon_sym_DASH_EQ] = ACTIONS(158),
    [anon_sym_u00d7] = ACTIONS(158),
    [anon_sym_SLASH] = ACTIONS(160),
    [anon_sym_u00f7] = ACTIONS(158),
    [anon_sym_STAR_STAR] = ACTIONS(158),
    [anon_sym_u220b] = ACTIONS(158),
    [anon_sym_u220c] = ACTIONS(158),
    [anon_sym_u2287] = ACTIONS(158),
    [anon_sym_u2283] = ACTIONS(158),
    [anon_sym_u2285] = ACTIONS(158),
    [anon_sym_u2208] = ACTIONS(158),
    [anon_sym_u2209] = ACTIONS(158),
    [anon_sym_u2286] = ACTIONS(158),
    [anon_sym_u2282] = ACTIONS(158),
    [anon_sym_u2284] = ACTIONS(158),
    [anon_sym_AT_AT] = ACTIONS(158),
  },
  [112] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(162),
    [sym_keyword_value] = ACTIONS(162),
    [sym_keyword_explain] = ACTIONS(162),
    [sym_keyword_parallel] = ACTIONS(162),
    [sym_keyword_timeout] = ACTIONS(162),
    [sym_keyword_fetch] = ACTIONS(162),
    [sym_keyword_limit] = ACTIONS(162),
    [sym_keyword_rand] = ACTIONS(162),
    [sym_keyword_collate] = ACTIONS(162),
    [sym_keyword_numeric] = ACTIONS(162),
    [sym_keyword_asc] = ACTIONS(162),
    [sym_keyword_desc] = ACTIONS(162),
    [sym_keyword_and] = ACTIONS(162),
    [sym_keyword_or] = ACTIONS(162),
    [sym_keyword_is] = ACTIONS(162),
    [sym_keyword_not] = ACTIONS(164),
    [sym_keyword_contains] = ACTIONS(162),
    [sym_keyword_contains_not] = ACTIONS(162),
    [sym_keyword_contains_all] = ACTIONS(162),
    [sym_keyword_contains_any] = ACTIONS(162),
    [sym_keyword_contains_none] = ACTIONS(162),
    [sym_keyword_inside] = ACTIONS(162),
    [sym_keyword_in] = ACTIONS(164),
    [sym_keyword_not_inside] = ACTIONS(162),
    [sym_keyword_all_inside] = ACTIONS(162),
    [sym_keyword_any_inside] = ACTIONS(162),
    [sym_keyword_none_inside] = ACTIONS(162),
    [sym_keyword_outside] = ACTIONS(162),
    [sym_keyword_intersects] = ACTIONS(162),
    [sym_keyword_flexible] = ACTIONS(162),
    [sym_keyword_readonly] = ACTIONS(162),
    [sym_keyword_type] = ACTIONS(162),
    [sym_keyword_default] = ACTIONS(162),
    [sym_keyword_assert] = ACTIONS(162),
    [sym_keyword_permissions] = ACTIONS(162),
    [sym_keyword_for] = ACTIONS(162),
    [sym_keyword_comment] = ACTIONS(162),
    [anon_sym_COMMA] = ACTIONS(162),
    [anon_sym_DASH_GT] = ACTIONS(162),
    [anon_sym_LBRACK] = ACTIONS(162),
    [anon_sym_RPAREN] = ACTIONS(162),
    [anon_sym_RBRACE] = ACTIONS(162),
    [anon_sym_LT_DASH] = ACTIONS(164),
    [anon_sym_LT_DASH_GT] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_DOT] = ACTIONS(162),
    [anon_sym_LT] = ACTIONS(164),
    [anon_sym_GT] = ACTIONS(164),
    [anon_sym_EQ] = ACTIONS(164),
    [anon_sym_DASH] = ACTIONS(164),
    [anon_sym_AT] = ACTIONS(164),
    [anon_sym_LT_PIPE] = ACTIONS(162),
    [anon_sym_AMP_AMP] = ACTIONS(162),
    [anon_sym_PIPE_PIPE] = ACTIONS(162),
    [anon_sym_QMARK_QMARK] = ACTIONS(162),
    [anon_sym_QMARK_COLON] = ACTIONS(162),
    [anon_sym_BANG_EQ] = ACTIONS(162),
    [anon_sym_EQ_EQ] = ACTIONS(162),
    [anon_sym_QMARK_EQ] = ACTIONS(162),
    [anon_sym_STAR_EQ] = ACTIONS(162),
    [anon_sym_TILDE] = ACTIONS(162),
    [anon_sym_BANG_TILDE] = ACTIONS(162),
    [anon_sym_STAR_TILDE] = ACTIONS(162),
    [anon_sym_LT_EQ] = ACTIONS(162),
    [anon_sym_GT_EQ] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(164),
    [anon_sym_PLUS_EQ] = ACTIONS(162),
    [anon_sym_DASH_EQ] = ACTIONS(162),
    [anon_sym_u00d7] = ACTIONS(162),
    [anon_sym_SLASH] = ACTIONS(164),
    [anon_sym_u00f7] = ACTIONS(162),
    [anon_sym_STAR_STAR] = ACTIONS(162),
    [anon_sym_u220b] = ACTIONS(162),
    [anon_sym_u220c] = ACTIONS(162),
    [anon_sym_u2287] = ACTIONS(162),
    [anon_sym_u2283] = ACTIONS(162),
    [anon_sym_u2285] = ACTIONS(162),
    [anon_sym_u2208] = ACTIONS(162),
    [anon_sym_u2209] = ACTIONS(162),
    [anon_sym_u2286] = ACTIONS(162),
    [anon_sym_u2282] = ACTIONS(162),
    [anon_sym_u2284] = ACTIONS(162),
    [anon_sym_AT_AT] = ACTIONS(162),
  },
  [113] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(170),
    [sym_keyword_value] = ACTIONS(170),
    [sym_keyword_explain] = ACTIONS(170),
    [sym_keyword_parallel] = ACTIONS(170),
    [sym_keyword_timeout] = ACTIONS(170),
    [sym_keyword_fetch] = ACTIONS(170),
    [sym_keyword_limit] = ACTIONS(170),
    [sym_keyword_rand] = ACTIONS(170),
    [sym_keyword_collate] = ACTIONS(170),
    [sym_keyword_numeric] = ACTIONS(170),
    [sym_keyword_asc] = ACTIONS(170),
    [sym_keyword_desc] = ACTIONS(170),
    [sym_keyword_and] = ACTIONS(170),
    [sym_keyword_or] = ACTIONS(170),
    [sym_keyword_is] = ACTIONS(170),
    [sym_keyword_not] = ACTIONS(172),
    [sym_keyword_contains] = ACTIONS(170),
    [sym_keyword_contains_not] = ACTIONS(170),
    [sym_keyword_contains_all] = ACTIONS(170),
    [sym_keyword_contains_any] = ACTIONS(170),
    [sym_keyword_contains_none] = ACTIONS(170),
    [sym_keyword_inside] = ACTIONS(170),
    [sym_keyword_in] = ACTIONS(172),
    [sym_keyword_not_inside] = ACTIONS(170),
    [sym_keyword_all_inside] = ACTIONS(170),
    [sym_keyword_any_inside] = ACTIONS(170),
    [sym_keyword_none_inside] = ACTIONS(170),
    [sym_keyword_outside] = ACTIONS(170),
    [sym_keyword_intersects] = ACTIONS(170),
    [sym_keyword_flexible] = ACTIONS(170),
    [sym_keyword_readonly] = ACTIONS(170),
    [sym_keyword_type] = ACTIONS(170),
    [sym_keyword_default] = ACTIONS(170),
    [sym_keyword_assert] = ACTIONS(170),
    [sym_keyword_permissions] = ACTIONS(170),
    [sym_keyword_for] = ACTIONS(170),
    [sym_keyword_comment] = ACTIONS(170),
    [anon_sym_COMMA] = ACTIONS(170),
    [anon_sym_DASH_GT] = ACTIONS(170),
    [anon_sym_LBRACK] = ACTIONS(170),
    [anon_sym_RPAREN] = ACTIONS(170),
    [anon_sym_RBRACE] = ACTIONS(170),
    [anon_sym_LT_DASH] = ACTIONS(172),
    [anon_sym_LT_DASH_GT] = ACTIONS(170),
    [anon_sym_STAR] = ACTIONS(172),
    [anon_sym_DOT] = ACTIONS(170),
    [anon_sym_LT] = ACTIONS(172),
    [anon_sym_GT] = ACTIONS(172),
    [anon_sym_EQ] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [anon_sym_AT] = ACTIONS(172),
    [anon_sym_LT_PIPE] = ACTIONS(170),
    [anon_sym_AMP_AMP] = ACTIONS(170),
    [anon_sym_PIPE_PIPE] = ACTIONS(170),
    [anon_sym_QMARK_QMARK] = ACTIONS(170),
    [anon_sym_QMARK_COLON] = ACTIONS(170),
    [anon_sym_BANG_EQ] = ACTIONS(170),
    [anon_sym_EQ_EQ] = ACTIONS(170),
    [anon_sym_QMARK_EQ] = ACTIONS(170),
    [anon_sym_STAR_EQ] = ACTIONS(170),
    [anon_sym_TILDE] = ACTIONS(170),
    [anon_sym_BANG_TILDE] = ACTIONS(170),
    [anon_sym_STAR_TILDE] = ACTIONS(170),
    [anon_sym_LT_EQ] = ACTIONS(170),
    [anon_sym_GT_EQ] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_PLUS_EQ] = ACTIONS(170),
    [anon_sym_DASH_EQ] = ACTIONS(170),
    [anon_sym_u00d7] = ACTIONS(170),
    [anon_sym_SLASH] = ACTIONS(172),
    [anon_sym_u00f7] = ACTIONS(170),
    [anon_sym_STAR_STAR] = ACTIONS(170),
    [anon_sym_u220b] = ACTIONS(170),
    [anon_sym_u220c] = ACTIONS(170),
    [anon_sym_u2287] = ACTIONS(170),
    [anon_sym_u2283] = ACTIONS(170),
    [anon_sym_u2285] = ACTIONS(170),
    [anon_sym_u2208] = ACTIONS(170),
    [anon_sym_u2209] = ACTIONS(170),
    [anon_sym_u2286] = ACTIONS(170),
    [anon_sym_u2282] = ACTIONS(170),
    [anon_sym_u2284] = ACTIONS(170),
    [anon_sym_AT_AT] = ACTIONS(170),
  },
  [114] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(174),
    [sym_keyword_value] = ACTIONS(174),
    [sym_keyword_explain] = ACTIONS(174),
    [sym_keyword_parallel] = ACTIONS(174),
    [sym_keyword_timeout] = ACTIONS(174),
    [sym_keyword_fetch] = ACTIONS(174),
    [sym_keyword_limit] = ACTIONS(174),
    [sym_keyword_rand] = ACTIONS(174),
    [sym_keyword_collate] = ACTIONS(174),
    [sym_keyword_numeric] = ACTIONS(174),
    [sym_keyword_asc] = ACTIONS(174),
    [sym_keyword_desc] = ACTIONS(174),
    [sym_keyword_and] = ACTIONS(174),
    [sym_keyword_or] = ACTIONS(174),
    [sym_keyword_is] = ACTIONS(174),
    [sym_keyword_not] = ACTIONS(176),
    [sym_keyword_contains] = ACTIONS(174),
    [sym_keyword_contains_not] = ACTIONS(174),
    [sym_keyword_contains_all] = ACTIONS(174),
    [sym_keyword_contains_any] = ACTIONS(174),
    [sym_keyword_contains_none] = ACTIONS(174),
    [sym_keyword_inside] = ACTIONS(174),
    [sym_keyword_in] = ACTIONS(176),
    [sym_keyword_not_inside] = ACTIONS(174),
    [sym_keyword_all_inside] = ACTIONS(174),
    [sym_keyword_any_inside] = ACTIONS(174),
    [sym_keyword_none_inside] = ACTIONS(174),
    [sym_keyword_outside] = ACTIONS(174),
    [sym_keyword_intersects] = ACTIONS(174),
    [sym_keyword_flexible] = ACTIONS(174),
    [sym_keyword_readonly] = ACTIONS(174),
    [sym_keyword_type] = ACTIONS(174),
    [sym_keyword_default] = ACTIONS(174),
    [sym_keyword_assert] = ACTIONS(174),
    [sym_keyword_permissions] = ACTIONS(174),
    [sym_keyword_for] = ACTIONS(174),
    [sym_keyword_comment] = ACTIONS(174),
    [anon_sym_COMMA] = ACTIONS(174),
    [anon_sym_DASH_GT] = ACTIONS(174),
    [anon_sym_LBRACK] = ACTIONS(174),
    [anon_sym_RPAREN] = ACTIONS(174),
    [anon_sym_RBRACE] = ACTIONS(174),
    [anon_sym_LT_DASH] = ACTIONS(176),
    [anon_sym_LT_DASH_GT] = ACTIONS(174),
    [anon_sym_STAR] = ACTIONS(176),
    [anon_sym_DOT] = ACTIONS(174),
    [anon_sym_LT] = ACTIONS(176),
    [anon_sym_GT] = ACTIONS(176),
    [anon_sym_EQ] = ACTIONS(176),
    [anon_sym_DASH] = ACTIONS(176),
    [anon_sym_AT] = ACTIONS(176),
    [anon_sym_LT_PIPE] = ACTIONS(174),
    [anon_sym_AMP_AMP] = ACTIONS(174),
    [anon_sym_PIPE_PIPE] = ACTIONS(174),
    [anon_sym_QMARK_QMARK] = ACTIONS(174),
    [anon_sym_QMARK_COLON] = ACTIONS(174),
    [anon_sym_BANG_EQ] = ACTIONS(174),
    [anon_sym_EQ_EQ] = ACTIONS(174),
    [anon_sym_QMARK_EQ] = ACTIONS(174),
    [anon_sym_STAR_EQ] = ACTIONS(174),
    [anon_sym_TILDE] = ACTIONS(174),
    [anon_sym_BANG_TILDE] = ACTIONS(174),
    [anon_sym_STAR_TILDE] = ACTIONS(174),
    [anon_sym_LT_EQ] = ACTIONS(174),
    [anon_sym_GT_EQ] = ACTIONS(174),
    [anon_sym_PLUS] = ACTIONS(176),
    [anon_sym_PLUS_EQ] = ACTIONS(174),
    [anon_sym_DASH_EQ] = ACTIONS(174),
    [anon_sym_u00d7] = ACTIONS(174),
    [anon_sym_SLASH] = ACTIONS(176),
    [anon_sym_u00f7] = ACTIONS(174),
    [anon_sym_STAR_STAR] = ACTIONS(174),
    [anon_sym_u220b] = ACTIONS(174),
    [anon_sym_u220c] = ACTIONS(174),
    [anon_sym_u2287] = ACTIONS(174),
    [anon_sym_u2283] = ACTIONS(174),
    [anon_sym_u2285] = ACTIONS(174),
    [anon_sym_u2208] = ACTIONS(174),
    [anon_sym_u2209] = ACTIONS(174),
    [anon_sym_u2286] = ACTIONS(174),
    [anon_sym_u2282] = ACTIONS(174),
    [anon_sym_u2284] = ACTIONS(174),
    [anon_sym_AT_AT] = ACTIONS(174),
  },
  [115] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(138),
    [sym_keyword_value] = ACTIONS(138),
    [sym_keyword_explain] = ACTIONS(138),
    [sym_keyword_parallel] = ACTIONS(138),
    [sym_keyword_timeout] = ACTIONS(138),
    [sym_keyword_fetch] = ACTIONS(138),
    [sym_keyword_limit] = ACTIONS(138),
    [sym_keyword_rand] = ACTIONS(138),
    [sym_keyword_collate] = ACTIONS(138),
    [sym_keyword_numeric] = ACTIONS(138),
    [sym_keyword_asc] = ACTIONS(138),
    [sym_keyword_desc] = ACTIONS(138),
    [sym_keyword_and] = ACTIONS(138),
    [sym_keyword_or] = ACTIONS(138),
    [sym_keyword_is] = ACTIONS(138),
    [sym_keyword_not] = ACTIONS(140),
    [sym_keyword_contains] = ACTIONS(138),
    [sym_keyword_contains_not] = ACTIONS(138),
    [sym_keyword_contains_all] = ACTIONS(138),
    [sym_keyword_contains_any] = ACTIONS(138),
    [sym_keyword_contains_none] = ACTIONS(138),
    [sym_keyword_inside] = ACTIONS(138),
    [sym_keyword_in] = ACTIONS(140),
    [sym_keyword_not_inside] = ACTIONS(138),
    [sym_keyword_all_inside] = ACTIONS(138),
    [sym_keyword_any_inside] = ACTIONS(138),
    [sym_keyword_none_inside] = ACTIONS(138),
    [sym_keyword_outside] = ACTIONS(138),
    [sym_keyword_intersects] = ACTIONS(138),
    [sym_keyword_flexible] = ACTIONS(138),
    [sym_keyword_readonly] = ACTIONS(138),
    [sym_keyword_type] = ACTIONS(138),
    [sym_keyword_default] = ACTIONS(138),
    [sym_keyword_assert] = ACTIONS(138),
    [sym_keyword_permissions] = ACTIONS(138),
    [sym_keyword_for] = ACTIONS(138),
    [sym_keyword_comment] = ACTIONS(138),
    [anon_sym_COMMA] = ACTIONS(138),
    [anon_sym_DASH_GT] = ACTIONS(138),
    [anon_sym_LBRACK] = ACTIONS(138),
    [anon_sym_RPAREN] = ACTIONS(138),
    [anon_sym_RBRACE] = ACTIONS(138),
    [anon_sym_LT_DASH] = ACTIONS(140),
    [anon_sym_LT_DASH_GT] = ACTIONS(138),
    [anon_sym_STAR] = ACTIONS(140),
    [anon_sym_DOT] = ACTIONS(138),
    [anon_sym_LT] = ACTIONS(140),
    [anon_sym_GT] = ACTIONS(140),
    [anon_sym_EQ] = ACTIONS(140),
    [anon_sym_DASH] = ACTIONS(140),
    [anon_sym_AT] = ACTIONS(140),
    [anon_sym_LT_PIPE] = ACTIONS(138),
    [anon_sym_AMP_AMP] = ACTIONS(138),
    [anon_sym_PIPE_PIPE] = ACTIONS(138),
    [anon_sym_QMARK_QMARK] = ACTIONS(138),
    [anon_sym_QMARK_COLON] = ACTIONS(138),
    [anon_sym_BANG_EQ] = ACTIONS(138),
    [anon_sym_EQ_EQ] = ACTIONS(138),
    [anon_sym_QMARK_EQ] = ACTIONS(138),
    [anon_sym_STAR_EQ] = ACTIONS(138),
    [anon_sym_TILDE] = ACTIONS(138),
    [anon_sym_BANG_TILDE] = ACTIONS(138),
    [anon_sym_STAR_TILDE] = ACTIONS(138),
    [anon_sym_LT_EQ] = ACTIONS(138),
    [anon_sym_GT_EQ] = ACTIONS(138),
    [anon_sym_PLUS] = ACTIONS(140),
    [anon_sym_PLUS_EQ] = ACTIONS(138),
    [anon_sym_DASH_EQ] = ACTIONS(138),
    [anon_sym_u00d7] = ACTIONS(138),
    [anon_sym_SLASH] = ACTIONS(140),
    [anon_sym_u00f7] = ACTIONS(138),
    [anon_sym_STAR_STAR] = ACTIONS(138),
    [anon_sym_u220b] = ACTIONS(138),
    [anon_sym_u220c] = ACTIONS(138),
    [anon_sym_u2287] = ACTIONS(138),
    [anon_sym_u2283] = ACTIONS(138),
    [anon_sym_u2285] = ACTIONS(138),
    [anon_sym_u2208] = ACTIONS(138),
    [anon_sym_u2209] = ACTIONS(138),
    [anon_sym_u2286] = ACTIONS(138),
    [anon_sym_u2282] = ACTIONS(138),
    [anon_sym_u2284] = ACTIONS(138),
    [anon_sym_AT_AT] = ACTIONS(138),
  },
  [116] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_value] = ACTIONS(182),
    [sym_keyword_explain] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_fetch] = ACTIONS(182),
    [sym_keyword_limit] = ACTIONS(182),
    [sym_keyword_rand] = ACTIONS(182),
    [sym_keyword_collate] = ACTIONS(182),
    [sym_keyword_numeric] = ACTIONS(182),
    [sym_keyword_asc] = ACTIONS(182),
    [sym_keyword_desc] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_flexible] = ACTIONS(182),
    [sym_keyword_readonly] = ACTIONS(182),
    [sym_keyword_type] = ACTIONS(182),
    [sym_keyword_default] = ACTIONS(182),
    [sym_keyword_assert] = ACTIONS(182),
    [sym_keyword_permissions] = ACTIONS(182),
    [sym_keyword_for] = ACTIONS(182),
    [sym_keyword_comment] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(182),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [117] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(194),
    [sym_keyword_value] = ACTIONS(194),
    [sym_keyword_explain] = ACTIONS(194),
    [sym_keyword_parallel] = ACTIONS(194),
    [sym_keyword_timeout] = ACTIONS(194),
    [sym_keyword_fetch] = ACTIONS(194),
    [sym_keyword_limit] = ACTIONS(194),
    [sym_keyword_rand] = ACTIONS(194),
    [sym_keyword_collate] = ACTIONS(194),
    [sym_keyword_numeric] = ACTIONS(194),
    [sym_keyword_asc] = ACTIONS(194),
    [sym_keyword_desc] = ACTIONS(194),
    [sym_keyword_and] = ACTIONS(194),
    [sym_keyword_or] = ACTIONS(194),
    [sym_keyword_is] = ACTIONS(194),
    [sym_keyword_not] = ACTIONS(196),
    [sym_keyword_contains] = ACTIONS(194),
    [sym_keyword_contains_not] = ACTIONS(194),
    [sym_keyword_contains_all] = ACTIONS(194),
    [sym_keyword_contains_any] = ACTIONS(194),
    [sym_keyword_contains_none] = ACTIONS(194),
    [sym_keyword_inside] = ACTIONS(194),
    [sym_keyword_in] = ACTIONS(196),
    [sym_keyword_not_inside] = ACTIONS(194),
    [sym_keyword_all_inside] = ACTIONS(194),
    [sym_keyword_any_inside] = ACTIONS(194),
    [sym_keyword_none_inside] = ACTIONS(194),
    [sym_keyword_outside] = ACTIONS(194),
    [sym_keyword_intersects] = ACTIONS(194),
    [sym_keyword_flexible] = ACTIONS(194),
    [sym_keyword_readonly] = ACTIONS(194),
    [sym_keyword_type] = ACTIONS(194),
    [sym_keyword_default] = ACTIONS(194),
    [sym_keyword_assert] = ACTIONS(194),
    [sym_keyword_permissions] = ACTIONS(194),
    [sym_keyword_for] = ACTIONS(194),
    [sym_keyword_comment] = ACTIONS(194),
    [anon_sym_COMMA] = ACTIONS(194),
    [anon_sym_DASH_GT] = ACTIONS(194),
    [anon_sym_LBRACK] = ACTIONS(194),
    [anon_sym_RPAREN] = ACTIONS(194),
    [anon_sym_RBRACE] = ACTIONS(194),
    [anon_sym_LT_DASH] = ACTIONS(196),
    [anon_sym_LT_DASH_GT] = ACTIONS(194),
    [anon_sym_STAR] = ACTIONS(196),
    [anon_sym_DOT] = ACTIONS(194),
    [anon_sym_LT] = ACTIONS(196),
    [anon_sym_GT] = ACTIONS(196),
    [anon_sym_EQ] = ACTIONS(196),
    [anon_sym_DASH] = ACTIONS(196),
    [anon_sym_AT] = ACTIONS(196),
    [anon_sym_LT_PIPE] = ACTIONS(194),
    [anon_sym_AMP_AMP] = ACTIONS(194),
    [anon_sym_PIPE_PIPE] = ACTIONS(194),
    [anon_sym_QMARK_QMARK] = ACTIONS(194),
    [anon_sym_QMARK_COLON] = ACTIONS(194),
    [anon_sym_BANG_EQ] = ACTIONS(194),
    [anon_sym_EQ_EQ] = ACTIONS(194),
    [anon_sym_QMARK_EQ] = ACTIONS(194),
    [anon_sym_STAR_EQ] = ACTIONS(194),
    [anon_sym_TILDE] = ACTIONS(194),
    [anon_sym_BANG_TILDE] = ACTIONS(194),
    [anon_sym_STAR_TILDE] = ACTIONS(194),
    [anon_sym_LT_EQ] = ACTIONS(194),
    [anon_sym_GT_EQ] = ACTIONS(194),
    [anon_sym_PLUS] = ACTIONS(196),
    [anon_sym_PLUS_EQ] = ACTIONS(194),
    [anon_sym_DASH_EQ] = ACTIONS(194),
    [anon_sym_u00d7] = ACTIONS(194),
    [anon_sym_SLASH] = ACTIONS(196),
    [anon_sym_u00f7] = ACTIONS(194),
    [anon_sym_STAR_STAR] = ACTIONS(194),
    [anon_sym_u220b] = ACTIONS(194),
    [anon_sym_u220c] = ACTIONS(194),
    [anon_sym_u2287] = ACTIONS(194),
    [anon_sym_u2283] = ACTIONS(194),
    [anon_sym_u2285] = ACTIONS(194),
    [anon_sym_u2208] = ACTIONS(194),
    [anon_sym_u2209] = ACTIONS(194),
    [anon_sym_u2286] = ACTIONS(194),
    [anon_sym_u2282] = ACTIONS(194),
    [anon_sym_u2284] = ACTIONS(194),
    [anon_sym_AT_AT] = ACTIONS(194),
  },
  [118] = {
    [ts_builtin_sym_end] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(55),
    [sym_keyword_value] = ACTIONS(55),
    [sym_keyword_explain] = ACTIONS(55),
    [sym_keyword_parallel] = ACTIONS(55),
    [sym_keyword_timeout] = ACTIONS(55),
    [sym_keyword_fetch] = ACTIONS(55),
    [sym_keyword_limit] = ACTIONS(55),
    [sym_keyword_order] = ACTIONS(55),
    [sym_keyword_with] = ACTIONS(55),
    [sym_keyword_where] = ACTIONS(55),
    [sym_keyword_split] = ACTIONS(55),
    [sym_keyword_group] = ACTIONS(55),
    [sym_keyword_and] = ACTIONS(55),
    [sym_keyword_or] = ACTIONS(57),
    [sym_keyword_is] = ACTIONS(55),
    [sym_keyword_not] = ACTIONS(57),
    [sym_keyword_contains] = ACTIONS(55),
    [sym_keyword_contains_not] = ACTIONS(55),
    [sym_keyword_contains_all] = ACTIONS(55),
    [sym_keyword_contains_any] = ACTIONS(55),
    [sym_keyword_contains_none] = ACTIONS(55),
    [sym_keyword_inside] = ACTIONS(55),
    [sym_keyword_in] = ACTIONS(57),
    [sym_keyword_not_inside] = ACTIONS(55),
    [sym_keyword_all_inside] = ACTIONS(55),
    [sym_keyword_any_inside] = ACTIONS(55),
    [sym_keyword_none_inside] = ACTIONS(55),
    [sym_keyword_outside] = ACTIONS(55),
    [sym_keyword_intersects] = ACTIONS(55),
    [sym_keyword_flexible] = ACTIONS(55),
    [sym_keyword_readonly] = ACTIONS(55),
    [sym_keyword_type] = ACTIONS(55),
    [sym_keyword_default] = ACTIONS(55),
    [sym_keyword_assert] = ACTIONS(55),
    [sym_keyword_permissions] = ACTIONS(55),
    [sym_keyword_comment] = ACTIONS(55),
    [anon_sym_COMMA] = ACTIONS(55),
    [anon_sym_DASH_GT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(55),
    [anon_sym_RPAREN] = ACTIONS(55),
    [anon_sym_RBRACE] = ACTIONS(55),
    [anon_sym_LT_DASH] = ACTIONS(57),
    [anon_sym_LT_DASH_GT] = ACTIONS(55),
    [anon_sym_STAR] = ACTIONS(57),
    [anon_sym_DOT] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(57),
    [anon_sym_GT] = ACTIONS(57),
    [anon_sym_EQ] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(57),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LT_PIPE] = ACTIONS(55),
    [anon_sym_AMP_AMP] = ACTIONS(55),
    [anon_sym_PIPE_PIPE] = ACTIONS(55),
    [anon_sym_QMARK_QMARK] = ACTIONS(55),
    [anon_sym_QMARK_COLON] = ACTIONS(55),
    [anon_sym_BANG_EQ] = ACTIONS(55),
    [anon_sym_EQ_EQ] = ACTIONS(55),
    [anon_sym_QMARK_EQ] = ACTIONS(55),
    [anon_sym_STAR_EQ] = ACTIONS(55),
    [anon_sym_TILDE] = ACTIONS(55),
    [anon_sym_BANG_TILDE] = ACTIONS(55),
    [anon_sym_STAR_TILDE] = ACTIONS(55),
    [anon_sym_LT_EQ] = ACTIONS(55),
    [anon_sym_GT_EQ] = ACTIONS(55),
    [anon_sym_PLUS] = ACTIONS(57),
    [anon_sym_PLUS_EQ] = ACTIONS(55),
    [anon_sym_DASH_EQ] = ACTIONS(55),
    [anon_sym_u00d7] = ACTIONS(55),
    [anon_sym_SLASH] = ACTIONS(57),
    [anon_sym_u00f7] = ACTIONS(55),
    [anon_sym_STAR_STAR] = ACTIONS(55),
    [anon_sym_u220b] = ACTIONS(55),
    [anon_sym_u220c] = ACTIONS(55),
    [anon_sym_u2287] = ACTIONS(55),
    [anon_sym_u2283] = ACTIONS(55),
    [anon_sym_u2285] = ACTIONS(55),
    [anon_sym_u2208] = ACTIONS(55),
    [anon_sym_u2209] = ACTIONS(55),
    [anon_sym_u2286] = ACTIONS(55),
    [anon_sym_u2282] = ACTIONS(55),
    [anon_sym_u2284] = ACTIONS(55),
    [anon_sym_AT_AT] = ACTIONS(55),
  },
  [119] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(202),
    [sym_keyword_value] = ACTIONS(202),
    [sym_keyword_explain] = ACTIONS(202),
    [sym_keyword_parallel] = ACTIONS(202),
    [sym_keyword_timeout] = ACTIONS(202),
    [sym_keyword_fetch] = ACTIONS(202),
    [sym_keyword_limit] = ACTIONS(202),
    [sym_keyword_rand] = ACTIONS(202),
    [sym_keyword_collate] = ACTIONS(202),
    [sym_keyword_numeric] = ACTIONS(202),
    [sym_keyword_asc] = ACTIONS(202),
    [sym_keyword_desc] = ACTIONS(202),
    [sym_keyword_and] = ACTIONS(202),
    [sym_keyword_or] = ACTIONS(202),
    [sym_keyword_is] = ACTIONS(202),
    [sym_keyword_not] = ACTIONS(204),
    [sym_keyword_contains] = ACTIONS(202),
    [sym_keyword_contains_not] = ACTIONS(202),
    [sym_keyword_contains_all] = ACTIONS(202),
    [sym_keyword_contains_any] = ACTIONS(202),
    [sym_keyword_contains_none] = ACTIONS(202),
    [sym_keyword_inside] = ACTIONS(202),
    [sym_keyword_in] = ACTIONS(204),
    [sym_keyword_not_inside] = ACTIONS(202),
    [sym_keyword_all_inside] = ACTIONS(202),
    [sym_keyword_any_inside] = ACTIONS(202),
    [sym_keyword_none_inside] = ACTIONS(202),
    [sym_keyword_outside] = ACTIONS(202),
    [sym_keyword_intersects] = ACTIONS(202),
    [sym_keyword_flexible] = ACTIONS(202),
    [sym_keyword_readonly] = ACTIONS(202),
    [sym_keyword_type] = ACTIONS(202),
    [sym_keyword_default] = ACTIONS(202),
    [sym_keyword_assert] = ACTIONS(202),
    [sym_keyword_permissions] = ACTIONS(202),
    [sym_keyword_for] = ACTIONS(202),
    [sym_keyword_comment] = ACTIONS(202),
    [anon_sym_COMMA] = ACTIONS(202),
    [anon_sym_DASH_GT] = ACTIONS(202),
    [anon_sym_LBRACK] = ACTIONS(202),
    [anon_sym_RPAREN] = ACTIONS(202),
    [anon_sym_RBRACE] = ACTIONS(202),
    [anon_sym_LT_DASH] = ACTIONS(204),
    [anon_sym_LT_DASH_GT] = ACTIONS(202),
    [anon_sym_STAR] = ACTIONS(204),
    [anon_sym_DOT] = ACTIONS(202),
    [anon_sym_LT] = ACTIONS(204),
    [anon_sym_GT] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(204),
    [anon_sym_DASH] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(204),
    [anon_sym_LT_PIPE] = ACTIONS(202),
    [anon_sym_AMP_AMP] = ACTIONS(202),
    [anon_sym_PIPE_PIPE] = ACTIONS(202),
    [anon_sym_QMARK_QMARK] = ACTIONS(202),
    [anon_sym_QMARK_COLON] = ACTIONS(202),
    [anon_sym_BANG_EQ] = ACTIONS(202),
    [anon_sym_EQ_EQ] = ACTIONS(202),
    [anon_sym_QMARK_EQ] = ACTIONS(202),
    [anon_sym_STAR_EQ] = ACTIONS(202),
    [anon_sym_TILDE] = ACTIONS(202),
    [anon_sym_BANG_TILDE] = ACTIONS(202),
    [anon_sym_STAR_TILDE] = ACTIONS(202),
    [anon_sym_LT_EQ] = ACTIONS(202),
    [anon_sym_GT_EQ] = ACTIONS(202),
    [anon_sym_PLUS] = ACTIONS(204),
    [anon_sym_PLUS_EQ] = ACTIONS(202),
    [anon_sym_DASH_EQ] = ACTIONS(202),
    [anon_sym_u00d7] = ACTIONS(202),
    [anon_sym_SLASH] = ACTIONS(204),
    [anon_sym_u00f7] = ACTIONS(202),
    [anon_sym_STAR_STAR] = ACTIONS(202),
    [anon_sym_u220b] = ACTIONS(202),
    [anon_sym_u220c] = ACTIONS(202),
    [anon_sym_u2287] = ACTIONS(202),
    [anon_sym_u2283] = ACTIONS(202),
    [anon_sym_u2285] = ACTIONS(202),
    [anon_sym_u2208] = ACTIONS(202),
    [anon_sym_u2209] = ACTIONS(202),
    [anon_sym_u2286] = ACTIONS(202),
    [anon_sym_u2282] = ACTIONS(202),
    [anon_sym_u2284] = ACTIONS(202),
    [anon_sym_AT_AT] = ACTIONS(202),
  },
  [120] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(142),
    [sym_keyword_value] = ACTIONS(142),
    [sym_keyword_explain] = ACTIONS(142),
    [sym_keyword_parallel] = ACTIONS(142),
    [sym_keyword_timeout] = ACTIONS(142),
    [sym_keyword_fetch] = ACTIONS(142),
    [sym_keyword_limit] = ACTIONS(142),
    [sym_keyword_rand] = ACTIONS(142),
    [sym_keyword_collate] = ACTIONS(142),
    [sym_keyword_numeric] = ACTIONS(142),
    [sym_keyword_asc] = ACTIONS(142),
    [sym_keyword_desc] = ACTIONS(142),
    [sym_keyword_and] = ACTIONS(142),
    [sym_keyword_or] = ACTIONS(142),
    [sym_keyword_is] = ACTIONS(142),
    [sym_keyword_not] = ACTIONS(144),
    [sym_keyword_contains] = ACTIONS(142),
    [sym_keyword_contains_not] = ACTIONS(142),
    [sym_keyword_contains_all] = ACTIONS(142),
    [sym_keyword_contains_any] = ACTIONS(142),
    [sym_keyword_contains_none] = ACTIONS(142),
    [sym_keyword_inside] = ACTIONS(142),
    [sym_keyword_in] = ACTIONS(144),
    [sym_keyword_not_inside] = ACTIONS(142),
    [sym_keyword_all_inside] = ACTIONS(142),
    [sym_keyword_any_inside] = ACTIONS(142),
    [sym_keyword_none_inside] = ACTIONS(142),
    [sym_keyword_outside] = ACTIONS(142),
    [sym_keyword_intersects] = ACTIONS(142),
    [sym_keyword_flexible] = ACTIONS(142),
    [sym_keyword_readonly] = ACTIONS(142),
    [sym_keyword_type] = ACTIONS(142),
    [sym_keyword_default] = ACTIONS(142),
    [sym_keyword_assert] = ACTIONS(142),
    [sym_keyword_permissions] = ACTIONS(142),
    [sym_keyword_for] = ACTIONS(142),
    [sym_keyword_comment] = ACTIONS(142),
    [anon_sym_COMMA] = ACTIONS(142),
    [anon_sym_DASH_GT] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(142),
    [anon_sym_RPAREN] = ACTIONS(142),
    [anon_sym_RBRACE] = ACTIONS(142),
    [anon_sym_LT_DASH] = ACTIONS(144),
    [anon_sym_LT_DASH_GT] = ACTIONS(142),
    [anon_sym_STAR] = ACTIONS(144),
    [anon_sym_DOT] = ACTIONS(142),
    [anon_sym_LT] = ACTIONS(144),
    [anon_sym_GT] = ACTIONS(144),
    [anon_sym_EQ] = ACTIONS(144),
    [anon_sym_DASH] = ACTIONS(144),
    [anon_sym_AT] = ACTIONS(144),
    [anon_sym_LT_PIPE] = ACTIONS(142),
    [anon_sym_AMP_AMP] = ACTIONS(142),
    [anon_sym_PIPE_PIPE] = ACTIONS(142),
    [anon_sym_QMARK_QMARK] = ACTIONS(142),
    [anon_sym_QMARK_COLON] = ACTIONS(142),
    [anon_sym_BANG_EQ] = ACTIONS(142),
    [anon_sym_EQ_EQ] = ACTIONS(142),
    [anon_sym_QMARK_EQ] = ACTIONS(142),
    [anon_sym_STAR_EQ] = ACTIONS(142),
    [anon_sym_TILDE] = ACTIONS(142),
    [anon_sym_BANG_TILDE] = ACTIONS(142),
    [anon_sym_STAR_TILDE] = ACTIONS(142),
    [anon_sym_LT_EQ] = ACTIONS(142),
    [anon_sym_GT_EQ] = ACTIONS(142),
    [anon_sym_PLUS] = ACTIONS(144),
    [anon_sym_PLUS_EQ] = ACTIONS(142),
    [anon_sym_DASH_EQ] = ACTIONS(142),
    [anon_sym_u00d7] = ACTIONS(142),
    [anon_sym_SLASH] = ACTIONS(144),
    [anon_sym_u00f7] = ACTIONS(142),
    [anon_sym_STAR_STAR] = ACTIONS(142),
    [anon_sym_u220b] = ACTIONS(142),
    [anon_sym_u220c] = ACTIONS(142),
    [anon_sym_u2287] = ACTIONS(142),
    [anon_sym_u2283] = ACTIONS(142),
    [anon_sym_u2285] = ACTIONS(142),
    [anon_sym_u2208] = ACTIONS(142),
    [anon_sym_u2209] = ACTIONS(142),
    [anon_sym_u2286] = ACTIONS(142),
    [anon_sym_u2282] = ACTIONS(142),
    [anon_sym_u2284] = ACTIONS(142),
    [anon_sym_AT_AT] = ACTIONS(142),
  },
  [121] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_value] = ACTIONS(178),
    [sym_keyword_explain] = ACTIONS(178),
    [sym_keyword_parallel] = ACTIONS(178),
    [sym_keyword_timeout] = ACTIONS(178),
    [sym_keyword_fetch] = ACTIONS(178),
    [sym_keyword_limit] = ACTIONS(178),
    [sym_keyword_rand] = ACTIONS(178),
    [sym_keyword_collate] = ACTIONS(178),
    [sym_keyword_numeric] = ACTIONS(178),
    [sym_keyword_asc] = ACTIONS(178),
    [sym_keyword_desc] = ACTIONS(178),
    [sym_keyword_and] = ACTIONS(178),
    [sym_keyword_or] = ACTIONS(178),
    [sym_keyword_is] = ACTIONS(178),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(178),
    [sym_keyword_contains_not] = ACTIONS(178),
    [sym_keyword_contains_all] = ACTIONS(178),
    [sym_keyword_contains_any] = ACTIONS(178),
    [sym_keyword_contains_none] = ACTIONS(178),
    [sym_keyword_inside] = ACTIONS(178),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(178),
    [sym_keyword_all_inside] = ACTIONS(178),
    [sym_keyword_any_inside] = ACTIONS(178),
    [sym_keyword_none_inside] = ACTIONS(178),
    [sym_keyword_outside] = ACTIONS(178),
    [sym_keyword_intersects] = ACTIONS(178),
    [sym_keyword_flexible] = ACTIONS(178),
    [sym_keyword_readonly] = ACTIONS(178),
    [sym_keyword_type] = ACTIONS(178),
    [sym_keyword_default] = ACTIONS(178),
    [sym_keyword_assert] = ACTIONS(178),
    [sym_keyword_permissions] = ACTIONS(178),
    [sym_keyword_for] = ACTIONS(178),
    [sym_keyword_comment] = ACTIONS(178),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [122] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(206),
    [sym_keyword_value] = ACTIONS(206),
    [sym_keyword_explain] = ACTIONS(206),
    [sym_keyword_parallel] = ACTIONS(206),
    [sym_keyword_timeout] = ACTIONS(206),
    [sym_keyword_fetch] = ACTIONS(206),
    [sym_keyword_limit] = ACTIONS(206),
    [sym_keyword_rand] = ACTIONS(206),
    [sym_keyword_collate] = ACTIONS(206),
    [sym_keyword_numeric] = ACTIONS(206),
    [sym_keyword_asc] = ACTIONS(206),
    [sym_keyword_desc] = ACTIONS(206),
    [sym_keyword_and] = ACTIONS(206),
    [sym_keyword_or] = ACTIONS(206),
    [sym_keyword_is] = ACTIONS(206),
    [sym_keyword_not] = ACTIONS(208),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(206),
    [sym_keyword_contains_all] = ACTIONS(206),
    [sym_keyword_contains_any] = ACTIONS(206),
    [sym_keyword_contains_none] = ACTIONS(206),
    [sym_keyword_inside] = ACTIONS(206),
    [sym_keyword_in] = ACTIONS(208),
    [sym_keyword_not_inside] = ACTIONS(206),
    [sym_keyword_all_inside] = ACTIONS(206),
    [sym_keyword_any_inside] = ACTIONS(206),
    [sym_keyword_none_inside] = ACTIONS(206),
    [sym_keyword_outside] = ACTIONS(206),
    [sym_keyword_intersects] = ACTIONS(206),
    [sym_keyword_flexible] = ACTIONS(206),
    [sym_keyword_readonly] = ACTIONS(206),
    [sym_keyword_type] = ACTIONS(206),
    [sym_keyword_default] = ACTIONS(206),
    [sym_keyword_assert] = ACTIONS(206),
    [sym_keyword_permissions] = ACTIONS(206),
    [sym_keyword_for] = ACTIONS(206),
    [sym_keyword_comment] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(206),
    [anon_sym_DASH_GT] = ACTIONS(206),
    [anon_sym_LBRACK] = ACTIONS(206),
    [anon_sym_RPAREN] = ACTIONS(206),
    [anon_sym_RBRACE] = ACTIONS(206),
    [anon_sym_LT_DASH] = ACTIONS(208),
    [anon_sym_LT_DASH_GT] = ACTIONS(206),
    [anon_sym_STAR] = ACTIONS(208),
    [anon_sym_DOT] = ACTIONS(206),
    [anon_sym_LT] = ACTIONS(208),
    [anon_sym_GT] = ACTIONS(208),
    [anon_sym_EQ] = ACTIONS(208),
    [anon_sym_DASH] = ACTIONS(208),
    [anon_sym_AT] = ACTIONS(208),
    [anon_sym_LT_PIPE] = ACTIONS(206),
    [anon_sym_AMP_AMP] = ACTIONS(206),
    [anon_sym_PIPE_PIPE] = ACTIONS(206),
    [anon_sym_QMARK_QMARK] = ACTIONS(206),
    [anon_sym_QMARK_COLON] = ACTIONS(206),
    [anon_sym_BANG_EQ] = ACTIONS(206),
    [anon_sym_EQ_EQ] = ACTIONS(206),
    [anon_sym_QMARK_EQ] = ACTIONS(206),
    [anon_sym_STAR_EQ] = ACTIONS(206),
    [anon_sym_TILDE] = ACTIONS(206),
    [anon_sym_BANG_TILDE] = ACTIONS(206),
    [anon_sym_STAR_TILDE] = ACTIONS(206),
    [anon_sym_LT_EQ] = ACTIONS(206),
    [anon_sym_GT_EQ] = ACTIONS(206),
    [anon_sym_PLUS] = ACTIONS(208),
    [anon_sym_PLUS_EQ] = ACTIONS(206),
    [anon_sym_DASH_EQ] = ACTIONS(206),
    [anon_sym_u00d7] = ACTIONS(206),
    [anon_sym_SLASH] = ACTIONS(208),
    [anon_sym_u00f7] = ACTIONS(206),
    [anon_sym_STAR_STAR] = ACTIONS(206),
    [anon_sym_u220b] = ACTIONS(206),
    [anon_sym_u220c] = ACTIONS(206),
    [anon_sym_u2287] = ACTIONS(206),
    [anon_sym_u2283] = ACTIONS(206),
    [anon_sym_u2285] = ACTIONS(206),
    [anon_sym_u2208] = ACTIONS(206),
    [anon_sym_u2209] = ACTIONS(206),
    [anon_sym_u2286] = ACTIONS(206),
    [anon_sym_u2282] = ACTIONS(206),
    [anon_sym_u2284] = ACTIONS(206),
    [anon_sym_AT_AT] = ACTIONS(206),
  },
  [123] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(190),
    [sym_keyword_value] = ACTIONS(190),
    [sym_keyword_explain] = ACTIONS(190),
    [sym_keyword_parallel] = ACTIONS(190),
    [sym_keyword_timeout] = ACTIONS(190),
    [sym_keyword_fetch] = ACTIONS(190),
    [sym_keyword_limit] = ACTIONS(190),
    [sym_keyword_rand] = ACTIONS(190),
    [sym_keyword_collate] = ACTIONS(190),
    [sym_keyword_numeric] = ACTIONS(190),
    [sym_keyword_asc] = ACTIONS(190),
    [sym_keyword_desc] = ACTIONS(190),
    [sym_keyword_and] = ACTIONS(190),
    [sym_keyword_or] = ACTIONS(190),
    [sym_keyword_is] = ACTIONS(190),
    [sym_keyword_not] = ACTIONS(192),
    [sym_keyword_contains] = ACTIONS(190),
    [sym_keyword_contains_not] = ACTIONS(190),
    [sym_keyword_contains_all] = ACTIONS(190),
    [sym_keyword_contains_any] = ACTIONS(190),
    [sym_keyword_contains_none] = ACTIONS(190),
    [sym_keyword_inside] = ACTIONS(190),
    [sym_keyword_in] = ACTIONS(192),
    [sym_keyword_not_inside] = ACTIONS(190),
    [sym_keyword_all_inside] = ACTIONS(190),
    [sym_keyword_any_inside] = ACTIONS(190),
    [sym_keyword_none_inside] = ACTIONS(190),
    [sym_keyword_outside] = ACTIONS(190),
    [sym_keyword_intersects] = ACTIONS(190),
    [sym_keyword_flexible] = ACTIONS(190),
    [sym_keyword_readonly] = ACTIONS(190),
    [sym_keyword_type] = ACTIONS(190),
    [sym_keyword_default] = ACTIONS(190),
    [sym_keyword_assert] = ACTIONS(190),
    [sym_keyword_permissions] = ACTIONS(190),
    [sym_keyword_for] = ACTIONS(190),
    [sym_keyword_comment] = ACTIONS(190),
    [anon_sym_COMMA] = ACTIONS(190),
    [anon_sym_DASH_GT] = ACTIONS(190),
    [anon_sym_LBRACK] = ACTIONS(190),
    [anon_sym_RPAREN] = ACTIONS(190),
    [anon_sym_RBRACE] = ACTIONS(190),
    [anon_sym_LT_DASH] = ACTIONS(192),
    [anon_sym_LT_DASH_GT] = ACTIONS(190),
    [anon_sym_STAR] = ACTIONS(192),
    [anon_sym_DOT] = ACTIONS(190),
    [anon_sym_LT] = ACTIONS(192),
    [anon_sym_GT] = ACTIONS(192),
    [anon_sym_EQ] = ACTIONS(192),
    [anon_sym_DASH] = ACTIONS(192),
    [anon_sym_AT] = ACTIONS(192),
    [anon_sym_LT_PIPE] = ACTIONS(190),
    [anon_sym_AMP_AMP] = ACTIONS(190),
    [anon_sym_PIPE_PIPE] = ACTIONS(190),
    [anon_sym_QMARK_QMARK] = ACTIONS(190),
    [anon_sym_QMARK_COLON] = ACTIONS(190),
    [anon_sym_BANG_EQ] = ACTIONS(190),
    [anon_sym_EQ_EQ] = ACTIONS(190),
    [anon_sym_QMARK_EQ] = ACTIONS(190),
    [anon_sym_STAR_EQ] = ACTIONS(190),
    [anon_sym_TILDE] = ACTIONS(190),
    [anon_sym_BANG_TILDE] = ACTIONS(190),
    [anon_sym_STAR_TILDE] = ACTIONS(190),
    [anon_sym_LT_EQ] = ACTIONS(190),
    [anon_sym_GT_EQ] = ACTIONS(190),
    [anon_sym_PLUS] = ACTIONS(192),
    [anon_sym_PLUS_EQ] = ACTIONS(190),
    [anon_sym_DASH_EQ] = ACTIONS(190),
    [anon_sym_u00d7] = ACTIONS(190),
    [anon_sym_SLASH] = ACTIONS(192),
    [anon_sym_u00f7] = ACTIONS(190),
    [anon_sym_STAR_STAR] = ACTIONS(190),
    [anon_sym_u220b] = ACTIONS(190),
    [anon_sym_u220c] = ACTIONS(190),
    [anon_sym_u2287] = ACTIONS(190),
    [anon_sym_u2283] = ACTIONS(190),
    [anon_sym_u2285] = ACTIONS(190),
    [anon_sym_u2208] = ACTIONS(190),
    [anon_sym_u2209] = ACTIONS(190),
    [anon_sym_u2286] = ACTIONS(190),
    [anon_sym_u2282] = ACTIONS(190),
    [anon_sym_u2284] = ACTIONS(190),
    [anon_sym_AT_AT] = ACTIONS(190),
  },
  [124] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(186),
    [sym_keyword_value] = ACTIONS(186),
    [sym_keyword_explain] = ACTIONS(186),
    [sym_keyword_parallel] = ACTIONS(186),
    [sym_keyword_timeout] = ACTIONS(186),
    [sym_keyword_fetch] = ACTIONS(186),
    [sym_keyword_limit] = ACTIONS(186),
    [sym_keyword_rand] = ACTIONS(186),
    [sym_keyword_collate] = ACTIONS(186),
    [sym_keyword_numeric] = ACTIONS(186),
    [sym_keyword_asc] = ACTIONS(186),
    [sym_keyword_desc] = ACTIONS(186),
    [sym_keyword_and] = ACTIONS(186),
    [sym_keyword_or] = ACTIONS(186),
    [sym_keyword_is] = ACTIONS(186),
    [sym_keyword_not] = ACTIONS(188),
    [sym_keyword_contains] = ACTIONS(186),
    [sym_keyword_contains_not] = ACTIONS(186),
    [sym_keyword_contains_all] = ACTIONS(186),
    [sym_keyword_contains_any] = ACTIONS(186),
    [sym_keyword_contains_none] = ACTIONS(186),
    [sym_keyword_inside] = ACTIONS(186),
    [sym_keyword_in] = ACTIONS(188),
    [sym_keyword_not_inside] = ACTIONS(186),
    [sym_keyword_all_inside] = ACTIONS(186),
    [sym_keyword_any_inside] = ACTIONS(186),
    [sym_keyword_none_inside] = ACTIONS(186),
    [sym_keyword_outside] = ACTIONS(186),
    [sym_keyword_intersects] = ACTIONS(186),
    [sym_keyword_flexible] = ACTIONS(186),
    [sym_keyword_readonly] = ACTIONS(186),
    [sym_keyword_type] = ACTIONS(186),
    [sym_keyword_default] = ACTIONS(186),
    [sym_keyword_assert] = ACTIONS(186),
    [sym_keyword_permissions] = ACTIONS(186),
    [sym_keyword_for] = ACTIONS(186),
    [sym_keyword_comment] = ACTIONS(186),
    [anon_sym_COMMA] = ACTIONS(186),
    [anon_sym_DASH_GT] = ACTIONS(186),
    [anon_sym_LBRACK] = ACTIONS(186),
    [anon_sym_RPAREN] = ACTIONS(186),
    [anon_sym_RBRACE] = ACTIONS(186),
    [anon_sym_LT_DASH] = ACTIONS(188),
    [anon_sym_LT_DASH_GT] = ACTIONS(186),
    [anon_sym_STAR] = ACTIONS(188),
    [anon_sym_DOT] = ACTIONS(186),
    [anon_sym_LT] = ACTIONS(188),
    [anon_sym_GT] = ACTIONS(188),
    [anon_sym_EQ] = ACTIONS(188),
    [anon_sym_DASH] = ACTIONS(188),
    [anon_sym_AT] = ACTIONS(188),
    [anon_sym_LT_PIPE] = ACTIONS(186),
    [anon_sym_AMP_AMP] = ACTIONS(186),
    [anon_sym_PIPE_PIPE] = ACTIONS(186),
    [anon_sym_QMARK_QMARK] = ACTIONS(186),
    [anon_sym_QMARK_COLON] = ACTIONS(186),
    [anon_sym_BANG_EQ] = ACTIONS(186),
    [anon_sym_EQ_EQ] = ACTIONS(186),
    [anon_sym_QMARK_EQ] = ACTIONS(186),
    [anon_sym_STAR_EQ] = ACTIONS(186),
    [anon_sym_TILDE] = ACTIONS(186),
    [anon_sym_BANG_TILDE] = ACTIONS(186),
    [anon_sym_STAR_TILDE] = ACTIONS(186),
    [anon_sym_LT_EQ] = ACTIONS(186),
    [anon_sym_GT_EQ] = ACTIONS(186),
    [anon_sym_PLUS] = ACTIONS(188),
    [anon_sym_PLUS_EQ] = ACTIONS(186),
    [anon_sym_DASH_EQ] = ACTIONS(186),
    [anon_sym_u00d7] = ACTIONS(186),
    [anon_sym_SLASH] = ACTIONS(188),
    [anon_sym_u00f7] = ACTIONS(186),
    [anon_sym_STAR_STAR] = ACTIONS(186),
    [anon_sym_u220b] = ACTIONS(186),
    [anon_sym_u220c] = ACTIONS(186),
    [anon_sym_u2287] = ACTIONS(186),
    [anon_sym_u2283] = ACTIONS(186),
    [anon_sym_u2285] = ACTIONS(186),
    [anon_sym_u2208] = ACTIONS(186),
    [anon_sym_u2209] = ACTIONS(186),
    [anon_sym_u2286] = ACTIONS(186),
    [anon_sym_u2282] = ACTIONS(186),
    [anon_sym_u2284] = ACTIONS(186),
    [anon_sym_AT_AT] = ACTIONS(186),
  },
  [125] = {
    [sym_with_clause] = STATE(780),
    [sym_where_clause] = STATE(797),
    [sym_split_clause] = STATE(820),
    [sym_group_clause] = STATE(862),
    [sym_order_clause] = STATE(892),
    [sym_limit_clause] = STATE(974),
    [sym_fetch_clause] = STATE(1007),
    [sym_timeout_clause] = STATE(1106),
    [sym_parallel_clause] = STATE(1251),
    [sym_explain_clause] = STATE(1309),
    [sym_operator] = STATE(659),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(760),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(289),
    [sym_keyword_explain] = ACTIONS(291),
    [sym_keyword_parallel] = ACTIONS(293),
    [sym_keyword_timeout] = ACTIONS(295),
    [sym_keyword_fetch] = ACTIONS(297),
    [sym_keyword_limit] = ACTIONS(299),
    [sym_keyword_order] = ACTIONS(301),
    [sym_keyword_with] = ACTIONS(303),
    [sym_keyword_where] = ACTIONS(305),
    [sym_keyword_split] = ACTIONS(307),
    [sym_keyword_group] = ACTIONS(309),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(313),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(319),
    [anon_sym_RPAREN] = ACTIONS(289),
    [anon_sym_RBRACE] = ACTIONS(289),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [126] = {
    [ts_builtin_sym_end] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(55),
    [sym_keyword_value] = ACTIONS(55),
    [sym_keyword_explain] = ACTIONS(55),
    [sym_keyword_parallel] = ACTIONS(55),
    [sym_keyword_timeout] = ACTIONS(55),
    [sym_keyword_fetch] = ACTIONS(55),
    [sym_keyword_limit] = ACTIONS(55),
    [sym_keyword_rand] = ACTIONS(55),
    [sym_keyword_collate] = ACTIONS(55),
    [sym_keyword_numeric] = ACTIONS(55),
    [sym_keyword_asc] = ACTIONS(55),
    [sym_keyword_desc] = ACTIONS(55),
    [sym_keyword_and] = ACTIONS(55),
    [sym_keyword_or] = ACTIONS(55),
    [sym_keyword_is] = ACTIONS(55),
    [sym_keyword_not] = ACTIONS(57),
    [sym_keyword_contains] = ACTIONS(55),
    [sym_keyword_contains_not] = ACTIONS(55),
    [sym_keyword_contains_all] = ACTIONS(55),
    [sym_keyword_contains_any] = ACTIONS(55),
    [sym_keyword_contains_none] = ACTIONS(55),
    [sym_keyword_inside] = ACTIONS(55),
    [sym_keyword_in] = ACTIONS(57),
    [sym_keyword_not_inside] = ACTIONS(55),
    [sym_keyword_all_inside] = ACTIONS(55),
    [sym_keyword_any_inside] = ACTIONS(55),
    [sym_keyword_none_inside] = ACTIONS(55),
    [sym_keyword_outside] = ACTIONS(55),
    [sym_keyword_intersects] = ACTIONS(55),
    [sym_keyword_flexible] = ACTIONS(55),
    [sym_keyword_readonly] = ACTIONS(55),
    [sym_keyword_type] = ACTIONS(55),
    [sym_keyword_default] = ACTIONS(55),
    [sym_keyword_assert] = ACTIONS(55),
    [sym_keyword_permissions] = ACTIONS(55),
    [sym_keyword_for] = ACTIONS(55),
    [sym_keyword_comment] = ACTIONS(55),
    [anon_sym_COMMA] = ACTIONS(55),
    [anon_sym_DASH_GT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(55),
    [anon_sym_LT_DASH] = ACTIONS(57),
    [anon_sym_LT_DASH_GT] = ACTIONS(55),
    [anon_sym_STAR] = ACTIONS(57),
    [anon_sym_DOT] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(57),
    [anon_sym_GT] = ACTIONS(57),
    [anon_sym_EQ] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(57),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LT_PIPE] = ACTIONS(55),
    [anon_sym_AMP_AMP] = ACTIONS(55),
    [anon_sym_PIPE_PIPE] = ACTIONS(55),
    [anon_sym_QMARK_QMARK] = ACTIONS(55),
    [anon_sym_QMARK_COLON] = ACTIONS(55),
    [anon_sym_BANG_EQ] = ACTIONS(55),
    [anon_sym_EQ_EQ] = ACTIONS(55),
    [anon_sym_QMARK_EQ] = ACTIONS(55),
    [anon_sym_STAR_EQ] = ACTIONS(55),
    [anon_sym_TILDE] = ACTIONS(55),
    [anon_sym_BANG_TILDE] = ACTIONS(55),
    [anon_sym_STAR_TILDE] = ACTIONS(55),
    [anon_sym_LT_EQ] = ACTIONS(55),
    [anon_sym_GT_EQ] = ACTIONS(55),
    [anon_sym_PLUS] = ACTIONS(57),
    [anon_sym_PLUS_EQ] = ACTIONS(55),
    [anon_sym_DASH_EQ] = ACTIONS(55),
    [anon_sym_u00d7] = ACTIONS(55),
    [anon_sym_SLASH] = ACTIONS(57),
    [anon_sym_u00f7] = ACTIONS(55),
    [anon_sym_STAR_STAR] = ACTIONS(55),
    [anon_sym_u220b] = ACTIONS(55),
    [anon_sym_u220c] = ACTIONS(55),
    [anon_sym_u2287] = ACTIONS(55),
    [anon_sym_u2283] = ACTIONS(55),
    [anon_sym_u2285] = ACTIONS(55),
    [anon_sym_u2208] = ACTIONS(55),
    [anon_sym_u2209] = ACTIONS(55),
    [anon_sym_u2286] = ACTIONS(55),
    [anon_sym_u2282] = ACTIONS(55),
    [anon_sym_u2284] = ACTIONS(55),
    [anon_sym_AT_AT] = ACTIONS(55),
  },
  [127] = {
    [sym_with_clause] = STATE(779),
    [sym_where_clause] = STATE(794),
    [sym_split_clause] = STATE(818),
    [sym_group_clause] = STATE(858),
    [sym_order_clause] = STATE(879),
    [sym_limit_clause] = STATE(961),
    [sym_fetch_clause] = STATE(1003),
    [sym_timeout_clause] = STATE(1145),
    [sym_parallel_clause] = STATE(1203),
    [sym_explain_clause] = STATE(1382),
    [sym_operator] = STATE(659),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(761),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(329),
    [sym_keyword_explain] = ACTIONS(291),
    [sym_keyword_parallel] = ACTIONS(293),
    [sym_keyword_timeout] = ACTIONS(295),
    [sym_keyword_fetch] = ACTIONS(297),
    [sym_keyword_limit] = ACTIONS(299),
    [sym_keyword_order] = ACTIONS(301),
    [sym_keyword_with] = ACTIONS(303),
    [sym_keyword_where] = ACTIONS(305),
    [sym_keyword_split] = ACTIONS(307),
    [sym_keyword_group] = ACTIONS(309),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(313),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(319),
    [anon_sym_RPAREN] = ACTIONS(329),
    [anon_sym_RBRACE] = ACTIONS(329),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [128] = {
    [sym_with_clause] = STATE(778),
    [sym_where_clause] = STATE(792),
    [sym_split_clause] = STATE(817),
    [sym_group_clause] = STATE(868),
    [sym_order_clause] = STATE(902),
    [sym_limit_clause] = STATE(981),
    [sym_fetch_clause] = STATE(1014),
    [sym_timeout_clause] = STATE(1137),
    [sym_parallel_clause] = STATE(1204),
    [sym_explain_clause] = STATE(1305),
    [sym_operator] = STATE(659),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(759),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(331),
    [sym_keyword_explain] = ACTIONS(291),
    [sym_keyword_parallel] = ACTIONS(293),
    [sym_keyword_timeout] = ACTIONS(295),
    [sym_keyword_fetch] = ACTIONS(297),
    [sym_keyword_limit] = ACTIONS(299),
    [sym_keyword_order] = ACTIONS(301),
    [sym_keyword_with] = ACTIONS(303),
    [sym_keyword_where] = ACTIONS(305),
    [sym_keyword_split] = ACTIONS(307),
    [sym_keyword_group] = ACTIONS(309),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(313),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(319),
    [anon_sym_RPAREN] = ACTIONS(331),
    [anon_sym_RBRACE] = ACTIONS(331),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [129] = {
    [sym_with_clause] = STATE(785),
    [sym_where_clause] = STATE(805),
    [sym_split_clause] = STATE(850),
    [sym_group_clause] = STATE(903),
    [sym_order_clause] = STATE(902),
    [sym_limit_clause] = STATE(981),
    [sym_fetch_clause] = STATE(1014),
    [sym_timeout_clause] = STATE(1137),
    [sym_parallel_clause] = STATE(1204),
    [sym_explain_clause] = STATE(1305),
    [sym_operator] = STATE(673),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(763),
    [ts_builtin_sym_end] = ACTIONS(331),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(331),
    [sym_keyword_explain] = ACTIONS(291),
    [sym_keyword_parallel] = ACTIONS(293),
    [sym_keyword_timeout] = ACTIONS(295),
    [sym_keyword_fetch] = ACTIONS(297),
    [sym_keyword_limit] = ACTIONS(299),
    [sym_keyword_order] = ACTIONS(333),
    [sym_keyword_with] = ACTIONS(335),
    [sym_keyword_where] = ACTIONS(337),
    [sym_keyword_split] = ACTIONS(307),
    [sym_keyword_group] = ACTIONS(309),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(313),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(339),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [130] = {
    [sym_with_clause] = STATE(783),
    [sym_where_clause] = STATE(798),
    [sym_split_clause] = STATE(854),
    [sym_group_clause] = STATE(880),
    [sym_order_clause] = STATE(879),
    [sym_limit_clause] = STATE(961),
    [sym_fetch_clause] = STATE(1003),
    [sym_timeout_clause] = STATE(1145),
    [sym_parallel_clause] = STATE(1203),
    [sym_explain_clause] = STATE(1382),
    [sym_operator] = STATE(673),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(765),
    [ts_builtin_sym_end] = ACTIONS(329),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(329),
    [sym_keyword_explain] = ACTIONS(291),
    [sym_keyword_parallel] = ACTIONS(293),
    [sym_keyword_timeout] = ACTIONS(295),
    [sym_keyword_fetch] = ACTIONS(297),
    [sym_keyword_limit] = ACTIONS(299),
    [sym_keyword_order] = ACTIONS(333),
    [sym_keyword_with] = ACTIONS(335),
    [sym_keyword_where] = ACTIONS(337),
    [sym_keyword_split] = ACTIONS(307),
    [sym_keyword_group] = ACTIONS(309),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(313),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(339),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [131] = {
    [sym_with_clause] = STATE(786),
    [sym_where_clause] = STATE(804),
    [sym_split_clause] = STATE(842),
    [sym_group_clause] = STATE(890),
    [sym_order_clause] = STATE(892),
    [sym_limit_clause] = STATE(974),
    [sym_fetch_clause] = STATE(1007),
    [sym_timeout_clause] = STATE(1106),
    [sym_parallel_clause] = STATE(1251),
    [sym_explain_clause] = STATE(1309),
    [sym_operator] = STATE(673),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(764),
    [ts_builtin_sym_end] = ACTIONS(289),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(289),
    [sym_keyword_explain] = ACTIONS(291),
    [sym_keyword_parallel] = ACTIONS(293),
    [sym_keyword_timeout] = ACTIONS(295),
    [sym_keyword_fetch] = ACTIONS(297),
    [sym_keyword_limit] = ACTIONS(299),
    [sym_keyword_order] = ACTIONS(333),
    [sym_keyword_with] = ACTIONS(335),
    [sym_keyword_where] = ACTIONS(337),
    [sym_keyword_split] = ACTIONS(307),
    [sym_keyword_group] = ACTIONS(309),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(313),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(339),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [132] = {
    [sym_where_clause] = STATE(1049),
    [sym_timeout_clause] = STATE(1200),
    [sym_parallel_clause] = STATE(1312),
    [sym_content_clause] = STATE(995),
    [sym_set_clause] = STATE(995),
    [sym_unset_clause] = STATE(995),
    [sym_return_clause] = STATE(1151),
    [sym_merge_clause] = STATE(995),
    [sym_patch_clause] = STATE(995),
    [sym_operator] = STATE(731),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(767),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(341),
    [sym_keyword_return] = ACTIONS(343),
    [sym_keyword_parallel] = ACTIONS(293),
    [sym_keyword_timeout] = ACTIONS(295),
    [sym_keyword_where] = ACTIONS(345),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_content] = ACTIONS(347),
    [sym_keyword_merge] = ACTIONS(349),
    [sym_keyword_patch] = ACTIONS(351),
    [sym_keyword_set] = ACTIONS(353),
    [sym_keyword_unset] = ACTIONS(355),
    [anon_sym_COMMA] = ACTIONS(357),
    [anon_sym_RPAREN] = ACTIONS(341),
    [anon_sym_RBRACE] = ACTIONS(341),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [133] = {
    [sym_array] = STATE(101),
    [sym_object] = STATE(101),
    [sym_record_id_value] = STATE(113),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_explain] = ACTIONS(180),
    [sym_keyword_parallel] = ACTIONS(180),
    [sym_keyword_timeout] = ACTIONS(180),
    [sym_keyword_fetch] = ACTIONS(180),
    [sym_keyword_limit] = ACTIONS(180),
    [sym_keyword_rand] = ACTIONS(180),
    [sym_keyword_collate] = ACTIONS(180),
    [sym_keyword_numeric] = ACTIONS(180),
    [sym_keyword_asc] = ACTIONS(180),
    [sym_keyword_desc] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(359),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(361),
    [sym_record_id_ident] = ACTIONS(361),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [134] = {
    [sym_array] = STATE(241),
    [sym_object] = STATE(241),
    [sym_record_id_value] = STATE(283),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_explain] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_fetch] = ACTIONS(212),
    [sym_keyword_limit] = ACTIONS(212),
    [sym_keyword_order] = ACTIONS(212),
    [sym_keyword_with] = ACTIONS(212),
    [sym_keyword_where] = ACTIONS(212),
    [sym_keyword_split] = ACTIONS(212),
    [sym_keyword_group] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(363),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(365),
    [sym_record_id_ident] = ACTIONS(365),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [135] = {
    [sym_array] = STATE(241),
    [sym_object] = STATE(241),
    [sym_record_id_value] = STATE(286),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_explain] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_fetch] = ACTIONS(369),
    [sym_keyword_limit] = ACTIONS(369),
    [sym_keyword_order] = ACTIONS(369),
    [sym_keyword_with] = ACTIONS(369),
    [sym_keyword_where] = ACTIONS(369),
    [sym_keyword_split] = ACTIONS(369),
    [sym_keyword_group] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_RPAREN] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(363),
    [anon_sym_RBRACE] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(365),
    [sym_record_id_ident] = ACTIONS(365),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [136] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(33),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_as] = ACTIONS(180),
    [sym_keyword_where] = ACTIONS(180),
    [sym_keyword_group] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [sym_keyword_drop] = ACTIONS(180),
    [sym_keyword_schemafull] = ACTIONS(180),
    [sym_keyword_schemaless] = ACTIONS(180),
    [sym_keyword_changefeed] = ACTIONS(180),
    [sym_keyword_type] = ACTIONS(180),
    [sym_keyword_permissions] = ACTIONS(180),
    [sym_keyword_comment] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [137] = {
    [sym_where_clause] = STATE(1099),
    [sym_timeout_clause] = STATE(1256),
    [sym_parallel_clause] = STATE(1395),
    [sym_content_clause] = STATE(990),
    [sym_set_clause] = STATE(990),
    [sym_unset_clause] = STATE(990),
    [sym_return_clause] = STATE(1166),
    [sym_merge_clause] = STATE(990),
    [sym_patch_clause] = STATE(990),
    [sym_operator] = STATE(731),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(768),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(375),
    [sym_keyword_return] = ACTIONS(343),
    [sym_keyword_parallel] = ACTIONS(293),
    [sym_keyword_timeout] = ACTIONS(295),
    [sym_keyword_where] = ACTIONS(345),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_content] = ACTIONS(347),
    [sym_keyword_merge] = ACTIONS(349),
    [sym_keyword_patch] = ACTIONS(351),
    [sym_keyword_set] = ACTIONS(353),
    [sym_keyword_unset] = ACTIONS(355),
    [anon_sym_COMMA] = ACTIONS(357),
    [anon_sym_RPAREN] = ACTIONS(375),
    [anon_sym_RBRACE] = ACTIONS(375),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [138] = {
    [sym_array] = STATE(241),
    [sym_object] = STATE(241),
    [sym_record_id_value] = STATE(278),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_explain] = ACTIONS(180),
    [sym_keyword_parallel] = ACTIONS(180),
    [sym_keyword_timeout] = ACTIONS(180),
    [sym_keyword_fetch] = ACTIONS(180),
    [sym_keyword_limit] = ACTIONS(180),
    [sym_keyword_order] = ACTIONS(180),
    [sym_keyword_with] = ACTIONS(180),
    [sym_keyword_where] = ACTIONS(180),
    [sym_keyword_split] = ACTIONS(180),
    [sym_keyword_group] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(363),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(365),
    [sym_record_id_ident] = ACTIONS(365),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [139] = {
    [sym_array] = STATE(101),
    [sym_object] = STATE(101),
    [sym_record_id_value] = STATE(121),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_explain] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_fetch] = ACTIONS(212),
    [sym_keyword_limit] = ACTIONS(212),
    [sym_keyword_rand] = ACTIONS(212),
    [sym_keyword_collate] = ACTIONS(212),
    [sym_keyword_numeric] = ACTIONS(212),
    [sym_keyword_asc] = ACTIONS(212),
    [sym_keyword_desc] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(359),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(361),
    [sym_record_id_ident] = ACTIONS(361),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [140] = {
    [sym_array] = STATE(101),
    [sym_object] = STATE(101),
    [sym_record_id_value] = STATE(103),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_explain] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_fetch] = ACTIONS(369),
    [sym_keyword_limit] = ACTIONS(369),
    [sym_keyword_rand] = ACTIONS(369),
    [sym_keyword_collate] = ACTIONS(369),
    [sym_keyword_numeric] = ACTIONS(369),
    [sym_keyword_asc] = ACTIONS(369),
    [sym_keyword_desc] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_RPAREN] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(359),
    [anon_sym_RBRACE] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(361),
    [sym_record_id_ident] = ACTIONS(361),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [141] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(45),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_as] = ACTIONS(369),
    [sym_keyword_where] = ACTIONS(369),
    [sym_keyword_group] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_drop] = ACTIONS(369),
    [sym_keyword_schemafull] = ACTIONS(369),
    [sym_keyword_schemaless] = ACTIONS(369),
    [sym_keyword_changefeed] = ACTIONS(369),
    [sym_keyword_type] = ACTIONS(369),
    [sym_keyword_permissions] = ACTIONS(369),
    [sym_keyword_comment] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_RPAREN] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [142] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(36),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_as] = ACTIONS(212),
    [sym_keyword_where] = ACTIONS(212),
    [sym_keyword_group] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_drop] = ACTIONS(212),
    [sym_keyword_schemafull] = ACTIONS(212),
    [sym_keyword_schemaless] = ACTIONS(212),
    [sym_keyword_changefeed] = ACTIONS(212),
    [sym_keyword_type] = ACTIONS(212),
    [sym_keyword_permissions] = ACTIONS(212),
    [sym_keyword_comment] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [143] = {
    [sym_filter] = STATE(64),
    [sym_path_element] = STATE(143),
    [sym_graph_path] = STATE(64),
    [sym_subscript] = STATE(64),
    [aux_sym_path_repeat1] = STATE(143),
    [ts_builtin_sym_end] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(75),
    [sym_keyword_return] = ACTIONS(75),
    [sym_keyword_parallel] = ACTIONS(75),
    [sym_keyword_timeout] = ACTIONS(75),
    [sym_keyword_where] = ACTIONS(75),
    [sym_keyword_and] = ACTIONS(75),
    [sym_keyword_or] = ACTIONS(75),
    [sym_keyword_is] = ACTIONS(75),
    [sym_keyword_not] = ACTIONS(77),
    [sym_keyword_contains] = ACTIONS(75),
    [sym_keyword_contains_not] = ACTIONS(75),
    [sym_keyword_contains_all] = ACTIONS(75),
    [sym_keyword_contains_any] = ACTIONS(75),
    [sym_keyword_contains_none] = ACTIONS(75),
    [sym_keyword_inside] = ACTIONS(75),
    [sym_keyword_in] = ACTIONS(77),
    [sym_keyword_not_inside] = ACTIONS(75),
    [sym_keyword_all_inside] = ACTIONS(75),
    [sym_keyword_any_inside] = ACTIONS(75),
    [sym_keyword_none_inside] = ACTIONS(75),
    [sym_keyword_outside] = ACTIONS(75),
    [sym_keyword_intersects] = ACTIONS(75),
    [sym_keyword_content] = ACTIONS(75),
    [sym_keyword_merge] = ACTIONS(75),
    [sym_keyword_patch] = ACTIONS(75),
    [sym_keyword_permissions] = ACTIONS(75),
    [sym_keyword_comment] = ACTIONS(75),
    [sym_keyword_set] = ACTIONS(75),
    [sym_keyword_unset] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(75),
    [anon_sym_DASH_GT] = ACTIONS(377),
    [anon_sym_LBRACK] = ACTIONS(266),
    [anon_sym_LT_DASH] = ACTIONS(380),
    [anon_sym_LT_DASH_GT] = ACTIONS(377),
    [anon_sym_STAR] = ACTIONS(77),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LT] = ACTIONS(77),
    [anon_sym_GT] = ACTIONS(77),
    [anon_sym_EQ] = ACTIONS(77),
    [anon_sym_DASH] = ACTIONS(77),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LT_PIPE] = ACTIONS(75),
    [anon_sym_AMP_AMP] = ACTIONS(75),
    [anon_sym_PIPE_PIPE] = ACTIONS(75),
    [anon_sym_QMARK_QMARK] = ACTIONS(75),
    [anon_sym_QMARK_COLON] = ACTIONS(75),
    [anon_sym_BANG_EQ] = ACTIONS(75),
    [anon_sym_EQ_EQ] = ACTIONS(75),
    [anon_sym_QMARK_EQ] = ACTIONS(75),
    [anon_sym_STAR_EQ] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_BANG_TILDE] = ACTIONS(75),
    [anon_sym_STAR_TILDE] = ACTIONS(75),
    [anon_sym_LT_EQ] = ACTIONS(75),
    [anon_sym_GT_EQ] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(77),
    [anon_sym_PLUS_EQ] = ACTIONS(75),
    [anon_sym_DASH_EQ] = ACTIONS(75),
    [anon_sym_u00d7] = ACTIONS(75),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_u00f7] = ACTIONS(75),
    [anon_sym_STAR_STAR] = ACTIONS(75),
    [anon_sym_u220b] = ACTIONS(75),
    [anon_sym_u220c] = ACTIONS(75),
    [anon_sym_u2287] = ACTIONS(75),
    [anon_sym_u2283] = ACTIONS(75),
    [anon_sym_u2285] = ACTIONS(75),
    [anon_sym_u2208] = ACTIONS(75),
    [anon_sym_u2209] = ACTIONS(75),
    [anon_sym_u2286] = ACTIONS(75),
    [anon_sym_u2282] = ACTIONS(75),
    [anon_sym_u2284] = ACTIONS(75),
    [anon_sym_AT_AT] = ACTIONS(75),
  },
  [144] = {
    [sym_filter] = STATE(266),
    [sym_path_element] = STATE(144),
    [sym_graph_path] = STATE(266),
    [sym_subscript] = STATE(266),
    [aux_sym_path_repeat1] = STATE(144),
    [ts_builtin_sym_end] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(75),
    [sym_keyword_as] = ACTIONS(75),
    [sym_keyword_where] = ACTIONS(75),
    [sym_keyword_group] = ACTIONS(75),
    [sym_keyword_and] = ACTIONS(75),
    [sym_keyword_or] = ACTIONS(75),
    [sym_keyword_is] = ACTIONS(75),
    [sym_keyword_not] = ACTIONS(77),
    [sym_keyword_contains] = ACTIONS(75),
    [sym_keyword_contains_not] = ACTIONS(75),
    [sym_keyword_contains_all] = ACTIONS(75),
    [sym_keyword_contains_any] = ACTIONS(75),
    [sym_keyword_contains_none] = ACTIONS(75),
    [sym_keyword_inside] = ACTIONS(75),
    [sym_keyword_in] = ACTIONS(77),
    [sym_keyword_not_inside] = ACTIONS(75),
    [sym_keyword_all_inside] = ACTIONS(75),
    [sym_keyword_any_inside] = ACTIONS(75),
    [sym_keyword_none_inside] = ACTIONS(75),
    [sym_keyword_outside] = ACTIONS(75),
    [sym_keyword_intersects] = ACTIONS(75),
    [sym_keyword_drop] = ACTIONS(75),
    [sym_keyword_schemafull] = ACTIONS(75),
    [sym_keyword_schemaless] = ACTIONS(75),
    [sym_keyword_changefeed] = ACTIONS(75),
    [sym_keyword_type] = ACTIONS(75),
    [sym_keyword_permissions] = ACTIONS(75),
    [sym_keyword_for] = ACTIONS(75),
    [sym_keyword_comment] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(75),
    [anon_sym_DASH_GT] = ACTIONS(386),
    [anon_sym_LBRACK] = ACTIONS(389),
    [anon_sym_LT_DASH] = ACTIONS(392),
    [anon_sym_LT_DASH_GT] = ACTIONS(386),
    [anon_sym_STAR] = ACTIONS(77),
    [anon_sym_DOT] = ACTIONS(395),
    [anon_sym_LT] = ACTIONS(77),
    [anon_sym_GT] = ACTIONS(77),
    [anon_sym_EQ] = ACTIONS(77),
    [anon_sym_DASH] = ACTIONS(77),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LT_PIPE] = ACTIONS(75),
    [anon_sym_AMP_AMP] = ACTIONS(75),
    [anon_sym_PIPE_PIPE] = ACTIONS(75),
    [anon_sym_QMARK_QMARK] = ACTIONS(75),
    [anon_sym_QMARK_COLON] = ACTIONS(75),
    [anon_sym_BANG_EQ] = ACTIONS(75),
    [anon_sym_EQ_EQ] = ACTIONS(75),
    [anon_sym_QMARK_EQ] = ACTIONS(75),
    [anon_sym_STAR_EQ] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_BANG_TILDE] = ACTIONS(75),
    [anon_sym_STAR_TILDE] = ACTIONS(75),
    [anon_sym_LT_EQ] = ACTIONS(75),
    [anon_sym_GT_EQ] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(77),
    [anon_sym_PLUS_EQ] = ACTIONS(75),
    [anon_sym_DASH_EQ] = ACTIONS(75),
    [anon_sym_u00d7] = ACTIONS(75),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_u00f7] = ACTIONS(75),
    [anon_sym_STAR_STAR] = ACTIONS(75),
    [anon_sym_u220b] = ACTIONS(75),
    [anon_sym_u220c] = ACTIONS(75),
    [anon_sym_u2287] = ACTIONS(75),
    [anon_sym_u2283] = ACTIONS(75),
    [anon_sym_u2285] = ACTIONS(75),
    [anon_sym_u2208] = ACTIONS(75),
    [anon_sym_u2209] = ACTIONS(75),
    [anon_sym_u2286] = ACTIONS(75),
    [anon_sym_u2282] = ACTIONS(75),
    [anon_sym_u2284] = ACTIONS(75),
    [anon_sym_AT_AT] = ACTIONS(75),
  },
  [145] = {
    [sym_array] = STATE(241),
    [sym_object] = STATE(241),
    [sym_record_id_value] = STATE(286),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_explain] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_fetch] = ACTIONS(369),
    [sym_keyword_limit] = ACTIONS(369),
    [sym_keyword_order] = ACTIONS(369),
    [sym_keyword_where] = ACTIONS(369),
    [sym_keyword_split] = ACTIONS(369),
    [sym_keyword_group] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_RPAREN] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(363),
    [anon_sym_RBRACE] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(365),
    [sym_record_id_ident] = ACTIONS(365),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [146] = {
    [sym_array] = STATE(226),
    [sym_object] = STATE(226),
    [sym_record_id_value] = STATE(259),
    [ts_builtin_sym_end] = ACTIONS(367),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_as] = ACTIONS(369),
    [sym_keyword_where] = ACTIONS(369),
    [sym_keyword_group] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_drop] = ACTIONS(369),
    [sym_keyword_schemafull] = ACTIONS(369),
    [sym_keyword_schemaless] = ACTIONS(369),
    [sym_keyword_changefeed] = ACTIONS(369),
    [sym_keyword_type] = ACTIONS(369),
    [sym_keyword_permissions] = ACTIONS(369),
    [sym_keyword_comment] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(398),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(400),
    [sym_record_id_ident] = ACTIONS(400),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [147] = {
    [sym_array] = STATE(241),
    [sym_object] = STATE(241),
    [sym_record_id_value] = STATE(278),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_explain] = ACTIONS(180),
    [sym_keyword_parallel] = ACTIONS(180),
    [sym_keyword_timeout] = ACTIONS(180),
    [sym_keyword_fetch] = ACTIONS(180),
    [sym_keyword_limit] = ACTIONS(180),
    [sym_keyword_order] = ACTIONS(180),
    [sym_keyword_where] = ACTIONS(180),
    [sym_keyword_split] = ACTIONS(180),
    [sym_keyword_group] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(363),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(365),
    [sym_record_id_ident] = ACTIONS(365),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [148] = {
    [sym_array] = STATE(226),
    [sym_object] = STATE(226),
    [sym_record_id_value] = STATE(254),
    [ts_builtin_sym_end] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_as] = ACTIONS(180),
    [sym_keyword_where] = ACTIONS(180),
    [sym_keyword_group] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [sym_keyword_drop] = ACTIONS(180),
    [sym_keyword_schemafull] = ACTIONS(180),
    [sym_keyword_schemaless] = ACTIONS(180),
    [sym_keyword_changefeed] = ACTIONS(180),
    [sym_keyword_type] = ACTIONS(180),
    [sym_keyword_permissions] = ACTIONS(180),
    [sym_keyword_comment] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(398),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(400),
    [sym_record_id_ident] = ACTIONS(400),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [149] = {
    [sym_filter] = STATE(64),
    [sym_path_element] = STATE(143),
    [sym_graph_path] = STATE(64),
    [sym_subscript] = STATE(64),
    [aux_sym_path_repeat1] = STATE(143),
    [ts_builtin_sym_end] = ACTIONS(91),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(91),
    [sym_keyword_return] = ACTIONS(91),
    [sym_keyword_parallel] = ACTIONS(91),
    [sym_keyword_timeout] = ACTIONS(91),
    [sym_keyword_where] = ACTIONS(91),
    [sym_keyword_and] = ACTIONS(91),
    [sym_keyword_or] = ACTIONS(91),
    [sym_keyword_is] = ACTIONS(91),
    [sym_keyword_not] = ACTIONS(93),
    [sym_keyword_contains] = ACTIONS(91),
    [sym_keyword_contains_not] = ACTIONS(91),
    [sym_keyword_contains_all] = ACTIONS(91),
    [sym_keyword_contains_any] = ACTIONS(91),
    [sym_keyword_contains_none] = ACTIONS(91),
    [sym_keyword_inside] = ACTIONS(91),
    [sym_keyword_in] = ACTIONS(93),
    [sym_keyword_not_inside] = ACTIONS(91),
    [sym_keyword_all_inside] = ACTIONS(91),
    [sym_keyword_any_inside] = ACTIONS(91),
    [sym_keyword_none_inside] = ACTIONS(91),
    [sym_keyword_outside] = ACTIONS(91),
    [sym_keyword_intersects] = ACTIONS(91),
    [sym_keyword_content] = ACTIONS(91),
    [sym_keyword_merge] = ACTIONS(91),
    [sym_keyword_patch] = ACTIONS(91),
    [sym_keyword_permissions] = ACTIONS(91),
    [sym_keyword_comment] = ACTIONS(91),
    [sym_keyword_set] = ACTIONS(91),
    [sym_keyword_unset] = ACTIONS(91),
    [anon_sym_COMMA] = ACTIONS(91),
    [anon_sym_DASH_GT] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(245),
    [anon_sym_LT_DASH] = ACTIONS(43),
    [anon_sym_LT_DASH_GT] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(93),
    [anon_sym_DOT] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(93),
    [anon_sym_GT] = ACTIONS(93),
    [anon_sym_EQ] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(93),
    [anon_sym_AT] = ACTIONS(93),
    [anon_sym_LT_PIPE] = ACTIONS(91),
    [anon_sym_AMP_AMP] = ACTIONS(91),
    [anon_sym_PIPE_PIPE] = ACTIONS(91),
    [anon_sym_QMARK_QMARK] = ACTIONS(91),
    [anon_sym_QMARK_COLON] = ACTIONS(91),
    [anon_sym_BANG_EQ] = ACTIONS(91),
    [anon_sym_EQ_EQ] = ACTIONS(91),
    [anon_sym_QMARK_EQ] = ACTIONS(91),
    [anon_sym_STAR_EQ] = ACTIONS(91),
    [anon_sym_TILDE] = ACTIONS(91),
    [anon_sym_BANG_TILDE] = ACTIONS(91),
    [anon_sym_STAR_TILDE] = ACTIONS(91),
    [anon_sym_LT_EQ] = ACTIONS(91),
    [anon_sym_GT_EQ] = ACTIONS(91),
    [anon_sym_PLUS] = ACTIONS(93),
    [anon_sym_PLUS_EQ] = ACTIONS(91),
    [anon_sym_DASH_EQ] = ACTIONS(91),
    [anon_sym_u00d7] = ACTIONS(91),
    [anon_sym_SLASH] = ACTIONS(93),
    [anon_sym_u00f7] = ACTIONS(91),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_u220b] = ACTIONS(91),
    [anon_sym_u220c] = ACTIONS(91),
    [anon_sym_u2287] = ACTIONS(91),
    [anon_sym_u2283] = ACTIONS(91),
    [anon_sym_u2285] = ACTIONS(91),
    [anon_sym_u2208] = ACTIONS(91),
    [anon_sym_u2209] = ACTIONS(91),
    [anon_sym_u2286] = ACTIONS(91),
    [anon_sym_u2282] = ACTIONS(91),
    [anon_sym_u2284] = ACTIONS(91),
    [anon_sym_AT_AT] = ACTIONS(91),
  },
  [150] = {
    [sym_filter] = STATE(295),
    [sym_path_element] = STATE(150),
    [sym_graph_path] = STATE(295),
    [sym_subscript] = STATE(295),
    [aux_sym_path_repeat1] = STATE(150),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(75),
    [sym_keyword_explain] = ACTIONS(75),
    [sym_keyword_parallel] = ACTIONS(75),
    [sym_keyword_timeout] = ACTIONS(75),
    [sym_keyword_fetch] = ACTIONS(75),
    [sym_keyword_limit] = ACTIONS(75),
    [sym_keyword_order] = ACTIONS(75),
    [sym_keyword_with] = ACTIONS(75),
    [sym_keyword_where] = ACTIONS(75),
    [sym_keyword_split] = ACTIONS(75),
    [sym_keyword_group] = ACTIONS(75),
    [sym_keyword_and] = ACTIONS(75),
    [sym_keyword_or] = ACTIONS(77),
    [sym_keyword_is] = ACTIONS(75),
    [sym_keyword_not] = ACTIONS(77),
    [sym_keyword_contains] = ACTIONS(75),
    [sym_keyword_contains_not] = ACTIONS(75),
    [sym_keyword_contains_all] = ACTIONS(75),
    [sym_keyword_contains_any] = ACTIONS(75),
    [sym_keyword_contains_none] = ACTIONS(75),
    [sym_keyword_inside] = ACTIONS(75),
    [sym_keyword_in] = ACTIONS(77),
    [sym_keyword_not_inside] = ACTIONS(75),
    [sym_keyword_all_inside] = ACTIONS(75),
    [sym_keyword_any_inside] = ACTIONS(75),
    [sym_keyword_none_inside] = ACTIONS(75),
    [sym_keyword_outside] = ACTIONS(75),
    [sym_keyword_intersects] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(75),
    [anon_sym_DASH_GT] = ACTIONS(404),
    [anon_sym_LBRACK] = ACTIONS(407),
    [anon_sym_RPAREN] = ACTIONS(75),
    [anon_sym_RBRACE] = ACTIONS(75),
    [anon_sym_LT_DASH] = ACTIONS(410),
    [anon_sym_LT_DASH_GT] = ACTIONS(404),
    [anon_sym_STAR] = ACTIONS(77),
    [anon_sym_DOT] = ACTIONS(413),
    [anon_sym_LT] = ACTIONS(77),
    [anon_sym_GT] = ACTIONS(77),
    [anon_sym_EQ] = ACTIONS(77),
    [anon_sym_DASH] = ACTIONS(77),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LT_PIPE] = ACTIONS(75),
    [anon_sym_AMP_AMP] = ACTIONS(75),
    [anon_sym_PIPE_PIPE] = ACTIONS(75),
    [anon_sym_QMARK_QMARK] = ACTIONS(75),
    [anon_sym_QMARK_COLON] = ACTIONS(75),
    [anon_sym_BANG_EQ] = ACTIONS(75),
    [anon_sym_EQ_EQ] = ACTIONS(75),
    [anon_sym_QMARK_EQ] = ACTIONS(75),
    [anon_sym_STAR_EQ] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_BANG_TILDE] = ACTIONS(75),
    [anon_sym_STAR_TILDE] = ACTIONS(75),
    [anon_sym_LT_EQ] = ACTIONS(75),
    [anon_sym_GT_EQ] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(77),
    [anon_sym_PLUS_EQ] = ACTIONS(75),
    [anon_sym_DASH_EQ] = ACTIONS(75),
    [anon_sym_u00d7] = ACTIONS(75),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_u00f7] = ACTIONS(75),
    [anon_sym_STAR_STAR] = ACTIONS(75),
    [anon_sym_u220b] = ACTIONS(75),
    [anon_sym_u220c] = ACTIONS(75),
    [anon_sym_u2287] = ACTIONS(75),
    [anon_sym_u2283] = ACTIONS(75),
    [anon_sym_u2285] = ACTIONS(75),
    [anon_sym_u2208] = ACTIONS(75),
    [anon_sym_u2209] = ACTIONS(75),
    [anon_sym_u2286] = ACTIONS(75),
    [anon_sym_u2282] = ACTIONS(75),
    [anon_sym_u2284] = ACTIONS(75),
    [anon_sym_AT_AT] = ACTIONS(75),
  },
  [151] = {
    [sym_array] = STATE(241),
    [sym_object] = STATE(241),
    [sym_record_id_value] = STATE(283),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_explain] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_fetch] = ACTIONS(212),
    [sym_keyword_limit] = ACTIONS(212),
    [sym_keyword_order] = ACTIONS(212),
    [sym_keyword_where] = ACTIONS(212),
    [sym_keyword_split] = ACTIONS(212),
    [sym_keyword_group] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(363),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(365),
    [sym_record_id_ident] = ACTIONS(365),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [152] = {
    [sym_filter] = STATE(295),
    [sym_path_element] = STATE(150),
    [sym_graph_path] = STATE(295),
    [sym_subscript] = STATE(295),
    [aux_sym_path_repeat1] = STATE(150),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(91),
    [sym_keyword_explain] = ACTIONS(91),
    [sym_keyword_parallel] = ACTIONS(91),
    [sym_keyword_timeout] = ACTIONS(91),
    [sym_keyword_fetch] = ACTIONS(91),
    [sym_keyword_limit] = ACTIONS(91),
    [sym_keyword_order] = ACTIONS(91),
    [sym_keyword_with] = ACTIONS(91),
    [sym_keyword_where] = ACTIONS(91),
    [sym_keyword_split] = ACTIONS(91),
    [sym_keyword_group] = ACTIONS(91),
    [sym_keyword_and] = ACTIONS(91),
    [sym_keyword_or] = ACTIONS(93),
    [sym_keyword_is] = ACTIONS(91),
    [sym_keyword_not] = ACTIONS(93),
    [sym_keyword_contains] = ACTIONS(91),
    [sym_keyword_contains_not] = ACTIONS(91),
    [sym_keyword_contains_all] = ACTIONS(91),
    [sym_keyword_contains_any] = ACTIONS(91),
    [sym_keyword_contains_none] = ACTIONS(91),
    [sym_keyword_inside] = ACTIONS(91),
    [sym_keyword_in] = ACTIONS(93),
    [sym_keyword_not_inside] = ACTIONS(91),
    [sym_keyword_all_inside] = ACTIONS(91),
    [sym_keyword_any_inside] = ACTIONS(91),
    [sym_keyword_none_inside] = ACTIONS(91),
    [sym_keyword_outside] = ACTIONS(91),
    [sym_keyword_intersects] = ACTIONS(91),
    [anon_sym_COMMA] = ACTIONS(91),
    [anon_sym_DASH_GT] = ACTIONS(416),
    [anon_sym_LBRACK] = ACTIONS(418),
    [anon_sym_RPAREN] = ACTIONS(91),
    [anon_sym_RBRACE] = ACTIONS(91),
    [anon_sym_LT_DASH] = ACTIONS(420),
    [anon_sym_LT_DASH_GT] = ACTIONS(416),
    [anon_sym_STAR] = ACTIONS(93),
    [anon_sym_DOT] = ACTIONS(422),
    [anon_sym_LT] = ACTIONS(93),
    [anon_sym_GT] = ACTIONS(93),
    [anon_sym_EQ] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(93),
    [anon_sym_AT] = ACTIONS(93),
    [anon_sym_LT_PIPE] = ACTIONS(91),
    [anon_sym_AMP_AMP] = ACTIONS(91),
    [anon_sym_PIPE_PIPE] = ACTIONS(91),
    [anon_sym_QMARK_QMARK] = ACTIONS(91),
    [anon_sym_QMARK_COLON] = ACTIONS(91),
    [anon_sym_BANG_EQ] = ACTIONS(91),
    [anon_sym_EQ_EQ] = ACTIONS(91),
    [anon_sym_QMARK_EQ] = ACTIONS(91),
    [anon_sym_STAR_EQ] = ACTIONS(91),
    [anon_sym_TILDE] = ACTIONS(91),
    [anon_sym_BANG_TILDE] = ACTIONS(91),
    [anon_sym_STAR_TILDE] = ACTIONS(91),
    [anon_sym_LT_EQ] = ACTIONS(91),
    [anon_sym_GT_EQ] = ACTIONS(91),
    [anon_sym_PLUS] = ACTIONS(93),
    [anon_sym_PLUS_EQ] = ACTIONS(91),
    [anon_sym_DASH_EQ] = ACTIONS(91),
    [anon_sym_u00d7] = ACTIONS(91),
    [anon_sym_SLASH] = ACTIONS(93),
    [anon_sym_u00f7] = ACTIONS(91),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_u220b] = ACTIONS(91),
    [anon_sym_u220c] = ACTIONS(91),
    [anon_sym_u2287] = ACTIONS(91),
    [anon_sym_u2283] = ACTIONS(91),
    [anon_sym_u2285] = ACTIONS(91),
    [anon_sym_u2208] = ACTIONS(91),
    [anon_sym_u2209] = ACTIONS(91),
    [anon_sym_u2286] = ACTIONS(91),
    [anon_sym_u2282] = ACTIONS(91),
    [anon_sym_u2284] = ACTIONS(91),
    [anon_sym_AT_AT] = ACTIONS(91),
  },
  [153] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(45),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_return] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_where] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_content] = ACTIONS(369),
    [sym_keyword_merge] = ACTIONS(369),
    [sym_keyword_patch] = ACTIONS(369),
    [sym_keyword_set] = ACTIONS(369),
    [sym_keyword_unset] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_RPAREN] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [154] = {
    [sym_where_clause] = STATE(1156),
    [sym_timeout_clause] = STATE(1200),
    [sym_parallel_clause] = STATE(1312),
    [sym_content_clause] = STATE(1002),
    [sym_set_clause] = STATE(1002),
    [sym_unset_clause] = STATE(1002),
    [sym_return_clause] = STATE(1151),
    [sym_merge_clause] = STATE(1002),
    [sym_patch_clause] = STATE(1002),
    [sym_operator] = STATE(752),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(772),
    [ts_builtin_sym_end] = ACTIONS(341),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(341),
    [sym_keyword_return] = ACTIONS(424),
    [sym_keyword_parallel] = ACTIONS(293),
    [sym_keyword_timeout] = ACTIONS(295),
    [sym_keyword_where] = ACTIONS(426),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_content] = ACTIONS(347),
    [sym_keyword_merge] = ACTIONS(349),
    [sym_keyword_patch] = ACTIONS(351),
    [sym_keyword_set] = ACTIONS(428),
    [sym_keyword_unset] = ACTIONS(430),
    [anon_sym_COMMA] = ACTIONS(432),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [155] = {
    [sym_filter] = STATE(295),
    [sym_path_element] = STATE(152),
    [sym_graph_path] = STATE(295),
    [sym_subscript] = STATE(295),
    [aux_sym_path_repeat1] = STATE(152),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(71),
    [sym_keyword_explain] = ACTIONS(71),
    [sym_keyword_parallel] = ACTIONS(71),
    [sym_keyword_timeout] = ACTIONS(71),
    [sym_keyword_fetch] = ACTIONS(71),
    [sym_keyword_limit] = ACTIONS(71),
    [sym_keyword_order] = ACTIONS(71),
    [sym_keyword_with] = ACTIONS(71),
    [sym_keyword_where] = ACTIONS(71),
    [sym_keyword_split] = ACTIONS(71),
    [sym_keyword_group] = ACTIONS(71),
    [sym_keyword_and] = ACTIONS(71),
    [sym_keyword_or] = ACTIONS(73),
    [sym_keyword_is] = ACTIONS(71),
    [sym_keyword_not] = ACTIONS(73),
    [sym_keyword_contains] = ACTIONS(71),
    [sym_keyword_contains_not] = ACTIONS(71),
    [sym_keyword_contains_all] = ACTIONS(71),
    [sym_keyword_contains_any] = ACTIONS(71),
    [sym_keyword_contains_none] = ACTIONS(71),
    [sym_keyword_inside] = ACTIONS(71),
    [sym_keyword_in] = ACTIONS(73),
    [sym_keyword_not_inside] = ACTIONS(71),
    [sym_keyword_all_inside] = ACTIONS(71),
    [sym_keyword_any_inside] = ACTIONS(71),
    [sym_keyword_none_inside] = ACTIONS(71),
    [sym_keyword_outside] = ACTIONS(71),
    [sym_keyword_intersects] = ACTIONS(71),
    [anon_sym_COMMA] = ACTIONS(71),
    [anon_sym_DASH_GT] = ACTIONS(416),
    [anon_sym_LBRACK] = ACTIONS(418),
    [anon_sym_RPAREN] = ACTIONS(71),
    [anon_sym_RBRACE] = ACTIONS(71),
    [anon_sym_LT_DASH] = ACTIONS(420),
    [anon_sym_LT_DASH_GT] = ACTIONS(416),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_DOT] = ACTIONS(422),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(73),
    [anon_sym_LT_PIPE] = ACTIONS(71),
    [anon_sym_AMP_AMP] = ACTIONS(71),
    [anon_sym_PIPE_PIPE] = ACTIONS(71),
    [anon_sym_QMARK_QMARK] = ACTIONS(71),
    [anon_sym_QMARK_COLON] = ACTIONS(71),
    [anon_sym_BANG_EQ] = ACTIONS(71),
    [anon_sym_EQ_EQ] = ACTIONS(71),
    [anon_sym_QMARK_EQ] = ACTIONS(71),
    [anon_sym_STAR_EQ] = ACTIONS(71),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_BANG_TILDE] = ACTIONS(71),
    [anon_sym_STAR_TILDE] = ACTIONS(71),
    [anon_sym_LT_EQ] = ACTIONS(71),
    [anon_sym_GT_EQ] = ACTIONS(71),
    [anon_sym_PLUS] = ACTIONS(73),
    [anon_sym_PLUS_EQ] = ACTIONS(71),
    [anon_sym_DASH_EQ] = ACTIONS(71),
    [anon_sym_u00d7] = ACTIONS(71),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_u00f7] = ACTIONS(71),
    [anon_sym_STAR_STAR] = ACTIONS(71),
    [anon_sym_u220b] = ACTIONS(71),
    [anon_sym_u220c] = ACTIONS(71),
    [anon_sym_u2287] = ACTIONS(71),
    [anon_sym_u2283] = ACTIONS(71),
    [anon_sym_u2285] = ACTIONS(71),
    [anon_sym_u2208] = ACTIONS(71),
    [anon_sym_u2209] = ACTIONS(71),
    [anon_sym_u2286] = ACTIONS(71),
    [anon_sym_u2282] = ACTIONS(71),
    [anon_sym_u2284] = ACTIONS(71),
    [anon_sym_AT_AT] = ACTIONS(71),
  },
  [156] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(36),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_return] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_where] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_content] = ACTIONS(212),
    [sym_keyword_merge] = ACTIONS(212),
    [sym_keyword_patch] = ACTIONS(212),
    [sym_keyword_set] = ACTIONS(212),
    [sym_keyword_unset] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [157] = {
    [sym_filter] = STATE(295),
    [sym_path_element] = STATE(152),
    [sym_graph_path] = STATE(295),
    [sym_subscript] = STATE(295),
    [aux_sym_path_repeat1] = STATE(152),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(59),
    [sym_keyword_explain] = ACTIONS(59),
    [sym_keyword_parallel] = ACTIONS(59),
    [sym_keyword_timeout] = ACTIONS(59),
    [sym_keyword_fetch] = ACTIONS(59),
    [sym_keyword_limit] = ACTIONS(59),
    [sym_keyword_order] = ACTIONS(59),
    [sym_keyword_with] = ACTIONS(59),
    [sym_keyword_where] = ACTIONS(59),
    [sym_keyword_split] = ACTIONS(59),
    [sym_keyword_group] = ACTIONS(59),
    [sym_keyword_and] = ACTIONS(59),
    [sym_keyword_or] = ACTIONS(61),
    [sym_keyword_is] = ACTIONS(59),
    [sym_keyword_not] = ACTIONS(61),
    [sym_keyword_contains] = ACTIONS(59),
    [sym_keyword_contains_not] = ACTIONS(59),
    [sym_keyword_contains_all] = ACTIONS(59),
    [sym_keyword_contains_any] = ACTIONS(59),
    [sym_keyword_contains_none] = ACTIONS(59),
    [sym_keyword_inside] = ACTIONS(59),
    [sym_keyword_in] = ACTIONS(61),
    [sym_keyword_not_inside] = ACTIONS(59),
    [sym_keyword_all_inside] = ACTIONS(59),
    [sym_keyword_any_inside] = ACTIONS(59),
    [sym_keyword_none_inside] = ACTIONS(59),
    [sym_keyword_outside] = ACTIONS(59),
    [sym_keyword_intersects] = ACTIONS(59),
    [anon_sym_COMMA] = ACTIONS(59),
    [anon_sym_DASH_GT] = ACTIONS(416),
    [anon_sym_LBRACK] = ACTIONS(418),
    [anon_sym_RPAREN] = ACTIONS(59),
    [anon_sym_RBRACE] = ACTIONS(59),
    [anon_sym_LT_DASH] = ACTIONS(420),
    [anon_sym_LT_DASH_GT] = ACTIONS(416),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_DOT] = ACTIONS(422),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(61),
    [anon_sym_LT_PIPE] = ACTIONS(59),
    [anon_sym_AMP_AMP] = ACTIONS(59),
    [anon_sym_PIPE_PIPE] = ACTIONS(59),
    [anon_sym_QMARK_QMARK] = ACTIONS(59),
    [anon_sym_QMARK_COLON] = ACTIONS(59),
    [anon_sym_BANG_EQ] = ACTIONS(59),
    [anon_sym_EQ_EQ] = ACTIONS(59),
    [anon_sym_QMARK_EQ] = ACTIONS(59),
    [anon_sym_STAR_EQ] = ACTIONS(59),
    [anon_sym_TILDE] = ACTIONS(59),
    [anon_sym_BANG_TILDE] = ACTIONS(59),
    [anon_sym_STAR_TILDE] = ACTIONS(59),
    [anon_sym_LT_EQ] = ACTIONS(59),
    [anon_sym_GT_EQ] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_PLUS_EQ] = ACTIONS(59),
    [anon_sym_DASH_EQ] = ACTIONS(59),
    [anon_sym_u00d7] = ACTIONS(59),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_u00f7] = ACTIONS(59),
    [anon_sym_STAR_STAR] = ACTIONS(59),
    [anon_sym_u220b] = ACTIONS(59),
    [anon_sym_u220c] = ACTIONS(59),
    [anon_sym_u2287] = ACTIONS(59),
    [anon_sym_u2283] = ACTIONS(59),
    [anon_sym_u2285] = ACTIONS(59),
    [anon_sym_u2208] = ACTIONS(59),
    [anon_sym_u2209] = ACTIONS(59),
    [anon_sym_u2286] = ACTIONS(59),
    [anon_sym_u2282] = ACTIONS(59),
    [anon_sym_u2284] = ACTIONS(59),
    [anon_sym_AT_AT] = ACTIONS(59),
  },
  [158] = {
    [sym_filter] = STATE(266),
    [sym_path_element] = STATE(160),
    [sym_graph_path] = STATE(266),
    [sym_subscript] = STATE(266),
    [aux_sym_path_repeat1] = STATE(160),
    [ts_builtin_sym_end] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(71),
    [sym_keyword_as] = ACTIONS(71),
    [sym_keyword_where] = ACTIONS(71),
    [sym_keyword_group] = ACTIONS(71),
    [sym_keyword_and] = ACTIONS(71),
    [sym_keyword_or] = ACTIONS(71),
    [sym_keyword_is] = ACTIONS(71),
    [sym_keyword_not] = ACTIONS(73),
    [sym_keyword_contains] = ACTIONS(71),
    [sym_keyword_contains_not] = ACTIONS(71),
    [sym_keyword_contains_all] = ACTIONS(71),
    [sym_keyword_contains_any] = ACTIONS(71),
    [sym_keyword_contains_none] = ACTIONS(71),
    [sym_keyword_inside] = ACTIONS(71),
    [sym_keyword_in] = ACTIONS(73),
    [sym_keyword_not_inside] = ACTIONS(71),
    [sym_keyword_all_inside] = ACTIONS(71),
    [sym_keyword_any_inside] = ACTIONS(71),
    [sym_keyword_none_inside] = ACTIONS(71),
    [sym_keyword_outside] = ACTIONS(71),
    [sym_keyword_intersects] = ACTIONS(71),
    [sym_keyword_drop] = ACTIONS(71),
    [sym_keyword_schemafull] = ACTIONS(71),
    [sym_keyword_schemaless] = ACTIONS(71),
    [sym_keyword_changefeed] = ACTIONS(71),
    [sym_keyword_type] = ACTIONS(71),
    [sym_keyword_permissions] = ACTIONS(71),
    [sym_keyword_for] = ACTIONS(71),
    [sym_keyword_comment] = ACTIONS(71),
    [anon_sym_COMMA] = ACTIONS(71),
    [anon_sym_DASH_GT] = ACTIONS(434),
    [anon_sym_LBRACK] = ACTIONS(436),
    [anon_sym_LT_DASH] = ACTIONS(438),
    [anon_sym_LT_DASH_GT] = ACTIONS(434),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_DOT] = ACTIONS(440),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(73),
    [anon_sym_LT_PIPE] = ACTIONS(71),
    [anon_sym_AMP_AMP] = ACTIONS(71),
    [anon_sym_PIPE_PIPE] = ACTIONS(71),
    [anon_sym_QMARK_QMARK] = ACTIONS(71),
    [anon_sym_QMARK_COLON] = ACTIONS(71),
    [anon_sym_BANG_EQ] = ACTIONS(71),
    [anon_sym_EQ_EQ] = ACTIONS(71),
    [anon_sym_QMARK_EQ] = ACTIONS(71),
    [anon_sym_STAR_EQ] = ACTIONS(71),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_BANG_TILDE] = ACTIONS(71),
    [anon_sym_STAR_TILDE] = ACTIONS(71),
    [anon_sym_LT_EQ] = ACTIONS(71),
    [anon_sym_GT_EQ] = ACTIONS(71),
    [anon_sym_PLUS] = ACTIONS(73),
    [anon_sym_PLUS_EQ] = ACTIONS(71),
    [anon_sym_DASH_EQ] = ACTIONS(71),
    [anon_sym_u00d7] = ACTIONS(71),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_u00f7] = ACTIONS(71),
    [anon_sym_STAR_STAR] = ACTIONS(71),
    [anon_sym_u220b] = ACTIONS(71),
    [anon_sym_u220c] = ACTIONS(71),
    [anon_sym_u2287] = ACTIONS(71),
    [anon_sym_u2283] = ACTIONS(71),
    [anon_sym_u2285] = ACTIONS(71),
    [anon_sym_u2208] = ACTIONS(71),
    [anon_sym_u2209] = ACTIONS(71),
    [anon_sym_u2286] = ACTIONS(71),
    [anon_sym_u2282] = ACTIONS(71),
    [anon_sym_u2284] = ACTIONS(71),
    [anon_sym_AT_AT] = ACTIONS(71),
  },
  [159] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(33),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_return] = ACTIONS(180),
    [sym_keyword_parallel] = ACTIONS(180),
    [sym_keyword_timeout] = ACTIONS(180),
    [sym_keyword_where] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [sym_keyword_content] = ACTIONS(180),
    [sym_keyword_merge] = ACTIONS(180),
    [sym_keyword_patch] = ACTIONS(180),
    [sym_keyword_set] = ACTIONS(180),
    [sym_keyword_unset] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [160] = {
    [sym_filter] = STATE(266),
    [sym_path_element] = STATE(144),
    [sym_graph_path] = STATE(266),
    [sym_subscript] = STATE(266),
    [aux_sym_path_repeat1] = STATE(144),
    [ts_builtin_sym_end] = ACTIONS(91),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(91),
    [sym_keyword_as] = ACTIONS(91),
    [sym_keyword_where] = ACTIONS(91),
    [sym_keyword_group] = ACTIONS(91),
    [sym_keyword_and] = ACTIONS(91),
    [sym_keyword_or] = ACTIONS(91),
    [sym_keyword_is] = ACTIONS(91),
    [sym_keyword_not] = ACTIONS(93),
    [sym_keyword_contains] = ACTIONS(91),
    [sym_keyword_contains_not] = ACTIONS(91),
    [sym_keyword_contains_all] = ACTIONS(91),
    [sym_keyword_contains_any] = ACTIONS(91),
    [sym_keyword_contains_none] = ACTIONS(91),
    [sym_keyword_inside] = ACTIONS(91),
    [sym_keyword_in] = ACTIONS(93),
    [sym_keyword_not_inside] = ACTIONS(91),
    [sym_keyword_all_inside] = ACTIONS(91),
    [sym_keyword_any_inside] = ACTIONS(91),
    [sym_keyword_none_inside] = ACTIONS(91),
    [sym_keyword_outside] = ACTIONS(91),
    [sym_keyword_intersects] = ACTIONS(91),
    [sym_keyword_drop] = ACTIONS(91),
    [sym_keyword_schemafull] = ACTIONS(91),
    [sym_keyword_schemaless] = ACTIONS(91),
    [sym_keyword_changefeed] = ACTIONS(91),
    [sym_keyword_type] = ACTIONS(91),
    [sym_keyword_permissions] = ACTIONS(91),
    [sym_keyword_for] = ACTIONS(91),
    [sym_keyword_comment] = ACTIONS(91),
    [anon_sym_COMMA] = ACTIONS(91),
    [anon_sym_DASH_GT] = ACTIONS(434),
    [anon_sym_LBRACK] = ACTIONS(436),
    [anon_sym_LT_DASH] = ACTIONS(438),
    [anon_sym_LT_DASH_GT] = ACTIONS(434),
    [anon_sym_STAR] = ACTIONS(93),
    [anon_sym_DOT] = ACTIONS(440),
    [anon_sym_LT] = ACTIONS(93),
    [anon_sym_GT] = ACTIONS(93),
    [anon_sym_EQ] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(93),
    [anon_sym_AT] = ACTIONS(93),
    [anon_sym_LT_PIPE] = ACTIONS(91),
    [anon_sym_AMP_AMP] = ACTIONS(91),
    [anon_sym_PIPE_PIPE] = ACTIONS(91),
    [anon_sym_QMARK_QMARK] = ACTIONS(91),
    [anon_sym_QMARK_COLON] = ACTIONS(91),
    [anon_sym_BANG_EQ] = ACTIONS(91),
    [anon_sym_EQ_EQ] = ACTIONS(91),
    [anon_sym_QMARK_EQ] = ACTIONS(91),
    [anon_sym_STAR_EQ] = ACTIONS(91),
    [anon_sym_TILDE] = ACTIONS(91),
    [anon_sym_BANG_TILDE] = ACTIONS(91),
    [anon_sym_STAR_TILDE] = ACTIONS(91),
    [anon_sym_LT_EQ] = ACTIONS(91),
    [anon_sym_GT_EQ] = ACTIONS(91),
    [anon_sym_PLUS] = ACTIONS(93),
    [anon_sym_PLUS_EQ] = ACTIONS(91),
    [anon_sym_DASH_EQ] = ACTIONS(91),
    [anon_sym_u00d7] = ACTIONS(91),
    [anon_sym_SLASH] = ACTIONS(93),
    [anon_sym_u00f7] = ACTIONS(91),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_u220b] = ACTIONS(91),
    [anon_sym_u220c] = ACTIONS(91),
    [anon_sym_u2287] = ACTIONS(91),
    [anon_sym_u2283] = ACTIONS(91),
    [anon_sym_u2285] = ACTIONS(91),
    [anon_sym_u2208] = ACTIONS(91),
    [anon_sym_u2209] = ACTIONS(91),
    [anon_sym_u2286] = ACTIONS(91),
    [anon_sym_u2282] = ACTIONS(91),
    [anon_sym_u2284] = ACTIONS(91),
    [anon_sym_AT_AT] = ACTIONS(91),
  },
  [161] = {
    [sym_array] = STATE(292),
    [sym_object] = STATE(292),
    [sym_record_id_value] = STATE(312),
    [ts_builtin_sym_end] = ACTIONS(367),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_explain] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_fetch] = ACTIONS(369),
    [sym_keyword_limit] = ACTIONS(369),
    [sym_keyword_order] = ACTIONS(369),
    [sym_keyword_with] = ACTIONS(369),
    [sym_keyword_where] = ACTIONS(369),
    [sym_keyword_split] = ACTIONS(369),
    [sym_keyword_group] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(442),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(444),
    [sym_record_id_ident] = ACTIONS(444),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [162] = {
    [sym_filter] = STATE(64),
    [sym_path_element] = STATE(149),
    [sym_graph_path] = STATE(64),
    [sym_subscript] = STATE(64),
    [aux_sym_path_repeat1] = STATE(149),
    [ts_builtin_sym_end] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(71),
    [sym_keyword_return] = ACTIONS(71),
    [sym_keyword_parallel] = ACTIONS(71),
    [sym_keyword_timeout] = ACTIONS(71),
    [sym_keyword_where] = ACTIONS(71),
    [sym_keyword_and] = ACTIONS(71),
    [sym_keyword_or] = ACTIONS(71),
    [sym_keyword_is] = ACTIONS(71),
    [sym_keyword_not] = ACTIONS(73),
    [sym_keyword_contains] = ACTIONS(71),
    [sym_keyword_contains_not] = ACTIONS(71),
    [sym_keyword_contains_all] = ACTIONS(71),
    [sym_keyword_contains_any] = ACTIONS(71),
    [sym_keyword_contains_none] = ACTIONS(71),
    [sym_keyword_inside] = ACTIONS(71),
    [sym_keyword_in] = ACTIONS(73),
    [sym_keyword_not_inside] = ACTIONS(71),
    [sym_keyword_all_inside] = ACTIONS(71),
    [sym_keyword_any_inside] = ACTIONS(71),
    [sym_keyword_none_inside] = ACTIONS(71),
    [sym_keyword_outside] = ACTIONS(71),
    [sym_keyword_intersects] = ACTIONS(71),
    [sym_keyword_content] = ACTIONS(71),
    [sym_keyword_merge] = ACTIONS(71),
    [sym_keyword_patch] = ACTIONS(71),
    [sym_keyword_permissions] = ACTIONS(71),
    [sym_keyword_comment] = ACTIONS(71),
    [sym_keyword_set] = ACTIONS(71),
    [sym_keyword_unset] = ACTIONS(71),
    [anon_sym_COMMA] = ACTIONS(71),
    [anon_sym_DASH_GT] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(245),
    [anon_sym_LT_DASH] = ACTIONS(43),
    [anon_sym_LT_DASH_GT] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_DOT] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(73),
    [anon_sym_LT_PIPE] = ACTIONS(71),
    [anon_sym_AMP_AMP] = ACTIONS(71),
    [anon_sym_PIPE_PIPE] = ACTIONS(71),
    [anon_sym_QMARK_QMARK] = ACTIONS(71),
    [anon_sym_QMARK_COLON] = ACTIONS(71),
    [anon_sym_BANG_EQ] = ACTIONS(71),
    [anon_sym_EQ_EQ] = ACTIONS(71),
    [anon_sym_QMARK_EQ] = ACTIONS(71),
    [anon_sym_STAR_EQ] = ACTIONS(71),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_BANG_TILDE] = ACTIONS(71),
    [anon_sym_STAR_TILDE] = ACTIONS(71),
    [anon_sym_LT_EQ] = ACTIONS(71),
    [anon_sym_GT_EQ] = ACTIONS(71),
    [anon_sym_PLUS] = ACTIONS(73),
    [anon_sym_PLUS_EQ] = ACTIONS(71),
    [anon_sym_DASH_EQ] = ACTIONS(71),
    [anon_sym_u00d7] = ACTIONS(71),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_u00f7] = ACTIONS(71),
    [anon_sym_STAR_STAR] = ACTIONS(71),
    [anon_sym_u220b] = ACTIONS(71),
    [anon_sym_u220c] = ACTIONS(71),
    [anon_sym_u2287] = ACTIONS(71),
    [anon_sym_u2283] = ACTIONS(71),
    [anon_sym_u2285] = ACTIONS(71),
    [anon_sym_u2208] = ACTIONS(71),
    [anon_sym_u2209] = ACTIONS(71),
    [anon_sym_u2286] = ACTIONS(71),
    [anon_sym_u2282] = ACTIONS(71),
    [anon_sym_u2284] = ACTIONS(71),
    [anon_sym_AT_AT] = ACTIONS(71),
  },
  [163] = {
    [sym_array] = STATE(292),
    [sym_object] = STATE(292),
    [sym_record_id_value] = STATE(317),
    [ts_builtin_sym_end] = ACTIONS(210),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_explain] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_fetch] = ACTIONS(212),
    [sym_keyword_limit] = ACTIONS(212),
    [sym_keyword_order] = ACTIONS(212),
    [sym_keyword_with] = ACTIONS(212),
    [sym_keyword_where] = ACTIONS(212),
    [sym_keyword_split] = ACTIONS(212),
    [sym_keyword_group] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(442),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(444),
    [sym_record_id_ident] = ACTIONS(444),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [164] = {
    [sym_where_clause] = STATE(1167),
    [sym_timeout_clause] = STATE(1256),
    [sym_parallel_clause] = STATE(1395),
    [sym_content_clause] = STATE(1017),
    [sym_set_clause] = STATE(1017),
    [sym_unset_clause] = STATE(1017),
    [sym_return_clause] = STATE(1166),
    [sym_merge_clause] = STATE(1017),
    [sym_patch_clause] = STATE(1017),
    [sym_operator] = STATE(752),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(776),
    [ts_builtin_sym_end] = ACTIONS(375),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(375),
    [sym_keyword_return] = ACTIONS(424),
    [sym_keyword_parallel] = ACTIONS(293),
    [sym_keyword_timeout] = ACTIONS(295),
    [sym_keyword_where] = ACTIONS(426),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_content] = ACTIONS(347),
    [sym_keyword_merge] = ACTIONS(349),
    [sym_keyword_patch] = ACTIONS(351),
    [sym_keyword_set] = ACTIONS(428),
    [sym_keyword_unset] = ACTIONS(430),
    [anon_sym_COMMA] = ACTIONS(432),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [165] = {
    [sym_array] = STATE(292),
    [sym_object] = STATE(292),
    [sym_record_id_value] = STATE(320),
    [ts_builtin_sym_end] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_explain] = ACTIONS(180),
    [sym_keyword_parallel] = ACTIONS(180),
    [sym_keyword_timeout] = ACTIONS(180),
    [sym_keyword_fetch] = ACTIONS(180),
    [sym_keyword_limit] = ACTIONS(180),
    [sym_keyword_order] = ACTIONS(180),
    [sym_keyword_with] = ACTIONS(180),
    [sym_keyword_where] = ACTIONS(180),
    [sym_keyword_split] = ACTIONS(180),
    [sym_keyword_group] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(442),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(444),
    [sym_record_id_ident] = ACTIONS(444),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [166] = {
    [sym_filter] = STATE(266),
    [sym_path_element] = STATE(160),
    [sym_graph_path] = STATE(266),
    [sym_subscript] = STATE(266),
    [aux_sym_path_repeat1] = STATE(160),
    [ts_builtin_sym_end] = ACTIONS(59),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(59),
    [sym_keyword_as] = ACTIONS(59),
    [sym_keyword_where] = ACTIONS(59),
    [sym_keyword_group] = ACTIONS(59),
    [sym_keyword_and] = ACTIONS(59),
    [sym_keyword_or] = ACTIONS(59),
    [sym_keyword_is] = ACTIONS(59),
    [sym_keyword_not] = ACTIONS(61),
    [sym_keyword_contains] = ACTIONS(59),
    [sym_keyword_contains_not] = ACTIONS(59),
    [sym_keyword_contains_all] = ACTIONS(59),
    [sym_keyword_contains_any] = ACTIONS(59),
    [sym_keyword_contains_none] = ACTIONS(59),
    [sym_keyword_inside] = ACTIONS(59),
    [sym_keyword_in] = ACTIONS(61),
    [sym_keyword_not_inside] = ACTIONS(59),
    [sym_keyword_all_inside] = ACTIONS(59),
    [sym_keyword_any_inside] = ACTIONS(59),
    [sym_keyword_none_inside] = ACTIONS(59),
    [sym_keyword_outside] = ACTIONS(59),
    [sym_keyword_intersects] = ACTIONS(59),
    [sym_keyword_drop] = ACTIONS(59),
    [sym_keyword_schemafull] = ACTIONS(59),
    [sym_keyword_schemaless] = ACTIONS(59),
    [sym_keyword_changefeed] = ACTIONS(59),
    [sym_keyword_type] = ACTIONS(59),
    [sym_keyword_permissions] = ACTIONS(59),
    [sym_keyword_for] = ACTIONS(59),
    [sym_keyword_comment] = ACTIONS(59),
    [anon_sym_COMMA] = ACTIONS(59),
    [anon_sym_DASH_GT] = ACTIONS(434),
    [anon_sym_LBRACK] = ACTIONS(436),
    [anon_sym_LT_DASH] = ACTIONS(438),
    [anon_sym_LT_DASH_GT] = ACTIONS(434),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_DOT] = ACTIONS(440),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(61),
    [anon_sym_LT_PIPE] = ACTIONS(59),
    [anon_sym_AMP_AMP] = ACTIONS(59),
    [anon_sym_PIPE_PIPE] = ACTIONS(59),
    [anon_sym_QMARK_QMARK] = ACTIONS(59),
    [anon_sym_QMARK_COLON] = ACTIONS(59),
    [anon_sym_BANG_EQ] = ACTIONS(59),
    [anon_sym_EQ_EQ] = ACTIONS(59),
    [anon_sym_QMARK_EQ] = ACTIONS(59),
    [anon_sym_STAR_EQ] = ACTIONS(59),
    [anon_sym_TILDE] = ACTIONS(59),
    [anon_sym_BANG_TILDE] = ACTIONS(59),
    [anon_sym_STAR_TILDE] = ACTIONS(59),
    [anon_sym_LT_EQ] = ACTIONS(59),
    [anon_sym_GT_EQ] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_PLUS_EQ] = ACTIONS(59),
    [anon_sym_DASH_EQ] = ACTIONS(59),
    [anon_sym_u00d7] = ACTIONS(59),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_u00f7] = ACTIONS(59),
    [anon_sym_STAR_STAR] = ACTIONS(59),
    [anon_sym_u220b] = ACTIONS(59),
    [anon_sym_u220c] = ACTIONS(59),
    [anon_sym_u2287] = ACTIONS(59),
    [anon_sym_u2283] = ACTIONS(59),
    [anon_sym_u2285] = ACTIONS(59),
    [anon_sym_u2208] = ACTIONS(59),
    [anon_sym_u2209] = ACTIONS(59),
    [anon_sym_u2286] = ACTIONS(59),
    [anon_sym_u2282] = ACTIONS(59),
    [anon_sym_u2284] = ACTIONS(59),
    [anon_sym_AT_AT] = ACTIONS(59),
  },
  [167] = {
    [sym_array] = STATE(226),
    [sym_object] = STATE(226),
    [sym_record_id_value] = STATE(256),
    [ts_builtin_sym_end] = ACTIONS(210),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_as] = ACTIONS(212),
    [sym_keyword_where] = ACTIONS(212),
    [sym_keyword_group] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_drop] = ACTIONS(212),
    [sym_keyword_schemafull] = ACTIONS(212),
    [sym_keyword_schemaless] = ACTIONS(212),
    [sym_keyword_changefeed] = ACTIONS(212),
    [sym_keyword_type] = ACTIONS(212),
    [sym_keyword_permissions] = ACTIONS(212),
    [sym_keyword_comment] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(398),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(400),
    [sym_record_id_ident] = ACTIONS(400),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [168] = {
    [sym_filter] = STATE(64),
    [sym_path_element] = STATE(149),
    [sym_graph_path] = STATE(64),
    [sym_subscript] = STATE(64),
    [aux_sym_path_repeat1] = STATE(149),
    [ts_builtin_sym_end] = ACTIONS(59),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(59),
    [sym_keyword_return] = ACTIONS(59),
    [sym_keyword_parallel] = ACTIONS(59),
    [sym_keyword_timeout] = ACTIONS(59),
    [sym_keyword_where] = ACTIONS(59),
    [sym_keyword_and] = ACTIONS(59),
    [sym_keyword_or] = ACTIONS(59),
    [sym_keyword_is] = ACTIONS(59),
    [sym_keyword_not] = ACTIONS(61),
    [sym_keyword_contains] = ACTIONS(59),
    [sym_keyword_contains_not] = ACTIONS(59),
    [sym_keyword_contains_all] = ACTIONS(59),
    [sym_keyword_contains_any] = ACTIONS(59),
    [sym_keyword_contains_none] = ACTIONS(59),
    [sym_keyword_inside] = ACTIONS(59),
    [sym_keyword_in] = ACTIONS(61),
    [sym_keyword_not_inside] = ACTIONS(59),
    [sym_keyword_all_inside] = ACTIONS(59),
    [sym_keyword_any_inside] = ACTIONS(59),
    [sym_keyword_none_inside] = ACTIONS(59),
    [sym_keyword_outside] = ACTIONS(59),
    [sym_keyword_intersects] = ACTIONS(59),
    [sym_keyword_content] = ACTIONS(59),
    [sym_keyword_merge] = ACTIONS(59),
    [sym_keyword_patch] = ACTIONS(59),
    [sym_keyword_permissions] = ACTIONS(59),
    [sym_keyword_comment] = ACTIONS(59),
    [sym_keyword_set] = ACTIONS(59),
    [sym_keyword_unset] = ACTIONS(59),
    [anon_sym_COMMA] = ACTIONS(59),
    [anon_sym_DASH_GT] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(245),
    [anon_sym_LT_DASH] = ACTIONS(43),
    [anon_sym_LT_DASH_GT] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_DOT] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(61),
    [anon_sym_LT_PIPE] = ACTIONS(59),
    [anon_sym_AMP_AMP] = ACTIONS(59),
    [anon_sym_PIPE_PIPE] = ACTIONS(59),
    [anon_sym_QMARK_QMARK] = ACTIONS(59),
    [anon_sym_QMARK_COLON] = ACTIONS(59),
    [anon_sym_BANG_EQ] = ACTIONS(59),
    [anon_sym_EQ_EQ] = ACTIONS(59),
    [anon_sym_QMARK_EQ] = ACTIONS(59),
    [anon_sym_STAR_EQ] = ACTIONS(59),
    [anon_sym_TILDE] = ACTIONS(59),
    [anon_sym_BANG_TILDE] = ACTIONS(59),
    [anon_sym_STAR_TILDE] = ACTIONS(59),
    [anon_sym_LT_EQ] = ACTIONS(59),
    [anon_sym_GT_EQ] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_PLUS_EQ] = ACTIONS(59),
    [anon_sym_DASH_EQ] = ACTIONS(59),
    [anon_sym_u00d7] = ACTIONS(59),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_u00f7] = ACTIONS(59),
    [anon_sym_STAR_STAR] = ACTIONS(59),
    [anon_sym_u220b] = ACTIONS(59),
    [anon_sym_u220c] = ACTIONS(59),
    [anon_sym_u2287] = ACTIONS(59),
    [anon_sym_u2283] = ACTIONS(59),
    [anon_sym_u2285] = ACTIONS(59),
    [anon_sym_u2208] = ACTIONS(59),
    [anon_sym_u2209] = ACTIONS(59),
    [anon_sym_u2286] = ACTIONS(59),
    [anon_sym_u2282] = ACTIONS(59),
    [anon_sym_u2284] = ACTIONS(59),
    [anon_sym_AT_AT] = ACTIONS(59),
  },
  [169] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(48),
    [ts_builtin_sym_end] = ACTIONS(367),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_explain] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_fetch] = ACTIONS(369),
    [sym_keyword_limit] = ACTIONS(369),
    [sym_keyword_rand] = ACTIONS(369),
    [sym_keyword_collate] = ACTIONS(369),
    [sym_keyword_numeric] = ACTIONS(369),
    [sym_keyword_asc] = ACTIONS(369),
    [sym_keyword_desc] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [170] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(49),
    [ts_builtin_sym_end] = ACTIONS(210),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_explain] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_fetch] = ACTIONS(212),
    [sym_keyword_limit] = ACTIONS(212),
    [sym_keyword_rand] = ACTIONS(212),
    [sym_keyword_collate] = ACTIONS(212),
    [sym_keyword_numeric] = ACTIONS(212),
    [sym_keyword_asc] = ACTIONS(212),
    [sym_keyword_desc] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [171] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(50),
    [ts_builtin_sym_end] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_explain] = ACTIONS(180),
    [sym_keyword_parallel] = ACTIONS(180),
    [sym_keyword_timeout] = ACTIONS(180),
    [sym_keyword_fetch] = ACTIONS(180),
    [sym_keyword_limit] = ACTIONS(180),
    [sym_keyword_rand] = ACTIONS(180),
    [sym_keyword_collate] = ACTIONS(180),
    [sym_keyword_numeric] = ACTIONS(180),
    [sym_keyword_asc] = ACTIONS(180),
    [sym_keyword_desc] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [172] = {
    [sym_filter] = STATE(334),
    [sym_path_element] = STATE(176),
    [sym_graph_path] = STATE(334),
    [sym_subscript] = STATE(334),
    [aux_sym_path_repeat1] = STATE(176),
    [ts_builtin_sym_end] = ACTIONS(91),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(91),
    [sym_keyword_explain] = ACTIONS(91),
    [sym_keyword_parallel] = ACTIONS(91),
    [sym_keyword_timeout] = ACTIONS(91),
    [sym_keyword_fetch] = ACTIONS(91),
    [sym_keyword_limit] = ACTIONS(91),
    [sym_keyword_order] = ACTIONS(91),
    [sym_keyword_with] = ACTIONS(91),
    [sym_keyword_where] = ACTIONS(91),
    [sym_keyword_split] = ACTIONS(91),
    [sym_keyword_group] = ACTIONS(91),
    [sym_keyword_and] = ACTIONS(91),
    [sym_keyword_or] = ACTIONS(93),
    [sym_keyword_is] = ACTIONS(91),
    [sym_keyword_not] = ACTIONS(93),
    [sym_keyword_contains] = ACTIONS(91),
    [sym_keyword_contains_not] = ACTIONS(91),
    [sym_keyword_contains_all] = ACTIONS(91),
    [sym_keyword_contains_any] = ACTIONS(91),
    [sym_keyword_contains_none] = ACTIONS(91),
    [sym_keyword_inside] = ACTIONS(91),
    [sym_keyword_in] = ACTIONS(93),
    [sym_keyword_not_inside] = ACTIONS(91),
    [sym_keyword_all_inside] = ACTIONS(91),
    [sym_keyword_any_inside] = ACTIONS(91),
    [sym_keyword_none_inside] = ACTIONS(91),
    [sym_keyword_outside] = ACTIONS(91),
    [sym_keyword_intersects] = ACTIONS(91),
    [anon_sym_COMMA] = ACTIONS(91),
    [anon_sym_DASH_GT] = ACTIONS(448),
    [anon_sym_LBRACK] = ACTIONS(450),
    [anon_sym_LT_DASH] = ACTIONS(452),
    [anon_sym_LT_DASH_GT] = ACTIONS(448),
    [anon_sym_STAR] = ACTIONS(93),
    [anon_sym_DOT] = ACTIONS(454),
    [anon_sym_LT] = ACTIONS(93),
    [anon_sym_GT] = ACTIONS(93),
    [anon_sym_EQ] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(93),
    [anon_sym_AT] = ACTIONS(93),
    [anon_sym_LT_PIPE] = ACTIONS(91),
    [anon_sym_AMP_AMP] = ACTIONS(91),
    [anon_sym_PIPE_PIPE] = ACTIONS(91),
    [anon_sym_QMARK_QMARK] = ACTIONS(91),
    [anon_sym_QMARK_COLON] = ACTIONS(91),
    [anon_sym_BANG_EQ] = ACTIONS(91),
    [anon_sym_EQ_EQ] = ACTIONS(91),
    [anon_sym_QMARK_EQ] = ACTIONS(91),
    [anon_sym_STAR_EQ] = ACTIONS(91),
    [anon_sym_TILDE] = ACTIONS(91),
    [anon_sym_BANG_TILDE] = ACTIONS(91),
    [anon_sym_STAR_TILDE] = ACTIONS(91),
    [anon_sym_LT_EQ] = ACTIONS(91),
    [anon_sym_GT_EQ] = ACTIONS(91),
    [anon_sym_PLUS] = ACTIONS(93),
    [anon_sym_PLUS_EQ] = ACTIONS(91),
    [anon_sym_DASH_EQ] = ACTIONS(91),
    [anon_sym_u00d7] = ACTIONS(91),
    [anon_sym_SLASH] = ACTIONS(93),
    [anon_sym_u00f7] = ACTIONS(91),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_u220b] = ACTIONS(91),
    [anon_sym_u220c] = ACTIONS(91),
    [anon_sym_u2287] = ACTIONS(91),
    [anon_sym_u2283] = ACTIONS(91),
    [anon_sym_u2285] = ACTIONS(91),
    [anon_sym_u2208] = ACTIONS(91),
    [anon_sym_u2209] = ACTIONS(91),
    [anon_sym_u2286] = ACTIONS(91),
    [anon_sym_u2282] = ACTIONS(91),
    [anon_sym_u2284] = ACTIONS(91),
    [anon_sym_AT_AT] = ACTIONS(91),
  },
  [173] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(259),
    [sym_keyword_value] = ACTIONS(259),
    [sym_keyword_explain] = ACTIONS(259),
    [sym_keyword_parallel] = ACTIONS(259),
    [sym_keyword_timeout] = ACTIONS(259),
    [sym_keyword_fetch] = ACTIONS(259),
    [sym_keyword_limit] = ACTIONS(259),
    [sym_keyword_rand] = ACTIONS(259),
    [sym_keyword_collate] = ACTIONS(259),
    [sym_keyword_numeric] = ACTIONS(259),
    [sym_keyword_asc] = ACTIONS(259),
    [sym_keyword_desc] = ACTIONS(259),
    [sym_keyword_and] = ACTIONS(259),
    [sym_keyword_or] = ACTIONS(259),
    [sym_keyword_is] = ACTIONS(259),
    [sym_keyword_not] = ACTIONS(261),
    [sym_keyword_contains] = ACTIONS(259),
    [sym_keyword_contains_not] = ACTIONS(259),
    [sym_keyword_contains_all] = ACTIONS(259),
    [sym_keyword_contains_any] = ACTIONS(259),
    [sym_keyword_contains_none] = ACTIONS(259),
    [sym_keyword_inside] = ACTIONS(259),
    [sym_keyword_in] = ACTIONS(261),
    [sym_keyword_not_inside] = ACTIONS(259),
    [sym_keyword_all_inside] = ACTIONS(259),
    [sym_keyword_any_inside] = ACTIONS(259),
    [sym_keyword_none_inside] = ACTIONS(259),
    [sym_keyword_outside] = ACTIONS(259),
    [sym_keyword_intersects] = ACTIONS(259),
    [sym_keyword_flexible] = ACTIONS(259),
    [sym_keyword_readonly] = ACTIONS(259),
    [sym_keyword_type] = ACTIONS(259),
    [sym_keyword_default] = ACTIONS(259),
    [sym_keyword_assert] = ACTIONS(259),
    [sym_keyword_permissions] = ACTIONS(259),
    [sym_keyword_for] = ACTIONS(259),
    [sym_keyword_comment] = ACTIONS(259),
    [anon_sym_COMMA] = ACTIONS(259),
    [anon_sym_RPAREN] = ACTIONS(259),
    [anon_sym_RBRACE] = ACTIONS(259),
    [anon_sym_STAR] = ACTIONS(261),
    [anon_sym_LT] = ACTIONS(261),
    [anon_sym_GT] = ACTIONS(261),
    [anon_sym_EQ] = ACTIONS(261),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_AT] = ACTIONS(261),
    [anon_sym_LT_PIPE] = ACTIONS(259),
    [anon_sym_AMP_AMP] = ACTIONS(259),
    [anon_sym_PIPE_PIPE] = ACTIONS(259),
    [anon_sym_QMARK_QMARK] = ACTIONS(259),
    [anon_sym_QMARK_COLON] = ACTIONS(259),
    [anon_sym_BANG_EQ] = ACTIONS(259),
    [anon_sym_EQ_EQ] = ACTIONS(259),
    [anon_sym_QMARK_EQ] = ACTIONS(259),
    [anon_sym_STAR_EQ] = ACTIONS(259),
    [anon_sym_TILDE] = ACTIONS(259),
    [anon_sym_BANG_TILDE] = ACTIONS(259),
    [anon_sym_STAR_TILDE] = ACTIONS(259),
    [anon_sym_LT_EQ] = ACTIONS(259),
    [anon_sym_GT_EQ] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(261),
    [anon_sym_PLUS_EQ] = ACTIONS(259),
    [anon_sym_DASH_EQ] = ACTIONS(259),
    [anon_sym_u00d7] = ACTIONS(259),
    [anon_sym_SLASH] = ACTIONS(261),
    [anon_sym_u00f7] = ACTIONS(259),
    [anon_sym_STAR_STAR] = ACTIONS(259),
    [anon_sym_u220b] = ACTIONS(259),
    [anon_sym_u220c] = ACTIONS(259),
    [anon_sym_u2287] = ACTIONS(259),
    [anon_sym_u2283] = ACTIONS(259),
    [anon_sym_u2285] = ACTIONS(259),
    [anon_sym_u2208] = ACTIONS(259),
    [anon_sym_u2209] = ACTIONS(259),
    [anon_sym_u2286] = ACTIONS(259),
    [anon_sym_u2282] = ACTIONS(259),
    [anon_sym_u2284] = ACTIONS(259),
    [anon_sym_AT_AT] = ACTIONS(259),
  },
  [174] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(138),
    [sym_keyword_value] = ACTIONS(138),
    [sym_keyword_explain] = ACTIONS(138),
    [sym_keyword_parallel] = ACTIONS(138),
    [sym_keyword_timeout] = ACTIONS(138),
    [sym_keyword_fetch] = ACTIONS(138),
    [sym_keyword_limit] = ACTIONS(138),
    [sym_keyword_rand] = ACTIONS(138),
    [sym_keyword_collate] = ACTIONS(138),
    [sym_keyword_numeric] = ACTIONS(138),
    [sym_keyword_asc] = ACTIONS(138),
    [sym_keyword_desc] = ACTIONS(138),
    [sym_keyword_and] = ACTIONS(138),
    [sym_keyword_or] = ACTIONS(138),
    [sym_keyword_is] = ACTIONS(138),
    [sym_keyword_not] = ACTIONS(140),
    [sym_keyword_contains] = ACTIONS(138),
    [sym_keyword_contains_not] = ACTIONS(138),
    [sym_keyword_contains_all] = ACTIONS(138),
    [sym_keyword_contains_any] = ACTIONS(138),
    [sym_keyword_contains_none] = ACTIONS(138),
    [sym_keyword_inside] = ACTIONS(138),
    [sym_keyword_in] = ACTIONS(140),
    [sym_keyword_not_inside] = ACTIONS(138),
    [sym_keyword_all_inside] = ACTIONS(138),
    [sym_keyword_any_inside] = ACTIONS(138),
    [sym_keyword_none_inside] = ACTIONS(138),
    [sym_keyword_outside] = ACTIONS(138),
    [sym_keyword_intersects] = ACTIONS(138),
    [sym_keyword_flexible] = ACTIONS(138),
    [sym_keyword_readonly] = ACTIONS(138),
    [sym_keyword_type] = ACTIONS(138),
    [sym_keyword_default] = ACTIONS(138),
    [sym_keyword_assert] = ACTIONS(138),
    [sym_keyword_permissions] = ACTIONS(138),
    [sym_keyword_for] = ACTIONS(138),
    [sym_keyword_comment] = ACTIONS(138),
    [anon_sym_COMMA] = ACTIONS(138),
    [anon_sym_RPAREN] = ACTIONS(138),
    [anon_sym_RBRACE] = ACTIONS(138),
    [anon_sym_STAR] = ACTIONS(140),
    [anon_sym_LT] = ACTIONS(140),
    [anon_sym_GT] = ACTIONS(140),
    [anon_sym_EQ] = ACTIONS(140),
    [anon_sym_DASH] = ACTIONS(140),
    [anon_sym_AT] = ACTIONS(140),
    [anon_sym_LT_PIPE] = ACTIONS(138),
    [anon_sym_AMP_AMP] = ACTIONS(138),
    [anon_sym_PIPE_PIPE] = ACTIONS(138),
    [anon_sym_QMARK_QMARK] = ACTIONS(138),
    [anon_sym_QMARK_COLON] = ACTIONS(138),
    [anon_sym_BANG_EQ] = ACTIONS(138),
    [anon_sym_EQ_EQ] = ACTIONS(138),
    [anon_sym_QMARK_EQ] = ACTIONS(138),
    [anon_sym_STAR_EQ] = ACTIONS(138),
    [anon_sym_TILDE] = ACTIONS(138),
    [anon_sym_BANG_TILDE] = ACTIONS(138),
    [anon_sym_STAR_TILDE] = ACTIONS(138),
    [anon_sym_LT_EQ] = ACTIONS(138),
    [anon_sym_GT_EQ] = ACTIONS(138),
    [anon_sym_PLUS] = ACTIONS(140),
    [anon_sym_PLUS_EQ] = ACTIONS(138),
    [anon_sym_DASH_EQ] = ACTIONS(138),
    [anon_sym_u00d7] = ACTIONS(138),
    [anon_sym_SLASH] = ACTIONS(140),
    [anon_sym_u00f7] = ACTIONS(138),
    [anon_sym_STAR_STAR] = ACTIONS(138),
    [anon_sym_u220b] = ACTIONS(138),
    [anon_sym_u220c] = ACTIONS(138),
    [anon_sym_u2287] = ACTIONS(138),
    [anon_sym_u2283] = ACTIONS(138),
    [anon_sym_u2285] = ACTIONS(138),
    [anon_sym_u2208] = ACTIONS(138),
    [anon_sym_u2209] = ACTIONS(138),
    [anon_sym_u2286] = ACTIONS(138),
    [anon_sym_u2282] = ACTIONS(138),
    [anon_sym_u2284] = ACTIONS(138),
    [anon_sym_AT_AT] = ACTIONS(138),
  },
  [175] = {
    [sym_filter] = STATE(334),
    [sym_path_element] = STATE(172),
    [sym_graph_path] = STATE(334),
    [sym_subscript] = STATE(334),
    [aux_sym_path_repeat1] = STATE(172),
    [ts_builtin_sym_end] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(71),
    [sym_keyword_explain] = ACTIONS(71),
    [sym_keyword_parallel] = ACTIONS(71),
    [sym_keyword_timeout] = ACTIONS(71),
    [sym_keyword_fetch] = ACTIONS(71),
    [sym_keyword_limit] = ACTIONS(71),
    [sym_keyword_order] = ACTIONS(71),
    [sym_keyword_with] = ACTIONS(71),
    [sym_keyword_where] = ACTIONS(71),
    [sym_keyword_split] = ACTIONS(71),
    [sym_keyword_group] = ACTIONS(71),
    [sym_keyword_and] = ACTIONS(71),
    [sym_keyword_or] = ACTIONS(73),
    [sym_keyword_is] = ACTIONS(71),
    [sym_keyword_not] = ACTIONS(73),
    [sym_keyword_contains] = ACTIONS(71),
    [sym_keyword_contains_not] = ACTIONS(71),
    [sym_keyword_contains_all] = ACTIONS(71),
    [sym_keyword_contains_any] = ACTIONS(71),
    [sym_keyword_contains_none] = ACTIONS(71),
    [sym_keyword_inside] = ACTIONS(71),
    [sym_keyword_in] = ACTIONS(73),
    [sym_keyword_not_inside] = ACTIONS(71),
    [sym_keyword_all_inside] = ACTIONS(71),
    [sym_keyword_any_inside] = ACTIONS(71),
    [sym_keyword_none_inside] = ACTIONS(71),
    [sym_keyword_outside] = ACTIONS(71),
    [sym_keyword_intersects] = ACTIONS(71),
    [anon_sym_COMMA] = ACTIONS(71),
    [anon_sym_DASH_GT] = ACTIONS(448),
    [anon_sym_LBRACK] = ACTIONS(450),
    [anon_sym_LT_DASH] = ACTIONS(452),
    [anon_sym_LT_DASH_GT] = ACTIONS(448),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_DOT] = ACTIONS(454),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(73),
    [anon_sym_LT_PIPE] = ACTIONS(71),
    [anon_sym_AMP_AMP] = ACTIONS(71),
    [anon_sym_PIPE_PIPE] = ACTIONS(71),
    [anon_sym_QMARK_QMARK] = ACTIONS(71),
    [anon_sym_QMARK_COLON] = ACTIONS(71),
    [anon_sym_BANG_EQ] = ACTIONS(71),
    [anon_sym_EQ_EQ] = ACTIONS(71),
    [anon_sym_QMARK_EQ] = ACTIONS(71),
    [anon_sym_STAR_EQ] = ACTIONS(71),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_BANG_TILDE] = ACTIONS(71),
    [anon_sym_STAR_TILDE] = ACTIONS(71),
    [anon_sym_LT_EQ] = ACTIONS(71),
    [anon_sym_GT_EQ] = ACTIONS(71),
    [anon_sym_PLUS] = ACTIONS(73),
    [anon_sym_PLUS_EQ] = ACTIONS(71),
    [anon_sym_DASH_EQ] = ACTIONS(71),
    [anon_sym_u00d7] = ACTIONS(71),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_u00f7] = ACTIONS(71),
    [anon_sym_STAR_STAR] = ACTIONS(71),
    [anon_sym_u220b] = ACTIONS(71),
    [anon_sym_u220c] = ACTIONS(71),
    [anon_sym_u2287] = ACTIONS(71),
    [anon_sym_u2283] = ACTIONS(71),
    [anon_sym_u2285] = ACTIONS(71),
    [anon_sym_u2208] = ACTIONS(71),
    [anon_sym_u2209] = ACTIONS(71),
    [anon_sym_u2286] = ACTIONS(71),
    [anon_sym_u2282] = ACTIONS(71),
    [anon_sym_u2284] = ACTIONS(71),
    [anon_sym_AT_AT] = ACTIONS(71),
  },
  [176] = {
    [sym_filter] = STATE(334),
    [sym_path_element] = STATE(176),
    [sym_graph_path] = STATE(334),
    [sym_subscript] = STATE(334),
    [aux_sym_path_repeat1] = STATE(176),
    [ts_builtin_sym_end] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(75),
    [sym_keyword_explain] = ACTIONS(75),
    [sym_keyword_parallel] = ACTIONS(75),
    [sym_keyword_timeout] = ACTIONS(75),
    [sym_keyword_fetch] = ACTIONS(75),
    [sym_keyword_limit] = ACTIONS(75),
    [sym_keyword_order] = ACTIONS(75),
    [sym_keyword_with] = ACTIONS(75),
    [sym_keyword_where] = ACTIONS(75),
    [sym_keyword_split] = ACTIONS(75),
    [sym_keyword_group] = ACTIONS(75),
    [sym_keyword_and] = ACTIONS(75),
    [sym_keyword_or] = ACTIONS(77),
    [sym_keyword_is] = ACTIONS(75),
    [sym_keyword_not] = ACTIONS(77),
    [sym_keyword_contains] = ACTIONS(75),
    [sym_keyword_contains_not] = ACTIONS(75),
    [sym_keyword_contains_all] = ACTIONS(75),
    [sym_keyword_contains_any] = ACTIONS(75),
    [sym_keyword_contains_none] = ACTIONS(75),
    [sym_keyword_inside] = ACTIONS(75),
    [sym_keyword_in] = ACTIONS(77),
    [sym_keyword_not_inside] = ACTIONS(75),
    [sym_keyword_all_inside] = ACTIONS(75),
    [sym_keyword_any_inside] = ACTIONS(75),
    [sym_keyword_none_inside] = ACTIONS(75),
    [sym_keyword_outside] = ACTIONS(75),
    [sym_keyword_intersects] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(75),
    [anon_sym_DASH_GT] = ACTIONS(456),
    [anon_sym_LBRACK] = ACTIONS(459),
    [anon_sym_LT_DASH] = ACTIONS(462),
    [anon_sym_LT_DASH_GT] = ACTIONS(456),
    [anon_sym_STAR] = ACTIONS(77),
    [anon_sym_DOT] = ACTIONS(465),
    [anon_sym_LT] = ACTIONS(77),
    [anon_sym_GT] = ACTIONS(77),
    [anon_sym_EQ] = ACTIONS(77),
    [anon_sym_DASH] = ACTIONS(77),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LT_PIPE] = ACTIONS(75),
    [anon_sym_AMP_AMP] = ACTIONS(75),
    [anon_sym_PIPE_PIPE] = ACTIONS(75),
    [anon_sym_QMARK_QMARK] = ACTIONS(75),
    [anon_sym_QMARK_COLON] = ACTIONS(75),
    [anon_sym_BANG_EQ] = ACTIONS(75),
    [anon_sym_EQ_EQ] = ACTIONS(75),
    [anon_sym_QMARK_EQ] = ACTIONS(75),
    [anon_sym_STAR_EQ] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_BANG_TILDE] = ACTIONS(75),
    [anon_sym_STAR_TILDE] = ACTIONS(75),
    [anon_sym_LT_EQ] = ACTIONS(75),
    [anon_sym_GT_EQ] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(77),
    [anon_sym_PLUS_EQ] = ACTIONS(75),
    [anon_sym_DASH_EQ] = ACTIONS(75),
    [anon_sym_u00d7] = ACTIONS(75),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_u00f7] = ACTIONS(75),
    [anon_sym_STAR_STAR] = ACTIONS(75),
    [anon_sym_u220b] = ACTIONS(75),
    [anon_sym_u220c] = ACTIONS(75),
    [anon_sym_u2287] = ACTIONS(75),
    [anon_sym_u2283] = ACTIONS(75),
    [anon_sym_u2285] = ACTIONS(75),
    [anon_sym_u2208] = ACTIONS(75),
    [anon_sym_u2209] = ACTIONS(75),
    [anon_sym_u2286] = ACTIONS(75),
    [anon_sym_u2282] = ACTIONS(75),
    [anon_sym_u2284] = ACTIONS(75),
    [anon_sym_AT_AT] = ACTIONS(75),
  },
  [177] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(33),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_as] = ACTIONS(180),
    [sym_keyword_group] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [sym_keyword_drop] = ACTIONS(180),
    [sym_keyword_schemafull] = ACTIONS(180),
    [sym_keyword_schemaless] = ACTIONS(180),
    [sym_keyword_changefeed] = ACTIONS(180),
    [sym_keyword_type] = ACTIONS(180),
    [sym_keyword_permissions] = ACTIONS(180),
    [sym_keyword_comment] = ACTIONS(180),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [178] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(36),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_as] = ACTIONS(212),
    [sym_keyword_group] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_drop] = ACTIONS(212),
    [sym_keyword_schemafull] = ACTIONS(212),
    [sym_keyword_schemaless] = ACTIONS(212),
    [sym_keyword_changefeed] = ACTIONS(212),
    [sym_keyword_type] = ACTIONS(212),
    [sym_keyword_permissions] = ACTIONS(212),
    [sym_keyword_comment] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [179] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(150),
    [sym_keyword_value] = ACTIONS(150),
    [sym_keyword_explain] = ACTIONS(150),
    [sym_keyword_parallel] = ACTIONS(150),
    [sym_keyword_timeout] = ACTIONS(150),
    [sym_keyword_fetch] = ACTIONS(150),
    [sym_keyword_limit] = ACTIONS(150),
    [sym_keyword_rand] = ACTIONS(150),
    [sym_keyword_collate] = ACTIONS(150),
    [sym_keyword_numeric] = ACTIONS(150),
    [sym_keyword_asc] = ACTIONS(150),
    [sym_keyword_desc] = ACTIONS(150),
    [sym_keyword_and] = ACTIONS(150),
    [sym_keyword_or] = ACTIONS(150),
    [sym_keyword_is] = ACTIONS(150),
    [sym_keyword_not] = ACTIONS(152),
    [sym_keyword_contains] = ACTIONS(150),
    [sym_keyword_contains_not] = ACTIONS(150),
    [sym_keyword_contains_all] = ACTIONS(150),
    [sym_keyword_contains_any] = ACTIONS(150),
    [sym_keyword_contains_none] = ACTIONS(150),
    [sym_keyword_inside] = ACTIONS(150),
    [sym_keyword_in] = ACTIONS(152),
    [sym_keyword_not_inside] = ACTIONS(150),
    [sym_keyword_all_inside] = ACTIONS(150),
    [sym_keyword_any_inside] = ACTIONS(150),
    [sym_keyword_none_inside] = ACTIONS(150),
    [sym_keyword_outside] = ACTIONS(150),
    [sym_keyword_intersects] = ACTIONS(150),
    [sym_keyword_flexible] = ACTIONS(150),
    [sym_keyword_readonly] = ACTIONS(150),
    [sym_keyword_type] = ACTIONS(150),
    [sym_keyword_default] = ACTIONS(150),
    [sym_keyword_assert] = ACTIONS(150),
    [sym_keyword_permissions] = ACTIONS(150),
    [sym_keyword_for] = ACTIONS(150),
    [sym_keyword_comment] = ACTIONS(150),
    [anon_sym_COMMA] = ACTIONS(150),
    [anon_sym_RPAREN] = ACTIONS(150),
    [anon_sym_RBRACE] = ACTIONS(150),
    [anon_sym_STAR] = ACTIONS(152),
    [anon_sym_LT] = ACTIONS(152),
    [anon_sym_GT] = ACTIONS(152),
    [anon_sym_EQ] = ACTIONS(152),
    [anon_sym_DASH] = ACTIONS(152),
    [anon_sym_AT] = ACTIONS(152),
    [anon_sym_LT_PIPE] = ACTIONS(150),
    [anon_sym_AMP_AMP] = ACTIONS(150),
    [anon_sym_PIPE_PIPE] = ACTIONS(150),
    [anon_sym_QMARK_QMARK] = ACTIONS(150),
    [anon_sym_QMARK_COLON] = ACTIONS(150),
    [anon_sym_BANG_EQ] = ACTIONS(150),
    [anon_sym_EQ_EQ] = ACTIONS(150),
    [anon_sym_QMARK_EQ] = ACTIONS(150),
    [anon_sym_STAR_EQ] = ACTIONS(150),
    [anon_sym_TILDE] = ACTIONS(150),
    [anon_sym_BANG_TILDE] = ACTIONS(150),
    [anon_sym_STAR_TILDE] = ACTIONS(150),
    [anon_sym_LT_EQ] = ACTIONS(150),
    [anon_sym_GT_EQ] = ACTIONS(150),
    [anon_sym_PLUS] = ACTIONS(152),
    [anon_sym_PLUS_EQ] = ACTIONS(150),
    [anon_sym_DASH_EQ] = ACTIONS(150),
    [anon_sym_u00d7] = ACTIONS(150),
    [anon_sym_SLASH] = ACTIONS(152),
    [anon_sym_u00f7] = ACTIONS(150),
    [anon_sym_STAR_STAR] = ACTIONS(150),
    [anon_sym_u220b] = ACTIONS(150),
    [anon_sym_u220c] = ACTIONS(150),
    [anon_sym_u2287] = ACTIONS(150),
    [anon_sym_u2283] = ACTIONS(150),
    [anon_sym_u2285] = ACTIONS(150),
    [anon_sym_u2208] = ACTIONS(150),
    [anon_sym_u2209] = ACTIONS(150),
    [anon_sym_u2286] = ACTIONS(150),
    [anon_sym_u2282] = ACTIONS(150),
    [anon_sym_u2284] = ACTIONS(150),
    [anon_sym_AT_AT] = ACTIONS(150),
  },
  [180] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(45),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_as] = ACTIONS(369),
    [sym_keyword_group] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_drop] = ACTIONS(369),
    [sym_keyword_schemafull] = ACTIONS(369),
    [sym_keyword_schemaless] = ACTIONS(369),
    [sym_keyword_changefeed] = ACTIONS(369),
    [sym_keyword_type] = ACTIONS(369),
    [sym_keyword_permissions] = ACTIONS(369),
    [sym_keyword_comment] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_RPAREN] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [181] = {
    [sym_array] = STATE(101),
    [sym_object] = STATE(101),
    [sym_record_id_value] = STATE(113),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_value] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [sym_keyword_flexible] = ACTIONS(180),
    [sym_keyword_readonly] = ACTIONS(180),
    [sym_keyword_type] = ACTIONS(180),
    [sym_keyword_default] = ACTIONS(180),
    [sym_keyword_assert] = ACTIONS(180),
    [sym_keyword_permissions] = ACTIONS(180),
    [sym_keyword_for] = ACTIONS(180),
    [sym_keyword_comment] = ACTIONS(180),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(359),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(361),
    [sym_record_id_ident] = ACTIONS(361),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [182] = {
    [sym_array] = STATE(292),
    [sym_object] = STATE(292),
    [sym_record_id_value] = STATE(312),
    [ts_builtin_sym_end] = ACTIONS(367),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_explain] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_fetch] = ACTIONS(369),
    [sym_keyword_limit] = ACTIONS(369),
    [sym_keyword_order] = ACTIONS(369),
    [sym_keyword_where] = ACTIONS(369),
    [sym_keyword_split] = ACTIONS(369),
    [sym_keyword_group] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(442),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(444),
    [sym_record_id_ident] = ACTIONS(444),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [183] = {
    [sym_array] = STATE(292),
    [sym_object] = STATE(292),
    [sym_record_id_value] = STATE(317),
    [ts_builtin_sym_end] = ACTIONS(210),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_explain] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_fetch] = ACTIONS(212),
    [sym_keyword_limit] = ACTIONS(212),
    [sym_keyword_order] = ACTIONS(212),
    [sym_keyword_where] = ACTIONS(212),
    [sym_keyword_split] = ACTIONS(212),
    [sym_keyword_group] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(442),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(444),
    [sym_record_id_ident] = ACTIONS(444),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [184] = {
    [sym_array] = STATE(292),
    [sym_object] = STATE(292),
    [sym_record_id_value] = STATE(320),
    [ts_builtin_sym_end] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_explain] = ACTIONS(180),
    [sym_keyword_parallel] = ACTIONS(180),
    [sym_keyword_timeout] = ACTIONS(180),
    [sym_keyword_fetch] = ACTIONS(180),
    [sym_keyword_limit] = ACTIONS(180),
    [sym_keyword_order] = ACTIONS(180),
    [sym_keyword_where] = ACTIONS(180),
    [sym_keyword_split] = ACTIONS(180),
    [sym_keyword_group] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(442),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(444),
    [sym_record_id_ident] = ACTIONS(444),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [185] = {
    [sym_filter] = STATE(334),
    [sym_path_element] = STATE(172),
    [sym_graph_path] = STATE(334),
    [sym_subscript] = STATE(334),
    [aux_sym_path_repeat1] = STATE(172),
    [ts_builtin_sym_end] = ACTIONS(59),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(59),
    [sym_keyword_explain] = ACTIONS(59),
    [sym_keyword_parallel] = ACTIONS(59),
    [sym_keyword_timeout] = ACTIONS(59),
    [sym_keyword_fetch] = ACTIONS(59),
    [sym_keyword_limit] = ACTIONS(59),
    [sym_keyword_order] = ACTIONS(59),
    [sym_keyword_with] = ACTIONS(59),
    [sym_keyword_where] = ACTIONS(59),
    [sym_keyword_split] = ACTIONS(59),
    [sym_keyword_group] = ACTIONS(59),
    [sym_keyword_and] = ACTIONS(59),
    [sym_keyword_or] = ACTIONS(61),
    [sym_keyword_is] = ACTIONS(59),
    [sym_keyword_not] = ACTIONS(61),
    [sym_keyword_contains] = ACTIONS(59),
    [sym_keyword_contains_not] = ACTIONS(59),
    [sym_keyword_contains_all] = ACTIONS(59),
    [sym_keyword_contains_any] = ACTIONS(59),
    [sym_keyword_contains_none] = ACTIONS(59),
    [sym_keyword_inside] = ACTIONS(59),
    [sym_keyword_in] = ACTIONS(61),
    [sym_keyword_not_inside] = ACTIONS(59),
    [sym_keyword_all_inside] = ACTIONS(59),
    [sym_keyword_any_inside] = ACTIONS(59),
    [sym_keyword_none_inside] = ACTIONS(59),
    [sym_keyword_outside] = ACTIONS(59),
    [sym_keyword_intersects] = ACTIONS(59),
    [anon_sym_COMMA] = ACTIONS(59),
    [anon_sym_DASH_GT] = ACTIONS(448),
    [anon_sym_LBRACK] = ACTIONS(450),
    [anon_sym_LT_DASH] = ACTIONS(452),
    [anon_sym_LT_DASH_GT] = ACTIONS(448),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_DOT] = ACTIONS(454),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(61),
    [anon_sym_LT_PIPE] = ACTIONS(59),
    [anon_sym_AMP_AMP] = ACTIONS(59),
    [anon_sym_PIPE_PIPE] = ACTIONS(59),
    [anon_sym_QMARK_QMARK] = ACTIONS(59),
    [anon_sym_QMARK_COLON] = ACTIONS(59),
    [anon_sym_BANG_EQ] = ACTIONS(59),
    [anon_sym_EQ_EQ] = ACTIONS(59),
    [anon_sym_QMARK_EQ] = ACTIONS(59),
    [anon_sym_STAR_EQ] = ACTIONS(59),
    [anon_sym_TILDE] = ACTIONS(59),
    [anon_sym_BANG_TILDE] = ACTIONS(59),
    [anon_sym_STAR_TILDE] = ACTIONS(59),
    [anon_sym_LT_EQ] = ACTIONS(59),
    [anon_sym_GT_EQ] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_PLUS_EQ] = ACTIONS(59),
    [anon_sym_DASH_EQ] = ACTIONS(59),
    [anon_sym_u00d7] = ACTIONS(59),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_u00f7] = ACTIONS(59),
    [anon_sym_STAR_STAR] = ACTIONS(59),
    [anon_sym_u220b] = ACTIONS(59),
    [anon_sym_u220c] = ACTIONS(59),
    [anon_sym_u2287] = ACTIONS(59),
    [anon_sym_u2283] = ACTIONS(59),
    [anon_sym_u2285] = ACTIONS(59),
    [anon_sym_u2208] = ACTIONS(59),
    [anon_sym_u2209] = ACTIONS(59),
    [anon_sym_u2286] = ACTIONS(59),
    [anon_sym_u2282] = ACTIONS(59),
    [anon_sym_u2284] = ACTIONS(59),
    [anon_sym_AT_AT] = ACTIONS(59),
  },
  [186] = {
    [sym_array] = STATE(101),
    [sym_object] = STATE(101),
    [sym_record_id_value] = STATE(121),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_value] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_flexible] = ACTIONS(212),
    [sym_keyword_readonly] = ACTIONS(212),
    [sym_keyword_type] = ACTIONS(212),
    [sym_keyword_default] = ACTIONS(212),
    [sym_keyword_assert] = ACTIONS(212),
    [sym_keyword_permissions] = ACTIONS(212),
    [sym_keyword_for] = ACTIONS(212),
    [sym_keyword_comment] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(359),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(361),
    [sym_record_id_ident] = ACTIONS(361),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [187] = {
    [sym_array] = STATE(101),
    [sym_object] = STATE(101),
    [sym_record_id_value] = STATE(103),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_value] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_flexible] = ACTIONS(369),
    [sym_keyword_readonly] = ACTIONS(369),
    [sym_keyword_type] = ACTIONS(369),
    [sym_keyword_default] = ACTIONS(369),
    [sym_keyword_assert] = ACTIONS(369),
    [sym_keyword_permissions] = ACTIONS(369),
    [sym_keyword_for] = ACTIONS(369),
    [sym_keyword_comment] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_RPAREN] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(359),
    [anon_sym_RBRACE] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(361),
    [sym_record_id_ident] = ACTIONS(361),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [188] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(198),
    [sym_keyword_value] = ACTIONS(198),
    [sym_keyword_explain] = ACTIONS(198),
    [sym_keyword_parallel] = ACTIONS(198),
    [sym_keyword_timeout] = ACTIONS(198),
    [sym_keyword_fetch] = ACTIONS(198),
    [sym_keyword_limit] = ACTIONS(198),
    [sym_keyword_rand] = ACTIONS(198),
    [sym_keyword_collate] = ACTIONS(198),
    [sym_keyword_numeric] = ACTIONS(198),
    [sym_keyword_asc] = ACTIONS(198),
    [sym_keyword_desc] = ACTIONS(198),
    [sym_keyword_and] = ACTIONS(198),
    [sym_keyword_or] = ACTIONS(198),
    [sym_keyword_is] = ACTIONS(198),
    [sym_keyword_not] = ACTIONS(200),
    [sym_keyword_contains] = ACTIONS(198),
    [sym_keyword_contains_not] = ACTIONS(198),
    [sym_keyword_contains_all] = ACTIONS(198),
    [sym_keyword_contains_any] = ACTIONS(198),
    [sym_keyword_contains_none] = ACTIONS(198),
    [sym_keyword_inside] = ACTIONS(198),
    [sym_keyword_in] = ACTIONS(200),
    [sym_keyword_not_inside] = ACTIONS(198),
    [sym_keyword_all_inside] = ACTIONS(198),
    [sym_keyword_any_inside] = ACTIONS(198),
    [sym_keyword_none_inside] = ACTIONS(198),
    [sym_keyword_outside] = ACTIONS(198),
    [sym_keyword_intersects] = ACTIONS(198),
    [sym_keyword_flexible] = ACTIONS(198),
    [sym_keyword_readonly] = ACTIONS(198),
    [sym_keyword_type] = ACTIONS(198),
    [sym_keyword_default] = ACTIONS(198),
    [sym_keyword_assert] = ACTIONS(198),
    [sym_keyword_permissions] = ACTIONS(198),
    [sym_keyword_for] = ACTIONS(198),
    [sym_keyword_comment] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(198),
    [anon_sym_RPAREN] = ACTIONS(198),
    [anon_sym_RBRACE] = ACTIONS(198),
    [anon_sym_STAR] = ACTIONS(200),
    [anon_sym_LT] = ACTIONS(200),
    [anon_sym_GT] = ACTIONS(200),
    [anon_sym_EQ] = ACTIONS(200),
    [anon_sym_DASH] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(200),
    [anon_sym_LT_PIPE] = ACTIONS(198),
    [anon_sym_AMP_AMP] = ACTIONS(198),
    [anon_sym_PIPE_PIPE] = ACTIONS(198),
    [anon_sym_QMARK_QMARK] = ACTIONS(198),
    [anon_sym_QMARK_COLON] = ACTIONS(198),
    [anon_sym_BANG_EQ] = ACTIONS(198),
    [anon_sym_EQ_EQ] = ACTIONS(198),
    [anon_sym_QMARK_EQ] = ACTIONS(198),
    [anon_sym_STAR_EQ] = ACTIONS(198),
    [anon_sym_TILDE] = ACTIONS(198),
    [anon_sym_BANG_TILDE] = ACTIONS(198),
    [anon_sym_STAR_TILDE] = ACTIONS(198),
    [anon_sym_LT_EQ] = ACTIONS(198),
    [anon_sym_GT_EQ] = ACTIONS(198),
    [anon_sym_PLUS] = ACTIONS(200),
    [anon_sym_PLUS_EQ] = ACTIONS(198),
    [anon_sym_DASH_EQ] = ACTIONS(198),
    [anon_sym_u00d7] = ACTIONS(198),
    [anon_sym_SLASH] = ACTIONS(200),
    [anon_sym_u00f7] = ACTIONS(198),
    [anon_sym_STAR_STAR] = ACTIONS(198),
    [anon_sym_u220b] = ACTIONS(198),
    [anon_sym_u220c] = ACTIONS(198),
    [anon_sym_u2287] = ACTIONS(198),
    [anon_sym_u2283] = ACTIONS(198),
    [anon_sym_u2285] = ACTIONS(198),
    [anon_sym_u2208] = ACTIONS(198),
    [anon_sym_u2209] = ACTIONS(198),
    [anon_sym_u2286] = ACTIONS(198),
    [anon_sym_u2282] = ACTIONS(198),
    [anon_sym_u2284] = ACTIONS(198),
    [anon_sym_AT_AT] = ACTIONS(198),
  },
  [189] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(33),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_as] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [sym_keyword_drop] = ACTIONS(180),
    [sym_keyword_schemafull] = ACTIONS(180),
    [sym_keyword_schemaless] = ACTIONS(180),
    [sym_keyword_changefeed] = ACTIONS(180),
    [sym_keyword_type] = ACTIONS(180),
    [sym_keyword_permissions] = ACTIONS(180),
    [sym_keyword_for] = ACTIONS(180),
    [sym_keyword_comment] = ACTIONS(180),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [190] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(36),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_as] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_drop] = ACTIONS(212),
    [sym_keyword_schemafull] = ACTIONS(212),
    [sym_keyword_schemaless] = ACTIONS(212),
    [sym_keyword_changefeed] = ACTIONS(212),
    [sym_keyword_type] = ACTIONS(212),
    [sym_keyword_permissions] = ACTIONS(212),
    [sym_keyword_for] = ACTIONS(212),
    [sym_keyword_comment] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [191] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(45),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_as] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_drop] = ACTIONS(369),
    [sym_keyword_schemafull] = ACTIONS(369),
    [sym_keyword_schemaless] = ACTIONS(369),
    [sym_keyword_changefeed] = ACTIONS(369),
    [sym_keyword_type] = ACTIONS(369),
    [sym_keyword_permissions] = ACTIONS(369),
    [sym_keyword_for] = ACTIONS(369),
    [sym_keyword_comment] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_RPAREN] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [192] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(59),
    [sym_keyword_value] = ACTIONS(59),
    [sym_keyword_explain] = ACTIONS(59),
    [sym_keyword_parallel] = ACTIONS(59),
    [sym_keyword_timeout] = ACTIONS(59),
    [sym_keyword_fetch] = ACTIONS(59),
    [sym_keyword_limit] = ACTIONS(59),
    [sym_keyword_rand] = ACTIONS(59),
    [sym_keyword_collate] = ACTIONS(59),
    [sym_keyword_numeric] = ACTIONS(59),
    [sym_keyword_asc] = ACTIONS(59),
    [sym_keyword_desc] = ACTIONS(59),
    [sym_keyword_and] = ACTIONS(59),
    [sym_keyword_or] = ACTIONS(59),
    [sym_keyword_is] = ACTIONS(59),
    [sym_keyword_not] = ACTIONS(61),
    [sym_keyword_contains] = ACTIONS(59),
    [sym_keyword_contains_not] = ACTIONS(59),
    [sym_keyword_contains_all] = ACTIONS(59),
    [sym_keyword_contains_any] = ACTIONS(59),
    [sym_keyword_contains_none] = ACTIONS(59),
    [sym_keyword_inside] = ACTIONS(59),
    [sym_keyword_in] = ACTIONS(61),
    [sym_keyword_not_inside] = ACTIONS(59),
    [sym_keyword_all_inside] = ACTIONS(59),
    [sym_keyword_any_inside] = ACTIONS(59),
    [sym_keyword_none_inside] = ACTIONS(59),
    [sym_keyword_outside] = ACTIONS(59),
    [sym_keyword_intersects] = ACTIONS(59),
    [sym_keyword_flexible] = ACTIONS(59),
    [sym_keyword_readonly] = ACTIONS(59),
    [sym_keyword_type] = ACTIONS(59),
    [sym_keyword_default] = ACTIONS(59),
    [sym_keyword_assert] = ACTIONS(59),
    [sym_keyword_permissions] = ACTIONS(59),
    [sym_keyword_for] = ACTIONS(59),
    [sym_keyword_comment] = ACTIONS(59),
    [anon_sym_COMMA] = ACTIONS(59),
    [anon_sym_RPAREN] = ACTIONS(59),
    [anon_sym_RBRACE] = ACTIONS(59),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(61),
    [anon_sym_LT_PIPE] = ACTIONS(59),
    [anon_sym_AMP_AMP] = ACTIONS(59),
    [anon_sym_PIPE_PIPE] = ACTIONS(59),
    [anon_sym_QMARK_QMARK] = ACTIONS(59),
    [anon_sym_QMARK_COLON] = ACTIONS(59),
    [anon_sym_BANG_EQ] = ACTIONS(59),
    [anon_sym_EQ_EQ] = ACTIONS(59),
    [anon_sym_QMARK_EQ] = ACTIONS(59),
    [anon_sym_STAR_EQ] = ACTIONS(59),
    [anon_sym_TILDE] = ACTIONS(59),
    [anon_sym_BANG_TILDE] = ACTIONS(59),
    [anon_sym_STAR_TILDE] = ACTIONS(59),
    [anon_sym_LT_EQ] = ACTIONS(59),
    [anon_sym_GT_EQ] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_PLUS_EQ] = ACTIONS(59),
    [anon_sym_DASH_EQ] = ACTIONS(59),
    [anon_sym_u00d7] = ACTIONS(59),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_u00f7] = ACTIONS(59),
    [anon_sym_STAR_STAR] = ACTIONS(59),
    [anon_sym_u220b] = ACTIONS(59),
    [anon_sym_u220c] = ACTIONS(59),
    [anon_sym_u2287] = ACTIONS(59),
    [anon_sym_u2283] = ACTIONS(59),
    [anon_sym_u2285] = ACTIONS(59),
    [anon_sym_u2208] = ACTIONS(59),
    [anon_sym_u2209] = ACTIONS(59),
    [anon_sym_u2286] = ACTIONS(59),
    [anon_sym_u2282] = ACTIONS(59),
    [anon_sym_u2284] = ACTIONS(59),
    [anon_sym_AT_AT] = ACTIONS(59),
  },
  [193] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(275),
    [sym_keyword_value] = ACTIONS(275),
    [sym_keyword_explain] = ACTIONS(275),
    [sym_keyword_parallel] = ACTIONS(275),
    [sym_keyword_timeout] = ACTIONS(275),
    [sym_keyword_fetch] = ACTIONS(275),
    [sym_keyword_limit] = ACTIONS(275),
    [sym_keyword_rand] = ACTIONS(275),
    [sym_keyword_collate] = ACTIONS(275),
    [sym_keyword_numeric] = ACTIONS(275),
    [sym_keyword_asc] = ACTIONS(275),
    [sym_keyword_desc] = ACTIONS(275),
    [sym_keyword_and] = ACTIONS(275),
    [sym_keyword_or] = ACTIONS(275),
    [sym_keyword_is] = ACTIONS(275),
    [sym_keyword_not] = ACTIONS(277),
    [sym_keyword_contains] = ACTIONS(275),
    [sym_keyword_contains_not] = ACTIONS(275),
    [sym_keyword_contains_all] = ACTIONS(275),
    [sym_keyword_contains_any] = ACTIONS(275),
    [sym_keyword_contains_none] = ACTIONS(275),
    [sym_keyword_inside] = ACTIONS(275),
    [sym_keyword_in] = ACTIONS(277),
    [sym_keyword_not_inside] = ACTIONS(275),
    [sym_keyword_all_inside] = ACTIONS(275),
    [sym_keyword_any_inside] = ACTIONS(275),
    [sym_keyword_none_inside] = ACTIONS(275),
    [sym_keyword_outside] = ACTIONS(275),
    [sym_keyword_intersects] = ACTIONS(275),
    [sym_keyword_flexible] = ACTIONS(275),
    [sym_keyword_readonly] = ACTIONS(275),
    [sym_keyword_type] = ACTIONS(275),
    [sym_keyword_default] = ACTIONS(275),
    [sym_keyword_assert] = ACTIONS(275),
    [sym_keyword_permissions] = ACTIONS(275),
    [sym_keyword_for] = ACTIONS(275),
    [sym_keyword_comment] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(275),
    [anon_sym_RPAREN] = ACTIONS(275),
    [anon_sym_RBRACE] = ACTIONS(275),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LT] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(277),
    [anon_sym_EQ] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_LT_PIPE] = ACTIONS(275),
    [anon_sym_AMP_AMP] = ACTIONS(275),
    [anon_sym_PIPE_PIPE] = ACTIONS(275),
    [anon_sym_QMARK_QMARK] = ACTIONS(275),
    [anon_sym_QMARK_COLON] = ACTIONS(275),
    [anon_sym_BANG_EQ] = ACTIONS(275),
    [anon_sym_EQ_EQ] = ACTIONS(275),
    [anon_sym_QMARK_EQ] = ACTIONS(275),
    [anon_sym_STAR_EQ] = ACTIONS(275),
    [anon_sym_TILDE] = ACTIONS(275),
    [anon_sym_BANG_TILDE] = ACTIONS(275),
    [anon_sym_STAR_TILDE] = ACTIONS(275),
    [anon_sym_LT_EQ] = ACTIONS(275),
    [anon_sym_GT_EQ] = ACTIONS(275),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_PLUS_EQ] = ACTIONS(275),
    [anon_sym_DASH_EQ] = ACTIONS(275),
    [anon_sym_u00d7] = ACTIONS(275),
    [anon_sym_SLASH] = ACTIONS(277),
    [anon_sym_u00f7] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(275),
    [anon_sym_u220b] = ACTIONS(275),
    [anon_sym_u220c] = ACTIONS(275),
    [anon_sym_u2287] = ACTIONS(275),
    [anon_sym_u2283] = ACTIONS(275),
    [anon_sym_u2285] = ACTIONS(275),
    [anon_sym_u2208] = ACTIONS(275),
    [anon_sym_u2209] = ACTIONS(275),
    [anon_sym_u2286] = ACTIONS(275),
    [anon_sym_u2282] = ACTIONS(275),
    [anon_sym_u2284] = ACTIONS(275),
    [anon_sym_AT_AT] = ACTIONS(275),
  },
  [194] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(251),
    [sym_keyword_value] = ACTIONS(251),
    [sym_keyword_explain] = ACTIONS(251),
    [sym_keyword_parallel] = ACTIONS(251),
    [sym_keyword_timeout] = ACTIONS(251),
    [sym_keyword_fetch] = ACTIONS(251),
    [sym_keyword_limit] = ACTIONS(251),
    [sym_keyword_rand] = ACTIONS(251),
    [sym_keyword_collate] = ACTIONS(251),
    [sym_keyword_numeric] = ACTIONS(251),
    [sym_keyword_asc] = ACTIONS(251),
    [sym_keyword_desc] = ACTIONS(251),
    [sym_keyword_and] = ACTIONS(251),
    [sym_keyword_or] = ACTIONS(251),
    [sym_keyword_is] = ACTIONS(251),
    [sym_keyword_not] = ACTIONS(253),
    [sym_keyword_contains] = ACTIONS(251),
    [sym_keyword_contains_not] = ACTIONS(251),
    [sym_keyword_contains_all] = ACTIONS(251),
    [sym_keyword_contains_any] = ACTIONS(251),
    [sym_keyword_contains_none] = ACTIONS(251),
    [sym_keyword_inside] = ACTIONS(251),
    [sym_keyword_in] = ACTIONS(253),
    [sym_keyword_not_inside] = ACTIONS(251),
    [sym_keyword_all_inside] = ACTIONS(251),
    [sym_keyword_any_inside] = ACTIONS(251),
    [sym_keyword_none_inside] = ACTIONS(251),
    [sym_keyword_outside] = ACTIONS(251),
    [sym_keyword_intersects] = ACTIONS(251),
    [sym_keyword_flexible] = ACTIONS(251),
    [sym_keyword_readonly] = ACTIONS(251),
    [sym_keyword_type] = ACTIONS(251),
    [sym_keyword_default] = ACTIONS(251),
    [sym_keyword_assert] = ACTIONS(251),
    [sym_keyword_permissions] = ACTIONS(251),
    [sym_keyword_for] = ACTIONS(251),
    [sym_keyword_comment] = ACTIONS(251),
    [anon_sym_COMMA] = ACTIONS(251),
    [anon_sym_RPAREN] = ACTIONS(251),
    [anon_sym_RBRACE] = ACTIONS(251),
    [anon_sym_STAR] = ACTIONS(253),
    [anon_sym_LT] = ACTIONS(253),
    [anon_sym_GT] = ACTIONS(253),
    [anon_sym_EQ] = ACTIONS(253),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_AT] = ACTIONS(253),
    [anon_sym_LT_PIPE] = ACTIONS(251),
    [anon_sym_AMP_AMP] = ACTIONS(251),
    [anon_sym_PIPE_PIPE] = ACTIONS(251),
    [anon_sym_QMARK_QMARK] = ACTIONS(251),
    [anon_sym_QMARK_COLON] = ACTIONS(251),
    [anon_sym_BANG_EQ] = ACTIONS(251),
    [anon_sym_EQ_EQ] = ACTIONS(251),
    [anon_sym_QMARK_EQ] = ACTIONS(251),
    [anon_sym_STAR_EQ] = ACTIONS(251),
    [anon_sym_TILDE] = ACTIONS(251),
    [anon_sym_BANG_TILDE] = ACTIONS(251),
    [anon_sym_STAR_TILDE] = ACTIONS(251),
    [anon_sym_LT_EQ] = ACTIONS(251),
    [anon_sym_GT_EQ] = ACTIONS(251),
    [anon_sym_PLUS] = ACTIONS(253),
    [anon_sym_PLUS_EQ] = ACTIONS(251),
    [anon_sym_DASH_EQ] = ACTIONS(251),
    [anon_sym_u00d7] = ACTIONS(251),
    [anon_sym_SLASH] = ACTIONS(253),
    [anon_sym_u00f7] = ACTIONS(251),
    [anon_sym_STAR_STAR] = ACTIONS(251),
    [anon_sym_u220b] = ACTIONS(251),
    [anon_sym_u220c] = ACTIONS(251),
    [anon_sym_u2287] = ACTIONS(251),
    [anon_sym_u2283] = ACTIONS(251),
    [anon_sym_u2285] = ACTIONS(251),
    [anon_sym_u2208] = ACTIONS(251),
    [anon_sym_u2209] = ACTIONS(251),
    [anon_sym_u2286] = ACTIONS(251),
    [anon_sym_u2282] = ACTIONS(251),
    [anon_sym_u2284] = ACTIONS(251),
    [anon_sym_AT_AT] = ACTIONS(251),
  },
  [195] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(255),
    [sym_keyword_value] = ACTIONS(255),
    [sym_keyword_explain] = ACTIONS(255),
    [sym_keyword_parallel] = ACTIONS(255),
    [sym_keyword_timeout] = ACTIONS(255),
    [sym_keyword_fetch] = ACTIONS(255),
    [sym_keyword_limit] = ACTIONS(255),
    [sym_keyword_rand] = ACTIONS(255),
    [sym_keyword_collate] = ACTIONS(255),
    [sym_keyword_numeric] = ACTIONS(255),
    [sym_keyword_asc] = ACTIONS(255),
    [sym_keyword_desc] = ACTIONS(255),
    [sym_keyword_and] = ACTIONS(255),
    [sym_keyword_or] = ACTIONS(255),
    [sym_keyword_is] = ACTIONS(255),
    [sym_keyword_not] = ACTIONS(257),
    [sym_keyword_contains] = ACTIONS(255),
    [sym_keyword_contains_not] = ACTIONS(255),
    [sym_keyword_contains_all] = ACTIONS(255),
    [sym_keyword_contains_any] = ACTIONS(255),
    [sym_keyword_contains_none] = ACTIONS(255),
    [sym_keyword_inside] = ACTIONS(255),
    [sym_keyword_in] = ACTIONS(257),
    [sym_keyword_not_inside] = ACTIONS(255),
    [sym_keyword_all_inside] = ACTIONS(255),
    [sym_keyword_any_inside] = ACTIONS(255),
    [sym_keyword_none_inside] = ACTIONS(255),
    [sym_keyword_outside] = ACTIONS(255),
    [sym_keyword_intersects] = ACTIONS(255),
    [sym_keyword_flexible] = ACTIONS(255),
    [sym_keyword_readonly] = ACTIONS(255),
    [sym_keyword_type] = ACTIONS(255),
    [sym_keyword_default] = ACTIONS(255),
    [sym_keyword_assert] = ACTIONS(255),
    [sym_keyword_permissions] = ACTIONS(255),
    [sym_keyword_for] = ACTIONS(255),
    [sym_keyword_comment] = ACTIONS(255),
    [anon_sym_COMMA] = ACTIONS(255),
    [anon_sym_RPAREN] = ACTIONS(255),
    [anon_sym_RBRACE] = ACTIONS(255),
    [anon_sym_STAR] = ACTIONS(257),
    [anon_sym_LT] = ACTIONS(257),
    [anon_sym_GT] = ACTIONS(257),
    [anon_sym_EQ] = ACTIONS(257),
    [anon_sym_DASH] = ACTIONS(257),
    [anon_sym_AT] = ACTIONS(257),
    [anon_sym_LT_PIPE] = ACTIONS(255),
    [anon_sym_AMP_AMP] = ACTIONS(255),
    [anon_sym_PIPE_PIPE] = ACTIONS(255),
    [anon_sym_QMARK_QMARK] = ACTIONS(255),
    [anon_sym_QMARK_COLON] = ACTIONS(255),
    [anon_sym_BANG_EQ] = ACTIONS(255),
    [anon_sym_EQ_EQ] = ACTIONS(255),
    [anon_sym_QMARK_EQ] = ACTIONS(255),
    [anon_sym_STAR_EQ] = ACTIONS(255),
    [anon_sym_TILDE] = ACTIONS(255),
    [anon_sym_BANG_TILDE] = ACTIONS(255),
    [anon_sym_STAR_TILDE] = ACTIONS(255),
    [anon_sym_LT_EQ] = ACTIONS(255),
    [anon_sym_GT_EQ] = ACTIONS(255),
    [anon_sym_PLUS] = ACTIONS(257),
    [anon_sym_PLUS_EQ] = ACTIONS(255),
    [anon_sym_DASH_EQ] = ACTIONS(255),
    [anon_sym_u00d7] = ACTIONS(255),
    [anon_sym_SLASH] = ACTIONS(257),
    [anon_sym_u00f7] = ACTIONS(255),
    [anon_sym_STAR_STAR] = ACTIONS(255),
    [anon_sym_u220b] = ACTIONS(255),
    [anon_sym_u220c] = ACTIONS(255),
    [anon_sym_u2287] = ACTIONS(255),
    [anon_sym_u2283] = ACTIONS(255),
    [anon_sym_u2285] = ACTIONS(255),
    [anon_sym_u2208] = ACTIONS(255),
    [anon_sym_u2209] = ACTIONS(255),
    [anon_sym_u2286] = ACTIONS(255),
    [anon_sym_u2282] = ACTIONS(255),
    [anon_sym_u2284] = ACTIONS(255),
    [anon_sym_AT_AT] = ACTIONS(255),
  },
  [196] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(48),
    [ts_builtin_sym_end] = ACTIONS(367),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_return] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_where] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_content] = ACTIONS(369),
    [sym_keyword_merge] = ACTIONS(369),
    [sym_keyword_patch] = ACTIONS(369),
    [sym_keyword_set] = ACTIONS(369),
    [sym_keyword_unset] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [197] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(49),
    [ts_builtin_sym_end] = ACTIONS(210),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_return] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_where] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_content] = ACTIONS(212),
    [sym_keyword_merge] = ACTIONS(212),
    [sym_keyword_patch] = ACTIONS(212),
    [sym_keyword_set] = ACTIONS(212),
    [sym_keyword_unset] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [198] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(50),
    [ts_builtin_sym_end] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_return] = ACTIONS(180),
    [sym_keyword_parallel] = ACTIONS(180),
    [sym_keyword_timeout] = ACTIONS(180),
    [sym_keyword_where] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [sym_keyword_content] = ACTIONS(180),
    [sym_keyword_merge] = ACTIONS(180),
    [sym_keyword_patch] = ACTIONS(180),
    [sym_keyword_set] = ACTIONS(180),
    [sym_keyword_unset] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [199] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(239),
    [sym_keyword_value] = ACTIONS(239),
    [sym_keyword_explain] = ACTIONS(239),
    [sym_keyword_parallel] = ACTIONS(239),
    [sym_keyword_timeout] = ACTIONS(239),
    [sym_keyword_fetch] = ACTIONS(239),
    [sym_keyword_limit] = ACTIONS(239),
    [sym_keyword_rand] = ACTIONS(239),
    [sym_keyword_collate] = ACTIONS(239),
    [sym_keyword_numeric] = ACTIONS(239),
    [sym_keyword_asc] = ACTIONS(239),
    [sym_keyword_desc] = ACTIONS(239),
    [sym_keyword_and] = ACTIONS(239),
    [sym_keyword_or] = ACTIONS(239),
    [sym_keyword_is] = ACTIONS(239),
    [sym_keyword_not] = ACTIONS(241),
    [sym_keyword_contains] = ACTIONS(239),
    [sym_keyword_contains_not] = ACTIONS(239),
    [sym_keyword_contains_all] = ACTIONS(239),
    [sym_keyword_contains_any] = ACTIONS(239),
    [sym_keyword_contains_none] = ACTIONS(239),
    [sym_keyword_inside] = ACTIONS(239),
    [sym_keyword_in] = ACTIONS(241),
    [sym_keyword_not_inside] = ACTIONS(239),
    [sym_keyword_all_inside] = ACTIONS(239),
    [sym_keyword_any_inside] = ACTIONS(239),
    [sym_keyword_none_inside] = ACTIONS(239),
    [sym_keyword_outside] = ACTIONS(239),
    [sym_keyword_intersects] = ACTIONS(239),
    [sym_keyword_flexible] = ACTIONS(239),
    [sym_keyword_readonly] = ACTIONS(239),
    [sym_keyword_type] = ACTIONS(239),
    [sym_keyword_default] = ACTIONS(239),
    [sym_keyword_assert] = ACTIONS(239),
    [sym_keyword_permissions] = ACTIONS(239),
    [sym_keyword_for] = ACTIONS(239),
    [sym_keyword_comment] = ACTIONS(239),
    [anon_sym_COMMA] = ACTIONS(239),
    [anon_sym_RPAREN] = ACTIONS(239),
    [anon_sym_RBRACE] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(241),
    [anon_sym_LT] = ACTIONS(241),
    [anon_sym_GT] = ACTIONS(241),
    [anon_sym_EQ] = ACTIONS(241),
    [anon_sym_DASH] = ACTIONS(241),
    [anon_sym_AT] = ACTIONS(241),
    [anon_sym_LT_PIPE] = ACTIONS(239),
    [anon_sym_AMP_AMP] = ACTIONS(239),
    [anon_sym_PIPE_PIPE] = ACTIONS(239),
    [anon_sym_QMARK_QMARK] = ACTIONS(239),
    [anon_sym_QMARK_COLON] = ACTIONS(239),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(239),
    [anon_sym_QMARK_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_TILDE] = ACTIONS(239),
    [anon_sym_BANG_TILDE] = ACTIONS(239),
    [anon_sym_STAR_TILDE] = ACTIONS(239),
    [anon_sym_LT_EQ] = ACTIONS(239),
    [anon_sym_GT_EQ] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(241),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_u00d7] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(241),
    [anon_sym_u00f7] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_u220b] = ACTIONS(239),
    [anon_sym_u220c] = ACTIONS(239),
    [anon_sym_u2287] = ACTIONS(239),
    [anon_sym_u2283] = ACTIONS(239),
    [anon_sym_u2285] = ACTIONS(239),
    [anon_sym_u2208] = ACTIONS(239),
    [anon_sym_u2209] = ACTIONS(239),
    [anon_sym_u2286] = ACTIONS(239),
    [anon_sym_u2282] = ACTIONS(239),
    [anon_sym_u2284] = ACTIONS(239),
    [anon_sym_AT_AT] = ACTIONS(239),
  },
  [200] = {
    [sym_array] = STATE(226),
    [sym_object] = STATE(226),
    [sym_record_id_value] = STATE(256),
    [ts_builtin_sym_end] = ACTIONS(210),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_as] = ACTIONS(212),
    [sym_keyword_group] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_drop] = ACTIONS(212),
    [sym_keyword_schemafull] = ACTIONS(212),
    [sym_keyword_schemaless] = ACTIONS(212),
    [sym_keyword_changefeed] = ACTIONS(212),
    [sym_keyword_type] = ACTIONS(212),
    [sym_keyword_permissions] = ACTIONS(212),
    [sym_keyword_comment] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(398),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(400),
    [sym_record_id_ident] = ACTIONS(400),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [201] = {
    [sym_array] = STATE(101),
    [sym_object] = STATE(101),
    [sym_record_id_value] = STATE(103),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_value] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_flexible] = ACTIONS(369),
    [sym_keyword_readonly] = ACTIONS(369),
    [sym_keyword_type] = ACTIONS(369),
    [sym_keyword_default] = ACTIONS(369),
    [sym_keyword_assert] = ACTIONS(369),
    [sym_keyword_permissions] = ACTIONS(369),
    [sym_keyword_comment] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_RPAREN] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(359),
    [anon_sym_RBRACE] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(361),
    [sym_record_id_ident] = ACTIONS(361),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [202] = {
    [sym_array] = STATE(226),
    [sym_object] = STATE(226),
    [sym_record_id_value] = STATE(254),
    [ts_builtin_sym_end] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_as] = ACTIONS(180),
    [sym_keyword_group] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [sym_keyword_drop] = ACTIONS(180),
    [sym_keyword_schemafull] = ACTIONS(180),
    [sym_keyword_schemaless] = ACTIONS(180),
    [sym_keyword_changefeed] = ACTIONS(180),
    [sym_keyword_type] = ACTIONS(180),
    [sym_keyword_permissions] = ACTIONS(180),
    [sym_keyword_comment] = ACTIONS(180),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(398),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(400),
    [sym_record_id_ident] = ACTIONS(400),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [203] = {
    [sym_array] = STATE(226),
    [sym_object] = STATE(226),
    [sym_record_id_value] = STATE(259),
    [ts_builtin_sym_end] = ACTIONS(367),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_as] = ACTIONS(369),
    [sym_keyword_group] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_drop] = ACTIONS(369),
    [sym_keyword_schemafull] = ACTIONS(369),
    [sym_keyword_schemaless] = ACTIONS(369),
    [sym_keyword_changefeed] = ACTIONS(369),
    [sym_keyword_type] = ACTIONS(369),
    [sym_keyword_permissions] = ACTIONS(369),
    [sym_keyword_comment] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(398),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(400),
    [sym_record_id_ident] = ACTIONS(400),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [204] = {
    [sym_array] = STATE(241),
    [sym_object] = STATE(241),
    [sym_record_id_value] = STATE(286),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_explain] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_fetch] = ACTIONS(369),
    [sym_keyword_limit] = ACTIONS(369),
    [sym_keyword_order] = ACTIONS(369),
    [sym_keyword_split] = ACTIONS(369),
    [sym_keyword_group] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_RPAREN] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(363),
    [anon_sym_RBRACE] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(365),
    [sym_record_id_ident] = ACTIONS(365),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [205] = {
    [sym_array] = STATE(226),
    [sym_object] = STATE(226),
    [sym_record_id_value] = STATE(259),
    [ts_builtin_sym_end] = ACTIONS(367),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_as] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_drop] = ACTIONS(369),
    [sym_keyword_schemafull] = ACTIONS(369),
    [sym_keyword_schemaless] = ACTIONS(369),
    [sym_keyword_changefeed] = ACTIONS(369),
    [sym_keyword_type] = ACTIONS(369),
    [sym_keyword_permissions] = ACTIONS(369),
    [sym_keyword_for] = ACTIONS(369),
    [sym_keyword_comment] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(398),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(400),
    [sym_record_id_ident] = ACTIONS(400),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [206] = {
    [sym_array] = STATE(226),
    [sym_object] = STATE(226),
    [sym_record_id_value] = STATE(256),
    [ts_builtin_sym_end] = ACTIONS(210),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_as] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_drop] = ACTIONS(212),
    [sym_keyword_schemafull] = ACTIONS(212),
    [sym_keyword_schemaless] = ACTIONS(212),
    [sym_keyword_changefeed] = ACTIONS(212),
    [sym_keyword_type] = ACTIONS(212),
    [sym_keyword_permissions] = ACTIONS(212),
    [sym_keyword_for] = ACTIONS(212),
    [sym_keyword_comment] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(398),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(400),
    [sym_record_id_ident] = ACTIONS(400),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [207] = {
    [sym_array] = STATE(226),
    [sym_object] = STATE(226),
    [sym_record_id_value] = STATE(254),
    [ts_builtin_sym_end] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_as] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [sym_keyword_drop] = ACTIONS(180),
    [sym_keyword_schemafull] = ACTIONS(180),
    [sym_keyword_schemaless] = ACTIONS(180),
    [sym_keyword_changefeed] = ACTIONS(180),
    [sym_keyword_type] = ACTIONS(180),
    [sym_keyword_permissions] = ACTIONS(180),
    [sym_keyword_for] = ACTIONS(180),
    [sym_keyword_comment] = ACTIONS(180),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(398),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(400),
    [sym_record_id_ident] = ACTIONS(400),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [208] = {
    [sym_array] = STATE(241),
    [sym_object] = STATE(241),
    [sym_record_id_value] = STATE(283),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_explain] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_fetch] = ACTIONS(212),
    [sym_keyword_limit] = ACTIONS(212),
    [sym_keyword_order] = ACTIONS(212),
    [sym_keyword_split] = ACTIONS(212),
    [sym_keyword_group] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(363),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(365),
    [sym_record_id_ident] = ACTIONS(365),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [209] = {
    [sym_array] = STATE(241),
    [sym_object] = STATE(241),
    [sym_record_id_value] = STATE(278),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_explain] = ACTIONS(180),
    [sym_keyword_parallel] = ACTIONS(180),
    [sym_keyword_timeout] = ACTIONS(180),
    [sym_keyword_fetch] = ACTIONS(180),
    [sym_keyword_limit] = ACTIONS(180),
    [sym_keyword_order] = ACTIONS(180),
    [sym_keyword_split] = ACTIONS(180),
    [sym_keyword_group] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(363),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(365),
    [sym_record_id_ident] = ACTIONS(365),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [210] = {
    [sym_array] = STATE(101),
    [sym_object] = STATE(101),
    [sym_record_id_value] = STATE(113),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_value] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [sym_keyword_flexible] = ACTIONS(180),
    [sym_keyword_readonly] = ACTIONS(180),
    [sym_keyword_type] = ACTIONS(180),
    [sym_keyword_default] = ACTIONS(180),
    [sym_keyword_assert] = ACTIONS(180),
    [sym_keyword_permissions] = ACTIONS(180),
    [sym_keyword_comment] = ACTIONS(180),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(359),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(361),
    [sym_record_id_ident] = ACTIONS(361),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [211] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(48),
    [ts_builtin_sym_end] = ACTIONS(367),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_value] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_flexible] = ACTIONS(369),
    [sym_keyword_readonly] = ACTIONS(369),
    [sym_keyword_type] = ACTIONS(369),
    [sym_keyword_default] = ACTIONS(369),
    [sym_keyword_assert] = ACTIONS(369),
    [sym_keyword_permissions] = ACTIONS(369),
    [sym_keyword_for] = ACTIONS(369),
    [sym_keyword_comment] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [212] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(49),
    [ts_builtin_sym_end] = ACTIONS(210),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_value] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_flexible] = ACTIONS(212),
    [sym_keyword_readonly] = ACTIONS(212),
    [sym_keyword_type] = ACTIONS(212),
    [sym_keyword_default] = ACTIONS(212),
    [sym_keyword_assert] = ACTIONS(212),
    [sym_keyword_permissions] = ACTIONS(212),
    [sym_keyword_for] = ACTIONS(212),
    [sym_keyword_comment] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [213] = {
    [sym_array] = STATE(101),
    [sym_object] = STATE(101),
    [sym_record_id_value] = STATE(121),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_value] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_flexible] = ACTIONS(212),
    [sym_keyword_readonly] = ACTIONS(212),
    [sym_keyword_type] = ACTIONS(212),
    [sym_keyword_default] = ACTIONS(212),
    [sym_keyword_assert] = ACTIONS(212),
    [sym_keyword_permissions] = ACTIONS(212),
    [sym_keyword_comment] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(359),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(361),
    [sym_record_id_ident] = ACTIONS(361),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [214] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(50),
    [ts_builtin_sym_end] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_value] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [sym_keyword_flexible] = ACTIONS(180),
    [sym_keyword_readonly] = ACTIONS(180),
    [sym_keyword_type] = ACTIONS(180),
    [sym_keyword_default] = ACTIONS(180),
    [sym_keyword_assert] = ACTIONS(180),
    [sym_keyword_permissions] = ACTIONS(180),
    [sym_keyword_for] = ACTIONS(180),
    [sym_keyword_comment] = ACTIONS(180),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [215] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(48),
    [ts_builtin_sym_end] = ACTIONS(367),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_value] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_flexible] = ACTIONS(369),
    [sym_keyword_readonly] = ACTIONS(369),
    [sym_keyword_type] = ACTIONS(369),
    [sym_keyword_default] = ACTIONS(369),
    [sym_keyword_assert] = ACTIONS(369),
    [sym_keyword_permissions] = ACTIONS(369),
    [sym_keyword_comment] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [216] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(50),
    [ts_builtin_sym_end] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_value] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [sym_keyword_flexible] = ACTIONS(180),
    [sym_keyword_readonly] = ACTIONS(180),
    [sym_keyword_type] = ACTIONS(180),
    [sym_keyword_default] = ACTIONS(180),
    [sym_keyword_assert] = ACTIONS(180),
    [sym_keyword_permissions] = ACTIONS(180),
    [sym_keyword_comment] = ACTIONS(180),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [217] = {
    [sym_array] = STATE(292),
    [sym_object] = STATE(292),
    [sym_record_id_value] = STATE(317),
    [ts_builtin_sym_end] = ACTIONS(210),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_explain] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_fetch] = ACTIONS(212),
    [sym_keyword_limit] = ACTIONS(212),
    [sym_keyword_order] = ACTIONS(212),
    [sym_keyword_split] = ACTIONS(212),
    [sym_keyword_group] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(442),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(444),
    [sym_record_id_ident] = ACTIONS(444),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [218] = {
    [sym_array] = STATE(292),
    [sym_object] = STATE(292),
    [sym_record_id_value] = STATE(320),
    [ts_builtin_sym_end] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_explain] = ACTIONS(180),
    [sym_keyword_parallel] = ACTIONS(180),
    [sym_keyword_timeout] = ACTIONS(180),
    [sym_keyword_fetch] = ACTIONS(180),
    [sym_keyword_limit] = ACTIONS(180),
    [sym_keyword_order] = ACTIONS(180),
    [sym_keyword_split] = ACTIONS(180),
    [sym_keyword_group] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(442),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(444),
    [sym_record_id_ident] = ACTIONS(444),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [219] = {
    [sym_array] = STATE(292),
    [sym_object] = STATE(292),
    [sym_record_id_value] = STATE(312),
    [ts_builtin_sym_end] = ACTIONS(367),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_explain] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_fetch] = ACTIONS(369),
    [sym_keyword_limit] = ACTIONS(369),
    [sym_keyword_order] = ACTIONS(369),
    [sym_keyword_split] = ACTIONS(369),
    [sym_keyword_group] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(442),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(444),
    [sym_record_id_ident] = ACTIONS(444),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [220] = {
    [aux_sym_duration_repeat1] = STATE(221),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(99),
    [sym_keyword_explain] = ACTIONS(99),
    [sym_keyword_parallel] = ACTIONS(99),
    [sym_keyword_timeout] = ACTIONS(99),
    [sym_keyword_fetch] = ACTIONS(99),
    [sym_keyword_limit] = ACTIONS(99),
    [sym_keyword_order] = ACTIONS(99),
    [sym_keyword_with] = ACTIONS(99),
    [sym_keyword_where] = ACTIONS(99),
    [sym_keyword_split] = ACTIONS(99),
    [sym_keyword_group] = ACTIONS(99),
    [sym_keyword_and] = ACTIONS(99),
    [sym_keyword_or] = ACTIONS(101),
    [sym_keyword_is] = ACTIONS(99),
    [sym_keyword_not] = ACTIONS(101),
    [sym_keyword_contains] = ACTIONS(99),
    [sym_keyword_contains_not] = ACTIONS(99),
    [sym_keyword_contains_all] = ACTIONS(99),
    [sym_keyword_contains_any] = ACTIONS(99),
    [sym_keyword_contains_none] = ACTIONS(99),
    [sym_keyword_inside] = ACTIONS(99),
    [sym_keyword_in] = ACTIONS(101),
    [sym_keyword_not_inside] = ACTIONS(99),
    [sym_keyword_all_inside] = ACTIONS(99),
    [sym_keyword_any_inside] = ACTIONS(99),
    [sym_keyword_none_inside] = ACTIONS(99),
    [sym_keyword_outside] = ACTIONS(99),
    [sym_keyword_intersects] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_DASH_GT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(99),
    [anon_sym_RPAREN] = ACTIONS(99),
    [anon_sym_RBRACE] = ACTIONS(99),
    [anon_sym_LT_DASH] = ACTIONS(101),
    [anon_sym_LT_DASH_GT] = ACTIONS(99),
    [anon_sym_STAR] = ACTIONS(101),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LT] = ACTIONS(101),
    [anon_sym_GT] = ACTIONS(101),
    [anon_sym_EQ] = ACTIONS(101),
    [sym_duration_part] = ACTIONS(468),
    [anon_sym_DASH] = ACTIONS(101),
    [anon_sym_AT] = ACTIONS(101),
    [anon_sym_LT_PIPE] = ACTIONS(99),
    [anon_sym_AMP_AMP] = ACTIONS(99),
    [anon_sym_PIPE_PIPE] = ACTIONS(99),
    [anon_sym_QMARK_QMARK] = ACTIONS(99),
    [anon_sym_QMARK_COLON] = ACTIONS(99),
    [anon_sym_BANG_EQ] = ACTIONS(99),
    [anon_sym_EQ_EQ] = ACTIONS(99),
    [anon_sym_QMARK_EQ] = ACTIONS(99),
    [anon_sym_STAR_EQ] = ACTIONS(99),
    [anon_sym_TILDE] = ACTIONS(99),
    [anon_sym_BANG_TILDE] = ACTIONS(99),
    [anon_sym_STAR_TILDE] = ACTIONS(99),
    [anon_sym_LT_EQ] = ACTIONS(99),
    [anon_sym_GT_EQ] = ACTIONS(99),
    [anon_sym_PLUS] = ACTIONS(101),
    [anon_sym_PLUS_EQ] = ACTIONS(99),
    [anon_sym_DASH_EQ] = ACTIONS(99),
    [anon_sym_u00d7] = ACTIONS(99),
    [anon_sym_SLASH] = ACTIONS(101),
    [anon_sym_u00f7] = ACTIONS(99),
    [anon_sym_STAR_STAR] = ACTIONS(99),
    [anon_sym_u220b] = ACTIONS(99),
    [anon_sym_u220c] = ACTIONS(99),
    [anon_sym_u2287] = ACTIONS(99),
    [anon_sym_u2283] = ACTIONS(99),
    [anon_sym_u2285] = ACTIONS(99),
    [anon_sym_u2208] = ACTIONS(99),
    [anon_sym_u2209] = ACTIONS(99),
    [anon_sym_u2286] = ACTIONS(99),
    [anon_sym_u2282] = ACTIONS(99),
    [anon_sym_u2284] = ACTIONS(99),
    [anon_sym_AT_AT] = ACTIONS(99),
  },
  [221] = {
    [aux_sym_duration_repeat1] = STATE(221),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(105),
    [sym_keyword_explain] = ACTIONS(105),
    [sym_keyword_parallel] = ACTIONS(105),
    [sym_keyword_timeout] = ACTIONS(105),
    [sym_keyword_fetch] = ACTIONS(105),
    [sym_keyword_limit] = ACTIONS(105),
    [sym_keyword_order] = ACTIONS(105),
    [sym_keyword_with] = ACTIONS(105),
    [sym_keyword_where] = ACTIONS(105),
    [sym_keyword_split] = ACTIONS(105),
    [sym_keyword_group] = ACTIONS(105),
    [sym_keyword_and] = ACTIONS(105),
    [sym_keyword_or] = ACTIONS(107),
    [sym_keyword_is] = ACTIONS(105),
    [sym_keyword_not] = ACTIONS(107),
    [sym_keyword_contains] = ACTIONS(105),
    [sym_keyword_contains_not] = ACTIONS(105),
    [sym_keyword_contains_all] = ACTIONS(105),
    [sym_keyword_contains_any] = ACTIONS(105),
    [sym_keyword_contains_none] = ACTIONS(105),
    [sym_keyword_inside] = ACTIONS(105),
    [sym_keyword_in] = ACTIONS(107),
    [sym_keyword_not_inside] = ACTIONS(105),
    [sym_keyword_all_inside] = ACTIONS(105),
    [sym_keyword_any_inside] = ACTIONS(105),
    [sym_keyword_none_inside] = ACTIONS(105),
    [sym_keyword_outside] = ACTIONS(105),
    [sym_keyword_intersects] = ACTIONS(105),
    [anon_sym_COMMA] = ACTIONS(105),
    [anon_sym_DASH_GT] = ACTIONS(105),
    [anon_sym_LBRACK] = ACTIONS(105),
    [anon_sym_RPAREN] = ACTIONS(105),
    [anon_sym_RBRACE] = ACTIONS(105),
    [anon_sym_LT_DASH] = ACTIONS(107),
    [anon_sym_LT_DASH_GT] = ACTIONS(105),
    [anon_sym_STAR] = ACTIONS(107),
    [anon_sym_DOT] = ACTIONS(105),
    [anon_sym_LT] = ACTIONS(107),
    [anon_sym_GT] = ACTIONS(107),
    [anon_sym_EQ] = ACTIONS(107),
    [sym_duration_part] = ACTIONS(470),
    [anon_sym_DASH] = ACTIONS(107),
    [anon_sym_AT] = ACTIONS(107),
    [anon_sym_LT_PIPE] = ACTIONS(105),
    [anon_sym_AMP_AMP] = ACTIONS(105),
    [anon_sym_PIPE_PIPE] = ACTIONS(105),
    [anon_sym_QMARK_QMARK] = ACTIONS(105),
    [anon_sym_QMARK_COLON] = ACTIONS(105),
    [anon_sym_BANG_EQ] = ACTIONS(105),
    [anon_sym_EQ_EQ] = ACTIONS(105),
    [anon_sym_QMARK_EQ] = ACTIONS(105),
    [anon_sym_STAR_EQ] = ACTIONS(105),
    [anon_sym_TILDE] = ACTIONS(105),
    [anon_sym_BANG_TILDE] = ACTIONS(105),
    [anon_sym_STAR_TILDE] = ACTIONS(105),
    [anon_sym_LT_EQ] = ACTIONS(105),
    [anon_sym_GT_EQ] = ACTIONS(105),
    [anon_sym_PLUS] = ACTIONS(107),
    [anon_sym_PLUS_EQ] = ACTIONS(105),
    [anon_sym_DASH_EQ] = ACTIONS(105),
    [anon_sym_u00d7] = ACTIONS(105),
    [anon_sym_SLASH] = ACTIONS(107),
    [anon_sym_u00f7] = ACTIONS(105),
    [anon_sym_STAR_STAR] = ACTIONS(105),
    [anon_sym_u220b] = ACTIONS(105),
    [anon_sym_u220c] = ACTIONS(105),
    [anon_sym_u2287] = ACTIONS(105),
    [anon_sym_u2283] = ACTIONS(105),
    [anon_sym_u2285] = ACTIONS(105),
    [anon_sym_u2208] = ACTIONS(105),
    [anon_sym_u2209] = ACTIONS(105),
    [anon_sym_u2286] = ACTIONS(105),
    [anon_sym_u2282] = ACTIONS(105),
    [anon_sym_u2284] = ACTIONS(105),
    [anon_sym_AT_AT] = ACTIONS(105),
  },
  [222] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(49),
    [ts_builtin_sym_end] = ACTIONS(210),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_value] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_flexible] = ACTIONS(212),
    [sym_keyword_readonly] = ACTIONS(212),
    [sym_keyword_type] = ACTIONS(212),
    [sym_keyword_default] = ACTIONS(212),
    [sym_keyword_assert] = ACTIONS(212),
    [sym_keyword_permissions] = ACTIONS(212),
    [sym_keyword_comment] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [223] = {
    [ts_builtin_sym_end] = ACTIONS(126),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(126),
    [sym_keyword_as] = ACTIONS(126),
    [sym_keyword_where] = ACTIONS(126),
    [sym_keyword_group] = ACTIONS(126),
    [sym_keyword_and] = ACTIONS(126),
    [sym_keyword_or] = ACTIONS(126),
    [sym_keyword_is] = ACTIONS(126),
    [sym_keyword_not] = ACTIONS(128),
    [sym_keyword_contains] = ACTIONS(126),
    [sym_keyword_contains_not] = ACTIONS(126),
    [sym_keyword_contains_all] = ACTIONS(126),
    [sym_keyword_contains_any] = ACTIONS(126),
    [sym_keyword_contains_none] = ACTIONS(126),
    [sym_keyword_inside] = ACTIONS(126),
    [sym_keyword_in] = ACTIONS(128),
    [sym_keyword_not_inside] = ACTIONS(126),
    [sym_keyword_all_inside] = ACTIONS(126),
    [sym_keyword_any_inside] = ACTIONS(126),
    [sym_keyword_none_inside] = ACTIONS(126),
    [sym_keyword_outside] = ACTIONS(126),
    [sym_keyword_intersects] = ACTIONS(126),
    [sym_keyword_drop] = ACTIONS(126),
    [sym_keyword_schemafull] = ACTIONS(126),
    [sym_keyword_schemaless] = ACTIONS(126),
    [sym_keyword_changefeed] = ACTIONS(126),
    [sym_keyword_type] = ACTIONS(126),
    [sym_keyword_permissions] = ACTIONS(126),
    [sym_keyword_for] = ACTIONS(126),
    [sym_keyword_comment] = ACTIONS(126),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_DASH_GT] = ACTIONS(126),
    [anon_sym_LBRACK] = ACTIONS(126),
    [anon_sym_LT_DASH] = ACTIONS(128),
    [anon_sym_LT_DASH_GT] = ACTIONS(126),
    [anon_sym_STAR] = ACTIONS(128),
    [anon_sym_DOT] = ACTIONS(128),
    [anon_sym_LT] = ACTIONS(128),
    [anon_sym_GT] = ACTIONS(128),
    [anon_sym_DOT_DOT] = ACTIONS(126),
    [anon_sym_EQ] = ACTIONS(128),
    [anon_sym_DASH] = ACTIONS(128),
    [anon_sym_AT] = ACTIONS(128),
    [anon_sym_LT_PIPE] = ACTIONS(126),
    [anon_sym_AMP_AMP] = ACTIONS(126),
    [anon_sym_PIPE_PIPE] = ACTIONS(126),
    [anon_sym_QMARK_QMARK] = ACTIONS(126),
    [anon_sym_QMARK_COLON] = ACTIONS(126),
    [anon_sym_BANG_EQ] = ACTIONS(126),
    [anon_sym_EQ_EQ] = ACTIONS(126),
    [anon_sym_QMARK_EQ] = ACTIONS(126),
    [anon_sym_STAR_EQ] = ACTIONS(126),
    [anon_sym_TILDE] = ACTIONS(126),
    [anon_sym_BANG_TILDE] = ACTIONS(126),
    [anon_sym_STAR_TILDE] = ACTIONS(126),
    [anon_sym_LT_EQ] = ACTIONS(126),
    [anon_sym_GT_EQ] = ACTIONS(126),
    [anon_sym_PLUS] = ACTIONS(128),
    [anon_sym_PLUS_EQ] = ACTIONS(126),
    [anon_sym_DASH_EQ] = ACTIONS(126),
    [anon_sym_u00d7] = ACTIONS(126),
    [anon_sym_SLASH] = ACTIONS(128),
    [anon_sym_u00f7] = ACTIONS(126),
    [anon_sym_STAR_STAR] = ACTIONS(126),
    [anon_sym_u220b] = ACTIONS(126),
    [anon_sym_u220c] = ACTIONS(126),
    [anon_sym_u2287] = ACTIONS(126),
    [anon_sym_u2283] = ACTIONS(126),
    [anon_sym_u2285] = ACTIONS(126),
    [anon_sym_u2208] = ACTIONS(126),
    [anon_sym_u2209] = ACTIONS(126),
    [anon_sym_u2286] = ACTIONS(126),
    [anon_sym_u2282] = ACTIONS(126),
    [anon_sym_u2284] = ACTIONS(126),
    [anon_sym_AT_AT] = ACTIONS(126),
  },
  [224] = {
    [ts_builtin_sym_end] = ACTIONS(116),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(116),
    [sym_keyword_as] = ACTIONS(116),
    [sym_keyword_where] = ACTIONS(116),
    [sym_keyword_group] = ACTIONS(116),
    [sym_keyword_and] = ACTIONS(116),
    [sym_keyword_or] = ACTIONS(116),
    [sym_keyword_is] = ACTIONS(116),
    [sym_keyword_not] = ACTIONS(118),
    [sym_keyword_contains] = ACTIONS(116),
    [sym_keyword_contains_not] = ACTIONS(116),
    [sym_keyword_contains_all] = ACTIONS(116),
    [sym_keyword_contains_any] = ACTIONS(116),
    [sym_keyword_contains_none] = ACTIONS(116),
    [sym_keyword_inside] = ACTIONS(116),
    [sym_keyword_in] = ACTIONS(118),
    [sym_keyword_not_inside] = ACTIONS(116),
    [sym_keyword_all_inside] = ACTIONS(116),
    [sym_keyword_any_inside] = ACTIONS(116),
    [sym_keyword_none_inside] = ACTIONS(116),
    [sym_keyword_outside] = ACTIONS(116),
    [sym_keyword_intersects] = ACTIONS(116),
    [sym_keyword_drop] = ACTIONS(116),
    [sym_keyword_schemafull] = ACTIONS(116),
    [sym_keyword_schemaless] = ACTIONS(116),
    [sym_keyword_changefeed] = ACTIONS(116),
    [sym_keyword_type] = ACTIONS(116),
    [sym_keyword_permissions] = ACTIONS(116),
    [sym_keyword_for] = ACTIONS(116),
    [sym_keyword_comment] = ACTIONS(116),
    [anon_sym_COMMA] = ACTIONS(116),
    [anon_sym_DASH_GT] = ACTIONS(116),
    [anon_sym_LBRACK] = ACTIONS(116),
    [anon_sym_LT_DASH] = ACTIONS(118),
    [anon_sym_LT_DASH_GT] = ACTIONS(116),
    [anon_sym_STAR] = ACTIONS(118),
    [anon_sym_DOT] = ACTIONS(118),
    [anon_sym_LT] = ACTIONS(118),
    [anon_sym_GT] = ACTIONS(118),
    [anon_sym_DOT_DOT] = ACTIONS(116),
    [anon_sym_EQ] = ACTIONS(118),
    [anon_sym_DASH] = ACTIONS(118),
    [anon_sym_AT] = ACTIONS(118),
    [anon_sym_LT_PIPE] = ACTIONS(116),
    [anon_sym_AMP_AMP] = ACTIONS(116),
    [anon_sym_PIPE_PIPE] = ACTIONS(116),
    [anon_sym_QMARK_QMARK] = ACTIONS(116),
    [anon_sym_QMARK_COLON] = ACTIONS(116),
    [anon_sym_BANG_EQ] = ACTIONS(116),
    [anon_sym_EQ_EQ] = ACTIONS(116),
    [anon_sym_QMARK_EQ] = ACTIONS(116),
    [anon_sym_STAR_EQ] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(116),
    [anon_sym_BANG_TILDE] = ACTIONS(116),
    [anon_sym_STAR_TILDE] = ACTIONS(116),
    [anon_sym_LT_EQ] = ACTIONS(116),
    [anon_sym_GT_EQ] = ACTIONS(116),
    [anon_sym_PLUS] = ACTIONS(118),
    [anon_sym_PLUS_EQ] = ACTIONS(116),
    [anon_sym_DASH_EQ] = ACTIONS(116),
    [anon_sym_u00d7] = ACTIONS(116),
    [anon_sym_SLASH] = ACTIONS(118),
    [anon_sym_u00f7] = ACTIONS(116),
    [anon_sym_STAR_STAR] = ACTIONS(116),
    [anon_sym_u220b] = ACTIONS(116),
    [anon_sym_u220c] = ACTIONS(116),
    [anon_sym_u2287] = ACTIONS(116),
    [anon_sym_u2283] = ACTIONS(116),
    [anon_sym_u2285] = ACTIONS(116),
    [anon_sym_u2208] = ACTIONS(116),
    [anon_sym_u2209] = ACTIONS(116),
    [anon_sym_u2286] = ACTIONS(116),
    [anon_sym_u2282] = ACTIONS(116),
    [anon_sym_u2284] = ACTIONS(116),
    [anon_sym_AT_AT] = ACTIONS(116),
  },
  [225] = {
    [ts_builtin_sym_end] = ACTIONS(130),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(130),
    [sym_keyword_as] = ACTIONS(130),
    [sym_keyword_where] = ACTIONS(130),
    [sym_keyword_group] = ACTIONS(130),
    [sym_keyword_and] = ACTIONS(130),
    [sym_keyword_or] = ACTIONS(130),
    [sym_keyword_is] = ACTIONS(130),
    [sym_keyword_not] = ACTIONS(132),
    [sym_keyword_contains] = ACTIONS(130),
    [sym_keyword_contains_not] = ACTIONS(130),
    [sym_keyword_contains_all] = ACTIONS(130),
    [sym_keyword_contains_any] = ACTIONS(130),
    [sym_keyword_contains_none] = ACTIONS(130),
    [sym_keyword_inside] = ACTIONS(130),
    [sym_keyword_in] = ACTIONS(132),
    [sym_keyword_not_inside] = ACTIONS(130),
    [sym_keyword_all_inside] = ACTIONS(130),
    [sym_keyword_any_inside] = ACTIONS(130),
    [sym_keyword_none_inside] = ACTIONS(130),
    [sym_keyword_outside] = ACTIONS(130),
    [sym_keyword_intersects] = ACTIONS(130),
    [sym_keyword_drop] = ACTIONS(130),
    [sym_keyword_schemafull] = ACTIONS(130),
    [sym_keyword_schemaless] = ACTIONS(130),
    [sym_keyword_changefeed] = ACTIONS(130),
    [sym_keyword_type] = ACTIONS(130),
    [sym_keyword_permissions] = ACTIONS(130),
    [sym_keyword_for] = ACTIONS(130),
    [sym_keyword_comment] = ACTIONS(130),
    [anon_sym_COMMA] = ACTIONS(130),
    [anon_sym_DASH_GT] = ACTIONS(130),
    [anon_sym_LBRACK] = ACTIONS(130),
    [anon_sym_LT_DASH] = ACTIONS(132),
    [anon_sym_LT_DASH_GT] = ACTIONS(130),
    [anon_sym_STAR] = ACTIONS(132),
    [anon_sym_DOT] = ACTIONS(132),
    [anon_sym_LT] = ACTIONS(132),
    [anon_sym_GT] = ACTIONS(132),
    [anon_sym_DOT_DOT] = ACTIONS(130),
    [anon_sym_EQ] = ACTIONS(132),
    [anon_sym_DASH] = ACTIONS(132),
    [anon_sym_AT] = ACTIONS(132),
    [anon_sym_LT_PIPE] = ACTIONS(130),
    [anon_sym_AMP_AMP] = ACTIONS(130),
    [anon_sym_PIPE_PIPE] = ACTIONS(130),
    [anon_sym_QMARK_QMARK] = ACTIONS(130),
    [anon_sym_QMARK_COLON] = ACTIONS(130),
    [anon_sym_BANG_EQ] = ACTIONS(130),
    [anon_sym_EQ_EQ] = ACTIONS(130),
    [anon_sym_QMARK_EQ] = ACTIONS(130),
    [anon_sym_STAR_EQ] = ACTIONS(130),
    [anon_sym_TILDE] = ACTIONS(130),
    [anon_sym_BANG_TILDE] = ACTIONS(130),
    [anon_sym_STAR_TILDE] = ACTIONS(130),
    [anon_sym_LT_EQ] = ACTIONS(130),
    [anon_sym_GT_EQ] = ACTIONS(130),
    [anon_sym_PLUS] = ACTIONS(132),
    [anon_sym_PLUS_EQ] = ACTIONS(130),
    [anon_sym_DASH_EQ] = ACTIONS(130),
    [anon_sym_u00d7] = ACTIONS(130),
    [anon_sym_SLASH] = ACTIONS(132),
    [anon_sym_u00f7] = ACTIONS(130),
    [anon_sym_STAR_STAR] = ACTIONS(130),
    [anon_sym_u220b] = ACTIONS(130),
    [anon_sym_u220c] = ACTIONS(130),
    [anon_sym_u2287] = ACTIONS(130),
    [anon_sym_u2283] = ACTIONS(130),
    [anon_sym_u2285] = ACTIONS(130),
    [anon_sym_u2208] = ACTIONS(130),
    [anon_sym_u2209] = ACTIONS(130),
    [anon_sym_u2286] = ACTIONS(130),
    [anon_sym_u2282] = ACTIONS(130),
    [anon_sym_u2284] = ACTIONS(130),
    [anon_sym_AT_AT] = ACTIONS(130),
  },
  [226] = {
    [ts_builtin_sym_end] = ACTIONS(134),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(134),
    [sym_keyword_as] = ACTIONS(134),
    [sym_keyword_where] = ACTIONS(134),
    [sym_keyword_group] = ACTIONS(134),
    [sym_keyword_and] = ACTIONS(134),
    [sym_keyword_or] = ACTIONS(134),
    [sym_keyword_is] = ACTIONS(134),
    [sym_keyword_not] = ACTIONS(136),
    [sym_keyword_contains] = ACTIONS(134),
    [sym_keyword_contains_not] = ACTIONS(134),
    [sym_keyword_contains_all] = ACTIONS(134),
    [sym_keyword_contains_any] = ACTIONS(134),
    [sym_keyword_contains_none] = ACTIONS(134),
    [sym_keyword_inside] = ACTIONS(134),
    [sym_keyword_in] = ACTIONS(136),
    [sym_keyword_not_inside] = ACTIONS(134),
    [sym_keyword_all_inside] = ACTIONS(134),
    [sym_keyword_any_inside] = ACTIONS(134),
    [sym_keyword_none_inside] = ACTIONS(134),
    [sym_keyword_outside] = ACTIONS(134),
    [sym_keyword_intersects] = ACTIONS(134),
    [sym_keyword_drop] = ACTIONS(134),
    [sym_keyword_schemafull] = ACTIONS(134),
    [sym_keyword_schemaless] = ACTIONS(134),
    [sym_keyword_changefeed] = ACTIONS(134),
    [sym_keyword_type] = ACTIONS(134),
    [sym_keyword_permissions] = ACTIONS(134),
    [sym_keyword_for] = ACTIONS(134),
    [sym_keyword_comment] = ACTIONS(134),
    [anon_sym_COMMA] = ACTIONS(134),
    [anon_sym_DASH_GT] = ACTIONS(134),
    [anon_sym_LBRACK] = ACTIONS(134),
    [anon_sym_LT_DASH] = ACTIONS(136),
    [anon_sym_LT_DASH_GT] = ACTIONS(134),
    [anon_sym_STAR] = ACTIONS(136),
    [anon_sym_DOT] = ACTIONS(136),
    [anon_sym_LT] = ACTIONS(136),
    [anon_sym_GT] = ACTIONS(136),
    [anon_sym_DOT_DOT] = ACTIONS(134),
    [anon_sym_EQ] = ACTIONS(136),
    [anon_sym_DASH] = ACTIONS(136),
    [anon_sym_AT] = ACTIONS(136),
    [anon_sym_LT_PIPE] = ACTIONS(134),
    [anon_sym_AMP_AMP] = ACTIONS(134),
    [anon_sym_PIPE_PIPE] = ACTIONS(134),
    [anon_sym_QMARK_QMARK] = ACTIONS(134),
    [anon_sym_QMARK_COLON] = ACTIONS(134),
    [anon_sym_BANG_EQ] = ACTIONS(134),
    [anon_sym_EQ_EQ] = ACTIONS(134),
    [anon_sym_QMARK_EQ] = ACTIONS(134),
    [anon_sym_STAR_EQ] = ACTIONS(134),
    [anon_sym_TILDE] = ACTIONS(134),
    [anon_sym_BANG_TILDE] = ACTIONS(134),
    [anon_sym_STAR_TILDE] = ACTIONS(134),
    [anon_sym_LT_EQ] = ACTIONS(134),
    [anon_sym_GT_EQ] = ACTIONS(134),
    [anon_sym_PLUS] = ACTIONS(136),
    [anon_sym_PLUS_EQ] = ACTIONS(134),
    [anon_sym_DASH_EQ] = ACTIONS(134),
    [anon_sym_u00d7] = ACTIONS(134),
    [anon_sym_SLASH] = ACTIONS(136),
    [anon_sym_u00f7] = ACTIONS(134),
    [anon_sym_STAR_STAR] = ACTIONS(134),
    [anon_sym_u220b] = ACTIONS(134),
    [anon_sym_u220c] = ACTIONS(134),
    [anon_sym_u2287] = ACTIONS(134),
    [anon_sym_u2283] = ACTIONS(134),
    [anon_sym_u2285] = ACTIONS(134),
    [anon_sym_u2208] = ACTIONS(134),
    [anon_sym_u2209] = ACTIONS(134),
    [anon_sym_u2286] = ACTIONS(134),
    [anon_sym_u2282] = ACTIONS(134),
    [anon_sym_u2284] = ACTIONS(134),
    [anon_sym_AT_AT] = ACTIONS(134),
  },
  [227] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_explain] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_fetch] = ACTIONS(182),
    [sym_keyword_limit] = ACTIONS(182),
    [sym_keyword_rand] = ACTIONS(182),
    [sym_keyword_collate] = ACTIONS(182),
    [sym_keyword_numeric] = ACTIONS(182),
    [sym_keyword_asc] = ACTIONS(182),
    [sym_keyword_desc] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(473),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [228] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_as] = ACTIONS(182),
    [sym_keyword_where] = ACTIONS(182),
    [sym_keyword_group] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_drop] = ACTIONS(182),
    [sym_keyword_schemafull] = ACTIONS(182),
    [sym_keyword_schemaless] = ACTIONS(182),
    [sym_keyword_changefeed] = ACTIONS(182),
    [sym_keyword_type] = ACTIONS(182),
    [sym_keyword_permissions] = ACTIONS(182),
    [sym_keyword_comment] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(475),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [229] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(126),
    [sym_keyword_explain] = ACTIONS(126),
    [sym_keyword_parallel] = ACTIONS(126),
    [sym_keyword_timeout] = ACTIONS(126),
    [sym_keyword_fetch] = ACTIONS(126),
    [sym_keyword_limit] = ACTIONS(126),
    [sym_keyword_order] = ACTIONS(126),
    [sym_keyword_with] = ACTIONS(126),
    [sym_keyword_where] = ACTIONS(126),
    [sym_keyword_split] = ACTIONS(126),
    [sym_keyword_group] = ACTIONS(126),
    [sym_keyword_and] = ACTIONS(126),
    [sym_keyword_or] = ACTIONS(128),
    [sym_keyword_is] = ACTIONS(126),
    [sym_keyword_not] = ACTIONS(128),
    [sym_keyword_contains] = ACTIONS(126),
    [sym_keyword_contains_not] = ACTIONS(126),
    [sym_keyword_contains_all] = ACTIONS(126),
    [sym_keyword_contains_any] = ACTIONS(126),
    [sym_keyword_contains_none] = ACTIONS(126),
    [sym_keyword_inside] = ACTIONS(126),
    [sym_keyword_in] = ACTIONS(128),
    [sym_keyword_not_inside] = ACTIONS(126),
    [sym_keyword_all_inside] = ACTIONS(126),
    [sym_keyword_any_inside] = ACTIONS(126),
    [sym_keyword_none_inside] = ACTIONS(126),
    [sym_keyword_outside] = ACTIONS(126),
    [sym_keyword_intersects] = ACTIONS(126),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_DASH_GT] = ACTIONS(126),
    [anon_sym_LBRACK] = ACTIONS(126),
    [anon_sym_RPAREN] = ACTIONS(126),
    [anon_sym_RBRACE] = ACTIONS(126),
    [anon_sym_LT_DASH] = ACTIONS(128),
    [anon_sym_LT_DASH_GT] = ACTIONS(126),
    [anon_sym_STAR] = ACTIONS(128),
    [anon_sym_DOT] = ACTIONS(128),
    [anon_sym_LT] = ACTIONS(128),
    [anon_sym_GT] = ACTIONS(128),
    [anon_sym_DOT_DOT] = ACTIONS(126),
    [anon_sym_EQ] = ACTIONS(128),
    [anon_sym_DASH] = ACTIONS(128),
    [anon_sym_AT] = ACTIONS(128),
    [anon_sym_LT_PIPE] = ACTIONS(126),
    [anon_sym_AMP_AMP] = ACTIONS(126),
    [anon_sym_PIPE_PIPE] = ACTIONS(126),
    [anon_sym_QMARK_QMARK] = ACTIONS(126),
    [anon_sym_QMARK_COLON] = ACTIONS(126),
    [anon_sym_BANG_EQ] = ACTIONS(126),
    [anon_sym_EQ_EQ] = ACTIONS(126),
    [anon_sym_QMARK_EQ] = ACTIONS(126),
    [anon_sym_STAR_EQ] = ACTIONS(126),
    [anon_sym_TILDE] = ACTIONS(126),
    [anon_sym_BANG_TILDE] = ACTIONS(126),
    [anon_sym_STAR_TILDE] = ACTIONS(126),
    [anon_sym_LT_EQ] = ACTIONS(126),
    [anon_sym_GT_EQ] = ACTIONS(126),
    [anon_sym_PLUS] = ACTIONS(128),
    [anon_sym_PLUS_EQ] = ACTIONS(126),
    [anon_sym_DASH_EQ] = ACTIONS(126),
    [anon_sym_u00d7] = ACTIONS(126),
    [anon_sym_SLASH] = ACTIONS(128),
    [anon_sym_u00f7] = ACTIONS(126),
    [anon_sym_STAR_STAR] = ACTIONS(126),
    [anon_sym_u220b] = ACTIONS(126),
    [anon_sym_u220c] = ACTIONS(126),
    [anon_sym_u2287] = ACTIONS(126),
    [anon_sym_u2283] = ACTIONS(126),
    [anon_sym_u2285] = ACTIONS(126),
    [anon_sym_u2208] = ACTIONS(126),
    [anon_sym_u2209] = ACTIONS(126),
    [anon_sym_u2286] = ACTIONS(126),
    [anon_sym_u2282] = ACTIONS(126),
    [anon_sym_u2284] = ACTIONS(126),
    [anon_sym_AT_AT] = ACTIONS(126),
  },
  [230] = {
    [ts_builtin_sym_end] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(55),
    [sym_keyword_as] = ACTIONS(55),
    [sym_keyword_where] = ACTIONS(55),
    [sym_keyword_group] = ACTIONS(55),
    [sym_keyword_and] = ACTIONS(55),
    [sym_keyword_or] = ACTIONS(55),
    [sym_keyword_is] = ACTIONS(55),
    [sym_keyword_not] = ACTIONS(57),
    [sym_keyword_contains] = ACTIONS(55),
    [sym_keyword_contains_not] = ACTIONS(55),
    [sym_keyword_contains_all] = ACTIONS(55),
    [sym_keyword_contains_any] = ACTIONS(55),
    [sym_keyword_contains_none] = ACTIONS(55),
    [sym_keyword_inside] = ACTIONS(55),
    [sym_keyword_in] = ACTIONS(57),
    [sym_keyword_not_inside] = ACTIONS(55),
    [sym_keyword_all_inside] = ACTIONS(55),
    [sym_keyword_any_inside] = ACTIONS(55),
    [sym_keyword_none_inside] = ACTIONS(55),
    [sym_keyword_outside] = ACTIONS(55),
    [sym_keyword_intersects] = ACTIONS(55),
    [sym_keyword_drop] = ACTIONS(55),
    [sym_keyword_schemafull] = ACTIONS(55),
    [sym_keyword_schemaless] = ACTIONS(55),
    [sym_keyword_changefeed] = ACTIONS(55),
    [sym_keyword_type] = ACTIONS(55),
    [sym_keyword_permissions] = ACTIONS(55),
    [sym_keyword_for] = ACTIONS(55),
    [sym_keyword_comment] = ACTIONS(55),
    [anon_sym_COMMA] = ACTIONS(55),
    [anon_sym_DASH_GT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(55),
    [anon_sym_COLON] = ACTIONS(120),
    [anon_sym_LT_DASH] = ACTIONS(57),
    [anon_sym_LT_DASH_GT] = ACTIONS(55),
    [anon_sym_STAR] = ACTIONS(57),
    [anon_sym_DOT] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(57),
    [anon_sym_GT] = ACTIONS(57),
    [anon_sym_EQ] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(57),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LT_PIPE] = ACTIONS(55),
    [anon_sym_AMP_AMP] = ACTIONS(55),
    [anon_sym_PIPE_PIPE] = ACTIONS(55),
    [anon_sym_QMARK_QMARK] = ACTIONS(55),
    [anon_sym_QMARK_COLON] = ACTIONS(55),
    [anon_sym_BANG_EQ] = ACTIONS(55),
    [anon_sym_EQ_EQ] = ACTIONS(55),
    [anon_sym_QMARK_EQ] = ACTIONS(55),
    [anon_sym_STAR_EQ] = ACTIONS(55),
    [anon_sym_TILDE] = ACTIONS(55),
    [anon_sym_BANG_TILDE] = ACTIONS(55),
    [anon_sym_STAR_TILDE] = ACTIONS(55),
    [anon_sym_LT_EQ] = ACTIONS(55),
    [anon_sym_GT_EQ] = ACTIONS(55),
    [anon_sym_PLUS] = ACTIONS(57),
    [anon_sym_PLUS_EQ] = ACTIONS(55),
    [anon_sym_DASH_EQ] = ACTIONS(55),
    [anon_sym_u00d7] = ACTIONS(55),
    [anon_sym_SLASH] = ACTIONS(57),
    [anon_sym_u00f7] = ACTIONS(55),
    [anon_sym_STAR_STAR] = ACTIONS(55),
    [anon_sym_u220b] = ACTIONS(55),
    [anon_sym_u220c] = ACTIONS(55),
    [anon_sym_u2287] = ACTIONS(55),
    [anon_sym_u2283] = ACTIONS(55),
    [anon_sym_u2285] = ACTIONS(55),
    [anon_sym_u2208] = ACTIONS(55),
    [anon_sym_u2209] = ACTIONS(55),
    [anon_sym_u2286] = ACTIONS(55),
    [anon_sym_u2282] = ACTIONS(55),
    [anon_sym_u2284] = ACTIONS(55),
    [anon_sym_AT_AT] = ACTIONS(55),
  },
  [231] = {
    [ts_builtin_sym_end] = ACTIONS(122),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(122),
    [sym_keyword_as] = ACTIONS(122),
    [sym_keyword_where] = ACTIONS(122),
    [sym_keyword_group] = ACTIONS(122),
    [sym_keyword_and] = ACTIONS(122),
    [sym_keyword_or] = ACTIONS(122),
    [sym_keyword_is] = ACTIONS(122),
    [sym_keyword_not] = ACTIONS(124),
    [sym_keyword_contains] = ACTIONS(122),
    [sym_keyword_contains_not] = ACTIONS(122),
    [sym_keyword_contains_all] = ACTIONS(122),
    [sym_keyword_contains_any] = ACTIONS(122),
    [sym_keyword_contains_none] = ACTIONS(122),
    [sym_keyword_inside] = ACTIONS(122),
    [sym_keyword_in] = ACTIONS(124),
    [sym_keyword_not_inside] = ACTIONS(122),
    [sym_keyword_all_inside] = ACTIONS(122),
    [sym_keyword_any_inside] = ACTIONS(122),
    [sym_keyword_none_inside] = ACTIONS(122),
    [sym_keyword_outside] = ACTIONS(122),
    [sym_keyword_intersects] = ACTIONS(122),
    [sym_keyword_drop] = ACTIONS(122),
    [sym_keyword_schemafull] = ACTIONS(122),
    [sym_keyword_schemaless] = ACTIONS(122),
    [sym_keyword_changefeed] = ACTIONS(122),
    [sym_keyword_type] = ACTIONS(122),
    [sym_keyword_permissions] = ACTIONS(122),
    [sym_keyword_for] = ACTIONS(122),
    [sym_keyword_comment] = ACTIONS(122),
    [anon_sym_COMMA] = ACTIONS(122),
    [anon_sym_DASH_GT] = ACTIONS(122),
    [anon_sym_LBRACK] = ACTIONS(122),
    [anon_sym_LT_DASH] = ACTIONS(124),
    [anon_sym_LT_DASH_GT] = ACTIONS(122),
    [anon_sym_STAR] = ACTIONS(124),
    [anon_sym_DOT] = ACTIONS(124),
    [anon_sym_LT] = ACTIONS(124),
    [anon_sym_GT] = ACTIONS(124),
    [anon_sym_DOT_DOT] = ACTIONS(122),
    [anon_sym_EQ] = ACTIONS(124),
    [anon_sym_DASH] = ACTIONS(124),
    [anon_sym_AT] = ACTIONS(124),
    [anon_sym_LT_PIPE] = ACTIONS(122),
    [anon_sym_AMP_AMP] = ACTIONS(122),
    [anon_sym_PIPE_PIPE] = ACTIONS(122),
    [anon_sym_QMARK_QMARK] = ACTIONS(122),
    [anon_sym_QMARK_COLON] = ACTIONS(122),
    [anon_sym_BANG_EQ] = ACTIONS(122),
    [anon_sym_EQ_EQ] = ACTIONS(122),
    [anon_sym_QMARK_EQ] = ACTIONS(122),
    [anon_sym_STAR_EQ] = ACTIONS(122),
    [anon_sym_TILDE] = ACTIONS(122),
    [anon_sym_BANG_TILDE] = ACTIONS(122),
    [anon_sym_STAR_TILDE] = ACTIONS(122),
    [anon_sym_LT_EQ] = ACTIONS(122),
    [anon_sym_GT_EQ] = ACTIONS(122),
    [anon_sym_PLUS] = ACTIONS(124),
    [anon_sym_PLUS_EQ] = ACTIONS(122),
    [anon_sym_DASH_EQ] = ACTIONS(122),
    [anon_sym_u00d7] = ACTIONS(122),
    [anon_sym_SLASH] = ACTIONS(124),
    [anon_sym_u00f7] = ACTIONS(122),
    [anon_sym_STAR_STAR] = ACTIONS(122),
    [anon_sym_u220b] = ACTIONS(122),
    [anon_sym_u220c] = ACTIONS(122),
    [anon_sym_u2287] = ACTIONS(122),
    [anon_sym_u2283] = ACTIONS(122),
    [anon_sym_u2285] = ACTIONS(122),
    [anon_sym_u2208] = ACTIONS(122),
    [anon_sym_u2209] = ACTIONS(122),
    [anon_sym_u2286] = ACTIONS(122),
    [anon_sym_u2282] = ACTIONS(122),
    [anon_sym_u2284] = ACTIONS(122),
    [anon_sym_AT_AT] = ACTIONS(122),
  },
  [232] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(112),
    [sym_keyword_explain] = ACTIONS(112),
    [sym_keyword_parallel] = ACTIONS(112),
    [sym_keyword_timeout] = ACTIONS(112),
    [sym_keyword_fetch] = ACTIONS(112),
    [sym_keyword_limit] = ACTIONS(112),
    [sym_keyword_order] = ACTIONS(112),
    [sym_keyword_with] = ACTIONS(112),
    [sym_keyword_where] = ACTIONS(112),
    [sym_keyword_split] = ACTIONS(112),
    [sym_keyword_group] = ACTIONS(112),
    [sym_keyword_and] = ACTIONS(112),
    [sym_keyword_or] = ACTIONS(114),
    [sym_keyword_is] = ACTIONS(112),
    [sym_keyword_not] = ACTIONS(114),
    [sym_keyword_contains] = ACTIONS(112),
    [sym_keyword_contains_not] = ACTIONS(112),
    [sym_keyword_contains_all] = ACTIONS(112),
    [sym_keyword_contains_any] = ACTIONS(112),
    [sym_keyword_contains_none] = ACTIONS(112),
    [sym_keyword_inside] = ACTIONS(112),
    [sym_keyword_in] = ACTIONS(114),
    [sym_keyword_not_inside] = ACTIONS(112),
    [sym_keyword_all_inside] = ACTIONS(112),
    [sym_keyword_any_inside] = ACTIONS(112),
    [sym_keyword_none_inside] = ACTIONS(112),
    [sym_keyword_outside] = ACTIONS(112),
    [sym_keyword_intersects] = ACTIONS(112),
    [anon_sym_COMMA] = ACTIONS(112),
    [anon_sym_DASH_GT] = ACTIONS(112),
    [anon_sym_LBRACK] = ACTIONS(112),
    [anon_sym_RPAREN] = ACTIONS(112),
    [anon_sym_RBRACE] = ACTIONS(112),
    [anon_sym_LT_DASH] = ACTIONS(114),
    [anon_sym_LT_DASH_GT] = ACTIONS(112),
    [anon_sym_STAR] = ACTIONS(114),
    [anon_sym_DOT] = ACTIONS(114),
    [anon_sym_LT] = ACTIONS(114),
    [anon_sym_GT] = ACTIONS(114),
    [anon_sym_DOT_DOT] = ACTIONS(112),
    [anon_sym_EQ] = ACTIONS(114),
    [anon_sym_DASH] = ACTIONS(114),
    [anon_sym_AT] = ACTIONS(114),
    [anon_sym_LT_PIPE] = ACTIONS(112),
    [anon_sym_AMP_AMP] = ACTIONS(112),
    [anon_sym_PIPE_PIPE] = ACTIONS(112),
    [anon_sym_QMARK_QMARK] = ACTIONS(112),
    [anon_sym_QMARK_COLON] = ACTIONS(112),
    [anon_sym_BANG_EQ] = ACTIONS(112),
    [anon_sym_EQ_EQ] = ACTIONS(112),
    [anon_sym_QMARK_EQ] = ACTIONS(112),
    [anon_sym_STAR_EQ] = ACTIONS(112),
    [anon_sym_TILDE] = ACTIONS(112),
    [anon_sym_BANG_TILDE] = ACTIONS(112),
    [anon_sym_STAR_TILDE] = ACTIONS(112),
    [anon_sym_LT_EQ] = ACTIONS(112),
    [anon_sym_GT_EQ] = ACTIONS(112),
    [anon_sym_PLUS] = ACTIONS(114),
    [anon_sym_PLUS_EQ] = ACTIONS(112),
    [anon_sym_DASH_EQ] = ACTIONS(112),
    [anon_sym_u00d7] = ACTIONS(112),
    [anon_sym_SLASH] = ACTIONS(114),
    [anon_sym_u00f7] = ACTIONS(112),
    [anon_sym_STAR_STAR] = ACTIONS(112),
    [anon_sym_u220b] = ACTIONS(112),
    [anon_sym_u220c] = ACTIONS(112),
    [anon_sym_u2287] = ACTIONS(112),
    [anon_sym_u2283] = ACTIONS(112),
    [anon_sym_u2285] = ACTIONS(112),
    [anon_sym_u2208] = ACTIONS(112),
    [anon_sym_u2209] = ACTIONS(112),
    [anon_sym_u2286] = ACTIONS(112),
    [anon_sym_u2282] = ACTIONS(112),
    [anon_sym_u2284] = ACTIONS(112),
    [anon_sym_AT_AT] = ACTIONS(112),
  },
  [233] = {
    [ts_builtin_sym_end] = ACTIONS(112),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(112),
    [sym_keyword_as] = ACTIONS(112),
    [sym_keyword_where] = ACTIONS(112),
    [sym_keyword_group] = ACTIONS(112),
    [sym_keyword_and] = ACTIONS(112),
    [sym_keyword_or] = ACTIONS(112),
    [sym_keyword_is] = ACTIONS(112),
    [sym_keyword_not] = ACTIONS(114),
    [sym_keyword_contains] = ACTIONS(112),
    [sym_keyword_contains_not] = ACTIONS(112),
    [sym_keyword_contains_all] = ACTIONS(112),
    [sym_keyword_contains_any] = ACTIONS(112),
    [sym_keyword_contains_none] = ACTIONS(112),
    [sym_keyword_inside] = ACTIONS(112),
    [sym_keyword_in] = ACTIONS(114),
    [sym_keyword_not_inside] = ACTIONS(112),
    [sym_keyword_all_inside] = ACTIONS(112),
    [sym_keyword_any_inside] = ACTIONS(112),
    [sym_keyword_none_inside] = ACTIONS(112),
    [sym_keyword_outside] = ACTIONS(112),
    [sym_keyword_intersects] = ACTIONS(112),
    [sym_keyword_drop] = ACTIONS(112),
    [sym_keyword_schemafull] = ACTIONS(112),
    [sym_keyword_schemaless] = ACTIONS(112),
    [sym_keyword_changefeed] = ACTIONS(112),
    [sym_keyword_type] = ACTIONS(112),
    [sym_keyword_permissions] = ACTIONS(112),
    [sym_keyword_for] = ACTIONS(112),
    [sym_keyword_comment] = ACTIONS(112),
    [anon_sym_COMMA] = ACTIONS(112),
    [anon_sym_DASH_GT] = ACTIONS(112),
    [anon_sym_LBRACK] = ACTIONS(112),
    [anon_sym_LT_DASH] = ACTIONS(114),
    [anon_sym_LT_DASH_GT] = ACTIONS(112),
    [anon_sym_STAR] = ACTIONS(114),
    [anon_sym_DOT] = ACTIONS(114),
    [anon_sym_LT] = ACTIONS(114),
    [anon_sym_GT] = ACTIONS(114),
    [anon_sym_DOT_DOT] = ACTIONS(112),
    [anon_sym_EQ] = ACTIONS(114),
    [anon_sym_DASH] = ACTIONS(114),
    [anon_sym_AT] = ACTIONS(114),
    [anon_sym_LT_PIPE] = ACTIONS(112),
    [anon_sym_AMP_AMP] = ACTIONS(112),
    [anon_sym_PIPE_PIPE] = ACTIONS(112),
    [anon_sym_QMARK_QMARK] = ACTIONS(112),
    [anon_sym_QMARK_COLON] = ACTIONS(112),
    [anon_sym_BANG_EQ] = ACTIONS(112),
    [anon_sym_EQ_EQ] = ACTIONS(112),
    [anon_sym_QMARK_EQ] = ACTIONS(112),
    [anon_sym_STAR_EQ] = ACTIONS(112),
    [anon_sym_TILDE] = ACTIONS(112),
    [anon_sym_BANG_TILDE] = ACTIONS(112),
    [anon_sym_STAR_TILDE] = ACTIONS(112),
    [anon_sym_LT_EQ] = ACTIONS(112),
    [anon_sym_GT_EQ] = ACTIONS(112),
    [anon_sym_PLUS] = ACTIONS(114),
    [anon_sym_PLUS_EQ] = ACTIONS(112),
    [anon_sym_DASH_EQ] = ACTIONS(112),
    [anon_sym_u00d7] = ACTIONS(112),
    [anon_sym_SLASH] = ACTIONS(114),
    [anon_sym_u00f7] = ACTIONS(112),
    [anon_sym_STAR_STAR] = ACTIONS(112),
    [anon_sym_u220b] = ACTIONS(112),
    [anon_sym_u220c] = ACTIONS(112),
    [anon_sym_u2287] = ACTIONS(112),
    [anon_sym_u2283] = ACTIONS(112),
    [anon_sym_u2285] = ACTIONS(112),
    [anon_sym_u2208] = ACTIONS(112),
    [anon_sym_u2209] = ACTIONS(112),
    [anon_sym_u2286] = ACTIONS(112),
    [anon_sym_u2282] = ACTIONS(112),
    [anon_sym_u2284] = ACTIONS(112),
    [anon_sym_AT_AT] = ACTIONS(112),
  },
  [234] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(122),
    [sym_keyword_explain] = ACTIONS(122),
    [sym_keyword_parallel] = ACTIONS(122),
    [sym_keyword_timeout] = ACTIONS(122),
    [sym_keyword_fetch] = ACTIONS(122),
    [sym_keyword_limit] = ACTIONS(122),
    [sym_keyword_order] = ACTIONS(122),
    [sym_keyword_with] = ACTIONS(122),
    [sym_keyword_where] = ACTIONS(122),
    [sym_keyword_split] = ACTIONS(122),
    [sym_keyword_group] = ACTIONS(122),
    [sym_keyword_and] = ACTIONS(122),
    [sym_keyword_or] = ACTIONS(124),
    [sym_keyword_is] = ACTIONS(122),
    [sym_keyword_not] = ACTIONS(124),
    [sym_keyword_contains] = ACTIONS(122),
    [sym_keyword_contains_not] = ACTIONS(122),
    [sym_keyword_contains_all] = ACTIONS(122),
    [sym_keyword_contains_any] = ACTIONS(122),
    [sym_keyword_contains_none] = ACTIONS(122),
    [sym_keyword_inside] = ACTIONS(122),
    [sym_keyword_in] = ACTIONS(124),
    [sym_keyword_not_inside] = ACTIONS(122),
    [sym_keyword_all_inside] = ACTIONS(122),
    [sym_keyword_any_inside] = ACTIONS(122),
    [sym_keyword_none_inside] = ACTIONS(122),
    [sym_keyword_outside] = ACTIONS(122),
    [sym_keyword_intersects] = ACTIONS(122),
    [anon_sym_COMMA] = ACTIONS(122),
    [anon_sym_DASH_GT] = ACTIONS(122),
    [anon_sym_LBRACK] = ACTIONS(122),
    [anon_sym_RPAREN] = ACTIONS(122),
    [anon_sym_RBRACE] = ACTIONS(122),
    [anon_sym_LT_DASH] = ACTIONS(124),
    [anon_sym_LT_DASH_GT] = ACTIONS(122),
    [anon_sym_STAR] = ACTIONS(124),
    [anon_sym_DOT] = ACTIONS(124),
    [anon_sym_LT] = ACTIONS(124),
    [anon_sym_GT] = ACTIONS(124),
    [anon_sym_DOT_DOT] = ACTIONS(122),
    [anon_sym_EQ] = ACTIONS(124),
    [anon_sym_DASH] = ACTIONS(124),
    [anon_sym_AT] = ACTIONS(124),
    [anon_sym_LT_PIPE] = ACTIONS(122),
    [anon_sym_AMP_AMP] = ACTIONS(122),
    [anon_sym_PIPE_PIPE] = ACTIONS(122),
    [anon_sym_QMARK_QMARK] = ACTIONS(122),
    [anon_sym_QMARK_COLON] = ACTIONS(122),
    [anon_sym_BANG_EQ] = ACTIONS(122),
    [anon_sym_EQ_EQ] = ACTIONS(122),
    [anon_sym_QMARK_EQ] = ACTIONS(122),
    [anon_sym_STAR_EQ] = ACTIONS(122),
    [anon_sym_TILDE] = ACTIONS(122),
    [anon_sym_BANG_TILDE] = ACTIONS(122),
    [anon_sym_STAR_TILDE] = ACTIONS(122),
    [anon_sym_LT_EQ] = ACTIONS(122),
    [anon_sym_GT_EQ] = ACTIONS(122),
    [anon_sym_PLUS] = ACTIONS(124),
    [anon_sym_PLUS_EQ] = ACTIONS(122),
    [anon_sym_DASH_EQ] = ACTIONS(122),
    [anon_sym_u00d7] = ACTIONS(122),
    [anon_sym_SLASH] = ACTIONS(124),
    [anon_sym_u00f7] = ACTIONS(122),
    [anon_sym_STAR_STAR] = ACTIONS(122),
    [anon_sym_u220b] = ACTIONS(122),
    [anon_sym_u220c] = ACTIONS(122),
    [anon_sym_u2287] = ACTIONS(122),
    [anon_sym_u2283] = ACTIONS(122),
    [anon_sym_u2285] = ACTIONS(122),
    [anon_sym_u2208] = ACTIONS(122),
    [anon_sym_u2209] = ACTIONS(122),
    [anon_sym_u2286] = ACTIONS(122),
    [anon_sym_u2282] = ACTIONS(122),
    [anon_sym_u2284] = ACTIONS(122),
    [anon_sym_AT_AT] = ACTIONS(122),
  },
  [235] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(130),
    [sym_keyword_explain] = ACTIONS(130),
    [sym_keyword_parallel] = ACTIONS(130),
    [sym_keyword_timeout] = ACTIONS(130),
    [sym_keyword_fetch] = ACTIONS(130),
    [sym_keyword_limit] = ACTIONS(130),
    [sym_keyword_order] = ACTIONS(130),
    [sym_keyword_with] = ACTIONS(130),
    [sym_keyword_where] = ACTIONS(130),
    [sym_keyword_split] = ACTIONS(130),
    [sym_keyword_group] = ACTIONS(130),
    [sym_keyword_and] = ACTIONS(130),
    [sym_keyword_or] = ACTIONS(132),
    [sym_keyword_is] = ACTIONS(130),
    [sym_keyword_not] = ACTIONS(132),
    [sym_keyword_contains] = ACTIONS(130),
    [sym_keyword_contains_not] = ACTIONS(130),
    [sym_keyword_contains_all] = ACTIONS(130),
    [sym_keyword_contains_any] = ACTIONS(130),
    [sym_keyword_contains_none] = ACTIONS(130),
    [sym_keyword_inside] = ACTIONS(130),
    [sym_keyword_in] = ACTIONS(132),
    [sym_keyword_not_inside] = ACTIONS(130),
    [sym_keyword_all_inside] = ACTIONS(130),
    [sym_keyword_any_inside] = ACTIONS(130),
    [sym_keyword_none_inside] = ACTIONS(130),
    [sym_keyword_outside] = ACTIONS(130),
    [sym_keyword_intersects] = ACTIONS(130),
    [anon_sym_COMMA] = ACTIONS(130),
    [anon_sym_DASH_GT] = ACTIONS(130),
    [anon_sym_LBRACK] = ACTIONS(130),
    [anon_sym_RPAREN] = ACTIONS(130),
    [anon_sym_RBRACE] = ACTIONS(130),
    [anon_sym_LT_DASH] = ACTIONS(132),
    [anon_sym_LT_DASH_GT] = ACTIONS(130),
    [anon_sym_STAR] = ACTIONS(132),
    [anon_sym_DOT] = ACTIONS(132),
    [anon_sym_LT] = ACTIONS(132),
    [anon_sym_GT] = ACTIONS(132),
    [anon_sym_DOT_DOT] = ACTIONS(130),
    [anon_sym_EQ] = ACTIONS(132),
    [anon_sym_DASH] = ACTIONS(132),
    [anon_sym_AT] = ACTIONS(132),
    [anon_sym_LT_PIPE] = ACTIONS(130),
    [anon_sym_AMP_AMP] = ACTIONS(130),
    [anon_sym_PIPE_PIPE] = ACTIONS(130),
    [anon_sym_QMARK_QMARK] = ACTIONS(130),
    [anon_sym_QMARK_COLON] = ACTIONS(130),
    [anon_sym_BANG_EQ] = ACTIONS(130),
    [anon_sym_EQ_EQ] = ACTIONS(130),
    [anon_sym_QMARK_EQ] = ACTIONS(130),
    [anon_sym_STAR_EQ] = ACTIONS(130),
    [anon_sym_TILDE] = ACTIONS(130),
    [anon_sym_BANG_TILDE] = ACTIONS(130),
    [anon_sym_STAR_TILDE] = ACTIONS(130),
    [anon_sym_LT_EQ] = ACTIONS(130),
    [anon_sym_GT_EQ] = ACTIONS(130),
    [anon_sym_PLUS] = ACTIONS(132),
    [anon_sym_PLUS_EQ] = ACTIONS(130),
    [anon_sym_DASH_EQ] = ACTIONS(130),
    [anon_sym_u00d7] = ACTIONS(130),
    [anon_sym_SLASH] = ACTIONS(132),
    [anon_sym_u00f7] = ACTIONS(130),
    [anon_sym_STAR_STAR] = ACTIONS(130),
    [anon_sym_u220b] = ACTIONS(130),
    [anon_sym_u220c] = ACTIONS(130),
    [anon_sym_u2287] = ACTIONS(130),
    [anon_sym_u2283] = ACTIONS(130),
    [anon_sym_u2285] = ACTIONS(130),
    [anon_sym_u2208] = ACTIONS(130),
    [anon_sym_u2209] = ACTIONS(130),
    [anon_sym_u2286] = ACTIONS(130),
    [anon_sym_u2282] = ACTIONS(130),
    [anon_sym_u2284] = ACTIONS(130),
    [anon_sym_AT_AT] = ACTIONS(130),
  },
  [236] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(116),
    [sym_keyword_explain] = ACTIONS(116),
    [sym_keyword_parallel] = ACTIONS(116),
    [sym_keyword_timeout] = ACTIONS(116),
    [sym_keyword_fetch] = ACTIONS(116),
    [sym_keyword_limit] = ACTIONS(116),
    [sym_keyword_order] = ACTIONS(116),
    [sym_keyword_with] = ACTIONS(116),
    [sym_keyword_where] = ACTIONS(116),
    [sym_keyword_split] = ACTIONS(116),
    [sym_keyword_group] = ACTIONS(116),
    [sym_keyword_and] = ACTIONS(116),
    [sym_keyword_or] = ACTIONS(118),
    [sym_keyword_is] = ACTIONS(116),
    [sym_keyword_not] = ACTIONS(118),
    [sym_keyword_contains] = ACTIONS(116),
    [sym_keyword_contains_not] = ACTIONS(116),
    [sym_keyword_contains_all] = ACTIONS(116),
    [sym_keyword_contains_any] = ACTIONS(116),
    [sym_keyword_contains_none] = ACTIONS(116),
    [sym_keyword_inside] = ACTIONS(116),
    [sym_keyword_in] = ACTIONS(118),
    [sym_keyword_not_inside] = ACTIONS(116),
    [sym_keyword_all_inside] = ACTIONS(116),
    [sym_keyword_any_inside] = ACTIONS(116),
    [sym_keyword_none_inside] = ACTIONS(116),
    [sym_keyword_outside] = ACTIONS(116),
    [sym_keyword_intersects] = ACTIONS(116),
    [anon_sym_COMMA] = ACTIONS(116),
    [anon_sym_DASH_GT] = ACTIONS(116),
    [anon_sym_LBRACK] = ACTIONS(116),
    [anon_sym_RPAREN] = ACTIONS(116),
    [anon_sym_RBRACE] = ACTIONS(116),
    [anon_sym_LT_DASH] = ACTIONS(118),
    [anon_sym_LT_DASH_GT] = ACTIONS(116),
    [anon_sym_STAR] = ACTIONS(118),
    [anon_sym_DOT] = ACTIONS(118),
    [anon_sym_LT] = ACTIONS(118),
    [anon_sym_GT] = ACTIONS(118),
    [anon_sym_DOT_DOT] = ACTIONS(116),
    [anon_sym_EQ] = ACTIONS(118),
    [anon_sym_DASH] = ACTIONS(118),
    [anon_sym_AT] = ACTIONS(118),
    [anon_sym_LT_PIPE] = ACTIONS(116),
    [anon_sym_AMP_AMP] = ACTIONS(116),
    [anon_sym_PIPE_PIPE] = ACTIONS(116),
    [anon_sym_QMARK_QMARK] = ACTIONS(116),
    [anon_sym_QMARK_COLON] = ACTIONS(116),
    [anon_sym_BANG_EQ] = ACTIONS(116),
    [anon_sym_EQ_EQ] = ACTIONS(116),
    [anon_sym_QMARK_EQ] = ACTIONS(116),
    [anon_sym_STAR_EQ] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(116),
    [anon_sym_BANG_TILDE] = ACTIONS(116),
    [anon_sym_STAR_TILDE] = ACTIONS(116),
    [anon_sym_LT_EQ] = ACTIONS(116),
    [anon_sym_GT_EQ] = ACTIONS(116),
    [anon_sym_PLUS] = ACTIONS(118),
    [anon_sym_PLUS_EQ] = ACTIONS(116),
    [anon_sym_DASH_EQ] = ACTIONS(116),
    [anon_sym_u00d7] = ACTIONS(116),
    [anon_sym_SLASH] = ACTIONS(118),
    [anon_sym_u00f7] = ACTIONS(116),
    [anon_sym_STAR_STAR] = ACTIONS(116),
    [anon_sym_u220b] = ACTIONS(116),
    [anon_sym_u220c] = ACTIONS(116),
    [anon_sym_u2287] = ACTIONS(116),
    [anon_sym_u2283] = ACTIONS(116),
    [anon_sym_u2285] = ACTIONS(116),
    [anon_sym_u2208] = ACTIONS(116),
    [anon_sym_u2209] = ACTIONS(116),
    [anon_sym_u2286] = ACTIONS(116),
    [anon_sym_u2282] = ACTIONS(116),
    [anon_sym_u2284] = ACTIONS(116),
    [anon_sym_AT_AT] = ACTIONS(116),
  },
  [237] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(55),
    [sym_keyword_explain] = ACTIONS(55),
    [sym_keyword_parallel] = ACTIONS(55),
    [sym_keyword_timeout] = ACTIONS(55),
    [sym_keyword_fetch] = ACTIONS(55),
    [sym_keyword_limit] = ACTIONS(55),
    [sym_keyword_order] = ACTIONS(55),
    [sym_keyword_with] = ACTIONS(55),
    [sym_keyword_where] = ACTIONS(55),
    [sym_keyword_split] = ACTIONS(55),
    [sym_keyword_group] = ACTIONS(55),
    [sym_keyword_and] = ACTIONS(55),
    [sym_keyword_or] = ACTIONS(57),
    [sym_keyword_is] = ACTIONS(55),
    [sym_keyword_not] = ACTIONS(57),
    [sym_keyword_contains] = ACTIONS(55),
    [sym_keyword_contains_not] = ACTIONS(55),
    [sym_keyword_contains_all] = ACTIONS(55),
    [sym_keyword_contains_any] = ACTIONS(55),
    [sym_keyword_contains_none] = ACTIONS(55),
    [sym_keyword_inside] = ACTIONS(55),
    [sym_keyword_in] = ACTIONS(57),
    [sym_keyword_not_inside] = ACTIONS(55),
    [sym_keyword_all_inside] = ACTIONS(55),
    [sym_keyword_any_inside] = ACTIONS(55),
    [sym_keyword_none_inside] = ACTIONS(55),
    [sym_keyword_outside] = ACTIONS(55),
    [sym_keyword_intersects] = ACTIONS(55),
    [anon_sym_COMMA] = ACTIONS(55),
    [anon_sym_DASH_GT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(55),
    [anon_sym_RPAREN] = ACTIONS(55),
    [anon_sym_COLON] = ACTIONS(120),
    [anon_sym_RBRACE] = ACTIONS(55),
    [anon_sym_LT_DASH] = ACTIONS(57),
    [anon_sym_LT_DASH_GT] = ACTIONS(55),
    [anon_sym_STAR] = ACTIONS(57),
    [anon_sym_DOT] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(57),
    [anon_sym_GT] = ACTIONS(57),
    [anon_sym_EQ] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(57),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LT_PIPE] = ACTIONS(55),
    [anon_sym_AMP_AMP] = ACTIONS(55),
    [anon_sym_PIPE_PIPE] = ACTIONS(55),
    [anon_sym_QMARK_QMARK] = ACTIONS(55),
    [anon_sym_QMARK_COLON] = ACTIONS(55),
    [anon_sym_BANG_EQ] = ACTIONS(55),
    [anon_sym_EQ_EQ] = ACTIONS(55),
    [anon_sym_QMARK_EQ] = ACTIONS(55),
    [anon_sym_STAR_EQ] = ACTIONS(55),
    [anon_sym_TILDE] = ACTIONS(55),
    [anon_sym_BANG_TILDE] = ACTIONS(55),
    [anon_sym_STAR_TILDE] = ACTIONS(55),
    [anon_sym_LT_EQ] = ACTIONS(55),
    [anon_sym_GT_EQ] = ACTIONS(55),
    [anon_sym_PLUS] = ACTIONS(57),
    [anon_sym_PLUS_EQ] = ACTIONS(55),
    [anon_sym_DASH_EQ] = ACTIONS(55),
    [anon_sym_u00d7] = ACTIONS(55),
    [anon_sym_SLASH] = ACTIONS(57),
    [anon_sym_u00f7] = ACTIONS(55),
    [anon_sym_STAR_STAR] = ACTIONS(55),
    [anon_sym_u220b] = ACTIONS(55),
    [anon_sym_u220c] = ACTIONS(55),
    [anon_sym_u2287] = ACTIONS(55),
    [anon_sym_u2283] = ACTIONS(55),
    [anon_sym_u2285] = ACTIONS(55),
    [anon_sym_u2208] = ACTIONS(55),
    [anon_sym_u2209] = ACTIONS(55),
    [anon_sym_u2286] = ACTIONS(55),
    [anon_sym_u2282] = ACTIONS(55),
    [anon_sym_u2284] = ACTIONS(55),
    [anon_sym_AT_AT] = ACTIONS(55),
  },
  [238] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_explain] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_fetch] = ACTIONS(182),
    [sym_keyword_limit] = ACTIONS(182),
    [sym_keyword_order] = ACTIONS(182),
    [sym_keyword_with] = ACTIONS(182),
    [sym_keyword_where] = ACTIONS(182),
    [sym_keyword_split] = ACTIONS(182),
    [sym_keyword_group] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(184),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(477),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [239] = {
    [aux_sym_duration_repeat1] = STATE(239),
    [ts_builtin_sym_end] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(105),
    [sym_keyword_explain] = ACTIONS(105),
    [sym_keyword_parallel] = ACTIONS(105),
    [sym_keyword_timeout] = ACTIONS(105),
    [sym_keyword_fetch] = ACTIONS(105),
    [sym_keyword_limit] = ACTIONS(105),
    [sym_keyword_order] = ACTIONS(105),
    [sym_keyword_with] = ACTIONS(105),
    [sym_keyword_where] = ACTIONS(105),
    [sym_keyword_split] = ACTIONS(105),
    [sym_keyword_group] = ACTIONS(105),
    [sym_keyword_and] = ACTIONS(105),
    [sym_keyword_or] = ACTIONS(107),
    [sym_keyword_is] = ACTIONS(105),
    [sym_keyword_not] = ACTIONS(107),
    [sym_keyword_contains] = ACTIONS(105),
    [sym_keyword_contains_not] = ACTIONS(105),
    [sym_keyword_contains_all] = ACTIONS(105),
    [sym_keyword_contains_any] = ACTIONS(105),
    [sym_keyword_contains_none] = ACTIONS(105),
    [sym_keyword_inside] = ACTIONS(105),
    [sym_keyword_in] = ACTIONS(107),
    [sym_keyword_not_inside] = ACTIONS(105),
    [sym_keyword_all_inside] = ACTIONS(105),
    [sym_keyword_any_inside] = ACTIONS(105),
    [sym_keyword_none_inside] = ACTIONS(105),
    [sym_keyword_outside] = ACTIONS(105),
    [sym_keyword_intersects] = ACTIONS(105),
    [anon_sym_COMMA] = ACTIONS(105),
    [anon_sym_DASH_GT] = ACTIONS(105),
    [anon_sym_LBRACK] = ACTIONS(105),
    [anon_sym_LT_DASH] = ACTIONS(107),
    [anon_sym_LT_DASH_GT] = ACTIONS(105),
    [anon_sym_STAR] = ACTIONS(107),
    [anon_sym_DOT] = ACTIONS(105),
    [anon_sym_LT] = ACTIONS(107),
    [anon_sym_GT] = ACTIONS(107),
    [anon_sym_EQ] = ACTIONS(107),
    [sym_duration_part] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(107),
    [anon_sym_AT] = ACTIONS(107),
    [anon_sym_LT_PIPE] = ACTIONS(105),
    [anon_sym_AMP_AMP] = ACTIONS(105),
    [anon_sym_PIPE_PIPE] = ACTIONS(105),
    [anon_sym_QMARK_QMARK] = ACTIONS(105),
    [anon_sym_QMARK_COLON] = ACTIONS(105),
    [anon_sym_BANG_EQ] = ACTIONS(105),
    [anon_sym_EQ_EQ] = ACTIONS(105),
    [anon_sym_QMARK_EQ] = ACTIONS(105),
    [anon_sym_STAR_EQ] = ACTIONS(105),
    [anon_sym_TILDE] = ACTIONS(105),
    [anon_sym_BANG_TILDE] = ACTIONS(105),
    [anon_sym_STAR_TILDE] = ACTIONS(105),
    [anon_sym_LT_EQ] = ACTIONS(105),
    [anon_sym_GT_EQ] = ACTIONS(105),
    [anon_sym_PLUS] = ACTIONS(107),
    [anon_sym_PLUS_EQ] = ACTIONS(105),
    [anon_sym_DASH_EQ] = ACTIONS(105),
    [anon_sym_u00d7] = ACTIONS(105),
    [anon_sym_SLASH] = ACTIONS(107),
    [anon_sym_u00f7] = ACTIONS(105),
    [anon_sym_STAR_STAR] = ACTIONS(105),
    [anon_sym_u220b] = ACTIONS(105),
    [anon_sym_u220c] = ACTIONS(105),
    [anon_sym_u2287] = ACTIONS(105),
    [anon_sym_u2283] = ACTIONS(105),
    [anon_sym_u2285] = ACTIONS(105),
    [anon_sym_u2208] = ACTIONS(105),
    [anon_sym_u2209] = ACTIONS(105),
    [anon_sym_u2286] = ACTIONS(105),
    [anon_sym_u2282] = ACTIONS(105),
    [anon_sym_u2284] = ACTIONS(105),
    [anon_sym_AT_AT] = ACTIONS(105),
  },
  [240] = {
    [aux_sym_duration_repeat1] = STATE(239),
    [ts_builtin_sym_end] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(99),
    [sym_keyword_explain] = ACTIONS(99),
    [sym_keyword_parallel] = ACTIONS(99),
    [sym_keyword_timeout] = ACTIONS(99),
    [sym_keyword_fetch] = ACTIONS(99),
    [sym_keyword_limit] = ACTIONS(99),
    [sym_keyword_order] = ACTIONS(99),
    [sym_keyword_with] = ACTIONS(99),
    [sym_keyword_where] = ACTIONS(99),
    [sym_keyword_split] = ACTIONS(99),
    [sym_keyword_group] = ACTIONS(99),
    [sym_keyword_and] = ACTIONS(99),
    [sym_keyword_or] = ACTIONS(101),
    [sym_keyword_is] = ACTIONS(99),
    [sym_keyword_not] = ACTIONS(101),
    [sym_keyword_contains] = ACTIONS(99),
    [sym_keyword_contains_not] = ACTIONS(99),
    [sym_keyword_contains_all] = ACTIONS(99),
    [sym_keyword_contains_any] = ACTIONS(99),
    [sym_keyword_contains_none] = ACTIONS(99),
    [sym_keyword_inside] = ACTIONS(99),
    [sym_keyword_in] = ACTIONS(101),
    [sym_keyword_not_inside] = ACTIONS(99),
    [sym_keyword_all_inside] = ACTIONS(99),
    [sym_keyword_any_inside] = ACTIONS(99),
    [sym_keyword_none_inside] = ACTIONS(99),
    [sym_keyword_outside] = ACTIONS(99),
    [sym_keyword_intersects] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_DASH_GT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(99),
    [anon_sym_LT_DASH] = ACTIONS(101),
    [anon_sym_LT_DASH_GT] = ACTIONS(99),
    [anon_sym_STAR] = ACTIONS(101),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LT] = ACTIONS(101),
    [anon_sym_GT] = ACTIONS(101),
    [anon_sym_EQ] = ACTIONS(101),
    [sym_duration_part] = ACTIONS(482),
    [anon_sym_DASH] = ACTIONS(101),
    [anon_sym_AT] = ACTIONS(101),
    [anon_sym_LT_PIPE] = ACTIONS(99),
    [anon_sym_AMP_AMP] = ACTIONS(99),
    [anon_sym_PIPE_PIPE] = ACTIONS(99),
    [anon_sym_QMARK_QMARK] = ACTIONS(99),
    [anon_sym_QMARK_COLON] = ACTIONS(99),
    [anon_sym_BANG_EQ] = ACTIONS(99),
    [anon_sym_EQ_EQ] = ACTIONS(99),
    [anon_sym_QMARK_EQ] = ACTIONS(99),
    [anon_sym_STAR_EQ] = ACTIONS(99),
    [anon_sym_TILDE] = ACTIONS(99),
    [anon_sym_BANG_TILDE] = ACTIONS(99),
    [anon_sym_STAR_TILDE] = ACTIONS(99),
    [anon_sym_LT_EQ] = ACTIONS(99),
    [anon_sym_GT_EQ] = ACTIONS(99),
    [anon_sym_PLUS] = ACTIONS(101),
    [anon_sym_PLUS_EQ] = ACTIONS(99),
    [anon_sym_DASH_EQ] = ACTIONS(99),
    [anon_sym_u00d7] = ACTIONS(99),
    [anon_sym_SLASH] = ACTIONS(101),
    [anon_sym_u00f7] = ACTIONS(99),
    [anon_sym_STAR_STAR] = ACTIONS(99),
    [anon_sym_u220b] = ACTIONS(99),
    [anon_sym_u220c] = ACTIONS(99),
    [anon_sym_u2287] = ACTIONS(99),
    [anon_sym_u2283] = ACTIONS(99),
    [anon_sym_u2285] = ACTIONS(99),
    [anon_sym_u2208] = ACTIONS(99),
    [anon_sym_u2209] = ACTIONS(99),
    [anon_sym_u2286] = ACTIONS(99),
    [anon_sym_u2282] = ACTIONS(99),
    [anon_sym_u2284] = ACTIONS(99),
    [anon_sym_AT_AT] = ACTIONS(99),
  },
  [241] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(134),
    [sym_keyword_explain] = ACTIONS(134),
    [sym_keyword_parallel] = ACTIONS(134),
    [sym_keyword_timeout] = ACTIONS(134),
    [sym_keyword_fetch] = ACTIONS(134),
    [sym_keyword_limit] = ACTIONS(134),
    [sym_keyword_order] = ACTIONS(134),
    [sym_keyword_with] = ACTIONS(134),
    [sym_keyword_where] = ACTIONS(134),
    [sym_keyword_split] = ACTIONS(134),
    [sym_keyword_group] = ACTIONS(134),
    [sym_keyword_and] = ACTIONS(134),
    [sym_keyword_or] = ACTIONS(136),
    [sym_keyword_is] = ACTIONS(134),
    [sym_keyword_not] = ACTIONS(136),
    [sym_keyword_contains] = ACTIONS(134),
    [sym_keyword_contains_not] = ACTIONS(134),
    [sym_keyword_contains_all] = ACTIONS(134),
    [sym_keyword_contains_any] = ACTIONS(134),
    [sym_keyword_contains_none] = ACTIONS(134),
    [sym_keyword_inside] = ACTIONS(134),
    [sym_keyword_in] = ACTIONS(136),
    [sym_keyword_not_inside] = ACTIONS(134),
    [sym_keyword_all_inside] = ACTIONS(134),
    [sym_keyword_any_inside] = ACTIONS(134),
    [sym_keyword_none_inside] = ACTIONS(134),
    [sym_keyword_outside] = ACTIONS(134),
    [sym_keyword_intersects] = ACTIONS(134),
    [anon_sym_COMMA] = ACTIONS(134),
    [anon_sym_DASH_GT] = ACTIONS(134),
    [anon_sym_LBRACK] = ACTIONS(134),
    [anon_sym_RPAREN] = ACTIONS(134),
    [anon_sym_RBRACE] = ACTIONS(134),
    [anon_sym_LT_DASH] = ACTIONS(136),
    [anon_sym_LT_DASH_GT] = ACTIONS(134),
    [anon_sym_STAR] = ACTIONS(136),
    [anon_sym_DOT] = ACTIONS(136),
    [anon_sym_LT] = ACTIONS(136),
    [anon_sym_GT] = ACTIONS(136),
    [anon_sym_DOT_DOT] = ACTIONS(134),
    [anon_sym_EQ] = ACTIONS(136),
    [anon_sym_DASH] = ACTIONS(136),
    [anon_sym_AT] = ACTIONS(136),
    [anon_sym_LT_PIPE] = ACTIONS(134),
    [anon_sym_AMP_AMP] = ACTIONS(134),
    [anon_sym_PIPE_PIPE] = ACTIONS(134),
    [anon_sym_QMARK_QMARK] = ACTIONS(134),
    [anon_sym_QMARK_COLON] = ACTIONS(134),
    [anon_sym_BANG_EQ] = ACTIONS(134),
    [anon_sym_EQ_EQ] = ACTIONS(134),
    [anon_sym_QMARK_EQ] = ACTIONS(134),
    [anon_sym_STAR_EQ] = ACTIONS(134),
    [anon_sym_TILDE] = ACTIONS(134),
    [anon_sym_BANG_TILDE] = ACTIONS(134),
    [anon_sym_STAR_TILDE] = ACTIONS(134),
    [anon_sym_LT_EQ] = ACTIONS(134),
    [anon_sym_GT_EQ] = ACTIONS(134),
    [anon_sym_PLUS] = ACTIONS(136),
    [anon_sym_PLUS_EQ] = ACTIONS(134),
    [anon_sym_DASH_EQ] = ACTIONS(134),
    [anon_sym_u00d7] = ACTIONS(134),
    [anon_sym_SLASH] = ACTIONS(136),
    [anon_sym_u00f7] = ACTIONS(134),
    [anon_sym_STAR_STAR] = ACTIONS(134),
    [anon_sym_u220b] = ACTIONS(134),
    [anon_sym_u220c] = ACTIONS(134),
    [anon_sym_u2287] = ACTIONS(134),
    [anon_sym_u2283] = ACTIONS(134),
    [anon_sym_u2285] = ACTIONS(134),
    [anon_sym_u2208] = ACTIONS(134),
    [anon_sym_u2209] = ACTIONS(134),
    [anon_sym_u2286] = ACTIONS(134),
    [anon_sym_u2282] = ACTIONS(134),
    [anon_sym_u2284] = ACTIONS(134),
    [anon_sym_AT_AT] = ACTIONS(134),
  },
  [242] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(142),
    [sym_keyword_explain] = ACTIONS(142),
    [sym_keyword_parallel] = ACTIONS(142),
    [sym_keyword_timeout] = ACTIONS(142),
    [sym_keyword_fetch] = ACTIONS(142),
    [sym_keyword_limit] = ACTIONS(142),
    [sym_keyword_order] = ACTIONS(142),
    [sym_keyword_with] = ACTIONS(142),
    [sym_keyword_where] = ACTIONS(142),
    [sym_keyword_split] = ACTIONS(142),
    [sym_keyword_group] = ACTIONS(142),
    [sym_keyword_and] = ACTIONS(142),
    [sym_keyword_or] = ACTIONS(144),
    [sym_keyword_is] = ACTIONS(142),
    [sym_keyword_not] = ACTIONS(144),
    [sym_keyword_contains] = ACTIONS(142),
    [sym_keyword_contains_not] = ACTIONS(142),
    [sym_keyword_contains_all] = ACTIONS(142),
    [sym_keyword_contains_any] = ACTIONS(142),
    [sym_keyword_contains_none] = ACTIONS(142),
    [sym_keyword_inside] = ACTIONS(142),
    [sym_keyword_in] = ACTIONS(144),
    [sym_keyword_not_inside] = ACTIONS(142),
    [sym_keyword_all_inside] = ACTIONS(142),
    [sym_keyword_any_inside] = ACTIONS(142),
    [sym_keyword_none_inside] = ACTIONS(142),
    [sym_keyword_outside] = ACTIONS(142),
    [sym_keyword_intersects] = ACTIONS(142),
    [anon_sym_COMMA] = ACTIONS(142),
    [anon_sym_DASH_GT] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(142),
    [anon_sym_RPAREN] = ACTIONS(142),
    [anon_sym_RBRACE] = ACTIONS(142),
    [anon_sym_LT_DASH] = ACTIONS(144),
    [anon_sym_LT_DASH_GT] = ACTIONS(142),
    [anon_sym_STAR] = ACTIONS(144),
    [anon_sym_DOT] = ACTIONS(142),
    [anon_sym_LT] = ACTIONS(144),
    [anon_sym_GT] = ACTIONS(144),
    [anon_sym_EQ] = ACTIONS(144),
    [anon_sym_DASH] = ACTIONS(144),
    [anon_sym_AT] = ACTIONS(144),
    [anon_sym_LT_PIPE] = ACTIONS(142),
    [anon_sym_AMP_AMP] = ACTIONS(142),
    [anon_sym_PIPE_PIPE] = ACTIONS(142),
    [anon_sym_QMARK_QMARK] = ACTIONS(142),
    [anon_sym_QMARK_COLON] = ACTIONS(142),
    [anon_sym_BANG_EQ] = ACTIONS(142),
    [anon_sym_EQ_EQ] = ACTIONS(142),
    [anon_sym_QMARK_EQ] = ACTIONS(142),
    [anon_sym_STAR_EQ] = ACTIONS(142),
    [anon_sym_TILDE] = ACTIONS(142),
    [anon_sym_BANG_TILDE] = ACTIONS(142),
    [anon_sym_STAR_TILDE] = ACTIONS(142),
    [anon_sym_LT_EQ] = ACTIONS(142),
    [anon_sym_GT_EQ] = ACTIONS(142),
    [anon_sym_PLUS] = ACTIONS(144),
    [anon_sym_PLUS_EQ] = ACTIONS(142),
    [anon_sym_DASH_EQ] = ACTIONS(142),
    [anon_sym_u00d7] = ACTIONS(142),
    [anon_sym_SLASH] = ACTIONS(144),
    [anon_sym_u00f7] = ACTIONS(142),
    [anon_sym_STAR_STAR] = ACTIONS(142),
    [anon_sym_u220b] = ACTIONS(142),
    [anon_sym_u220c] = ACTIONS(142),
    [anon_sym_u2287] = ACTIONS(142),
    [anon_sym_u2283] = ACTIONS(142),
    [anon_sym_u2285] = ACTIONS(142),
    [anon_sym_u2208] = ACTIONS(142),
    [anon_sym_u2209] = ACTIONS(142),
    [anon_sym_u2286] = ACTIONS(142),
    [anon_sym_u2282] = ACTIONS(142),
    [anon_sym_u2284] = ACTIONS(142),
    [anon_sym_AT_AT] = ACTIONS(142),
  },
  [243] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(158),
    [sym_keyword_explain] = ACTIONS(158),
    [sym_keyword_parallel] = ACTIONS(158),
    [sym_keyword_timeout] = ACTIONS(158),
    [sym_keyword_fetch] = ACTIONS(158),
    [sym_keyword_limit] = ACTIONS(158),
    [sym_keyword_order] = ACTIONS(158),
    [sym_keyword_with] = ACTIONS(158),
    [sym_keyword_where] = ACTIONS(158),
    [sym_keyword_split] = ACTIONS(158),
    [sym_keyword_group] = ACTIONS(158),
    [sym_keyword_and] = ACTIONS(158),
    [sym_keyword_or] = ACTIONS(160),
    [sym_keyword_is] = ACTIONS(158),
    [sym_keyword_not] = ACTIONS(160),
    [sym_keyword_contains] = ACTIONS(158),
    [sym_keyword_contains_not] = ACTIONS(158),
    [sym_keyword_contains_all] = ACTIONS(158),
    [sym_keyword_contains_any] = ACTIONS(158),
    [sym_keyword_contains_none] = ACTIONS(158),
    [sym_keyword_inside] = ACTIONS(158),
    [sym_keyword_in] = ACTIONS(160),
    [sym_keyword_not_inside] = ACTIONS(158),
    [sym_keyword_all_inside] = ACTIONS(158),
    [sym_keyword_any_inside] = ACTIONS(158),
    [sym_keyword_none_inside] = ACTIONS(158),
    [sym_keyword_outside] = ACTIONS(158),
    [sym_keyword_intersects] = ACTIONS(158),
    [anon_sym_COMMA] = ACTIONS(158),
    [anon_sym_DASH_GT] = ACTIONS(158),
    [anon_sym_LBRACK] = ACTIONS(158),
    [anon_sym_RPAREN] = ACTIONS(158),
    [anon_sym_RBRACE] = ACTIONS(158),
    [anon_sym_LT_DASH] = ACTIONS(160),
    [anon_sym_LT_DASH_GT] = ACTIONS(158),
    [anon_sym_STAR] = ACTIONS(160),
    [anon_sym_DOT] = ACTIONS(158),
    [anon_sym_LT] = ACTIONS(160),
    [anon_sym_GT] = ACTIONS(160),
    [anon_sym_EQ] = ACTIONS(160),
    [anon_sym_DASH] = ACTIONS(160),
    [anon_sym_AT] = ACTIONS(160),
    [anon_sym_LT_PIPE] = ACTIONS(158),
    [anon_sym_AMP_AMP] = ACTIONS(158),
    [anon_sym_PIPE_PIPE] = ACTIONS(158),
    [anon_sym_QMARK_QMARK] = ACTIONS(158),
    [anon_sym_QMARK_COLON] = ACTIONS(158),
    [anon_sym_BANG_EQ] = ACTIONS(158),
    [anon_sym_EQ_EQ] = ACTIONS(158),
    [anon_sym_QMARK_EQ] = ACTIONS(158),
    [anon_sym_STAR_EQ] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(158),
    [anon_sym_BANG_TILDE] = ACTIONS(158),
    [anon_sym_STAR_TILDE] = ACTIONS(158),
    [anon_sym_LT_EQ] = ACTIONS(158),
    [anon_sym_GT_EQ] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(160),
    [anon_sym_PLUS_EQ] = ACTIONS(158),
    [anon_sym_DASH_EQ] = ACTIONS(158),
    [anon_sym_u00d7] = ACTIONS(158),
    [anon_sym_SLASH] = ACTIONS(160),
    [anon_sym_u00f7] = ACTIONS(158),
    [anon_sym_STAR_STAR] = ACTIONS(158),
    [anon_sym_u220b] = ACTIONS(158),
    [anon_sym_u220c] = ACTIONS(158),
    [anon_sym_u2287] = ACTIONS(158),
    [anon_sym_u2283] = ACTIONS(158),
    [anon_sym_u2285] = ACTIONS(158),
    [anon_sym_u2208] = ACTIONS(158),
    [anon_sym_u2209] = ACTIONS(158),
    [anon_sym_u2286] = ACTIONS(158),
    [anon_sym_u2282] = ACTIONS(158),
    [anon_sym_u2284] = ACTIONS(158),
    [anon_sym_AT_AT] = ACTIONS(158),
  },
  [244] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(36),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_return] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_where] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [245] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(138),
    [sym_keyword_explain] = ACTIONS(138),
    [sym_keyword_parallel] = ACTIONS(138),
    [sym_keyword_timeout] = ACTIONS(138),
    [sym_keyword_fetch] = ACTIONS(138),
    [sym_keyword_limit] = ACTIONS(138),
    [sym_keyword_order] = ACTIONS(138),
    [sym_keyword_with] = ACTIONS(138),
    [sym_keyword_where] = ACTIONS(138),
    [sym_keyword_split] = ACTIONS(138),
    [sym_keyword_group] = ACTIONS(138),
    [sym_keyword_and] = ACTIONS(138),
    [sym_keyword_or] = ACTIONS(140),
    [sym_keyword_is] = ACTIONS(138),
    [sym_keyword_not] = ACTIONS(140),
    [sym_keyword_contains] = ACTIONS(138),
    [sym_keyword_contains_not] = ACTIONS(138),
    [sym_keyword_contains_all] = ACTIONS(138),
    [sym_keyword_contains_any] = ACTIONS(138),
    [sym_keyword_contains_none] = ACTIONS(138),
    [sym_keyword_inside] = ACTIONS(138),
    [sym_keyword_in] = ACTIONS(140),
    [sym_keyword_not_inside] = ACTIONS(138),
    [sym_keyword_all_inside] = ACTIONS(138),
    [sym_keyword_any_inside] = ACTIONS(138),
    [sym_keyword_none_inside] = ACTIONS(138),
    [sym_keyword_outside] = ACTIONS(138),
    [sym_keyword_intersects] = ACTIONS(138),
    [anon_sym_COMMA] = ACTIONS(138),
    [anon_sym_DASH_GT] = ACTIONS(138),
    [anon_sym_LBRACK] = ACTIONS(138),
    [anon_sym_RPAREN] = ACTIONS(138),
    [anon_sym_RBRACE] = ACTIONS(138),
    [anon_sym_LT_DASH] = ACTIONS(140),
    [anon_sym_LT_DASH_GT] = ACTIONS(138),
    [anon_sym_STAR] = ACTIONS(140),
    [anon_sym_DOT] = ACTIONS(138),
    [anon_sym_LT] = ACTIONS(140),
    [anon_sym_GT] = ACTIONS(140),
    [anon_sym_EQ] = ACTIONS(140),
    [anon_sym_DASH] = ACTIONS(140),
    [anon_sym_AT] = ACTIONS(140),
    [anon_sym_LT_PIPE] = ACTIONS(138),
    [anon_sym_AMP_AMP] = ACTIONS(138),
    [anon_sym_PIPE_PIPE] = ACTIONS(138),
    [anon_sym_QMARK_QMARK] = ACTIONS(138),
    [anon_sym_QMARK_COLON] = ACTIONS(138),
    [anon_sym_BANG_EQ] = ACTIONS(138),
    [anon_sym_EQ_EQ] = ACTIONS(138),
    [anon_sym_QMARK_EQ] = ACTIONS(138),
    [anon_sym_STAR_EQ] = ACTIONS(138),
    [anon_sym_TILDE] = ACTIONS(138),
    [anon_sym_BANG_TILDE] = ACTIONS(138),
    [anon_sym_STAR_TILDE] = ACTIONS(138),
    [anon_sym_LT_EQ] = ACTIONS(138),
    [anon_sym_GT_EQ] = ACTIONS(138),
    [anon_sym_PLUS] = ACTIONS(140),
    [anon_sym_PLUS_EQ] = ACTIONS(138),
    [anon_sym_DASH_EQ] = ACTIONS(138),
    [anon_sym_u00d7] = ACTIONS(138),
    [anon_sym_SLASH] = ACTIONS(140),
    [anon_sym_u00f7] = ACTIONS(138),
    [anon_sym_STAR_STAR] = ACTIONS(138),
    [anon_sym_u220b] = ACTIONS(138),
    [anon_sym_u220c] = ACTIONS(138),
    [anon_sym_u2287] = ACTIONS(138),
    [anon_sym_u2283] = ACTIONS(138),
    [anon_sym_u2285] = ACTIONS(138),
    [anon_sym_u2208] = ACTIONS(138),
    [anon_sym_u2209] = ACTIONS(138),
    [anon_sym_u2286] = ACTIONS(138),
    [anon_sym_u2282] = ACTIONS(138),
    [anon_sym_u2284] = ACTIONS(138),
    [anon_sym_AT_AT] = ACTIONS(138),
  },
  [246] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(33),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_return] = ACTIONS(180),
    [sym_keyword_parallel] = ACTIONS(180),
    [sym_keyword_timeout] = ACTIONS(180),
    [sym_keyword_where] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [247] = {
    [ts_builtin_sym_end] = ACTIONS(150),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(150),
    [sym_keyword_as] = ACTIONS(150),
    [sym_keyword_where] = ACTIONS(150),
    [sym_keyword_group] = ACTIONS(150),
    [sym_keyword_and] = ACTIONS(150),
    [sym_keyword_or] = ACTIONS(150),
    [sym_keyword_is] = ACTIONS(150),
    [sym_keyword_not] = ACTIONS(152),
    [sym_keyword_contains] = ACTIONS(150),
    [sym_keyword_contains_not] = ACTIONS(150),
    [sym_keyword_contains_all] = ACTIONS(150),
    [sym_keyword_contains_any] = ACTIONS(150),
    [sym_keyword_contains_none] = ACTIONS(150),
    [sym_keyword_inside] = ACTIONS(150),
    [sym_keyword_in] = ACTIONS(152),
    [sym_keyword_not_inside] = ACTIONS(150),
    [sym_keyword_all_inside] = ACTIONS(150),
    [sym_keyword_any_inside] = ACTIONS(150),
    [sym_keyword_none_inside] = ACTIONS(150),
    [sym_keyword_outside] = ACTIONS(150),
    [sym_keyword_intersects] = ACTIONS(150),
    [sym_keyword_drop] = ACTIONS(150),
    [sym_keyword_schemafull] = ACTIONS(150),
    [sym_keyword_schemaless] = ACTIONS(150),
    [sym_keyword_changefeed] = ACTIONS(150),
    [sym_keyword_type] = ACTIONS(150),
    [sym_keyword_permissions] = ACTIONS(150),
    [sym_keyword_for] = ACTIONS(150),
    [sym_keyword_comment] = ACTIONS(150),
    [anon_sym_COMMA] = ACTIONS(150),
    [anon_sym_DASH_GT] = ACTIONS(150),
    [anon_sym_LBRACK] = ACTIONS(150),
    [anon_sym_LT_DASH] = ACTIONS(152),
    [anon_sym_LT_DASH_GT] = ACTIONS(150),
    [anon_sym_STAR] = ACTIONS(152),
    [anon_sym_DOT] = ACTIONS(150),
    [anon_sym_LT] = ACTIONS(152),
    [anon_sym_GT] = ACTIONS(152),
    [anon_sym_EQ] = ACTIONS(152),
    [anon_sym_DASH] = ACTIONS(152),
    [anon_sym_AT] = ACTIONS(152),
    [anon_sym_LT_PIPE] = ACTIONS(150),
    [anon_sym_AMP_AMP] = ACTIONS(150),
    [anon_sym_PIPE_PIPE] = ACTIONS(150),
    [anon_sym_QMARK_QMARK] = ACTIONS(150),
    [anon_sym_QMARK_COLON] = ACTIONS(150),
    [anon_sym_BANG_EQ] = ACTIONS(150),
    [anon_sym_EQ_EQ] = ACTIONS(150),
    [anon_sym_QMARK_EQ] = ACTIONS(150),
    [anon_sym_STAR_EQ] = ACTIONS(150),
    [anon_sym_TILDE] = ACTIONS(150),
    [anon_sym_BANG_TILDE] = ACTIONS(150),
    [anon_sym_STAR_TILDE] = ACTIONS(150),
    [anon_sym_LT_EQ] = ACTIONS(150),
    [anon_sym_GT_EQ] = ACTIONS(150),
    [anon_sym_PLUS] = ACTIONS(152),
    [anon_sym_PLUS_EQ] = ACTIONS(150),
    [anon_sym_DASH_EQ] = ACTIONS(150),
    [anon_sym_u00d7] = ACTIONS(150),
    [anon_sym_SLASH] = ACTIONS(152),
    [anon_sym_u00f7] = ACTIONS(150),
    [anon_sym_STAR_STAR] = ACTIONS(150),
    [anon_sym_u220b] = ACTIONS(150),
    [anon_sym_u220c] = ACTIONS(150),
    [anon_sym_u2287] = ACTIONS(150),
    [anon_sym_u2283] = ACTIONS(150),
    [anon_sym_u2285] = ACTIONS(150),
    [anon_sym_u2208] = ACTIONS(150),
    [anon_sym_u2209] = ACTIONS(150),
    [anon_sym_u2286] = ACTIONS(150),
    [anon_sym_u2282] = ACTIONS(150),
    [anon_sym_u2284] = ACTIONS(150),
    [anon_sym_AT_AT] = ACTIONS(150),
  },
  [248] = {
    [ts_builtin_sym_end] = ACTIONS(198),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(198),
    [sym_keyword_as] = ACTIONS(198),
    [sym_keyword_where] = ACTIONS(198),
    [sym_keyword_group] = ACTIONS(198),
    [sym_keyword_and] = ACTIONS(198),
    [sym_keyword_or] = ACTIONS(198),
    [sym_keyword_is] = ACTIONS(198),
    [sym_keyword_not] = ACTIONS(200),
    [sym_keyword_contains] = ACTIONS(198),
    [sym_keyword_contains_not] = ACTIONS(198),
    [sym_keyword_contains_all] = ACTIONS(198),
    [sym_keyword_contains_any] = ACTIONS(198),
    [sym_keyword_contains_none] = ACTIONS(198),
    [sym_keyword_inside] = ACTIONS(198),
    [sym_keyword_in] = ACTIONS(200),
    [sym_keyword_not_inside] = ACTIONS(198),
    [sym_keyword_all_inside] = ACTIONS(198),
    [sym_keyword_any_inside] = ACTIONS(198),
    [sym_keyword_none_inside] = ACTIONS(198),
    [sym_keyword_outside] = ACTIONS(198),
    [sym_keyword_intersects] = ACTIONS(198),
    [sym_keyword_drop] = ACTIONS(198),
    [sym_keyword_schemafull] = ACTIONS(198),
    [sym_keyword_schemaless] = ACTIONS(198),
    [sym_keyword_changefeed] = ACTIONS(198),
    [sym_keyword_type] = ACTIONS(198),
    [sym_keyword_permissions] = ACTIONS(198),
    [sym_keyword_for] = ACTIONS(198),
    [sym_keyword_comment] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(198),
    [anon_sym_DASH_GT] = ACTIONS(198),
    [anon_sym_LBRACK] = ACTIONS(198),
    [anon_sym_LT_DASH] = ACTIONS(200),
    [anon_sym_LT_DASH_GT] = ACTIONS(198),
    [anon_sym_STAR] = ACTIONS(200),
    [anon_sym_DOT] = ACTIONS(198),
    [anon_sym_LT] = ACTIONS(200),
    [anon_sym_GT] = ACTIONS(200),
    [anon_sym_EQ] = ACTIONS(200),
    [anon_sym_DASH] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(200),
    [anon_sym_LT_PIPE] = ACTIONS(198),
    [anon_sym_AMP_AMP] = ACTIONS(198),
    [anon_sym_PIPE_PIPE] = ACTIONS(198),
    [anon_sym_QMARK_QMARK] = ACTIONS(198),
    [anon_sym_QMARK_COLON] = ACTIONS(198),
    [anon_sym_BANG_EQ] = ACTIONS(198),
    [anon_sym_EQ_EQ] = ACTIONS(198),
    [anon_sym_QMARK_EQ] = ACTIONS(198),
    [anon_sym_STAR_EQ] = ACTIONS(198),
    [anon_sym_TILDE] = ACTIONS(198),
    [anon_sym_BANG_TILDE] = ACTIONS(198),
    [anon_sym_STAR_TILDE] = ACTIONS(198),
    [anon_sym_LT_EQ] = ACTIONS(198),
    [anon_sym_GT_EQ] = ACTIONS(198),
    [anon_sym_PLUS] = ACTIONS(200),
    [anon_sym_PLUS_EQ] = ACTIONS(198),
    [anon_sym_DASH_EQ] = ACTIONS(198),
    [anon_sym_u00d7] = ACTIONS(198),
    [anon_sym_SLASH] = ACTIONS(200),
    [anon_sym_u00f7] = ACTIONS(198),
    [anon_sym_STAR_STAR] = ACTIONS(198),
    [anon_sym_u220b] = ACTIONS(198),
    [anon_sym_u220c] = ACTIONS(198),
    [anon_sym_u2287] = ACTIONS(198),
    [anon_sym_u2283] = ACTIONS(198),
    [anon_sym_u2285] = ACTIONS(198),
    [anon_sym_u2208] = ACTIONS(198),
    [anon_sym_u2209] = ACTIONS(198),
    [anon_sym_u2286] = ACTIONS(198),
    [anon_sym_u2282] = ACTIONS(198),
    [anon_sym_u2284] = ACTIONS(198),
    [anon_sym_AT_AT] = ACTIONS(198),
  },
  [249] = {
    [ts_builtin_sym_end] = ACTIONS(138),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(138),
    [sym_keyword_as] = ACTIONS(138),
    [sym_keyword_where] = ACTIONS(138),
    [sym_keyword_group] = ACTIONS(138),
    [sym_keyword_and] = ACTIONS(138),
    [sym_keyword_or] = ACTIONS(138),
    [sym_keyword_is] = ACTIONS(138),
    [sym_keyword_not] = ACTIONS(140),
    [sym_keyword_contains] = ACTIONS(138),
    [sym_keyword_contains_not] = ACTIONS(138),
    [sym_keyword_contains_all] = ACTIONS(138),
    [sym_keyword_contains_any] = ACTIONS(138),
    [sym_keyword_contains_none] = ACTIONS(138),
    [sym_keyword_inside] = ACTIONS(138),
    [sym_keyword_in] = ACTIONS(140),
    [sym_keyword_not_inside] = ACTIONS(138),
    [sym_keyword_all_inside] = ACTIONS(138),
    [sym_keyword_any_inside] = ACTIONS(138),
    [sym_keyword_none_inside] = ACTIONS(138),
    [sym_keyword_outside] = ACTIONS(138),
    [sym_keyword_intersects] = ACTIONS(138),
    [sym_keyword_drop] = ACTIONS(138),
    [sym_keyword_schemafull] = ACTIONS(138),
    [sym_keyword_schemaless] = ACTIONS(138),
    [sym_keyword_changefeed] = ACTIONS(138),
    [sym_keyword_type] = ACTIONS(138),
    [sym_keyword_permissions] = ACTIONS(138),
    [sym_keyword_for] = ACTIONS(138),
    [sym_keyword_comment] = ACTIONS(138),
    [anon_sym_COMMA] = ACTIONS(138),
    [anon_sym_DASH_GT] = ACTIONS(138),
    [anon_sym_LBRACK] = ACTIONS(138),
    [anon_sym_LT_DASH] = ACTIONS(140),
    [anon_sym_LT_DASH_GT] = ACTIONS(138),
    [anon_sym_STAR] = ACTIONS(140),
    [anon_sym_DOT] = ACTIONS(138),
    [anon_sym_LT] = ACTIONS(140),
    [anon_sym_GT] = ACTIONS(140),
    [anon_sym_EQ] = ACTIONS(140),
    [anon_sym_DASH] = ACTIONS(140),
    [anon_sym_AT] = ACTIONS(140),
    [anon_sym_LT_PIPE] = ACTIONS(138),
    [anon_sym_AMP_AMP] = ACTIONS(138),
    [anon_sym_PIPE_PIPE] = ACTIONS(138),
    [anon_sym_QMARK_QMARK] = ACTIONS(138),
    [anon_sym_QMARK_COLON] = ACTIONS(138),
    [anon_sym_BANG_EQ] = ACTIONS(138),
    [anon_sym_EQ_EQ] = ACTIONS(138),
    [anon_sym_QMARK_EQ] = ACTIONS(138),
    [anon_sym_STAR_EQ] = ACTIONS(138),
    [anon_sym_TILDE] = ACTIONS(138),
    [anon_sym_BANG_TILDE] = ACTIONS(138),
    [anon_sym_STAR_TILDE] = ACTIONS(138),
    [anon_sym_LT_EQ] = ACTIONS(138),
    [anon_sym_GT_EQ] = ACTIONS(138),
    [anon_sym_PLUS] = ACTIONS(140),
    [anon_sym_PLUS_EQ] = ACTIONS(138),
    [anon_sym_DASH_EQ] = ACTIONS(138),
    [anon_sym_u00d7] = ACTIONS(138),
    [anon_sym_SLASH] = ACTIONS(140),
    [anon_sym_u00f7] = ACTIONS(138),
    [anon_sym_STAR_STAR] = ACTIONS(138),
    [anon_sym_u220b] = ACTIONS(138),
    [anon_sym_u220c] = ACTIONS(138),
    [anon_sym_u2287] = ACTIONS(138),
    [anon_sym_u2283] = ACTIONS(138),
    [anon_sym_u2285] = ACTIONS(138),
    [anon_sym_u2208] = ACTIONS(138),
    [anon_sym_u2209] = ACTIONS(138),
    [anon_sym_u2286] = ACTIONS(138),
    [anon_sym_u2282] = ACTIONS(138),
    [anon_sym_u2284] = ACTIONS(138),
    [anon_sym_AT_AT] = ACTIONS(138),
  },
  [250] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(45),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_return] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_where] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_RPAREN] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [251] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(150),
    [sym_keyword_explain] = ACTIONS(150),
    [sym_keyword_parallel] = ACTIONS(150),
    [sym_keyword_timeout] = ACTIONS(150),
    [sym_keyword_fetch] = ACTIONS(150),
    [sym_keyword_limit] = ACTIONS(150),
    [sym_keyword_order] = ACTIONS(150),
    [sym_keyword_with] = ACTIONS(150),
    [sym_keyword_where] = ACTIONS(150),
    [sym_keyword_split] = ACTIONS(150),
    [sym_keyword_group] = ACTIONS(150),
    [sym_keyword_and] = ACTIONS(150),
    [sym_keyword_or] = ACTIONS(152),
    [sym_keyword_is] = ACTIONS(150),
    [sym_keyword_not] = ACTIONS(152),
    [sym_keyword_contains] = ACTIONS(150),
    [sym_keyword_contains_not] = ACTIONS(150),
    [sym_keyword_contains_all] = ACTIONS(150),
    [sym_keyword_contains_any] = ACTIONS(150),
    [sym_keyword_contains_none] = ACTIONS(150),
    [sym_keyword_inside] = ACTIONS(150),
    [sym_keyword_in] = ACTIONS(152),
    [sym_keyword_not_inside] = ACTIONS(150),
    [sym_keyword_all_inside] = ACTIONS(150),
    [sym_keyword_any_inside] = ACTIONS(150),
    [sym_keyword_none_inside] = ACTIONS(150),
    [sym_keyword_outside] = ACTIONS(150),
    [sym_keyword_intersects] = ACTIONS(150),
    [anon_sym_COMMA] = ACTIONS(150),
    [anon_sym_DASH_GT] = ACTIONS(150),
    [anon_sym_LBRACK] = ACTIONS(150),
    [anon_sym_RPAREN] = ACTIONS(150),
    [anon_sym_RBRACE] = ACTIONS(150),
    [anon_sym_LT_DASH] = ACTIONS(152),
    [anon_sym_LT_DASH_GT] = ACTIONS(150),
    [anon_sym_STAR] = ACTIONS(152),
    [anon_sym_DOT] = ACTIONS(150),
    [anon_sym_LT] = ACTIONS(152),
    [anon_sym_GT] = ACTIONS(152),
    [anon_sym_EQ] = ACTIONS(152),
    [anon_sym_DASH] = ACTIONS(152),
    [anon_sym_AT] = ACTIONS(152),
    [anon_sym_LT_PIPE] = ACTIONS(150),
    [anon_sym_AMP_AMP] = ACTIONS(150),
    [anon_sym_PIPE_PIPE] = ACTIONS(150),
    [anon_sym_QMARK_QMARK] = ACTIONS(150),
    [anon_sym_QMARK_COLON] = ACTIONS(150),
    [anon_sym_BANG_EQ] = ACTIONS(150),
    [anon_sym_EQ_EQ] = ACTIONS(150),
    [anon_sym_QMARK_EQ] = ACTIONS(150),
    [anon_sym_STAR_EQ] = ACTIONS(150),
    [anon_sym_TILDE] = ACTIONS(150),
    [anon_sym_BANG_TILDE] = ACTIONS(150),
    [anon_sym_STAR_TILDE] = ACTIONS(150),
    [anon_sym_LT_EQ] = ACTIONS(150),
    [anon_sym_GT_EQ] = ACTIONS(150),
    [anon_sym_PLUS] = ACTIONS(152),
    [anon_sym_PLUS_EQ] = ACTIONS(150),
    [anon_sym_DASH_EQ] = ACTIONS(150),
    [anon_sym_u00d7] = ACTIONS(150),
    [anon_sym_SLASH] = ACTIONS(152),
    [anon_sym_u00f7] = ACTIONS(150),
    [anon_sym_STAR_STAR] = ACTIONS(150),
    [anon_sym_u220b] = ACTIONS(150),
    [anon_sym_u220c] = ACTIONS(150),
    [anon_sym_u2287] = ACTIONS(150),
    [anon_sym_u2283] = ACTIONS(150),
    [anon_sym_u2285] = ACTIONS(150),
    [anon_sym_u2208] = ACTIONS(150),
    [anon_sym_u2209] = ACTIONS(150),
    [anon_sym_u2286] = ACTIONS(150),
    [anon_sym_u2282] = ACTIONS(150),
    [anon_sym_u2284] = ACTIONS(150),
    [anon_sym_AT_AT] = ACTIONS(150),
  },
  [252] = {
    [ts_builtin_sym_end] = ACTIONS(182),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_as] = ACTIONS(182),
    [sym_keyword_where] = ACTIONS(182),
    [sym_keyword_group] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_drop] = ACTIONS(182),
    [sym_keyword_schemafull] = ACTIONS(182),
    [sym_keyword_schemaless] = ACTIONS(182),
    [sym_keyword_changefeed] = ACTIONS(182),
    [sym_keyword_type] = ACTIONS(182),
    [sym_keyword_permissions] = ACTIONS(182),
    [sym_keyword_comment] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(484),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [253] = {
    [ts_builtin_sym_end] = ACTIONS(162),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(162),
    [sym_keyword_as] = ACTIONS(162),
    [sym_keyword_where] = ACTIONS(162),
    [sym_keyword_group] = ACTIONS(162),
    [sym_keyword_and] = ACTIONS(162),
    [sym_keyword_or] = ACTIONS(162),
    [sym_keyword_is] = ACTIONS(162),
    [sym_keyword_not] = ACTIONS(164),
    [sym_keyword_contains] = ACTIONS(162),
    [sym_keyword_contains_not] = ACTIONS(162),
    [sym_keyword_contains_all] = ACTIONS(162),
    [sym_keyword_contains_any] = ACTIONS(162),
    [sym_keyword_contains_none] = ACTIONS(162),
    [sym_keyword_inside] = ACTIONS(162),
    [sym_keyword_in] = ACTIONS(164),
    [sym_keyword_not_inside] = ACTIONS(162),
    [sym_keyword_all_inside] = ACTIONS(162),
    [sym_keyword_any_inside] = ACTIONS(162),
    [sym_keyword_none_inside] = ACTIONS(162),
    [sym_keyword_outside] = ACTIONS(162),
    [sym_keyword_intersects] = ACTIONS(162),
    [sym_keyword_drop] = ACTIONS(162),
    [sym_keyword_schemafull] = ACTIONS(162),
    [sym_keyword_schemaless] = ACTIONS(162),
    [sym_keyword_changefeed] = ACTIONS(162),
    [sym_keyword_type] = ACTIONS(162),
    [sym_keyword_permissions] = ACTIONS(162),
    [sym_keyword_for] = ACTIONS(162),
    [sym_keyword_comment] = ACTIONS(162),
    [anon_sym_COMMA] = ACTIONS(162),
    [anon_sym_DASH_GT] = ACTIONS(162),
    [anon_sym_LBRACK] = ACTIONS(162),
    [anon_sym_LT_DASH] = ACTIONS(164),
    [anon_sym_LT_DASH_GT] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_DOT] = ACTIONS(162),
    [anon_sym_LT] = ACTIONS(164),
    [anon_sym_GT] = ACTIONS(164),
    [anon_sym_EQ] = ACTIONS(164),
    [anon_sym_DASH] = ACTIONS(164),
    [anon_sym_AT] = ACTIONS(164),
    [anon_sym_LT_PIPE] = ACTIONS(162),
    [anon_sym_AMP_AMP] = ACTIONS(162),
    [anon_sym_PIPE_PIPE] = ACTIONS(162),
    [anon_sym_QMARK_QMARK] = ACTIONS(162),
    [anon_sym_QMARK_COLON] = ACTIONS(162),
    [anon_sym_BANG_EQ] = ACTIONS(162),
    [anon_sym_EQ_EQ] = ACTIONS(162),
    [anon_sym_QMARK_EQ] = ACTIONS(162),
    [anon_sym_STAR_EQ] = ACTIONS(162),
    [anon_sym_TILDE] = ACTIONS(162),
    [anon_sym_BANG_TILDE] = ACTIONS(162),
    [anon_sym_STAR_TILDE] = ACTIONS(162),
    [anon_sym_LT_EQ] = ACTIONS(162),
    [anon_sym_GT_EQ] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(164),
    [anon_sym_PLUS_EQ] = ACTIONS(162),
    [anon_sym_DASH_EQ] = ACTIONS(162),
    [anon_sym_u00d7] = ACTIONS(162),
    [anon_sym_SLASH] = ACTIONS(164),
    [anon_sym_u00f7] = ACTIONS(162),
    [anon_sym_STAR_STAR] = ACTIONS(162),
    [anon_sym_u220b] = ACTIONS(162),
    [anon_sym_u220c] = ACTIONS(162),
    [anon_sym_u2287] = ACTIONS(162),
    [anon_sym_u2283] = ACTIONS(162),
    [anon_sym_u2285] = ACTIONS(162),
    [anon_sym_u2208] = ACTIONS(162),
    [anon_sym_u2209] = ACTIONS(162),
    [anon_sym_u2286] = ACTIONS(162),
    [anon_sym_u2282] = ACTIONS(162),
    [anon_sym_u2284] = ACTIONS(162),
    [anon_sym_AT_AT] = ACTIONS(162),
  },
  [254] = {
    [ts_builtin_sym_end] = ACTIONS(170),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(170),
    [sym_keyword_as] = ACTIONS(170),
    [sym_keyword_where] = ACTIONS(170),
    [sym_keyword_group] = ACTIONS(170),
    [sym_keyword_and] = ACTIONS(170),
    [sym_keyword_or] = ACTIONS(170),
    [sym_keyword_is] = ACTIONS(170),
    [sym_keyword_not] = ACTIONS(172),
    [sym_keyword_contains] = ACTIONS(170),
    [sym_keyword_contains_not] = ACTIONS(170),
    [sym_keyword_contains_all] = ACTIONS(170),
    [sym_keyword_contains_any] = ACTIONS(170),
    [sym_keyword_contains_none] = ACTIONS(170),
    [sym_keyword_inside] = ACTIONS(170),
    [sym_keyword_in] = ACTIONS(172),
    [sym_keyword_not_inside] = ACTIONS(170),
    [sym_keyword_all_inside] = ACTIONS(170),
    [sym_keyword_any_inside] = ACTIONS(170),
    [sym_keyword_none_inside] = ACTIONS(170),
    [sym_keyword_outside] = ACTIONS(170),
    [sym_keyword_intersects] = ACTIONS(170),
    [sym_keyword_drop] = ACTIONS(170),
    [sym_keyword_schemafull] = ACTIONS(170),
    [sym_keyword_schemaless] = ACTIONS(170),
    [sym_keyword_changefeed] = ACTIONS(170),
    [sym_keyword_type] = ACTIONS(170),
    [sym_keyword_permissions] = ACTIONS(170),
    [sym_keyword_for] = ACTIONS(170),
    [sym_keyword_comment] = ACTIONS(170),
    [anon_sym_COMMA] = ACTIONS(170),
    [anon_sym_DASH_GT] = ACTIONS(170),
    [anon_sym_LBRACK] = ACTIONS(170),
    [anon_sym_LT_DASH] = ACTIONS(172),
    [anon_sym_LT_DASH_GT] = ACTIONS(170),
    [anon_sym_STAR] = ACTIONS(172),
    [anon_sym_DOT] = ACTIONS(170),
    [anon_sym_LT] = ACTIONS(172),
    [anon_sym_GT] = ACTIONS(172),
    [anon_sym_EQ] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [anon_sym_AT] = ACTIONS(172),
    [anon_sym_LT_PIPE] = ACTIONS(170),
    [anon_sym_AMP_AMP] = ACTIONS(170),
    [anon_sym_PIPE_PIPE] = ACTIONS(170),
    [anon_sym_QMARK_QMARK] = ACTIONS(170),
    [anon_sym_QMARK_COLON] = ACTIONS(170),
    [anon_sym_BANG_EQ] = ACTIONS(170),
    [anon_sym_EQ_EQ] = ACTIONS(170),
    [anon_sym_QMARK_EQ] = ACTIONS(170),
    [anon_sym_STAR_EQ] = ACTIONS(170),
    [anon_sym_TILDE] = ACTIONS(170),
    [anon_sym_BANG_TILDE] = ACTIONS(170),
    [anon_sym_STAR_TILDE] = ACTIONS(170),
    [anon_sym_LT_EQ] = ACTIONS(170),
    [anon_sym_GT_EQ] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_PLUS_EQ] = ACTIONS(170),
    [anon_sym_DASH_EQ] = ACTIONS(170),
    [anon_sym_u00d7] = ACTIONS(170),
    [anon_sym_SLASH] = ACTIONS(172),
    [anon_sym_u00f7] = ACTIONS(170),
    [anon_sym_STAR_STAR] = ACTIONS(170),
    [anon_sym_u220b] = ACTIONS(170),
    [anon_sym_u220c] = ACTIONS(170),
    [anon_sym_u2287] = ACTIONS(170),
    [anon_sym_u2283] = ACTIONS(170),
    [anon_sym_u2285] = ACTIONS(170),
    [anon_sym_u2208] = ACTIONS(170),
    [anon_sym_u2209] = ACTIONS(170),
    [anon_sym_u2286] = ACTIONS(170),
    [anon_sym_u2282] = ACTIONS(170),
    [anon_sym_u2284] = ACTIONS(170),
    [anon_sym_AT_AT] = ACTIONS(170),
  },
  [255] = {
    [ts_builtin_sym_end] = ACTIONS(174),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(174),
    [sym_keyword_as] = ACTIONS(174),
    [sym_keyword_where] = ACTIONS(174),
    [sym_keyword_group] = ACTIONS(174),
    [sym_keyword_and] = ACTIONS(174),
    [sym_keyword_or] = ACTIONS(174),
    [sym_keyword_is] = ACTIONS(174),
    [sym_keyword_not] = ACTIONS(176),
    [sym_keyword_contains] = ACTIONS(174),
    [sym_keyword_contains_not] = ACTIONS(174),
    [sym_keyword_contains_all] = ACTIONS(174),
    [sym_keyword_contains_any] = ACTIONS(174),
    [sym_keyword_contains_none] = ACTIONS(174),
    [sym_keyword_inside] = ACTIONS(174),
    [sym_keyword_in] = ACTIONS(176),
    [sym_keyword_not_inside] = ACTIONS(174),
    [sym_keyword_all_inside] = ACTIONS(174),
    [sym_keyword_any_inside] = ACTIONS(174),
    [sym_keyword_none_inside] = ACTIONS(174),
    [sym_keyword_outside] = ACTIONS(174),
    [sym_keyword_intersects] = ACTIONS(174),
    [sym_keyword_drop] = ACTIONS(174),
    [sym_keyword_schemafull] = ACTIONS(174),
    [sym_keyword_schemaless] = ACTIONS(174),
    [sym_keyword_changefeed] = ACTIONS(174),
    [sym_keyword_type] = ACTIONS(174),
    [sym_keyword_permissions] = ACTIONS(174),
    [sym_keyword_for] = ACTIONS(174),
    [sym_keyword_comment] = ACTIONS(174),
    [anon_sym_COMMA] = ACTIONS(174),
    [anon_sym_DASH_GT] = ACTIONS(174),
    [anon_sym_LBRACK] = ACTIONS(174),
    [anon_sym_LT_DASH] = ACTIONS(176),
    [anon_sym_LT_DASH_GT] = ACTIONS(174),
    [anon_sym_STAR] = ACTIONS(176),
    [anon_sym_DOT] = ACTIONS(174),
    [anon_sym_LT] = ACTIONS(176),
    [anon_sym_GT] = ACTIONS(176),
    [anon_sym_EQ] = ACTIONS(176),
    [anon_sym_DASH] = ACTIONS(176),
    [anon_sym_AT] = ACTIONS(176),
    [anon_sym_LT_PIPE] = ACTIONS(174),
    [anon_sym_AMP_AMP] = ACTIONS(174),
    [anon_sym_PIPE_PIPE] = ACTIONS(174),
    [anon_sym_QMARK_QMARK] = ACTIONS(174),
    [anon_sym_QMARK_COLON] = ACTIONS(174),
    [anon_sym_BANG_EQ] = ACTIONS(174),
    [anon_sym_EQ_EQ] = ACTIONS(174),
    [anon_sym_QMARK_EQ] = ACTIONS(174),
    [anon_sym_STAR_EQ] = ACTIONS(174),
    [anon_sym_TILDE] = ACTIONS(174),
    [anon_sym_BANG_TILDE] = ACTIONS(174),
    [anon_sym_STAR_TILDE] = ACTIONS(174),
    [anon_sym_LT_EQ] = ACTIONS(174),
    [anon_sym_GT_EQ] = ACTIONS(174),
    [anon_sym_PLUS] = ACTIONS(176),
    [anon_sym_PLUS_EQ] = ACTIONS(174),
    [anon_sym_DASH_EQ] = ACTIONS(174),
    [anon_sym_u00d7] = ACTIONS(174),
    [anon_sym_SLASH] = ACTIONS(176),
    [anon_sym_u00f7] = ACTIONS(174),
    [anon_sym_STAR_STAR] = ACTIONS(174),
    [anon_sym_u220b] = ACTIONS(174),
    [anon_sym_u220c] = ACTIONS(174),
    [anon_sym_u2287] = ACTIONS(174),
    [anon_sym_u2283] = ACTIONS(174),
    [anon_sym_u2285] = ACTIONS(174),
    [anon_sym_u2208] = ACTIONS(174),
    [anon_sym_u2209] = ACTIONS(174),
    [anon_sym_u2286] = ACTIONS(174),
    [anon_sym_u2282] = ACTIONS(174),
    [anon_sym_u2284] = ACTIONS(174),
    [anon_sym_AT_AT] = ACTIONS(174),
  },
  [256] = {
    [ts_builtin_sym_end] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_as] = ACTIONS(178),
    [sym_keyword_where] = ACTIONS(178),
    [sym_keyword_group] = ACTIONS(178),
    [sym_keyword_and] = ACTIONS(178),
    [sym_keyword_or] = ACTIONS(178),
    [sym_keyword_is] = ACTIONS(178),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(178),
    [sym_keyword_contains_not] = ACTIONS(178),
    [sym_keyword_contains_all] = ACTIONS(178),
    [sym_keyword_contains_any] = ACTIONS(178),
    [sym_keyword_contains_none] = ACTIONS(178),
    [sym_keyword_inside] = ACTIONS(178),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(178),
    [sym_keyword_all_inside] = ACTIONS(178),
    [sym_keyword_any_inside] = ACTIONS(178),
    [sym_keyword_none_inside] = ACTIONS(178),
    [sym_keyword_outside] = ACTIONS(178),
    [sym_keyword_intersects] = ACTIONS(178),
    [sym_keyword_drop] = ACTIONS(178),
    [sym_keyword_schemafull] = ACTIONS(178),
    [sym_keyword_schemaless] = ACTIONS(178),
    [sym_keyword_changefeed] = ACTIONS(178),
    [sym_keyword_type] = ACTIONS(178),
    [sym_keyword_permissions] = ACTIONS(178),
    [sym_keyword_for] = ACTIONS(178),
    [sym_keyword_comment] = ACTIONS(178),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [257] = {
    [ts_builtin_sym_end] = ACTIONS(186),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(186),
    [sym_keyword_as] = ACTIONS(186),
    [sym_keyword_where] = ACTIONS(186),
    [sym_keyword_group] = ACTIONS(186),
    [sym_keyword_and] = ACTIONS(186),
    [sym_keyword_or] = ACTIONS(186),
    [sym_keyword_is] = ACTIONS(186),
    [sym_keyword_not] = ACTIONS(188),
    [sym_keyword_contains] = ACTIONS(186),
    [sym_keyword_contains_not] = ACTIONS(186),
    [sym_keyword_contains_all] = ACTIONS(186),
    [sym_keyword_contains_any] = ACTIONS(186),
    [sym_keyword_contains_none] = ACTIONS(186),
    [sym_keyword_inside] = ACTIONS(186),
    [sym_keyword_in] = ACTIONS(188),
    [sym_keyword_not_inside] = ACTIONS(186),
    [sym_keyword_all_inside] = ACTIONS(186),
    [sym_keyword_any_inside] = ACTIONS(186),
    [sym_keyword_none_inside] = ACTIONS(186),
    [sym_keyword_outside] = ACTIONS(186),
    [sym_keyword_intersects] = ACTIONS(186),
    [sym_keyword_drop] = ACTIONS(186),
    [sym_keyword_schemafull] = ACTIONS(186),
    [sym_keyword_schemaless] = ACTIONS(186),
    [sym_keyword_changefeed] = ACTIONS(186),
    [sym_keyword_type] = ACTIONS(186),
    [sym_keyword_permissions] = ACTIONS(186),
    [sym_keyword_for] = ACTIONS(186),
    [sym_keyword_comment] = ACTIONS(186),
    [anon_sym_COMMA] = ACTIONS(186),
    [anon_sym_DASH_GT] = ACTIONS(186),
    [anon_sym_LBRACK] = ACTIONS(186),
    [anon_sym_LT_DASH] = ACTIONS(188),
    [anon_sym_LT_DASH_GT] = ACTIONS(186),
    [anon_sym_STAR] = ACTIONS(188),
    [anon_sym_DOT] = ACTIONS(186),
    [anon_sym_LT] = ACTIONS(188),
    [anon_sym_GT] = ACTIONS(188),
    [anon_sym_EQ] = ACTIONS(188),
    [anon_sym_DASH] = ACTIONS(188),
    [anon_sym_AT] = ACTIONS(188),
    [anon_sym_LT_PIPE] = ACTIONS(186),
    [anon_sym_AMP_AMP] = ACTIONS(186),
    [anon_sym_PIPE_PIPE] = ACTIONS(186),
    [anon_sym_QMARK_QMARK] = ACTIONS(186),
    [anon_sym_QMARK_COLON] = ACTIONS(186),
    [anon_sym_BANG_EQ] = ACTIONS(186),
    [anon_sym_EQ_EQ] = ACTIONS(186),
    [anon_sym_QMARK_EQ] = ACTIONS(186),
    [anon_sym_STAR_EQ] = ACTIONS(186),
    [anon_sym_TILDE] = ACTIONS(186),
    [anon_sym_BANG_TILDE] = ACTIONS(186),
    [anon_sym_STAR_TILDE] = ACTIONS(186),
    [anon_sym_LT_EQ] = ACTIONS(186),
    [anon_sym_GT_EQ] = ACTIONS(186),
    [anon_sym_PLUS] = ACTIONS(188),
    [anon_sym_PLUS_EQ] = ACTIONS(186),
    [anon_sym_DASH_EQ] = ACTIONS(186),
    [anon_sym_u00d7] = ACTIONS(186),
    [anon_sym_SLASH] = ACTIONS(188),
    [anon_sym_u00f7] = ACTIONS(186),
    [anon_sym_STAR_STAR] = ACTIONS(186),
    [anon_sym_u220b] = ACTIONS(186),
    [anon_sym_u220c] = ACTIONS(186),
    [anon_sym_u2287] = ACTIONS(186),
    [anon_sym_u2283] = ACTIONS(186),
    [anon_sym_u2285] = ACTIONS(186),
    [anon_sym_u2208] = ACTIONS(186),
    [anon_sym_u2209] = ACTIONS(186),
    [anon_sym_u2286] = ACTIONS(186),
    [anon_sym_u2282] = ACTIONS(186),
    [anon_sym_u2284] = ACTIONS(186),
    [anon_sym_AT_AT] = ACTIONS(186),
  },
  [258] = {
    [ts_builtin_sym_end] = ACTIONS(190),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(190),
    [sym_keyword_as] = ACTIONS(190),
    [sym_keyword_where] = ACTIONS(190),
    [sym_keyword_group] = ACTIONS(190),
    [sym_keyword_and] = ACTIONS(190),
    [sym_keyword_or] = ACTIONS(190),
    [sym_keyword_is] = ACTIONS(190),
    [sym_keyword_not] = ACTIONS(192),
    [sym_keyword_contains] = ACTIONS(190),
    [sym_keyword_contains_not] = ACTIONS(190),
    [sym_keyword_contains_all] = ACTIONS(190),
    [sym_keyword_contains_any] = ACTIONS(190),
    [sym_keyword_contains_none] = ACTIONS(190),
    [sym_keyword_inside] = ACTIONS(190),
    [sym_keyword_in] = ACTIONS(192),
    [sym_keyword_not_inside] = ACTIONS(190),
    [sym_keyword_all_inside] = ACTIONS(190),
    [sym_keyword_any_inside] = ACTIONS(190),
    [sym_keyword_none_inside] = ACTIONS(190),
    [sym_keyword_outside] = ACTIONS(190),
    [sym_keyword_intersects] = ACTIONS(190),
    [sym_keyword_drop] = ACTIONS(190),
    [sym_keyword_schemafull] = ACTIONS(190),
    [sym_keyword_schemaless] = ACTIONS(190),
    [sym_keyword_changefeed] = ACTIONS(190),
    [sym_keyword_type] = ACTIONS(190),
    [sym_keyword_permissions] = ACTIONS(190),
    [sym_keyword_for] = ACTIONS(190),
    [sym_keyword_comment] = ACTIONS(190),
    [anon_sym_COMMA] = ACTIONS(190),
    [anon_sym_DASH_GT] = ACTIONS(190),
    [anon_sym_LBRACK] = ACTIONS(190),
    [anon_sym_LT_DASH] = ACTIONS(192),
    [anon_sym_LT_DASH_GT] = ACTIONS(190),
    [anon_sym_STAR] = ACTIONS(192),
    [anon_sym_DOT] = ACTIONS(190),
    [anon_sym_LT] = ACTIONS(192),
    [anon_sym_GT] = ACTIONS(192),
    [anon_sym_EQ] = ACTIONS(192),
    [anon_sym_DASH] = ACTIONS(192),
    [anon_sym_AT] = ACTIONS(192),
    [anon_sym_LT_PIPE] = ACTIONS(190),
    [anon_sym_AMP_AMP] = ACTIONS(190),
    [anon_sym_PIPE_PIPE] = ACTIONS(190),
    [anon_sym_QMARK_QMARK] = ACTIONS(190),
    [anon_sym_QMARK_COLON] = ACTIONS(190),
    [anon_sym_BANG_EQ] = ACTIONS(190),
    [anon_sym_EQ_EQ] = ACTIONS(190),
    [anon_sym_QMARK_EQ] = ACTIONS(190),
    [anon_sym_STAR_EQ] = ACTIONS(190),
    [anon_sym_TILDE] = ACTIONS(190),
    [anon_sym_BANG_TILDE] = ACTIONS(190),
    [anon_sym_STAR_TILDE] = ACTIONS(190),
    [anon_sym_LT_EQ] = ACTIONS(190),
    [anon_sym_GT_EQ] = ACTIONS(190),
    [anon_sym_PLUS] = ACTIONS(192),
    [anon_sym_PLUS_EQ] = ACTIONS(190),
    [anon_sym_DASH_EQ] = ACTIONS(190),
    [anon_sym_u00d7] = ACTIONS(190),
    [anon_sym_SLASH] = ACTIONS(192),
    [anon_sym_u00f7] = ACTIONS(190),
    [anon_sym_STAR_STAR] = ACTIONS(190),
    [anon_sym_u220b] = ACTIONS(190),
    [anon_sym_u220c] = ACTIONS(190),
    [anon_sym_u2287] = ACTIONS(190),
    [anon_sym_u2283] = ACTIONS(190),
    [anon_sym_u2285] = ACTIONS(190),
    [anon_sym_u2208] = ACTIONS(190),
    [anon_sym_u2209] = ACTIONS(190),
    [anon_sym_u2286] = ACTIONS(190),
    [anon_sym_u2282] = ACTIONS(190),
    [anon_sym_u2284] = ACTIONS(190),
    [anon_sym_AT_AT] = ACTIONS(190),
  },
  [259] = {
    [ts_builtin_sym_end] = ACTIONS(210),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_as] = ACTIONS(210),
    [sym_keyword_where] = ACTIONS(210),
    [sym_keyword_group] = ACTIONS(210),
    [sym_keyword_and] = ACTIONS(210),
    [sym_keyword_or] = ACTIONS(210),
    [sym_keyword_is] = ACTIONS(210),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(210),
    [sym_keyword_contains_not] = ACTIONS(210),
    [sym_keyword_contains_all] = ACTIONS(210),
    [sym_keyword_contains_any] = ACTIONS(210),
    [sym_keyword_contains_none] = ACTIONS(210),
    [sym_keyword_inside] = ACTIONS(210),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(210),
    [sym_keyword_all_inside] = ACTIONS(210),
    [sym_keyword_any_inside] = ACTIONS(210),
    [sym_keyword_none_inside] = ACTIONS(210),
    [sym_keyword_outside] = ACTIONS(210),
    [sym_keyword_intersects] = ACTIONS(210),
    [sym_keyword_drop] = ACTIONS(210),
    [sym_keyword_schemafull] = ACTIONS(210),
    [sym_keyword_schemaless] = ACTIONS(210),
    [sym_keyword_changefeed] = ACTIONS(210),
    [sym_keyword_type] = ACTIONS(210),
    [sym_keyword_permissions] = ACTIONS(210),
    [sym_keyword_for] = ACTIONS(210),
    [sym_keyword_comment] = ACTIONS(210),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [260] = {
    [ts_builtin_sym_end] = ACTIONS(142),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(142),
    [sym_keyword_as] = ACTIONS(142),
    [sym_keyword_where] = ACTIONS(142),
    [sym_keyword_group] = ACTIONS(142),
    [sym_keyword_and] = ACTIONS(142),
    [sym_keyword_or] = ACTIONS(142),
    [sym_keyword_is] = ACTIONS(142),
    [sym_keyword_not] = ACTIONS(144),
    [sym_keyword_contains] = ACTIONS(142),
    [sym_keyword_contains_not] = ACTIONS(142),
    [sym_keyword_contains_all] = ACTIONS(142),
    [sym_keyword_contains_any] = ACTIONS(142),
    [sym_keyword_contains_none] = ACTIONS(142),
    [sym_keyword_inside] = ACTIONS(142),
    [sym_keyword_in] = ACTIONS(144),
    [sym_keyword_not_inside] = ACTIONS(142),
    [sym_keyword_all_inside] = ACTIONS(142),
    [sym_keyword_any_inside] = ACTIONS(142),
    [sym_keyword_none_inside] = ACTIONS(142),
    [sym_keyword_outside] = ACTIONS(142),
    [sym_keyword_intersects] = ACTIONS(142),
    [sym_keyword_drop] = ACTIONS(142),
    [sym_keyword_schemafull] = ACTIONS(142),
    [sym_keyword_schemaless] = ACTIONS(142),
    [sym_keyword_changefeed] = ACTIONS(142),
    [sym_keyword_type] = ACTIONS(142),
    [sym_keyword_permissions] = ACTIONS(142),
    [sym_keyword_for] = ACTIONS(142),
    [sym_keyword_comment] = ACTIONS(142),
    [anon_sym_COMMA] = ACTIONS(142),
    [anon_sym_DASH_GT] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(142),
    [anon_sym_LT_DASH] = ACTIONS(144),
    [anon_sym_LT_DASH_GT] = ACTIONS(142),
    [anon_sym_STAR] = ACTIONS(144),
    [anon_sym_DOT] = ACTIONS(142),
    [anon_sym_LT] = ACTIONS(144),
    [anon_sym_GT] = ACTIONS(144),
    [anon_sym_EQ] = ACTIONS(144),
    [anon_sym_DASH] = ACTIONS(144),
    [anon_sym_AT] = ACTIONS(144),
    [anon_sym_LT_PIPE] = ACTIONS(142),
    [anon_sym_AMP_AMP] = ACTIONS(142),
    [anon_sym_PIPE_PIPE] = ACTIONS(142),
    [anon_sym_QMARK_QMARK] = ACTIONS(142),
    [anon_sym_QMARK_COLON] = ACTIONS(142),
    [anon_sym_BANG_EQ] = ACTIONS(142),
    [anon_sym_EQ_EQ] = ACTIONS(142),
    [anon_sym_QMARK_EQ] = ACTIONS(142),
    [anon_sym_STAR_EQ] = ACTIONS(142),
    [anon_sym_TILDE] = ACTIONS(142),
    [anon_sym_BANG_TILDE] = ACTIONS(142),
    [anon_sym_STAR_TILDE] = ACTIONS(142),
    [anon_sym_LT_EQ] = ACTIONS(142),
    [anon_sym_GT_EQ] = ACTIONS(142),
    [anon_sym_PLUS] = ACTIONS(144),
    [anon_sym_PLUS_EQ] = ACTIONS(142),
    [anon_sym_DASH_EQ] = ACTIONS(142),
    [anon_sym_u00d7] = ACTIONS(142),
    [anon_sym_SLASH] = ACTIONS(144),
    [anon_sym_u00f7] = ACTIONS(142),
    [anon_sym_STAR_STAR] = ACTIONS(142),
    [anon_sym_u220b] = ACTIONS(142),
    [anon_sym_u220c] = ACTIONS(142),
    [anon_sym_u2287] = ACTIONS(142),
    [anon_sym_u2283] = ACTIONS(142),
    [anon_sym_u2285] = ACTIONS(142),
    [anon_sym_u2208] = ACTIONS(142),
    [anon_sym_u2209] = ACTIONS(142),
    [anon_sym_u2286] = ACTIONS(142),
    [anon_sym_u2282] = ACTIONS(142),
    [anon_sym_u2284] = ACTIONS(142),
    [anon_sym_AT_AT] = ACTIONS(142),
  },
  [261] = {
    [ts_builtin_sym_end] = ACTIONS(202),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(202),
    [sym_keyword_as] = ACTIONS(202),
    [sym_keyword_where] = ACTIONS(202),
    [sym_keyword_group] = ACTIONS(202),
    [sym_keyword_and] = ACTIONS(202),
    [sym_keyword_or] = ACTIONS(202),
    [sym_keyword_is] = ACTIONS(202),
    [sym_keyword_not] = ACTIONS(204),
    [sym_keyword_contains] = ACTIONS(202),
    [sym_keyword_contains_not] = ACTIONS(202),
    [sym_keyword_contains_all] = ACTIONS(202),
    [sym_keyword_contains_any] = ACTIONS(202),
    [sym_keyword_contains_none] = ACTIONS(202),
    [sym_keyword_inside] = ACTIONS(202),
    [sym_keyword_in] = ACTIONS(204),
    [sym_keyword_not_inside] = ACTIONS(202),
    [sym_keyword_all_inside] = ACTIONS(202),
    [sym_keyword_any_inside] = ACTIONS(202),
    [sym_keyword_none_inside] = ACTIONS(202),
    [sym_keyword_outside] = ACTIONS(202),
    [sym_keyword_intersects] = ACTIONS(202),
    [sym_keyword_drop] = ACTIONS(202),
    [sym_keyword_schemafull] = ACTIONS(202),
    [sym_keyword_schemaless] = ACTIONS(202),
    [sym_keyword_changefeed] = ACTIONS(202),
    [sym_keyword_type] = ACTIONS(202),
    [sym_keyword_permissions] = ACTIONS(202),
    [sym_keyword_for] = ACTIONS(202),
    [sym_keyword_comment] = ACTIONS(202),
    [anon_sym_COMMA] = ACTIONS(202),
    [anon_sym_DASH_GT] = ACTIONS(202),
    [anon_sym_LBRACK] = ACTIONS(202),
    [anon_sym_LT_DASH] = ACTIONS(204),
    [anon_sym_LT_DASH_GT] = ACTIONS(202),
    [anon_sym_STAR] = ACTIONS(204),
    [anon_sym_DOT] = ACTIONS(202),
    [anon_sym_LT] = ACTIONS(204),
    [anon_sym_GT] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(204),
    [anon_sym_DASH] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(204),
    [anon_sym_LT_PIPE] = ACTIONS(202),
    [anon_sym_AMP_AMP] = ACTIONS(202),
    [anon_sym_PIPE_PIPE] = ACTIONS(202),
    [anon_sym_QMARK_QMARK] = ACTIONS(202),
    [anon_sym_QMARK_COLON] = ACTIONS(202),
    [anon_sym_BANG_EQ] = ACTIONS(202),
    [anon_sym_EQ_EQ] = ACTIONS(202),
    [anon_sym_QMARK_EQ] = ACTIONS(202),
    [anon_sym_STAR_EQ] = ACTIONS(202),
    [anon_sym_TILDE] = ACTIONS(202),
    [anon_sym_BANG_TILDE] = ACTIONS(202),
    [anon_sym_STAR_TILDE] = ACTIONS(202),
    [anon_sym_LT_EQ] = ACTIONS(202),
    [anon_sym_GT_EQ] = ACTIONS(202),
    [anon_sym_PLUS] = ACTIONS(204),
    [anon_sym_PLUS_EQ] = ACTIONS(202),
    [anon_sym_DASH_EQ] = ACTIONS(202),
    [anon_sym_u00d7] = ACTIONS(202),
    [anon_sym_SLASH] = ACTIONS(204),
    [anon_sym_u00f7] = ACTIONS(202),
    [anon_sym_STAR_STAR] = ACTIONS(202),
    [anon_sym_u220b] = ACTIONS(202),
    [anon_sym_u220c] = ACTIONS(202),
    [anon_sym_u2287] = ACTIONS(202),
    [anon_sym_u2283] = ACTIONS(202),
    [anon_sym_u2285] = ACTIONS(202),
    [anon_sym_u2208] = ACTIONS(202),
    [anon_sym_u2209] = ACTIONS(202),
    [anon_sym_u2286] = ACTIONS(202),
    [anon_sym_u2282] = ACTIONS(202),
    [anon_sym_u2284] = ACTIONS(202),
    [anon_sym_AT_AT] = ACTIONS(202),
  },
  [262] = {
    [ts_builtin_sym_end] = ACTIONS(194),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(194),
    [sym_keyword_as] = ACTIONS(194),
    [sym_keyword_where] = ACTIONS(194),
    [sym_keyword_group] = ACTIONS(194),
    [sym_keyword_and] = ACTIONS(194),
    [sym_keyword_or] = ACTIONS(194),
    [sym_keyword_is] = ACTIONS(194),
    [sym_keyword_not] = ACTIONS(196),
    [sym_keyword_contains] = ACTIONS(194),
    [sym_keyword_contains_not] = ACTIONS(194),
    [sym_keyword_contains_all] = ACTIONS(194),
    [sym_keyword_contains_any] = ACTIONS(194),
    [sym_keyword_contains_none] = ACTIONS(194),
    [sym_keyword_inside] = ACTIONS(194),
    [sym_keyword_in] = ACTIONS(196),
    [sym_keyword_not_inside] = ACTIONS(194),
    [sym_keyword_all_inside] = ACTIONS(194),
    [sym_keyword_any_inside] = ACTIONS(194),
    [sym_keyword_none_inside] = ACTIONS(194),
    [sym_keyword_outside] = ACTIONS(194),
    [sym_keyword_intersects] = ACTIONS(194),
    [sym_keyword_drop] = ACTIONS(194),
    [sym_keyword_schemafull] = ACTIONS(194),
    [sym_keyword_schemaless] = ACTIONS(194),
    [sym_keyword_changefeed] = ACTIONS(194),
    [sym_keyword_type] = ACTIONS(194),
    [sym_keyword_permissions] = ACTIONS(194),
    [sym_keyword_for] = ACTIONS(194),
    [sym_keyword_comment] = ACTIONS(194),
    [anon_sym_COMMA] = ACTIONS(194),
    [anon_sym_DASH_GT] = ACTIONS(194),
    [anon_sym_LBRACK] = ACTIONS(194),
    [anon_sym_LT_DASH] = ACTIONS(196),
    [anon_sym_LT_DASH_GT] = ACTIONS(194),
    [anon_sym_STAR] = ACTIONS(196),
    [anon_sym_DOT] = ACTIONS(194),
    [anon_sym_LT] = ACTIONS(196),
    [anon_sym_GT] = ACTIONS(196),
    [anon_sym_EQ] = ACTIONS(196),
    [anon_sym_DASH] = ACTIONS(196),
    [anon_sym_AT] = ACTIONS(196),
    [anon_sym_LT_PIPE] = ACTIONS(194),
    [anon_sym_AMP_AMP] = ACTIONS(194),
    [anon_sym_PIPE_PIPE] = ACTIONS(194),
    [anon_sym_QMARK_QMARK] = ACTIONS(194),
    [anon_sym_QMARK_COLON] = ACTIONS(194),
    [anon_sym_BANG_EQ] = ACTIONS(194),
    [anon_sym_EQ_EQ] = ACTIONS(194),
    [anon_sym_QMARK_EQ] = ACTIONS(194),
    [anon_sym_STAR_EQ] = ACTIONS(194),
    [anon_sym_TILDE] = ACTIONS(194),
    [anon_sym_BANG_TILDE] = ACTIONS(194),
    [anon_sym_STAR_TILDE] = ACTIONS(194),
    [anon_sym_LT_EQ] = ACTIONS(194),
    [anon_sym_GT_EQ] = ACTIONS(194),
    [anon_sym_PLUS] = ACTIONS(196),
    [anon_sym_PLUS_EQ] = ACTIONS(194),
    [anon_sym_DASH_EQ] = ACTIONS(194),
    [anon_sym_u00d7] = ACTIONS(194),
    [anon_sym_SLASH] = ACTIONS(196),
    [anon_sym_u00f7] = ACTIONS(194),
    [anon_sym_STAR_STAR] = ACTIONS(194),
    [anon_sym_u220b] = ACTIONS(194),
    [anon_sym_u220c] = ACTIONS(194),
    [anon_sym_u2287] = ACTIONS(194),
    [anon_sym_u2283] = ACTIONS(194),
    [anon_sym_u2285] = ACTIONS(194),
    [anon_sym_u2208] = ACTIONS(194),
    [anon_sym_u2209] = ACTIONS(194),
    [anon_sym_u2286] = ACTIONS(194),
    [anon_sym_u2282] = ACTIONS(194),
    [anon_sym_u2284] = ACTIONS(194),
    [anon_sym_AT_AT] = ACTIONS(194),
  },
  [263] = {
    [ts_builtin_sym_end] = ACTIONS(182),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_as] = ACTIONS(182),
    [sym_keyword_where] = ACTIONS(182),
    [sym_keyword_group] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_drop] = ACTIONS(182),
    [sym_keyword_schemafull] = ACTIONS(182),
    [sym_keyword_schemaless] = ACTIONS(182),
    [sym_keyword_changefeed] = ACTIONS(182),
    [sym_keyword_type] = ACTIONS(182),
    [sym_keyword_permissions] = ACTIONS(182),
    [sym_keyword_for] = ACTIONS(182),
    [sym_keyword_comment] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(182),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [264] = {
    [ts_builtin_sym_end] = ACTIONS(166),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(166),
    [sym_keyword_as] = ACTIONS(166),
    [sym_keyword_where] = ACTIONS(166),
    [sym_keyword_group] = ACTIONS(166),
    [sym_keyword_and] = ACTIONS(166),
    [sym_keyword_or] = ACTIONS(166),
    [sym_keyword_is] = ACTIONS(166),
    [sym_keyword_not] = ACTIONS(168),
    [sym_keyword_contains] = ACTIONS(166),
    [sym_keyword_contains_not] = ACTIONS(166),
    [sym_keyword_contains_all] = ACTIONS(166),
    [sym_keyword_contains_any] = ACTIONS(166),
    [sym_keyword_contains_none] = ACTIONS(166),
    [sym_keyword_inside] = ACTIONS(166),
    [sym_keyword_in] = ACTIONS(168),
    [sym_keyword_not_inside] = ACTIONS(166),
    [sym_keyword_all_inside] = ACTIONS(166),
    [sym_keyword_any_inside] = ACTIONS(166),
    [sym_keyword_none_inside] = ACTIONS(166),
    [sym_keyword_outside] = ACTIONS(166),
    [sym_keyword_intersects] = ACTIONS(166),
    [sym_keyword_drop] = ACTIONS(166),
    [sym_keyword_schemafull] = ACTIONS(166),
    [sym_keyword_schemaless] = ACTIONS(166),
    [sym_keyword_changefeed] = ACTIONS(166),
    [sym_keyword_type] = ACTIONS(166),
    [sym_keyword_permissions] = ACTIONS(166),
    [sym_keyword_for] = ACTIONS(166),
    [sym_keyword_comment] = ACTIONS(166),
    [anon_sym_COMMA] = ACTIONS(166),
    [anon_sym_DASH_GT] = ACTIONS(166),
    [anon_sym_LBRACK] = ACTIONS(166),
    [anon_sym_LT_DASH] = ACTIONS(168),
    [anon_sym_LT_DASH_GT] = ACTIONS(166),
    [anon_sym_STAR] = ACTIONS(168),
    [anon_sym_DOT] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [anon_sym_GT] = ACTIONS(168),
    [anon_sym_EQ] = ACTIONS(168),
    [anon_sym_DASH] = ACTIONS(168),
    [anon_sym_AT] = ACTIONS(168),
    [anon_sym_LT_PIPE] = ACTIONS(166),
    [anon_sym_AMP_AMP] = ACTIONS(166),
    [anon_sym_PIPE_PIPE] = ACTIONS(166),
    [anon_sym_QMARK_QMARK] = ACTIONS(166),
    [anon_sym_QMARK_COLON] = ACTIONS(166),
    [anon_sym_BANG_EQ] = ACTIONS(166),
    [anon_sym_EQ_EQ] = ACTIONS(166),
    [anon_sym_QMARK_EQ] = ACTIONS(166),
    [anon_sym_STAR_EQ] = ACTIONS(166),
    [anon_sym_TILDE] = ACTIONS(166),
    [anon_sym_BANG_TILDE] = ACTIONS(166),
    [anon_sym_STAR_TILDE] = ACTIONS(166),
    [anon_sym_LT_EQ] = ACTIONS(166),
    [anon_sym_GT_EQ] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(168),
    [anon_sym_PLUS_EQ] = ACTIONS(166),
    [anon_sym_DASH_EQ] = ACTIONS(166),
    [anon_sym_u00d7] = ACTIONS(166),
    [anon_sym_SLASH] = ACTIONS(168),
    [anon_sym_u00f7] = ACTIONS(166),
    [anon_sym_STAR_STAR] = ACTIONS(166),
    [anon_sym_u220b] = ACTIONS(166),
    [anon_sym_u220c] = ACTIONS(166),
    [anon_sym_u2287] = ACTIONS(166),
    [anon_sym_u2283] = ACTIONS(166),
    [anon_sym_u2285] = ACTIONS(166),
    [anon_sym_u2208] = ACTIONS(166),
    [anon_sym_u2209] = ACTIONS(166),
    [anon_sym_u2286] = ACTIONS(166),
    [anon_sym_u2282] = ACTIONS(166),
    [anon_sym_u2284] = ACTIONS(166),
    [anon_sym_AT_AT] = ACTIONS(166),
  },
  [265] = {
    [ts_builtin_sym_end] = ACTIONS(95),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(95),
    [sym_keyword_as] = ACTIONS(95),
    [sym_keyword_where] = ACTIONS(95),
    [sym_keyword_group] = ACTIONS(95),
    [sym_keyword_and] = ACTIONS(95),
    [sym_keyword_or] = ACTIONS(95),
    [sym_keyword_is] = ACTIONS(95),
    [sym_keyword_not] = ACTIONS(97),
    [sym_keyword_contains] = ACTIONS(95),
    [sym_keyword_contains_not] = ACTIONS(95),
    [sym_keyword_contains_all] = ACTIONS(95),
    [sym_keyword_contains_any] = ACTIONS(95),
    [sym_keyword_contains_none] = ACTIONS(95),
    [sym_keyword_inside] = ACTIONS(95),
    [sym_keyword_in] = ACTIONS(97),
    [sym_keyword_not_inside] = ACTIONS(95),
    [sym_keyword_all_inside] = ACTIONS(95),
    [sym_keyword_any_inside] = ACTIONS(95),
    [sym_keyword_none_inside] = ACTIONS(95),
    [sym_keyword_outside] = ACTIONS(95),
    [sym_keyword_intersects] = ACTIONS(95),
    [sym_keyword_drop] = ACTIONS(95),
    [sym_keyword_schemafull] = ACTIONS(95),
    [sym_keyword_schemaless] = ACTIONS(95),
    [sym_keyword_changefeed] = ACTIONS(95),
    [sym_keyword_type] = ACTIONS(95),
    [sym_keyword_permissions] = ACTIONS(95),
    [sym_keyword_for] = ACTIONS(95),
    [sym_keyword_comment] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(95),
    [anon_sym_DASH_GT] = ACTIONS(95),
    [anon_sym_LBRACK] = ACTIONS(95),
    [anon_sym_LT_DASH] = ACTIONS(97),
    [anon_sym_LT_DASH_GT] = ACTIONS(95),
    [anon_sym_STAR] = ACTIONS(97),
    [anon_sym_DOT] = ACTIONS(95),
    [anon_sym_LT] = ACTIONS(97),
    [anon_sym_GT] = ACTIONS(97),
    [anon_sym_EQ] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_LT_PIPE] = ACTIONS(95),
    [anon_sym_AMP_AMP] = ACTIONS(95),
    [anon_sym_PIPE_PIPE] = ACTIONS(95),
    [anon_sym_QMARK_QMARK] = ACTIONS(95),
    [anon_sym_QMARK_COLON] = ACTIONS(95),
    [anon_sym_BANG_EQ] = ACTIONS(95),
    [anon_sym_EQ_EQ] = ACTIONS(95),
    [anon_sym_QMARK_EQ] = ACTIONS(95),
    [anon_sym_STAR_EQ] = ACTIONS(95),
    [anon_sym_TILDE] = ACTIONS(95),
    [anon_sym_BANG_TILDE] = ACTIONS(95),
    [anon_sym_STAR_TILDE] = ACTIONS(95),
    [anon_sym_LT_EQ] = ACTIONS(95),
    [anon_sym_GT_EQ] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_PLUS_EQ] = ACTIONS(95),
    [anon_sym_DASH_EQ] = ACTIONS(95),
    [anon_sym_u00d7] = ACTIONS(95),
    [anon_sym_SLASH] = ACTIONS(97),
    [anon_sym_u00f7] = ACTIONS(95),
    [anon_sym_STAR_STAR] = ACTIONS(95),
    [anon_sym_u220b] = ACTIONS(95),
    [anon_sym_u220c] = ACTIONS(95),
    [anon_sym_u2287] = ACTIONS(95),
    [anon_sym_u2283] = ACTIONS(95),
    [anon_sym_u2285] = ACTIONS(95),
    [anon_sym_u2208] = ACTIONS(95),
    [anon_sym_u2209] = ACTIONS(95),
    [anon_sym_u2286] = ACTIONS(95),
    [anon_sym_u2282] = ACTIONS(95),
    [anon_sym_u2284] = ACTIONS(95),
    [anon_sym_AT_AT] = ACTIONS(95),
  },
  [266] = {
    [ts_builtin_sym_end] = ACTIONS(146),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(146),
    [sym_keyword_as] = ACTIONS(146),
    [sym_keyword_where] = ACTIONS(146),
    [sym_keyword_group] = ACTIONS(146),
    [sym_keyword_and] = ACTIONS(146),
    [sym_keyword_or] = ACTIONS(146),
    [sym_keyword_is] = ACTIONS(146),
    [sym_keyword_not] = ACTIONS(148),
    [sym_keyword_contains] = ACTIONS(146),
    [sym_keyword_contains_not] = ACTIONS(146),
    [sym_keyword_contains_all] = ACTIONS(146),
    [sym_keyword_contains_any] = ACTIONS(146),
    [sym_keyword_contains_none] = ACTIONS(146),
    [sym_keyword_inside] = ACTIONS(146),
    [sym_keyword_in] = ACTIONS(148),
    [sym_keyword_not_inside] = ACTIONS(146),
    [sym_keyword_all_inside] = ACTIONS(146),
    [sym_keyword_any_inside] = ACTIONS(146),
    [sym_keyword_none_inside] = ACTIONS(146),
    [sym_keyword_outside] = ACTIONS(146),
    [sym_keyword_intersects] = ACTIONS(146),
    [sym_keyword_drop] = ACTIONS(146),
    [sym_keyword_schemafull] = ACTIONS(146),
    [sym_keyword_schemaless] = ACTIONS(146),
    [sym_keyword_changefeed] = ACTIONS(146),
    [sym_keyword_type] = ACTIONS(146),
    [sym_keyword_permissions] = ACTIONS(146),
    [sym_keyword_for] = ACTIONS(146),
    [sym_keyword_comment] = ACTIONS(146),
    [anon_sym_COMMA] = ACTIONS(146),
    [anon_sym_DASH_GT] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(146),
    [anon_sym_LT_DASH] = ACTIONS(148),
    [anon_sym_LT_DASH_GT] = ACTIONS(146),
    [anon_sym_STAR] = ACTIONS(148),
    [anon_sym_DOT] = ACTIONS(146),
    [anon_sym_LT] = ACTIONS(148),
    [anon_sym_GT] = ACTIONS(148),
    [anon_sym_EQ] = ACTIONS(148),
    [anon_sym_DASH] = ACTIONS(148),
    [anon_sym_AT] = ACTIONS(148),
    [anon_sym_LT_PIPE] = ACTIONS(146),
    [anon_sym_AMP_AMP] = ACTIONS(146),
    [anon_sym_PIPE_PIPE] = ACTIONS(146),
    [anon_sym_QMARK_QMARK] = ACTIONS(146),
    [anon_sym_QMARK_COLON] = ACTIONS(146),
    [anon_sym_BANG_EQ] = ACTIONS(146),
    [anon_sym_EQ_EQ] = ACTIONS(146),
    [anon_sym_QMARK_EQ] = ACTIONS(146),
    [anon_sym_STAR_EQ] = ACTIONS(146),
    [anon_sym_TILDE] = ACTIONS(146),
    [anon_sym_BANG_TILDE] = ACTIONS(146),
    [anon_sym_STAR_TILDE] = ACTIONS(146),
    [anon_sym_LT_EQ] = ACTIONS(146),
    [anon_sym_GT_EQ] = ACTIONS(146),
    [anon_sym_PLUS] = ACTIONS(148),
    [anon_sym_PLUS_EQ] = ACTIONS(146),
    [anon_sym_DASH_EQ] = ACTIONS(146),
    [anon_sym_u00d7] = ACTIONS(146),
    [anon_sym_SLASH] = ACTIONS(148),
    [anon_sym_u00f7] = ACTIONS(146),
    [anon_sym_STAR_STAR] = ACTIONS(146),
    [anon_sym_u220b] = ACTIONS(146),
    [anon_sym_u220c] = ACTIONS(146),
    [anon_sym_u2287] = ACTIONS(146),
    [anon_sym_u2283] = ACTIONS(146),
    [anon_sym_u2285] = ACTIONS(146),
    [anon_sym_u2208] = ACTIONS(146),
    [anon_sym_u2209] = ACTIONS(146),
    [anon_sym_u2286] = ACTIONS(146),
    [anon_sym_u2282] = ACTIONS(146),
    [anon_sym_u2284] = ACTIONS(146),
    [anon_sym_AT_AT] = ACTIONS(146),
  },
  [267] = {
    [ts_builtin_sym_end] = ACTIONS(206),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(206),
    [sym_keyword_as] = ACTIONS(206),
    [sym_keyword_where] = ACTIONS(206),
    [sym_keyword_group] = ACTIONS(206),
    [sym_keyword_and] = ACTIONS(206),
    [sym_keyword_or] = ACTIONS(206),
    [sym_keyword_is] = ACTIONS(206),
    [sym_keyword_not] = ACTIONS(208),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(206),
    [sym_keyword_contains_all] = ACTIONS(206),
    [sym_keyword_contains_any] = ACTIONS(206),
    [sym_keyword_contains_none] = ACTIONS(206),
    [sym_keyword_inside] = ACTIONS(206),
    [sym_keyword_in] = ACTIONS(208),
    [sym_keyword_not_inside] = ACTIONS(206),
    [sym_keyword_all_inside] = ACTIONS(206),
    [sym_keyword_any_inside] = ACTIONS(206),
    [sym_keyword_none_inside] = ACTIONS(206),
    [sym_keyword_outside] = ACTIONS(206),
    [sym_keyword_intersects] = ACTIONS(206),
    [sym_keyword_drop] = ACTIONS(206),
    [sym_keyword_schemafull] = ACTIONS(206),
    [sym_keyword_schemaless] = ACTIONS(206),
    [sym_keyword_changefeed] = ACTIONS(206),
    [sym_keyword_type] = ACTIONS(206),
    [sym_keyword_permissions] = ACTIONS(206),
    [sym_keyword_for] = ACTIONS(206),
    [sym_keyword_comment] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(206),
    [anon_sym_DASH_GT] = ACTIONS(206),
    [anon_sym_LBRACK] = ACTIONS(206),
    [anon_sym_LT_DASH] = ACTIONS(208),
    [anon_sym_LT_DASH_GT] = ACTIONS(206),
    [anon_sym_STAR] = ACTIONS(208),
    [anon_sym_DOT] = ACTIONS(206),
    [anon_sym_LT] = ACTIONS(208),
    [anon_sym_GT] = ACTIONS(208),
    [anon_sym_EQ] = ACTIONS(208),
    [anon_sym_DASH] = ACTIONS(208),
    [anon_sym_AT] = ACTIONS(208),
    [anon_sym_LT_PIPE] = ACTIONS(206),
    [anon_sym_AMP_AMP] = ACTIONS(206),
    [anon_sym_PIPE_PIPE] = ACTIONS(206),
    [anon_sym_QMARK_QMARK] = ACTIONS(206),
    [anon_sym_QMARK_COLON] = ACTIONS(206),
    [anon_sym_BANG_EQ] = ACTIONS(206),
    [anon_sym_EQ_EQ] = ACTIONS(206),
    [anon_sym_QMARK_EQ] = ACTIONS(206),
    [anon_sym_STAR_EQ] = ACTIONS(206),
    [anon_sym_TILDE] = ACTIONS(206),
    [anon_sym_BANG_TILDE] = ACTIONS(206),
    [anon_sym_STAR_TILDE] = ACTIONS(206),
    [anon_sym_LT_EQ] = ACTIONS(206),
    [anon_sym_GT_EQ] = ACTIONS(206),
    [anon_sym_PLUS] = ACTIONS(208),
    [anon_sym_PLUS_EQ] = ACTIONS(206),
    [anon_sym_DASH_EQ] = ACTIONS(206),
    [anon_sym_u00d7] = ACTIONS(206),
    [anon_sym_SLASH] = ACTIONS(208),
    [anon_sym_u00f7] = ACTIONS(206),
    [anon_sym_STAR_STAR] = ACTIONS(206),
    [anon_sym_u220b] = ACTIONS(206),
    [anon_sym_u220c] = ACTIONS(206),
    [anon_sym_u2287] = ACTIONS(206),
    [anon_sym_u2283] = ACTIONS(206),
    [anon_sym_u2285] = ACTIONS(206),
    [anon_sym_u2208] = ACTIONS(206),
    [anon_sym_u2209] = ACTIONS(206),
    [anon_sym_u2286] = ACTIONS(206),
    [anon_sym_u2282] = ACTIONS(206),
    [anon_sym_u2284] = ACTIONS(206),
    [anon_sym_AT_AT] = ACTIONS(206),
  },
  [268] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_explain] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_fetch] = ACTIONS(182),
    [sym_keyword_limit] = ACTIONS(182),
    [sym_keyword_order] = ACTIONS(182),
    [sym_keyword_where] = ACTIONS(182),
    [sym_keyword_split] = ACTIONS(182),
    [sym_keyword_group] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(184),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(486),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [269] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_return] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_where] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_content] = ACTIONS(182),
    [sym_keyword_merge] = ACTIONS(182),
    [sym_keyword_patch] = ACTIONS(182),
    [sym_keyword_set] = ACTIONS(182),
    [sym_keyword_unset] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(488),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [270] = {
    [ts_builtin_sym_end] = ACTIONS(158),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(158),
    [sym_keyword_as] = ACTIONS(158),
    [sym_keyword_where] = ACTIONS(158),
    [sym_keyword_group] = ACTIONS(158),
    [sym_keyword_and] = ACTIONS(158),
    [sym_keyword_or] = ACTIONS(158),
    [sym_keyword_is] = ACTIONS(158),
    [sym_keyword_not] = ACTIONS(160),
    [sym_keyword_contains] = ACTIONS(158),
    [sym_keyword_contains_not] = ACTIONS(158),
    [sym_keyword_contains_all] = ACTIONS(158),
    [sym_keyword_contains_any] = ACTIONS(158),
    [sym_keyword_contains_none] = ACTIONS(158),
    [sym_keyword_inside] = ACTIONS(158),
    [sym_keyword_in] = ACTIONS(160),
    [sym_keyword_not_inside] = ACTIONS(158),
    [sym_keyword_all_inside] = ACTIONS(158),
    [sym_keyword_any_inside] = ACTIONS(158),
    [sym_keyword_none_inside] = ACTIONS(158),
    [sym_keyword_outside] = ACTIONS(158),
    [sym_keyword_intersects] = ACTIONS(158),
    [sym_keyword_drop] = ACTIONS(158),
    [sym_keyword_schemafull] = ACTIONS(158),
    [sym_keyword_schemaless] = ACTIONS(158),
    [sym_keyword_changefeed] = ACTIONS(158),
    [sym_keyword_type] = ACTIONS(158),
    [sym_keyword_permissions] = ACTIONS(158),
    [sym_keyword_for] = ACTIONS(158),
    [sym_keyword_comment] = ACTIONS(158),
    [anon_sym_COMMA] = ACTIONS(158),
    [anon_sym_DASH_GT] = ACTIONS(158),
    [anon_sym_LBRACK] = ACTIONS(158),
    [anon_sym_LT_DASH] = ACTIONS(160),
    [anon_sym_LT_DASH_GT] = ACTIONS(158),
    [anon_sym_STAR] = ACTIONS(160),
    [anon_sym_DOT] = ACTIONS(158),
    [anon_sym_LT] = ACTIONS(160),
    [anon_sym_GT] = ACTIONS(160),
    [anon_sym_EQ] = ACTIONS(160),
    [anon_sym_DASH] = ACTIONS(160),
    [anon_sym_AT] = ACTIONS(160),
    [anon_sym_LT_PIPE] = ACTIONS(158),
    [anon_sym_AMP_AMP] = ACTIONS(158),
    [anon_sym_PIPE_PIPE] = ACTIONS(158),
    [anon_sym_QMARK_QMARK] = ACTIONS(158),
    [anon_sym_QMARK_COLON] = ACTIONS(158),
    [anon_sym_BANG_EQ] = ACTIONS(158),
    [anon_sym_EQ_EQ] = ACTIONS(158),
    [anon_sym_QMARK_EQ] = ACTIONS(158),
    [anon_sym_STAR_EQ] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(158),
    [anon_sym_BANG_TILDE] = ACTIONS(158),
    [anon_sym_STAR_TILDE] = ACTIONS(158),
    [anon_sym_LT_EQ] = ACTIONS(158),
    [anon_sym_GT_EQ] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(160),
    [anon_sym_PLUS_EQ] = ACTIONS(158),
    [anon_sym_DASH_EQ] = ACTIONS(158),
    [anon_sym_u00d7] = ACTIONS(158),
    [anon_sym_SLASH] = ACTIONS(160),
    [anon_sym_u00f7] = ACTIONS(158),
    [anon_sym_STAR_STAR] = ACTIONS(158),
    [anon_sym_u220b] = ACTIONS(158),
    [anon_sym_u220c] = ACTIONS(158),
    [anon_sym_u2287] = ACTIONS(158),
    [anon_sym_u2283] = ACTIONS(158),
    [anon_sym_u2285] = ACTIONS(158),
    [anon_sym_u2208] = ACTIONS(158),
    [anon_sym_u2209] = ACTIONS(158),
    [anon_sym_u2286] = ACTIONS(158),
    [anon_sym_u2282] = ACTIONS(158),
    [anon_sym_u2284] = ACTIONS(158),
    [anon_sym_AT_AT] = ACTIONS(158),
  },
  [271] = {
    [sym_where_clause] = STATE(881),
    [sym_group_clause] = STATE(957),
    [sym_operator] = STATE(702),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(826),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(490),
    [sym_keyword_as] = ACTIONS(490),
    [sym_keyword_where] = ACTIONS(492),
    [sym_keyword_group] = ACTIONS(494),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_drop] = ACTIONS(490),
    [sym_keyword_schemafull] = ACTIONS(490),
    [sym_keyword_schemaless] = ACTIONS(490),
    [sym_keyword_changefeed] = ACTIONS(490),
    [sym_keyword_type] = ACTIONS(490),
    [sym_keyword_permissions] = ACTIONS(490),
    [sym_keyword_comment] = ACTIONS(490),
    [anon_sym_COMMA] = ACTIONS(496),
    [anon_sym_RPAREN] = ACTIONS(490),
    [anon_sym_RBRACE] = ACTIONS(490),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [272] = {
    [sym_where_clause] = STATE(889),
    [sym_group_clause] = STATE(973),
    [sym_operator] = STATE(702),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(827),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(498),
    [sym_keyword_as] = ACTIONS(498),
    [sym_keyword_where] = ACTIONS(492),
    [sym_keyword_group] = ACTIONS(494),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_drop] = ACTIONS(498),
    [sym_keyword_schemafull] = ACTIONS(498),
    [sym_keyword_schemaless] = ACTIONS(498),
    [sym_keyword_changefeed] = ACTIONS(498),
    [sym_keyword_type] = ACTIONS(498),
    [sym_keyword_permissions] = ACTIONS(498),
    [sym_keyword_comment] = ACTIONS(498),
    [anon_sym_COMMA] = ACTIONS(496),
    [anon_sym_RPAREN] = ACTIONS(498),
    [anon_sym_RBRACE] = ACTIONS(498),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [273] = {
    [ts_builtin_sym_end] = ACTIONS(154),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(154),
    [sym_keyword_as] = ACTIONS(154),
    [sym_keyword_where] = ACTIONS(154),
    [sym_keyword_group] = ACTIONS(154),
    [sym_keyword_and] = ACTIONS(154),
    [sym_keyword_or] = ACTIONS(154),
    [sym_keyword_is] = ACTIONS(154),
    [sym_keyword_not] = ACTIONS(156),
    [sym_keyword_contains] = ACTIONS(154),
    [sym_keyword_contains_not] = ACTIONS(154),
    [sym_keyword_contains_all] = ACTIONS(154),
    [sym_keyword_contains_any] = ACTIONS(154),
    [sym_keyword_contains_none] = ACTIONS(154),
    [sym_keyword_inside] = ACTIONS(154),
    [sym_keyword_in] = ACTIONS(156),
    [sym_keyword_not_inside] = ACTIONS(154),
    [sym_keyword_all_inside] = ACTIONS(154),
    [sym_keyword_any_inside] = ACTIONS(154),
    [sym_keyword_none_inside] = ACTIONS(154),
    [sym_keyword_outside] = ACTIONS(154),
    [sym_keyword_intersects] = ACTIONS(154),
    [sym_keyword_drop] = ACTIONS(154),
    [sym_keyword_schemafull] = ACTIONS(154),
    [sym_keyword_schemaless] = ACTIONS(154),
    [sym_keyword_changefeed] = ACTIONS(154),
    [sym_keyword_type] = ACTIONS(154),
    [sym_keyword_permissions] = ACTIONS(154),
    [sym_keyword_for] = ACTIONS(154),
    [sym_keyword_comment] = ACTIONS(154),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_DASH_GT] = ACTIONS(154),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_LT_DASH] = ACTIONS(156),
    [anon_sym_LT_DASH_GT] = ACTIONS(154),
    [anon_sym_STAR] = ACTIONS(156),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_LT] = ACTIONS(156),
    [anon_sym_GT] = ACTIONS(156),
    [anon_sym_EQ] = ACTIONS(156),
    [anon_sym_DASH] = ACTIONS(156),
    [anon_sym_AT] = ACTIONS(156),
    [anon_sym_LT_PIPE] = ACTIONS(154),
    [anon_sym_AMP_AMP] = ACTIONS(154),
    [anon_sym_PIPE_PIPE] = ACTIONS(154),
    [anon_sym_QMARK_QMARK] = ACTIONS(154),
    [anon_sym_QMARK_COLON] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(154),
    [anon_sym_QMARK_EQ] = ACTIONS(154),
    [anon_sym_STAR_EQ] = ACTIONS(154),
    [anon_sym_TILDE] = ACTIONS(154),
    [anon_sym_BANG_TILDE] = ACTIONS(154),
    [anon_sym_STAR_TILDE] = ACTIONS(154),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_PLUS] = ACTIONS(156),
    [anon_sym_PLUS_EQ] = ACTIONS(154),
    [anon_sym_DASH_EQ] = ACTIONS(154),
    [anon_sym_u00d7] = ACTIONS(154),
    [anon_sym_SLASH] = ACTIONS(156),
    [anon_sym_u00f7] = ACTIONS(154),
    [anon_sym_STAR_STAR] = ACTIONS(154),
    [anon_sym_u220b] = ACTIONS(154),
    [anon_sym_u220c] = ACTIONS(154),
    [anon_sym_u2287] = ACTIONS(154),
    [anon_sym_u2283] = ACTIONS(154),
    [anon_sym_u2285] = ACTIONS(154),
    [anon_sym_u2208] = ACTIONS(154),
    [anon_sym_u2209] = ACTIONS(154),
    [anon_sym_u2286] = ACTIONS(154),
    [anon_sym_u2282] = ACTIONS(154),
    [anon_sym_u2284] = ACTIONS(154),
    [anon_sym_AT_AT] = ACTIONS(154),
  },
  [274] = {
    [sym_expressions] = STATE(1867),
    [sym_expression] = STATE(1524),
    [sym_statement] = STATE(1384),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(576),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1780),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(524),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(532),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [275] = {
    [ts_builtin_sym_end] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(55),
    [sym_keyword_explain] = ACTIONS(55),
    [sym_keyword_parallel] = ACTIONS(55),
    [sym_keyword_timeout] = ACTIONS(55),
    [sym_keyword_fetch] = ACTIONS(55),
    [sym_keyword_limit] = ACTIONS(55),
    [sym_keyword_order] = ACTIONS(55),
    [sym_keyword_with] = ACTIONS(55),
    [sym_keyword_where] = ACTIONS(55),
    [sym_keyword_split] = ACTIONS(55),
    [sym_keyword_group] = ACTIONS(55),
    [sym_keyword_and] = ACTIONS(55),
    [sym_keyword_or] = ACTIONS(57),
    [sym_keyword_is] = ACTIONS(55),
    [sym_keyword_not] = ACTIONS(57),
    [sym_keyword_contains] = ACTIONS(55),
    [sym_keyword_contains_not] = ACTIONS(55),
    [sym_keyword_contains_all] = ACTIONS(55),
    [sym_keyword_contains_any] = ACTIONS(55),
    [sym_keyword_contains_none] = ACTIONS(55),
    [sym_keyword_inside] = ACTIONS(55),
    [sym_keyword_in] = ACTIONS(57),
    [sym_keyword_not_inside] = ACTIONS(55),
    [sym_keyword_all_inside] = ACTIONS(55),
    [sym_keyword_any_inside] = ACTIONS(55),
    [sym_keyword_none_inside] = ACTIONS(55),
    [sym_keyword_outside] = ACTIONS(55),
    [sym_keyword_intersects] = ACTIONS(55),
    [anon_sym_COMMA] = ACTIONS(55),
    [anon_sym_DASH_GT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(55),
    [anon_sym_COLON] = ACTIONS(120),
    [anon_sym_LT_DASH] = ACTIONS(57),
    [anon_sym_LT_DASH_GT] = ACTIONS(55),
    [anon_sym_STAR] = ACTIONS(57),
    [anon_sym_DOT] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(57),
    [anon_sym_GT] = ACTIONS(57),
    [anon_sym_EQ] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(57),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LT_PIPE] = ACTIONS(55),
    [anon_sym_AMP_AMP] = ACTIONS(55),
    [anon_sym_PIPE_PIPE] = ACTIONS(55),
    [anon_sym_QMARK_QMARK] = ACTIONS(55),
    [anon_sym_QMARK_COLON] = ACTIONS(55),
    [anon_sym_BANG_EQ] = ACTIONS(55),
    [anon_sym_EQ_EQ] = ACTIONS(55),
    [anon_sym_QMARK_EQ] = ACTIONS(55),
    [anon_sym_STAR_EQ] = ACTIONS(55),
    [anon_sym_TILDE] = ACTIONS(55),
    [anon_sym_BANG_TILDE] = ACTIONS(55),
    [anon_sym_STAR_TILDE] = ACTIONS(55),
    [anon_sym_LT_EQ] = ACTIONS(55),
    [anon_sym_GT_EQ] = ACTIONS(55),
    [anon_sym_PLUS] = ACTIONS(57),
    [anon_sym_PLUS_EQ] = ACTIONS(55),
    [anon_sym_DASH_EQ] = ACTIONS(55),
    [anon_sym_u00d7] = ACTIONS(55),
    [anon_sym_SLASH] = ACTIONS(57),
    [anon_sym_u00f7] = ACTIONS(55),
    [anon_sym_STAR_STAR] = ACTIONS(55),
    [anon_sym_u220b] = ACTIONS(55),
    [anon_sym_u220c] = ACTIONS(55),
    [anon_sym_u2287] = ACTIONS(55),
    [anon_sym_u2283] = ACTIONS(55),
    [anon_sym_u2285] = ACTIONS(55),
    [anon_sym_u2208] = ACTIONS(55),
    [anon_sym_u2209] = ACTIONS(55),
    [anon_sym_u2286] = ACTIONS(55),
    [anon_sym_u2282] = ACTIONS(55),
    [anon_sym_u2284] = ACTIONS(55),
    [anon_sym_AT_AT] = ACTIONS(55),
  },
  [276] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(55),
    [sym_keyword_explain] = ACTIONS(55),
    [sym_keyword_parallel] = ACTIONS(55),
    [sym_keyword_timeout] = ACTIONS(55),
    [sym_keyword_fetch] = ACTIONS(55),
    [sym_keyword_limit] = ACTIONS(55),
    [sym_keyword_order] = ACTIONS(55),
    [sym_keyword_with] = ACTIONS(55),
    [sym_keyword_where] = ACTIONS(55),
    [sym_keyword_split] = ACTIONS(55),
    [sym_keyword_group] = ACTIONS(55),
    [sym_keyword_and] = ACTIONS(55),
    [sym_keyword_or] = ACTIONS(57),
    [sym_keyword_is] = ACTIONS(55),
    [sym_keyword_not] = ACTIONS(57),
    [sym_keyword_contains] = ACTIONS(55),
    [sym_keyword_contains_not] = ACTIONS(55),
    [sym_keyword_contains_all] = ACTIONS(55),
    [sym_keyword_contains_any] = ACTIONS(55),
    [sym_keyword_contains_none] = ACTIONS(55),
    [sym_keyword_inside] = ACTIONS(55),
    [sym_keyword_in] = ACTIONS(57),
    [sym_keyword_not_inside] = ACTIONS(55),
    [sym_keyword_all_inside] = ACTIONS(55),
    [sym_keyword_any_inside] = ACTIONS(55),
    [sym_keyword_none_inside] = ACTIONS(55),
    [sym_keyword_outside] = ACTIONS(55),
    [sym_keyword_intersects] = ACTIONS(55),
    [anon_sym_COMMA] = ACTIONS(55),
    [anon_sym_DASH_GT] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(55),
    [anon_sym_RPAREN] = ACTIONS(55),
    [anon_sym_RBRACE] = ACTIONS(55),
    [anon_sym_LT_DASH] = ACTIONS(57),
    [anon_sym_LT_DASH_GT] = ACTIONS(55),
    [anon_sym_STAR] = ACTIONS(57),
    [anon_sym_DOT] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(57),
    [anon_sym_GT] = ACTIONS(57),
    [anon_sym_EQ] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(57),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LT_PIPE] = ACTIONS(55),
    [anon_sym_AMP_AMP] = ACTIONS(55),
    [anon_sym_PIPE_PIPE] = ACTIONS(55),
    [anon_sym_QMARK_QMARK] = ACTIONS(55),
    [anon_sym_QMARK_COLON] = ACTIONS(55),
    [anon_sym_BANG_EQ] = ACTIONS(55),
    [anon_sym_EQ_EQ] = ACTIONS(55),
    [anon_sym_QMARK_EQ] = ACTIONS(55),
    [anon_sym_STAR_EQ] = ACTIONS(55),
    [anon_sym_TILDE] = ACTIONS(55),
    [anon_sym_BANG_TILDE] = ACTIONS(55),
    [anon_sym_STAR_TILDE] = ACTIONS(55),
    [anon_sym_LT_EQ] = ACTIONS(55),
    [anon_sym_GT_EQ] = ACTIONS(55),
    [anon_sym_PLUS] = ACTIONS(57),
    [anon_sym_PLUS_EQ] = ACTIONS(55),
    [anon_sym_DASH_EQ] = ACTIONS(55),
    [anon_sym_u00d7] = ACTIONS(55),
    [anon_sym_SLASH] = ACTIONS(57),
    [anon_sym_u00f7] = ACTIONS(55),
    [anon_sym_STAR_STAR] = ACTIONS(55),
    [anon_sym_u220b] = ACTIONS(55),
    [anon_sym_u220c] = ACTIONS(55),
    [anon_sym_u2287] = ACTIONS(55),
    [anon_sym_u2283] = ACTIONS(55),
    [anon_sym_u2285] = ACTIONS(55),
    [anon_sym_u2208] = ACTIONS(55),
    [anon_sym_u2209] = ACTIONS(55),
    [anon_sym_u2286] = ACTIONS(55),
    [anon_sym_u2282] = ACTIONS(55),
    [anon_sym_u2284] = ACTIONS(55),
    [anon_sym_AT_AT] = ACTIONS(55),
  },
  [277] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(162),
    [sym_keyword_explain] = ACTIONS(162),
    [sym_keyword_parallel] = ACTIONS(162),
    [sym_keyword_timeout] = ACTIONS(162),
    [sym_keyword_fetch] = ACTIONS(162),
    [sym_keyword_limit] = ACTIONS(162),
    [sym_keyword_order] = ACTIONS(162),
    [sym_keyword_with] = ACTIONS(162),
    [sym_keyword_where] = ACTIONS(162),
    [sym_keyword_split] = ACTIONS(162),
    [sym_keyword_group] = ACTIONS(162),
    [sym_keyword_and] = ACTIONS(162),
    [sym_keyword_or] = ACTIONS(164),
    [sym_keyword_is] = ACTIONS(162),
    [sym_keyword_not] = ACTIONS(164),
    [sym_keyword_contains] = ACTIONS(162),
    [sym_keyword_contains_not] = ACTIONS(162),
    [sym_keyword_contains_all] = ACTIONS(162),
    [sym_keyword_contains_any] = ACTIONS(162),
    [sym_keyword_contains_none] = ACTIONS(162),
    [sym_keyword_inside] = ACTIONS(162),
    [sym_keyword_in] = ACTIONS(164),
    [sym_keyword_not_inside] = ACTIONS(162),
    [sym_keyword_all_inside] = ACTIONS(162),
    [sym_keyword_any_inside] = ACTIONS(162),
    [sym_keyword_none_inside] = ACTIONS(162),
    [sym_keyword_outside] = ACTIONS(162),
    [sym_keyword_intersects] = ACTIONS(162),
    [anon_sym_COMMA] = ACTIONS(162),
    [anon_sym_DASH_GT] = ACTIONS(162),
    [anon_sym_LBRACK] = ACTIONS(162),
    [anon_sym_RPAREN] = ACTIONS(162),
    [anon_sym_RBRACE] = ACTIONS(162),
    [anon_sym_LT_DASH] = ACTIONS(164),
    [anon_sym_LT_DASH_GT] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_DOT] = ACTIONS(162),
    [anon_sym_LT] = ACTIONS(164),
    [anon_sym_GT] = ACTIONS(164),
    [anon_sym_EQ] = ACTIONS(164),
    [anon_sym_DASH] = ACTIONS(164),
    [anon_sym_AT] = ACTIONS(164),
    [anon_sym_LT_PIPE] = ACTIONS(162),
    [anon_sym_AMP_AMP] = ACTIONS(162),
    [anon_sym_PIPE_PIPE] = ACTIONS(162),
    [anon_sym_QMARK_QMARK] = ACTIONS(162),
    [anon_sym_QMARK_COLON] = ACTIONS(162),
    [anon_sym_BANG_EQ] = ACTIONS(162),
    [anon_sym_EQ_EQ] = ACTIONS(162),
    [anon_sym_QMARK_EQ] = ACTIONS(162),
    [anon_sym_STAR_EQ] = ACTIONS(162),
    [anon_sym_TILDE] = ACTIONS(162),
    [anon_sym_BANG_TILDE] = ACTIONS(162),
    [anon_sym_STAR_TILDE] = ACTIONS(162),
    [anon_sym_LT_EQ] = ACTIONS(162),
    [anon_sym_GT_EQ] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(164),
    [anon_sym_PLUS_EQ] = ACTIONS(162),
    [anon_sym_DASH_EQ] = ACTIONS(162),
    [anon_sym_u00d7] = ACTIONS(162),
    [anon_sym_SLASH] = ACTIONS(164),
    [anon_sym_u00f7] = ACTIONS(162),
    [anon_sym_STAR_STAR] = ACTIONS(162),
    [anon_sym_u220b] = ACTIONS(162),
    [anon_sym_u220c] = ACTIONS(162),
    [anon_sym_u2287] = ACTIONS(162),
    [anon_sym_u2283] = ACTIONS(162),
    [anon_sym_u2285] = ACTIONS(162),
    [anon_sym_u2208] = ACTIONS(162),
    [anon_sym_u2209] = ACTIONS(162),
    [anon_sym_u2286] = ACTIONS(162),
    [anon_sym_u2282] = ACTIONS(162),
    [anon_sym_u2284] = ACTIONS(162),
    [anon_sym_AT_AT] = ACTIONS(162),
  },
  [278] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(170),
    [sym_keyword_explain] = ACTIONS(170),
    [sym_keyword_parallel] = ACTIONS(170),
    [sym_keyword_timeout] = ACTIONS(170),
    [sym_keyword_fetch] = ACTIONS(170),
    [sym_keyword_limit] = ACTIONS(170),
    [sym_keyword_order] = ACTIONS(170),
    [sym_keyword_with] = ACTIONS(170),
    [sym_keyword_where] = ACTIONS(170),
    [sym_keyword_split] = ACTIONS(170),
    [sym_keyword_group] = ACTIONS(170),
    [sym_keyword_and] = ACTIONS(170),
    [sym_keyword_or] = ACTIONS(172),
    [sym_keyword_is] = ACTIONS(170),
    [sym_keyword_not] = ACTIONS(172),
    [sym_keyword_contains] = ACTIONS(170),
    [sym_keyword_contains_not] = ACTIONS(170),
    [sym_keyword_contains_all] = ACTIONS(170),
    [sym_keyword_contains_any] = ACTIONS(170),
    [sym_keyword_contains_none] = ACTIONS(170),
    [sym_keyword_inside] = ACTIONS(170),
    [sym_keyword_in] = ACTIONS(172),
    [sym_keyword_not_inside] = ACTIONS(170),
    [sym_keyword_all_inside] = ACTIONS(170),
    [sym_keyword_any_inside] = ACTIONS(170),
    [sym_keyword_none_inside] = ACTIONS(170),
    [sym_keyword_outside] = ACTIONS(170),
    [sym_keyword_intersects] = ACTIONS(170),
    [anon_sym_COMMA] = ACTIONS(170),
    [anon_sym_DASH_GT] = ACTIONS(170),
    [anon_sym_LBRACK] = ACTIONS(170),
    [anon_sym_RPAREN] = ACTIONS(170),
    [anon_sym_RBRACE] = ACTIONS(170),
    [anon_sym_LT_DASH] = ACTIONS(172),
    [anon_sym_LT_DASH_GT] = ACTIONS(170),
    [anon_sym_STAR] = ACTIONS(172),
    [anon_sym_DOT] = ACTIONS(170),
    [anon_sym_LT] = ACTIONS(172),
    [anon_sym_GT] = ACTIONS(172),
    [anon_sym_EQ] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [anon_sym_AT] = ACTIONS(172),
    [anon_sym_LT_PIPE] = ACTIONS(170),
    [anon_sym_AMP_AMP] = ACTIONS(170),
    [anon_sym_PIPE_PIPE] = ACTIONS(170),
    [anon_sym_QMARK_QMARK] = ACTIONS(170),
    [anon_sym_QMARK_COLON] = ACTIONS(170),
    [anon_sym_BANG_EQ] = ACTIONS(170),
    [anon_sym_EQ_EQ] = ACTIONS(170),
    [anon_sym_QMARK_EQ] = ACTIONS(170),
    [anon_sym_STAR_EQ] = ACTIONS(170),
    [anon_sym_TILDE] = ACTIONS(170),
    [anon_sym_BANG_TILDE] = ACTIONS(170),
    [anon_sym_STAR_TILDE] = ACTIONS(170),
    [anon_sym_LT_EQ] = ACTIONS(170),
    [anon_sym_GT_EQ] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_PLUS_EQ] = ACTIONS(170),
    [anon_sym_DASH_EQ] = ACTIONS(170),
    [anon_sym_u00d7] = ACTIONS(170),
    [anon_sym_SLASH] = ACTIONS(172),
    [anon_sym_u00f7] = ACTIONS(170),
    [anon_sym_STAR_STAR] = ACTIONS(170),
    [anon_sym_u220b] = ACTIONS(170),
    [anon_sym_u220c] = ACTIONS(170),
    [anon_sym_u2287] = ACTIONS(170),
    [anon_sym_u2283] = ACTIONS(170),
    [anon_sym_u2285] = ACTIONS(170),
    [anon_sym_u2208] = ACTIONS(170),
    [anon_sym_u2209] = ACTIONS(170),
    [anon_sym_u2286] = ACTIONS(170),
    [anon_sym_u2282] = ACTIONS(170),
    [anon_sym_u2284] = ACTIONS(170),
    [anon_sym_AT_AT] = ACTIONS(170),
  },
  [279] = {
    [ts_builtin_sym_end] = ACTIONS(130),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(130),
    [sym_keyword_explain] = ACTIONS(130),
    [sym_keyword_parallel] = ACTIONS(130),
    [sym_keyword_timeout] = ACTIONS(130),
    [sym_keyword_fetch] = ACTIONS(130),
    [sym_keyword_limit] = ACTIONS(130),
    [sym_keyword_order] = ACTIONS(130),
    [sym_keyword_with] = ACTIONS(130),
    [sym_keyword_where] = ACTIONS(130),
    [sym_keyword_split] = ACTIONS(130),
    [sym_keyword_group] = ACTIONS(130),
    [sym_keyword_and] = ACTIONS(130),
    [sym_keyword_or] = ACTIONS(132),
    [sym_keyword_is] = ACTIONS(130),
    [sym_keyword_not] = ACTIONS(132),
    [sym_keyword_contains] = ACTIONS(130),
    [sym_keyword_contains_not] = ACTIONS(130),
    [sym_keyword_contains_all] = ACTIONS(130),
    [sym_keyword_contains_any] = ACTIONS(130),
    [sym_keyword_contains_none] = ACTIONS(130),
    [sym_keyword_inside] = ACTIONS(130),
    [sym_keyword_in] = ACTIONS(132),
    [sym_keyword_not_inside] = ACTIONS(130),
    [sym_keyword_all_inside] = ACTIONS(130),
    [sym_keyword_any_inside] = ACTIONS(130),
    [sym_keyword_none_inside] = ACTIONS(130),
    [sym_keyword_outside] = ACTIONS(130),
    [sym_keyword_intersects] = ACTIONS(130),
    [anon_sym_COMMA] = ACTIONS(130),
    [anon_sym_DASH_GT] = ACTIONS(130),
    [anon_sym_LBRACK] = ACTIONS(130),
    [anon_sym_LT_DASH] = ACTIONS(132),
    [anon_sym_LT_DASH_GT] = ACTIONS(130),
    [anon_sym_STAR] = ACTIONS(132),
    [anon_sym_DOT] = ACTIONS(132),
    [anon_sym_LT] = ACTIONS(132),
    [anon_sym_GT] = ACTIONS(132),
    [anon_sym_DOT_DOT] = ACTIONS(130),
    [anon_sym_EQ] = ACTIONS(132),
    [anon_sym_DASH] = ACTIONS(132),
    [anon_sym_AT] = ACTIONS(132),
    [anon_sym_LT_PIPE] = ACTIONS(130),
    [anon_sym_AMP_AMP] = ACTIONS(130),
    [anon_sym_PIPE_PIPE] = ACTIONS(130),
    [anon_sym_QMARK_QMARK] = ACTIONS(130),
    [anon_sym_QMARK_COLON] = ACTIONS(130),
    [anon_sym_BANG_EQ] = ACTIONS(130),
    [anon_sym_EQ_EQ] = ACTIONS(130),
    [anon_sym_QMARK_EQ] = ACTIONS(130),
    [anon_sym_STAR_EQ] = ACTIONS(130),
    [anon_sym_TILDE] = ACTIONS(130),
    [anon_sym_BANG_TILDE] = ACTIONS(130),
    [anon_sym_STAR_TILDE] = ACTIONS(130),
    [anon_sym_LT_EQ] = ACTIONS(130),
    [anon_sym_GT_EQ] = ACTIONS(130),
    [anon_sym_PLUS] = ACTIONS(132),
    [anon_sym_PLUS_EQ] = ACTIONS(130),
    [anon_sym_DASH_EQ] = ACTIONS(130),
    [anon_sym_u00d7] = ACTIONS(130),
    [anon_sym_SLASH] = ACTIONS(132),
    [anon_sym_u00f7] = ACTIONS(130),
    [anon_sym_STAR_STAR] = ACTIONS(130),
    [anon_sym_u220b] = ACTIONS(130),
    [anon_sym_u220c] = ACTIONS(130),
    [anon_sym_u2287] = ACTIONS(130),
    [anon_sym_u2283] = ACTIONS(130),
    [anon_sym_u2285] = ACTIONS(130),
    [anon_sym_u2208] = ACTIONS(130),
    [anon_sym_u2209] = ACTIONS(130),
    [anon_sym_u2286] = ACTIONS(130),
    [anon_sym_u2282] = ACTIONS(130),
    [anon_sym_u2284] = ACTIONS(130),
    [anon_sym_AT_AT] = ACTIONS(130),
  },
  [280] = {
    [ts_builtin_sym_end] = ACTIONS(122),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(122),
    [sym_keyword_explain] = ACTIONS(122),
    [sym_keyword_parallel] = ACTIONS(122),
    [sym_keyword_timeout] = ACTIONS(122),
    [sym_keyword_fetch] = ACTIONS(122),
    [sym_keyword_limit] = ACTIONS(122),
    [sym_keyword_order] = ACTIONS(122),
    [sym_keyword_with] = ACTIONS(122),
    [sym_keyword_where] = ACTIONS(122),
    [sym_keyword_split] = ACTIONS(122),
    [sym_keyword_group] = ACTIONS(122),
    [sym_keyword_and] = ACTIONS(122),
    [sym_keyword_or] = ACTIONS(124),
    [sym_keyword_is] = ACTIONS(122),
    [sym_keyword_not] = ACTIONS(124),
    [sym_keyword_contains] = ACTIONS(122),
    [sym_keyword_contains_not] = ACTIONS(122),
    [sym_keyword_contains_all] = ACTIONS(122),
    [sym_keyword_contains_any] = ACTIONS(122),
    [sym_keyword_contains_none] = ACTIONS(122),
    [sym_keyword_inside] = ACTIONS(122),
    [sym_keyword_in] = ACTIONS(124),
    [sym_keyword_not_inside] = ACTIONS(122),
    [sym_keyword_all_inside] = ACTIONS(122),
    [sym_keyword_any_inside] = ACTIONS(122),
    [sym_keyword_none_inside] = ACTIONS(122),
    [sym_keyword_outside] = ACTIONS(122),
    [sym_keyword_intersects] = ACTIONS(122),
    [anon_sym_COMMA] = ACTIONS(122),
    [anon_sym_DASH_GT] = ACTIONS(122),
    [anon_sym_LBRACK] = ACTIONS(122),
    [anon_sym_LT_DASH] = ACTIONS(124),
    [anon_sym_LT_DASH_GT] = ACTIONS(122),
    [anon_sym_STAR] = ACTIONS(124),
    [anon_sym_DOT] = ACTIONS(124),
    [anon_sym_LT] = ACTIONS(124),
    [anon_sym_GT] = ACTIONS(124),
    [anon_sym_DOT_DOT] = ACTIONS(122),
    [anon_sym_EQ] = ACTIONS(124),
    [anon_sym_DASH] = ACTIONS(124),
    [anon_sym_AT] = ACTIONS(124),
    [anon_sym_LT_PIPE] = ACTIONS(122),
    [anon_sym_AMP_AMP] = ACTIONS(122),
    [anon_sym_PIPE_PIPE] = ACTIONS(122),
    [anon_sym_QMARK_QMARK] = ACTIONS(122),
    [anon_sym_QMARK_COLON] = ACTIONS(122),
    [anon_sym_BANG_EQ] = ACTIONS(122),
    [anon_sym_EQ_EQ] = ACTIONS(122),
    [anon_sym_QMARK_EQ] = ACTIONS(122),
    [anon_sym_STAR_EQ] = ACTIONS(122),
    [anon_sym_TILDE] = ACTIONS(122),
    [anon_sym_BANG_TILDE] = ACTIONS(122),
    [anon_sym_STAR_TILDE] = ACTIONS(122),
    [anon_sym_LT_EQ] = ACTIONS(122),
    [anon_sym_GT_EQ] = ACTIONS(122),
    [anon_sym_PLUS] = ACTIONS(124),
    [anon_sym_PLUS_EQ] = ACTIONS(122),
    [anon_sym_DASH_EQ] = ACTIONS(122),
    [anon_sym_u00d7] = ACTIONS(122),
    [anon_sym_SLASH] = ACTIONS(124),
    [anon_sym_u00f7] = ACTIONS(122),
    [anon_sym_STAR_STAR] = ACTIONS(122),
    [anon_sym_u220b] = ACTIONS(122),
    [anon_sym_u220c] = ACTIONS(122),
    [anon_sym_u2287] = ACTIONS(122),
    [anon_sym_u2283] = ACTIONS(122),
    [anon_sym_u2285] = ACTIONS(122),
    [anon_sym_u2208] = ACTIONS(122),
    [anon_sym_u2209] = ACTIONS(122),
    [anon_sym_u2286] = ACTIONS(122),
    [anon_sym_u2282] = ACTIONS(122),
    [anon_sym_u2284] = ACTIONS(122),
    [anon_sym_AT_AT] = ACTIONS(122),
  },
  [281] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(174),
    [sym_keyword_explain] = ACTIONS(174),
    [sym_keyword_parallel] = ACTIONS(174),
    [sym_keyword_timeout] = ACTIONS(174),
    [sym_keyword_fetch] = ACTIONS(174),
    [sym_keyword_limit] = ACTIONS(174),
    [sym_keyword_order] = ACTIONS(174),
    [sym_keyword_with] = ACTIONS(174),
    [sym_keyword_where] = ACTIONS(174),
    [sym_keyword_split] = ACTIONS(174),
    [sym_keyword_group] = ACTIONS(174),
    [sym_keyword_and] = ACTIONS(174),
    [sym_keyword_or] = ACTIONS(176),
    [sym_keyword_is] = ACTIONS(174),
    [sym_keyword_not] = ACTIONS(176),
    [sym_keyword_contains] = ACTIONS(174),
    [sym_keyword_contains_not] = ACTIONS(174),
    [sym_keyword_contains_all] = ACTIONS(174),
    [sym_keyword_contains_any] = ACTIONS(174),
    [sym_keyword_contains_none] = ACTIONS(174),
    [sym_keyword_inside] = ACTIONS(174),
    [sym_keyword_in] = ACTIONS(176),
    [sym_keyword_not_inside] = ACTIONS(174),
    [sym_keyword_all_inside] = ACTIONS(174),
    [sym_keyword_any_inside] = ACTIONS(174),
    [sym_keyword_none_inside] = ACTIONS(174),
    [sym_keyword_outside] = ACTIONS(174),
    [sym_keyword_intersects] = ACTIONS(174),
    [anon_sym_COMMA] = ACTIONS(174),
    [anon_sym_DASH_GT] = ACTIONS(174),
    [anon_sym_LBRACK] = ACTIONS(174),
    [anon_sym_RPAREN] = ACTIONS(174),
    [anon_sym_RBRACE] = ACTIONS(174),
    [anon_sym_LT_DASH] = ACTIONS(176),
    [anon_sym_LT_DASH_GT] = ACTIONS(174),
    [anon_sym_STAR] = ACTIONS(176),
    [anon_sym_DOT] = ACTIONS(174),
    [anon_sym_LT] = ACTIONS(176),
    [anon_sym_GT] = ACTIONS(176),
    [anon_sym_EQ] = ACTIONS(176),
    [anon_sym_DASH] = ACTIONS(176),
    [anon_sym_AT] = ACTIONS(176),
    [anon_sym_LT_PIPE] = ACTIONS(174),
    [anon_sym_AMP_AMP] = ACTIONS(174),
    [anon_sym_PIPE_PIPE] = ACTIONS(174),
    [anon_sym_QMARK_QMARK] = ACTIONS(174),
    [anon_sym_QMARK_COLON] = ACTIONS(174),
    [anon_sym_BANG_EQ] = ACTIONS(174),
    [anon_sym_EQ_EQ] = ACTIONS(174),
    [anon_sym_QMARK_EQ] = ACTIONS(174),
    [anon_sym_STAR_EQ] = ACTIONS(174),
    [anon_sym_TILDE] = ACTIONS(174),
    [anon_sym_BANG_TILDE] = ACTIONS(174),
    [anon_sym_STAR_TILDE] = ACTIONS(174),
    [anon_sym_LT_EQ] = ACTIONS(174),
    [anon_sym_GT_EQ] = ACTIONS(174),
    [anon_sym_PLUS] = ACTIONS(176),
    [anon_sym_PLUS_EQ] = ACTIONS(174),
    [anon_sym_DASH_EQ] = ACTIONS(174),
    [anon_sym_u00d7] = ACTIONS(174),
    [anon_sym_SLASH] = ACTIONS(176),
    [anon_sym_u00f7] = ACTIONS(174),
    [anon_sym_STAR_STAR] = ACTIONS(174),
    [anon_sym_u220b] = ACTIONS(174),
    [anon_sym_u220c] = ACTIONS(174),
    [anon_sym_u2287] = ACTIONS(174),
    [anon_sym_u2283] = ACTIONS(174),
    [anon_sym_u2285] = ACTIONS(174),
    [anon_sym_u2208] = ACTIONS(174),
    [anon_sym_u2209] = ACTIONS(174),
    [anon_sym_u2286] = ACTIONS(174),
    [anon_sym_u2282] = ACTIONS(174),
    [anon_sym_u2284] = ACTIONS(174),
    [anon_sym_AT_AT] = ACTIONS(174),
  },
  [282] = {
    [ts_builtin_sym_end] = ACTIONS(112),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(112),
    [sym_keyword_explain] = ACTIONS(112),
    [sym_keyword_parallel] = ACTIONS(112),
    [sym_keyword_timeout] = ACTIONS(112),
    [sym_keyword_fetch] = ACTIONS(112),
    [sym_keyword_limit] = ACTIONS(112),
    [sym_keyword_order] = ACTIONS(112),
    [sym_keyword_with] = ACTIONS(112),
    [sym_keyword_where] = ACTIONS(112),
    [sym_keyword_split] = ACTIONS(112),
    [sym_keyword_group] = ACTIONS(112),
    [sym_keyword_and] = ACTIONS(112),
    [sym_keyword_or] = ACTIONS(114),
    [sym_keyword_is] = ACTIONS(112),
    [sym_keyword_not] = ACTIONS(114),
    [sym_keyword_contains] = ACTIONS(112),
    [sym_keyword_contains_not] = ACTIONS(112),
    [sym_keyword_contains_all] = ACTIONS(112),
    [sym_keyword_contains_any] = ACTIONS(112),
    [sym_keyword_contains_none] = ACTIONS(112),
    [sym_keyword_inside] = ACTIONS(112),
    [sym_keyword_in] = ACTIONS(114),
    [sym_keyword_not_inside] = ACTIONS(112),
    [sym_keyword_all_inside] = ACTIONS(112),
    [sym_keyword_any_inside] = ACTIONS(112),
    [sym_keyword_none_inside] = ACTIONS(112),
    [sym_keyword_outside] = ACTIONS(112),
    [sym_keyword_intersects] = ACTIONS(112),
    [anon_sym_COMMA] = ACTIONS(112),
    [anon_sym_DASH_GT] = ACTIONS(112),
    [anon_sym_LBRACK] = ACTIONS(112),
    [anon_sym_LT_DASH] = ACTIONS(114),
    [anon_sym_LT_DASH_GT] = ACTIONS(112),
    [anon_sym_STAR] = ACTIONS(114),
    [anon_sym_DOT] = ACTIONS(114),
    [anon_sym_LT] = ACTIONS(114),
    [anon_sym_GT] = ACTIONS(114),
    [anon_sym_DOT_DOT] = ACTIONS(112),
    [anon_sym_EQ] = ACTIONS(114),
    [anon_sym_DASH] = ACTIONS(114),
    [anon_sym_AT] = ACTIONS(114),
    [anon_sym_LT_PIPE] = ACTIONS(112),
    [anon_sym_AMP_AMP] = ACTIONS(112),
    [anon_sym_PIPE_PIPE] = ACTIONS(112),
    [anon_sym_QMARK_QMARK] = ACTIONS(112),
    [anon_sym_QMARK_COLON] = ACTIONS(112),
    [anon_sym_BANG_EQ] = ACTIONS(112),
    [anon_sym_EQ_EQ] = ACTIONS(112),
    [anon_sym_QMARK_EQ] = ACTIONS(112),
    [anon_sym_STAR_EQ] = ACTIONS(112),
    [anon_sym_TILDE] = ACTIONS(112),
    [anon_sym_BANG_TILDE] = ACTIONS(112),
    [anon_sym_STAR_TILDE] = ACTIONS(112),
    [anon_sym_LT_EQ] = ACTIONS(112),
    [anon_sym_GT_EQ] = ACTIONS(112),
    [anon_sym_PLUS] = ACTIONS(114),
    [anon_sym_PLUS_EQ] = ACTIONS(112),
    [anon_sym_DASH_EQ] = ACTIONS(112),
    [anon_sym_u00d7] = ACTIONS(112),
    [anon_sym_SLASH] = ACTIONS(114),
    [anon_sym_u00f7] = ACTIONS(112),
    [anon_sym_STAR_STAR] = ACTIONS(112),
    [anon_sym_u220b] = ACTIONS(112),
    [anon_sym_u220c] = ACTIONS(112),
    [anon_sym_u2287] = ACTIONS(112),
    [anon_sym_u2283] = ACTIONS(112),
    [anon_sym_u2285] = ACTIONS(112),
    [anon_sym_u2208] = ACTIONS(112),
    [anon_sym_u2209] = ACTIONS(112),
    [anon_sym_u2286] = ACTIONS(112),
    [anon_sym_u2282] = ACTIONS(112),
    [anon_sym_u2284] = ACTIONS(112),
    [anon_sym_AT_AT] = ACTIONS(112),
  },
  [283] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_explain] = ACTIONS(178),
    [sym_keyword_parallel] = ACTIONS(178),
    [sym_keyword_timeout] = ACTIONS(178),
    [sym_keyword_fetch] = ACTIONS(178),
    [sym_keyword_limit] = ACTIONS(178),
    [sym_keyword_order] = ACTIONS(178),
    [sym_keyword_with] = ACTIONS(178),
    [sym_keyword_where] = ACTIONS(178),
    [sym_keyword_split] = ACTIONS(178),
    [sym_keyword_group] = ACTIONS(178),
    [sym_keyword_and] = ACTIONS(178),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(178),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(178),
    [sym_keyword_contains_not] = ACTIONS(178),
    [sym_keyword_contains_all] = ACTIONS(178),
    [sym_keyword_contains_any] = ACTIONS(178),
    [sym_keyword_contains_none] = ACTIONS(178),
    [sym_keyword_inside] = ACTIONS(178),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(178),
    [sym_keyword_all_inside] = ACTIONS(178),
    [sym_keyword_any_inside] = ACTIONS(178),
    [sym_keyword_none_inside] = ACTIONS(178),
    [sym_keyword_outside] = ACTIONS(178),
    [sym_keyword_intersects] = ACTIONS(178),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [284] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(186),
    [sym_keyword_explain] = ACTIONS(186),
    [sym_keyword_parallel] = ACTIONS(186),
    [sym_keyword_timeout] = ACTIONS(186),
    [sym_keyword_fetch] = ACTIONS(186),
    [sym_keyword_limit] = ACTIONS(186),
    [sym_keyword_order] = ACTIONS(186),
    [sym_keyword_with] = ACTIONS(186),
    [sym_keyword_where] = ACTIONS(186),
    [sym_keyword_split] = ACTIONS(186),
    [sym_keyword_group] = ACTIONS(186),
    [sym_keyword_and] = ACTIONS(186),
    [sym_keyword_or] = ACTIONS(188),
    [sym_keyword_is] = ACTIONS(186),
    [sym_keyword_not] = ACTIONS(188),
    [sym_keyword_contains] = ACTIONS(186),
    [sym_keyword_contains_not] = ACTIONS(186),
    [sym_keyword_contains_all] = ACTIONS(186),
    [sym_keyword_contains_any] = ACTIONS(186),
    [sym_keyword_contains_none] = ACTIONS(186),
    [sym_keyword_inside] = ACTIONS(186),
    [sym_keyword_in] = ACTIONS(188),
    [sym_keyword_not_inside] = ACTIONS(186),
    [sym_keyword_all_inside] = ACTIONS(186),
    [sym_keyword_any_inside] = ACTIONS(186),
    [sym_keyword_none_inside] = ACTIONS(186),
    [sym_keyword_outside] = ACTIONS(186),
    [sym_keyword_intersects] = ACTIONS(186),
    [anon_sym_COMMA] = ACTIONS(186),
    [anon_sym_DASH_GT] = ACTIONS(186),
    [anon_sym_LBRACK] = ACTIONS(186),
    [anon_sym_RPAREN] = ACTIONS(186),
    [anon_sym_RBRACE] = ACTIONS(186),
    [anon_sym_LT_DASH] = ACTIONS(188),
    [anon_sym_LT_DASH_GT] = ACTIONS(186),
    [anon_sym_STAR] = ACTIONS(188),
    [anon_sym_DOT] = ACTIONS(186),
    [anon_sym_LT] = ACTIONS(188),
    [anon_sym_GT] = ACTIONS(188),
    [anon_sym_EQ] = ACTIONS(188),
    [anon_sym_DASH] = ACTIONS(188),
    [anon_sym_AT] = ACTIONS(188),
    [anon_sym_LT_PIPE] = ACTIONS(186),
    [anon_sym_AMP_AMP] = ACTIONS(186),
    [anon_sym_PIPE_PIPE] = ACTIONS(186),
    [anon_sym_QMARK_QMARK] = ACTIONS(186),
    [anon_sym_QMARK_COLON] = ACTIONS(186),
    [anon_sym_BANG_EQ] = ACTIONS(186),
    [anon_sym_EQ_EQ] = ACTIONS(186),
    [anon_sym_QMARK_EQ] = ACTIONS(186),
    [anon_sym_STAR_EQ] = ACTIONS(186),
    [anon_sym_TILDE] = ACTIONS(186),
    [anon_sym_BANG_TILDE] = ACTIONS(186),
    [anon_sym_STAR_TILDE] = ACTIONS(186),
    [anon_sym_LT_EQ] = ACTIONS(186),
    [anon_sym_GT_EQ] = ACTIONS(186),
    [anon_sym_PLUS] = ACTIONS(188),
    [anon_sym_PLUS_EQ] = ACTIONS(186),
    [anon_sym_DASH_EQ] = ACTIONS(186),
    [anon_sym_u00d7] = ACTIONS(186),
    [anon_sym_SLASH] = ACTIONS(188),
    [anon_sym_u00f7] = ACTIONS(186),
    [anon_sym_STAR_STAR] = ACTIONS(186),
    [anon_sym_u220b] = ACTIONS(186),
    [anon_sym_u220c] = ACTIONS(186),
    [anon_sym_u2287] = ACTIONS(186),
    [anon_sym_u2283] = ACTIONS(186),
    [anon_sym_u2285] = ACTIONS(186),
    [anon_sym_u2208] = ACTIONS(186),
    [anon_sym_u2209] = ACTIONS(186),
    [anon_sym_u2286] = ACTIONS(186),
    [anon_sym_u2282] = ACTIONS(186),
    [anon_sym_u2284] = ACTIONS(186),
    [anon_sym_AT_AT] = ACTIONS(186),
  },
  [285] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(190),
    [sym_keyword_explain] = ACTIONS(190),
    [sym_keyword_parallel] = ACTIONS(190),
    [sym_keyword_timeout] = ACTIONS(190),
    [sym_keyword_fetch] = ACTIONS(190),
    [sym_keyword_limit] = ACTIONS(190),
    [sym_keyword_order] = ACTIONS(190),
    [sym_keyword_with] = ACTIONS(190),
    [sym_keyword_where] = ACTIONS(190),
    [sym_keyword_split] = ACTIONS(190),
    [sym_keyword_group] = ACTIONS(190),
    [sym_keyword_and] = ACTIONS(190),
    [sym_keyword_or] = ACTIONS(192),
    [sym_keyword_is] = ACTIONS(190),
    [sym_keyword_not] = ACTIONS(192),
    [sym_keyword_contains] = ACTIONS(190),
    [sym_keyword_contains_not] = ACTIONS(190),
    [sym_keyword_contains_all] = ACTIONS(190),
    [sym_keyword_contains_any] = ACTIONS(190),
    [sym_keyword_contains_none] = ACTIONS(190),
    [sym_keyword_inside] = ACTIONS(190),
    [sym_keyword_in] = ACTIONS(192),
    [sym_keyword_not_inside] = ACTIONS(190),
    [sym_keyword_all_inside] = ACTIONS(190),
    [sym_keyword_any_inside] = ACTIONS(190),
    [sym_keyword_none_inside] = ACTIONS(190),
    [sym_keyword_outside] = ACTIONS(190),
    [sym_keyword_intersects] = ACTIONS(190),
    [anon_sym_COMMA] = ACTIONS(190),
    [anon_sym_DASH_GT] = ACTIONS(190),
    [anon_sym_LBRACK] = ACTIONS(190),
    [anon_sym_RPAREN] = ACTIONS(190),
    [anon_sym_RBRACE] = ACTIONS(190),
    [anon_sym_LT_DASH] = ACTIONS(192),
    [anon_sym_LT_DASH_GT] = ACTIONS(190),
    [anon_sym_STAR] = ACTIONS(192),
    [anon_sym_DOT] = ACTIONS(190),
    [anon_sym_LT] = ACTIONS(192),
    [anon_sym_GT] = ACTIONS(192),
    [anon_sym_EQ] = ACTIONS(192),
    [anon_sym_DASH] = ACTIONS(192),
    [anon_sym_AT] = ACTIONS(192),
    [anon_sym_LT_PIPE] = ACTIONS(190),
    [anon_sym_AMP_AMP] = ACTIONS(190),
    [anon_sym_PIPE_PIPE] = ACTIONS(190),
    [anon_sym_QMARK_QMARK] = ACTIONS(190),
    [anon_sym_QMARK_COLON] = ACTIONS(190),
    [anon_sym_BANG_EQ] = ACTIONS(190),
    [anon_sym_EQ_EQ] = ACTIONS(190),
    [anon_sym_QMARK_EQ] = ACTIONS(190),
    [anon_sym_STAR_EQ] = ACTIONS(190),
    [anon_sym_TILDE] = ACTIONS(190),
    [anon_sym_BANG_TILDE] = ACTIONS(190),
    [anon_sym_STAR_TILDE] = ACTIONS(190),
    [anon_sym_LT_EQ] = ACTIONS(190),
    [anon_sym_GT_EQ] = ACTIONS(190),
    [anon_sym_PLUS] = ACTIONS(192),
    [anon_sym_PLUS_EQ] = ACTIONS(190),
    [anon_sym_DASH_EQ] = ACTIONS(190),
    [anon_sym_u00d7] = ACTIONS(190),
    [anon_sym_SLASH] = ACTIONS(192),
    [anon_sym_u00f7] = ACTIONS(190),
    [anon_sym_STAR_STAR] = ACTIONS(190),
    [anon_sym_u220b] = ACTIONS(190),
    [anon_sym_u220c] = ACTIONS(190),
    [anon_sym_u2287] = ACTIONS(190),
    [anon_sym_u2283] = ACTIONS(190),
    [anon_sym_u2285] = ACTIONS(190),
    [anon_sym_u2208] = ACTIONS(190),
    [anon_sym_u2209] = ACTIONS(190),
    [anon_sym_u2286] = ACTIONS(190),
    [anon_sym_u2282] = ACTIONS(190),
    [anon_sym_u2284] = ACTIONS(190),
    [anon_sym_AT_AT] = ACTIONS(190),
  },
  [286] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_explain] = ACTIONS(210),
    [sym_keyword_parallel] = ACTIONS(210),
    [sym_keyword_timeout] = ACTIONS(210),
    [sym_keyword_fetch] = ACTIONS(210),
    [sym_keyword_limit] = ACTIONS(210),
    [sym_keyword_order] = ACTIONS(210),
    [sym_keyword_with] = ACTIONS(210),
    [sym_keyword_where] = ACTIONS(210),
    [sym_keyword_split] = ACTIONS(210),
    [sym_keyword_group] = ACTIONS(210),
    [sym_keyword_and] = ACTIONS(210),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(210),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(210),
    [sym_keyword_contains_not] = ACTIONS(210),
    [sym_keyword_contains_all] = ACTIONS(210),
    [sym_keyword_contains_any] = ACTIONS(210),
    [sym_keyword_contains_none] = ACTIONS(210),
    [sym_keyword_inside] = ACTIONS(210),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(210),
    [sym_keyword_all_inside] = ACTIONS(210),
    [sym_keyword_any_inside] = ACTIONS(210),
    [sym_keyword_none_inside] = ACTIONS(210),
    [sym_keyword_outside] = ACTIONS(210),
    [sym_keyword_intersects] = ACTIONS(210),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [287] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(198),
    [sym_keyword_explain] = ACTIONS(198),
    [sym_keyword_parallel] = ACTIONS(198),
    [sym_keyword_timeout] = ACTIONS(198),
    [sym_keyword_fetch] = ACTIONS(198),
    [sym_keyword_limit] = ACTIONS(198),
    [sym_keyword_order] = ACTIONS(198),
    [sym_keyword_with] = ACTIONS(198),
    [sym_keyword_where] = ACTIONS(198),
    [sym_keyword_split] = ACTIONS(198),
    [sym_keyword_group] = ACTIONS(198),
    [sym_keyword_and] = ACTIONS(198),
    [sym_keyword_or] = ACTIONS(200),
    [sym_keyword_is] = ACTIONS(198),
    [sym_keyword_not] = ACTIONS(200),
    [sym_keyword_contains] = ACTIONS(198),
    [sym_keyword_contains_not] = ACTIONS(198),
    [sym_keyword_contains_all] = ACTIONS(198),
    [sym_keyword_contains_any] = ACTIONS(198),
    [sym_keyword_contains_none] = ACTIONS(198),
    [sym_keyword_inside] = ACTIONS(198),
    [sym_keyword_in] = ACTIONS(200),
    [sym_keyword_not_inside] = ACTIONS(198),
    [sym_keyword_all_inside] = ACTIONS(198),
    [sym_keyword_any_inside] = ACTIONS(198),
    [sym_keyword_none_inside] = ACTIONS(198),
    [sym_keyword_outside] = ACTIONS(198),
    [sym_keyword_intersects] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(198),
    [anon_sym_DASH_GT] = ACTIONS(198),
    [anon_sym_LBRACK] = ACTIONS(198),
    [anon_sym_RPAREN] = ACTIONS(198),
    [anon_sym_RBRACE] = ACTIONS(198),
    [anon_sym_LT_DASH] = ACTIONS(200),
    [anon_sym_LT_DASH_GT] = ACTIONS(198),
    [anon_sym_STAR] = ACTIONS(200),
    [anon_sym_DOT] = ACTIONS(198),
    [anon_sym_LT] = ACTIONS(200),
    [anon_sym_GT] = ACTIONS(200),
    [anon_sym_EQ] = ACTIONS(200),
    [anon_sym_DASH] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(200),
    [anon_sym_LT_PIPE] = ACTIONS(198),
    [anon_sym_AMP_AMP] = ACTIONS(198),
    [anon_sym_PIPE_PIPE] = ACTIONS(198),
    [anon_sym_QMARK_QMARK] = ACTIONS(198),
    [anon_sym_QMARK_COLON] = ACTIONS(198),
    [anon_sym_BANG_EQ] = ACTIONS(198),
    [anon_sym_EQ_EQ] = ACTIONS(198),
    [anon_sym_QMARK_EQ] = ACTIONS(198),
    [anon_sym_STAR_EQ] = ACTIONS(198),
    [anon_sym_TILDE] = ACTIONS(198),
    [anon_sym_BANG_TILDE] = ACTIONS(198),
    [anon_sym_STAR_TILDE] = ACTIONS(198),
    [anon_sym_LT_EQ] = ACTIONS(198),
    [anon_sym_GT_EQ] = ACTIONS(198),
    [anon_sym_PLUS] = ACTIONS(200),
    [anon_sym_PLUS_EQ] = ACTIONS(198),
    [anon_sym_DASH_EQ] = ACTIONS(198),
    [anon_sym_u00d7] = ACTIONS(198),
    [anon_sym_SLASH] = ACTIONS(200),
    [anon_sym_u00f7] = ACTIONS(198),
    [anon_sym_STAR_STAR] = ACTIONS(198),
    [anon_sym_u220b] = ACTIONS(198),
    [anon_sym_u220c] = ACTIONS(198),
    [anon_sym_u2287] = ACTIONS(198),
    [anon_sym_u2283] = ACTIONS(198),
    [anon_sym_u2285] = ACTIONS(198),
    [anon_sym_u2208] = ACTIONS(198),
    [anon_sym_u2209] = ACTIONS(198),
    [anon_sym_u2286] = ACTIONS(198),
    [anon_sym_u2282] = ACTIONS(198),
    [anon_sym_u2284] = ACTIONS(198),
    [anon_sym_AT_AT] = ACTIONS(198),
  },
  [288] = {
    [ts_builtin_sym_end] = ACTIONS(116),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(116),
    [sym_keyword_explain] = ACTIONS(116),
    [sym_keyword_parallel] = ACTIONS(116),
    [sym_keyword_timeout] = ACTIONS(116),
    [sym_keyword_fetch] = ACTIONS(116),
    [sym_keyword_limit] = ACTIONS(116),
    [sym_keyword_order] = ACTIONS(116),
    [sym_keyword_with] = ACTIONS(116),
    [sym_keyword_where] = ACTIONS(116),
    [sym_keyword_split] = ACTIONS(116),
    [sym_keyword_group] = ACTIONS(116),
    [sym_keyword_and] = ACTIONS(116),
    [sym_keyword_or] = ACTIONS(118),
    [sym_keyword_is] = ACTIONS(116),
    [sym_keyword_not] = ACTIONS(118),
    [sym_keyword_contains] = ACTIONS(116),
    [sym_keyword_contains_not] = ACTIONS(116),
    [sym_keyword_contains_all] = ACTIONS(116),
    [sym_keyword_contains_any] = ACTIONS(116),
    [sym_keyword_contains_none] = ACTIONS(116),
    [sym_keyword_inside] = ACTIONS(116),
    [sym_keyword_in] = ACTIONS(118),
    [sym_keyword_not_inside] = ACTIONS(116),
    [sym_keyword_all_inside] = ACTIONS(116),
    [sym_keyword_any_inside] = ACTIONS(116),
    [sym_keyword_none_inside] = ACTIONS(116),
    [sym_keyword_outside] = ACTIONS(116),
    [sym_keyword_intersects] = ACTIONS(116),
    [anon_sym_COMMA] = ACTIONS(116),
    [anon_sym_DASH_GT] = ACTIONS(116),
    [anon_sym_LBRACK] = ACTIONS(116),
    [anon_sym_LT_DASH] = ACTIONS(118),
    [anon_sym_LT_DASH_GT] = ACTIONS(116),
    [anon_sym_STAR] = ACTIONS(118),
    [anon_sym_DOT] = ACTIONS(118),
    [anon_sym_LT] = ACTIONS(118),
    [anon_sym_GT] = ACTIONS(118),
    [anon_sym_DOT_DOT] = ACTIONS(116),
    [anon_sym_EQ] = ACTIONS(118),
    [anon_sym_DASH] = ACTIONS(118),
    [anon_sym_AT] = ACTIONS(118),
    [anon_sym_LT_PIPE] = ACTIONS(116),
    [anon_sym_AMP_AMP] = ACTIONS(116),
    [anon_sym_PIPE_PIPE] = ACTIONS(116),
    [anon_sym_QMARK_QMARK] = ACTIONS(116),
    [anon_sym_QMARK_COLON] = ACTIONS(116),
    [anon_sym_BANG_EQ] = ACTIONS(116),
    [anon_sym_EQ_EQ] = ACTIONS(116),
    [anon_sym_QMARK_EQ] = ACTIONS(116),
    [anon_sym_STAR_EQ] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(116),
    [anon_sym_BANG_TILDE] = ACTIONS(116),
    [anon_sym_STAR_TILDE] = ACTIONS(116),
    [anon_sym_LT_EQ] = ACTIONS(116),
    [anon_sym_GT_EQ] = ACTIONS(116),
    [anon_sym_PLUS] = ACTIONS(118),
    [anon_sym_PLUS_EQ] = ACTIONS(116),
    [anon_sym_DASH_EQ] = ACTIONS(116),
    [anon_sym_u00d7] = ACTIONS(116),
    [anon_sym_SLASH] = ACTIONS(118),
    [anon_sym_u00f7] = ACTIONS(116),
    [anon_sym_STAR_STAR] = ACTIONS(116),
    [anon_sym_u220b] = ACTIONS(116),
    [anon_sym_u220c] = ACTIONS(116),
    [anon_sym_u2287] = ACTIONS(116),
    [anon_sym_u2283] = ACTIONS(116),
    [anon_sym_u2285] = ACTIONS(116),
    [anon_sym_u2208] = ACTIONS(116),
    [anon_sym_u2209] = ACTIONS(116),
    [anon_sym_u2286] = ACTIONS(116),
    [anon_sym_u2282] = ACTIONS(116),
    [anon_sym_u2284] = ACTIONS(116),
    [anon_sym_AT_AT] = ACTIONS(116),
  },
  [289] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_explain] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_fetch] = ACTIONS(182),
    [sym_keyword_limit] = ACTIONS(182),
    [sym_keyword_order] = ACTIONS(182),
    [sym_keyword_with] = ACTIONS(182),
    [sym_keyword_where] = ACTIONS(182),
    [sym_keyword_split] = ACTIONS(182),
    [sym_keyword_group] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(184),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(182),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [290] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(166),
    [sym_keyword_explain] = ACTIONS(166),
    [sym_keyword_parallel] = ACTIONS(166),
    [sym_keyword_timeout] = ACTIONS(166),
    [sym_keyword_fetch] = ACTIONS(166),
    [sym_keyword_limit] = ACTIONS(166),
    [sym_keyword_order] = ACTIONS(166),
    [sym_keyword_with] = ACTIONS(166),
    [sym_keyword_where] = ACTIONS(166),
    [sym_keyword_split] = ACTIONS(166),
    [sym_keyword_group] = ACTIONS(166),
    [sym_keyword_and] = ACTIONS(166),
    [sym_keyword_or] = ACTIONS(168),
    [sym_keyword_is] = ACTIONS(166),
    [sym_keyword_not] = ACTIONS(168),
    [sym_keyword_contains] = ACTIONS(166),
    [sym_keyword_contains_not] = ACTIONS(166),
    [sym_keyword_contains_all] = ACTIONS(166),
    [sym_keyword_contains_any] = ACTIONS(166),
    [sym_keyword_contains_none] = ACTIONS(166),
    [sym_keyword_inside] = ACTIONS(166),
    [sym_keyword_in] = ACTIONS(168),
    [sym_keyword_not_inside] = ACTIONS(166),
    [sym_keyword_all_inside] = ACTIONS(166),
    [sym_keyword_any_inside] = ACTIONS(166),
    [sym_keyword_none_inside] = ACTIONS(166),
    [sym_keyword_outside] = ACTIONS(166),
    [sym_keyword_intersects] = ACTIONS(166),
    [anon_sym_COMMA] = ACTIONS(166),
    [anon_sym_DASH_GT] = ACTIONS(166),
    [anon_sym_LBRACK] = ACTIONS(166),
    [anon_sym_RPAREN] = ACTIONS(166),
    [anon_sym_RBRACE] = ACTIONS(166),
    [anon_sym_LT_DASH] = ACTIONS(168),
    [anon_sym_LT_DASH_GT] = ACTIONS(166),
    [anon_sym_STAR] = ACTIONS(168),
    [anon_sym_DOT] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [anon_sym_GT] = ACTIONS(168),
    [anon_sym_EQ] = ACTIONS(168),
    [anon_sym_DASH] = ACTIONS(168),
    [anon_sym_AT] = ACTIONS(168),
    [anon_sym_LT_PIPE] = ACTIONS(166),
    [anon_sym_AMP_AMP] = ACTIONS(166),
    [anon_sym_PIPE_PIPE] = ACTIONS(166),
    [anon_sym_QMARK_QMARK] = ACTIONS(166),
    [anon_sym_QMARK_COLON] = ACTIONS(166),
    [anon_sym_BANG_EQ] = ACTIONS(166),
    [anon_sym_EQ_EQ] = ACTIONS(166),
    [anon_sym_QMARK_EQ] = ACTIONS(166),
    [anon_sym_STAR_EQ] = ACTIONS(166),
    [anon_sym_TILDE] = ACTIONS(166),
    [anon_sym_BANG_TILDE] = ACTIONS(166),
    [anon_sym_STAR_TILDE] = ACTIONS(166),
    [anon_sym_LT_EQ] = ACTIONS(166),
    [anon_sym_GT_EQ] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(168),
    [anon_sym_PLUS_EQ] = ACTIONS(166),
    [anon_sym_DASH_EQ] = ACTIONS(166),
    [anon_sym_u00d7] = ACTIONS(166),
    [anon_sym_SLASH] = ACTIONS(168),
    [anon_sym_u00f7] = ACTIONS(166),
    [anon_sym_STAR_STAR] = ACTIONS(166),
    [anon_sym_u220b] = ACTIONS(166),
    [anon_sym_u220c] = ACTIONS(166),
    [anon_sym_u2287] = ACTIONS(166),
    [anon_sym_u2283] = ACTIONS(166),
    [anon_sym_u2285] = ACTIONS(166),
    [anon_sym_u2208] = ACTIONS(166),
    [anon_sym_u2209] = ACTIONS(166),
    [anon_sym_u2286] = ACTIONS(166),
    [anon_sym_u2282] = ACTIONS(166),
    [anon_sym_u2284] = ACTIONS(166),
    [anon_sym_AT_AT] = ACTIONS(166),
  },
  [291] = {
    [ts_builtin_sym_end] = ACTIONS(182),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_explain] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_fetch] = ACTIONS(182),
    [sym_keyword_limit] = ACTIONS(182),
    [sym_keyword_rand] = ACTIONS(182),
    [sym_keyword_collate] = ACTIONS(182),
    [sym_keyword_numeric] = ACTIONS(182),
    [sym_keyword_asc] = ACTIONS(182),
    [sym_keyword_desc] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(536),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [292] = {
    [ts_builtin_sym_end] = ACTIONS(134),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(134),
    [sym_keyword_explain] = ACTIONS(134),
    [sym_keyword_parallel] = ACTIONS(134),
    [sym_keyword_timeout] = ACTIONS(134),
    [sym_keyword_fetch] = ACTIONS(134),
    [sym_keyword_limit] = ACTIONS(134),
    [sym_keyword_order] = ACTIONS(134),
    [sym_keyword_with] = ACTIONS(134),
    [sym_keyword_where] = ACTIONS(134),
    [sym_keyword_split] = ACTIONS(134),
    [sym_keyword_group] = ACTIONS(134),
    [sym_keyword_and] = ACTIONS(134),
    [sym_keyword_or] = ACTIONS(136),
    [sym_keyword_is] = ACTIONS(134),
    [sym_keyword_not] = ACTIONS(136),
    [sym_keyword_contains] = ACTIONS(134),
    [sym_keyword_contains_not] = ACTIONS(134),
    [sym_keyword_contains_all] = ACTIONS(134),
    [sym_keyword_contains_any] = ACTIONS(134),
    [sym_keyword_contains_none] = ACTIONS(134),
    [sym_keyword_inside] = ACTIONS(134),
    [sym_keyword_in] = ACTIONS(136),
    [sym_keyword_not_inside] = ACTIONS(134),
    [sym_keyword_all_inside] = ACTIONS(134),
    [sym_keyword_any_inside] = ACTIONS(134),
    [sym_keyword_none_inside] = ACTIONS(134),
    [sym_keyword_outside] = ACTIONS(134),
    [sym_keyword_intersects] = ACTIONS(134),
    [anon_sym_COMMA] = ACTIONS(134),
    [anon_sym_DASH_GT] = ACTIONS(134),
    [anon_sym_LBRACK] = ACTIONS(134),
    [anon_sym_LT_DASH] = ACTIONS(136),
    [anon_sym_LT_DASH_GT] = ACTIONS(134),
    [anon_sym_STAR] = ACTIONS(136),
    [anon_sym_DOT] = ACTIONS(136),
    [anon_sym_LT] = ACTIONS(136),
    [anon_sym_GT] = ACTIONS(136),
    [anon_sym_DOT_DOT] = ACTIONS(134),
    [anon_sym_EQ] = ACTIONS(136),
    [anon_sym_DASH] = ACTIONS(136),
    [anon_sym_AT] = ACTIONS(136),
    [anon_sym_LT_PIPE] = ACTIONS(134),
    [anon_sym_AMP_AMP] = ACTIONS(134),
    [anon_sym_PIPE_PIPE] = ACTIONS(134),
    [anon_sym_QMARK_QMARK] = ACTIONS(134),
    [anon_sym_QMARK_COLON] = ACTIONS(134),
    [anon_sym_BANG_EQ] = ACTIONS(134),
    [anon_sym_EQ_EQ] = ACTIONS(134),
    [anon_sym_QMARK_EQ] = ACTIONS(134),
    [anon_sym_STAR_EQ] = ACTIONS(134),
    [anon_sym_TILDE] = ACTIONS(134),
    [anon_sym_BANG_TILDE] = ACTIONS(134),
    [anon_sym_STAR_TILDE] = ACTIONS(134),
    [anon_sym_LT_EQ] = ACTIONS(134),
    [anon_sym_GT_EQ] = ACTIONS(134),
    [anon_sym_PLUS] = ACTIONS(136),
    [anon_sym_PLUS_EQ] = ACTIONS(134),
    [anon_sym_DASH_EQ] = ACTIONS(134),
    [anon_sym_u00d7] = ACTIONS(134),
    [anon_sym_SLASH] = ACTIONS(136),
    [anon_sym_u00f7] = ACTIONS(134),
    [anon_sym_STAR_STAR] = ACTIONS(134),
    [anon_sym_u220b] = ACTIONS(134),
    [anon_sym_u220c] = ACTIONS(134),
    [anon_sym_u2287] = ACTIONS(134),
    [anon_sym_u2283] = ACTIONS(134),
    [anon_sym_u2285] = ACTIONS(134),
    [anon_sym_u2208] = ACTIONS(134),
    [anon_sym_u2209] = ACTIONS(134),
    [anon_sym_u2286] = ACTIONS(134),
    [anon_sym_u2282] = ACTIONS(134),
    [anon_sym_u2284] = ACTIONS(134),
    [anon_sym_AT_AT] = ACTIONS(134),
  },
  [293] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(206),
    [sym_keyword_explain] = ACTIONS(206),
    [sym_keyword_parallel] = ACTIONS(206),
    [sym_keyword_timeout] = ACTIONS(206),
    [sym_keyword_fetch] = ACTIONS(206),
    [sym_keyword_limit] = ACTIONS(206),
    [sym_keyword_order] = ACTIONS(206),
    [sym_keyword_with] = ACTIONS(206),
    [sym_keyword_where] = ACTIONS(206),
    [sym_keyword_split] = ACTIONS(206),
    [sym_keyword_group] = ACTIONS(206),
    [sym_keyword_and] = ACTIONS(206),
    [sym_keyword_or] = ACTIONS(208),
    [sym_keyword_is] = ACTIONS(206),
    [sym_keyword_not] = ACTIONS(208),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(206),
    [sym_keyword_contains_all] = ACTIONS(206),
    [sym_keyword_contains_any] = ACTIONS(206),
    [sym_keyword_contains_none] = ACTIONS(206),
    [sym_keyword_inside] = ACTIONS(206),
    [sym_keyword_in] = ACTIONS(208),
    [sym_keyword_not_inside] = ACTIONS(206),
    [sym_keyword_all_inside] = ACTIONS(206),
    [sym_keyword_any_inside] = ACTIONS(206),
    [sym_keyword_none_inside] = ACTIONS(206),
    [sym_keyword_outside] = ACTIONS(206),
    [sym_keyword_intersects] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(206),
    [anon_sym_DASH_GT] = ACTIONS(206),
    [anon_sym_LBRACK] = ACTIONS(206),
    [anon_sym_RPAREN] = ACTIONS(206),
    [anon_sym_RBRACE] = ACTIONS(206),
    [anon_sym_LT_DASH] = ACTIONS(208),
    [anon_sym_LT_DASH_GT] = ACTIONS(206),
    [anon_sym_STAR] = ACTIONS(208),
    [anon_sym_DOT] = ACTIONS(206),
    [anon_sym_LT] = ACTIONS(208),
    [anon_sym_GT] = ACTIONS(208),
    [anon_sym_EQ] = ACTIONS(208),
    [anon_sym_DASH] = ACTIONS(208),
    [anon_sym_AT] = ACTIONS(208),
    [anon_sym_LT_PIPE] = ACTIONS(206),
    [anon_sym_AMP_AMP] = ACTIONS(206),
    [anon_sym_PIPE_PIPE] = ACTIONS(206),
    [anon_sym_QMARK_QMARK] = ACTIONS(206),
    [anon_sym_QMARK_COLON] = ACTIONS(206),
    [anon_sym_BANG_EQ] = ACTIONS(206),
    [anon_sym_EQ_EQ] = ACTIONS(206),
    [anon_sym_QMARK_EQ] = ACTIONS(206),
    [anon_sym_STAR_EQ] = ACTIONS(206),
    [anon_sym_TILDE] = ACTIONS(206),
    [anon_sym_BANG_TILDE] = ACTIONS(206),
    [anon_sym_STAR_TILDE] = ACTIONS(206),
    [anon_sym_LT_EQ] = ACTIONS(206),
    [anon_sym_GT_EQ] = ACTIONS(206),
    [anon_sym_PLUS] = ACTIONS(208),
    [anon_sym_PLUS_EQ] = ACTIONS(206),
    [anon_sym_DASH_EQ] = ACTIONS(206),
    [anon_sym_u00d7] = ACTIONS(206),
    [anon_sym_SLASH] = ACTIONS(208),
    [anon_sym_u00f7] = ACTIONS(206),
    [anon_sym_STAR_STAR] = ACTIONS(206),
    [anon_sym_u220b] = ACTIONS(206),
    [anon_sym_u220c] = ACTIONS(206),
    [anon_sym_u2287] = ACTIONS(206),
    [anon_sym_u2283] = ACTIONS(206),
    [anon_sym_u2285] = ACTIONS(206),
    [anon_sym_u2208] = ACTIONS(206),
    [anon_sym_u2209] = ACTIONS(206),
    [anon_sym_u2286] = ACTIONS(206),
    [anon_sym_u2282] = ACTIONS(206),
    [anon_sym_u2284] = ACTIONS(206),
    [anon_sym_AT_AT] = ACTIONS(206),
  },
  [294] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(202),
    [sym_keyword_explain] = ACTIONS(202),
    [sym_keyword_parallel] = ACTIONS(202),
    [sym_keyword_timeout] = ACTIONS(202),
    [sym_keyword_fetch] = ACTIONS(202),
    [sym_keyword_limit] = ACTIONS(202),
    [sym_keyword_order] = ACTIONS(202),
    [sym_keyword_with] = ACTIONS(202),
    [sym_keyword_where] = ACTIONS(202),
    [sym_keyword_split] = ACTIONS(202),
    [sym_keyword_group] = ACTIONS(202),
    [sym_keyword_and] = ACTIONS(202),
    [sym_keyword_or] = ACTIONS(204),
    [sym_keyword_is] = ACTIONS(202),
    [sym_keyword_not] = ACTIONS(204),
    [sym_keyword_contains] = ACTIONS(202),
    [sym_keyword_contains_not] = ACTIONS(202),
    [sym_keyword_contains_all] = ACTIONS(202),
    [sym_keyword_contains_any] = ACTIONS(202),
    [sym_keyword_contains_none] = ACTIONS(202),
    [sym_keyword_inside] = ACTIONS(202),
    [sym_keyword_in] = ACTIONS(204),
    [sym_keyword_not_inside] = ACTIONS(202),
    [sym_keyword_all_inside] = ACTIONS(202),
    [sym_keyword_any_inside] = ACTIONS(202),
    [sym_keyword_none_inside] = ACTIONS(202),
    [sym_keyword_outside] = ACTIONS(202),
    [sym_keyword_intersects] = ACTIONS(202),
    [anon_sym_COMMA] = ACTIONS(202),
    [anon_sym_DASH_GT] = ACTIONS(202),
    [anon_sym_LBRACK] = ACTIONS(202),
    [anon_sym_RPAREN] = ACTIONS(202),
    [anon_sym_RBRACE] = ACTIONS(202),
    [anon_sym_LT_DASH] = ACTIONS(204),
    [anon_sym_LT_DASH_GT] = ACTIONS(202),
    [anon_sym_STAR] = ACTIONS(204),
    [anon_sym_DOT] = ACTIONS(202),
    [anon_sym_LT] = ACTIONS(204),
    [anon_sym_GT] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(204),
    [anon_sym_DASH] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(204),
    [anon_sym_LT_PIPE] = ACTIONS(202),
    [anon_sym_AMP_AMP] = ACTIONS(202),
    [anon_sym_PIPE_PIPE] = ACTIONS(202),
    [anon_sym_QMARK_QMARK] = ACTIONS(202),
    [anon_sym_QMARK_COLON] = ACTIONS(202),
    [anon_sym_BANG_EQ] = ACTIONS(202),
    [anon_sym_EQ_EQ] = ACTIONS(202),
    [anon_sym_QMARK_EQ] = ACTIONS(202),
    [anon_sym_STAR_EQ] = ACTIONS(202),
    [anon_sym_TILDE] = ACTIONS(202),
    [anon_sym_BANG_TILDE] = ACTIONS(202),
    [anon_sym_STAR_TILDE] = ACTIONS(202),
    [anon_sym_LT_EQ] = ACTIONS(202),
    [anon_sym_GT_EQ] = ACTIONS(202),
    [anon_sym_PLUS] = ACTIONS(204),
    [anon_sym_PLUS_EQ] = ACTIONS(202),
    [anon_sym_DASH_EQ] = ACTIONS(202),
    [anon_sym_u00d7] = ACTIONS(202),
    [anon_sym_SLASH] = ACTIONS(204),
    [anon_sym_u00f7] = ACTIONS(202),
    [anon_sym_STAR_STAR] = ACTIONS(202),
    [anon_sym_u220b] = ACTIONS(202),
    [anon_sym_u220c] = ACTIONS(202),
    [anon_sym_u2287] = ACTIONS(202),
    [anon_sym_u2283] = ACTIONS(202),
    [anon_sym_u2285] = ACTIONS(202),
    [anon_sym_u2208] = ACTIONS(202),
    [anon_sym_u2209] = ACTIONS(202),
    [anon_sym_u2286] = ACTIONS(202),
    [anon_sym_u2282] = ACTIONS(202),
    [anon_sym_u2284] = ACTIONS(202),
    [anon_sym_AT_AT] = ACTIONS(202),
  },
  [295] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(146),
    [sym_keyword_explain] = ACTIONS(146),
    [sym_keyword_parallel] = ACTIONS(146),
    [sym_keyword_timeout] = ACTIONS(146),
    [sym_keyword_fetch] = ACTIONS(146),
    [sym_keyword_limit] = ACTIONS(146),
    [sym_keyword_order] = ACTIONS(146),
    [sym_keyword_with] = ACTIONS(146),
    [sym_keyword_where] = ACTIONS(146),
    [sym_keyword_split] = ACTIONS(146),
    [sym_keyword_group] = ACTIONS(146),
    [sym_keyword_and] = ACTIONS(146),
    [sym_keyword_or] = ACTIONS(148),
    [sym_keyword_is] = ACTIONS(146),
    [sym_keyword_not] = ACTIONS(148),
    [sym_keyword_contains] = ACTIONS(146),
    [sym_keyword_contains_not] = ACTIONS(146),
    [sym_keyword_contains_all] = ACTIONS(146),
    [sym_keyword_contains_any] = ACTIONS(146),
    [sym_keyword_contains_none] = ACTIONS(146),
    [sym_keyword_inside] = ACTIONS(146),
    [sym_keyword_in] = ACTIONS(148),
    [sym_keyword_not_inside] = ACTIONS(146),
    [sym_keyword_all_inside] = ACTIONS(146),
    [sym_keyword_any_inside] = ACTIONS(146),
    [sym_keyword_none_inside] = ACTIONS(146),
    [sym_keyword_outside] = ACTIONS(146),
    [sym_keyword_intersects] = ACTIONS(146),
    [anon_sym_COMMA] = ACTIONS(146),
    [anon_sym_DASH_GT] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(146),
    [anon_sym_RPAREN] = ACTIONS(146),
    [anon_sym_RBRACE] = ACTIONS(146),
    [anon_sym_LT_DASH] = ACTIONS(148),
    [anon_sym_LT_DASH_GT] = ACTIONS(146),
    [anon_sym_STAR] = ACTIONS(148),
    [anon_sym_DOT] = ACTIONS(146),
    [anon_sym_LT] = ACTIONS(148),
    [anon_sym_GT] = ACTIONS(148),
    [anon_sym_EQ] = ACTIONS(148),
    [anon_sym_DASH] = ACTIONS(148),
    [anon_sym_AT] = ACTIONS(148),
    [anon_sym_LT_PIPE] = ACTIONS(146),
    [anon_sym_AMP_AMP] = ACTIONS(146),
    [anon_sym_PIPE_PIPE] = ACTIONS(146),
    [anon_sym_QMARK_QMARK] = ACTIONS(146),
    [anon_sym_QMARK_COLON] = ACTIONS(146),
    [anon_sym_BANG_EQ] = ACTIONS(146),
    [anon_sym_EQ_EQ] = ACTIONS(146),
    [anon_sym_QMARK_EQ] = ACTIONS(146),
    [anon_sym_STAR_EQ] = ACTIONS(146),
    [anon_sym_TILDE] = ACTIONS(146),
    [anon_sym_BANG_TILDE] = ACTIONS(146),
    [anon_sym_STAR_TILDE] = ACTIONS(146),
    [anon_sym_LT_EQ] = ACTIONS(146),
    [anon_sym_GT_EQ] = ACTIONS(146),
    [anon_sym_PLUS] = ACTIONS(148),
    [anon_sym_PLUS_EQ] = ACTIONS(146),
    [anon_sym_DASH_EQ] = ACTIONS(146),
    [anon_sym_u00d7] = ACTIONS(146),
    [anon_sym_SLASH] = ACTIONS(148),
    [anon_sym_u00f7] = ACTIONS(146),
    [anon_sym_STAR_STAR] = ACTIONS(146),
    [anon_sym_u220b] = ACTIONS(146),
    [anon_sym_u220c] = ACTIONS(146),
    [anon_sym_u2287] = ACTIONS(146),
    [anon_sym_u2283] = ACTIONS(146),
    [anon_sym_u2285] = ACTIONS(146),
    [anon_sym_u2208] = ACTIONS(146),
    [anon_sym_u2209] = ACTIONS(146),
    [anon_sym_u2286] = ACTIONS(146),
    [anon_sym_u2282] = ACTIONS(146),
    [anon_sym_u2284] = ACTIONS(146),
    [anon_sym_AT_AT] = ACTIONS(146),
  },
  [296] = {
    [ts_builtin_sym_end] = ACTIONS(182),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_explain] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_fetch] = ACTIONS(182),
    [sym_keyword_limit] = ACTIONS(182),
    [sym_keyword_order] = ACTIONS(182),
    [sym_keyword_with] = ACTIONS(182),
    [sym_keyword_where] = ACTIONS(182),
    [sym_keyword_split] = ACTIONS(182),
    [sym_keyword_group] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(184),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(538),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [297] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(194),
    [sym_keyword_explain] = ACTIONS(194),
    [sym_keyword_parallel] = ACTIONS(194),
    [sym_keyword_timeout] = ACTIONS(194),
    [sym_keyword_fetch] = ACTIONS(194),
    [sym_keyword_limit] = ACTIONS(194),
    [sym_keyword_order] = ACTIONS(194),
    [sym_keyword_with] = ACTIONS(194),
    [sym_keyword_where] = ACTIONS(194),
    [sym_keyword_split] = ACTIONS(194),
    [sym_keyword_group] = ACTIONS(194),
    [sym_keyword_and] = ACTIONS(194),
    [sym_keyword_or] = ACTIONS(196),
    [sym_keyword_is] = ACTIONS(194),
    [sym_keyword_not] = ACTIONS(196),
    [sym_keyword_contains] = ACTIONS(194),
    [sym_keyword_contains_not] = ACTIONS(194),
    [sym_keyword_contains_all] = ACTIONS(194),
    [sym_keyword_contains_any] = ACTIONS(194),
    [sym_keyword_contains_none] = ACTIONS(194),
    [sym_keyword_inside] = ACTIONS(194),
    [sym_keyword_in] = ACTIONS(196),
    [sym_keyword_not_inside] = ACTIONS(194),
    [sym_keyword_all_inside] = ACTIONS(194),
    [sym_keyword_any_inside] = ACTIONS(194),
    [sym_keyword_none_inside] = ACTIONS(194),
    [sym_keyword_outside] = ACTIONS(194),
    [sym_keyword_intersects] = ACTIONS(194),
    [anon_sym_COMMA] = ACTIONS(194),
    [anon_sym_DASH_GT] = ACTIONS(194),
    [anon_sym_LBRACK] = ACTIONS(194),
    [anon_sym_RPAREN] = ACTIONS(194),
    [anon_sym_RBRACE] = ACTIONS(194),
    [anon_sym_LT_DASH] = ACTIONS(196),
    [anon_sym_LT_DASH_GT] = ACTIONS(194),
    [anon_sym_STAR] = ACTIONS(196),
    [anon_sym_DOT] = ACTIONS(194),
    [anon_sym_LT] = ACTIONS(196),
    [anon_sym_GT] = ACTIONS(196),
    [anon_sym_EQ] = ACTIONS(196),
    [anon_sym_DASH] = ACTIONS(196),
    [anon_sym_AT] = ACTIONS(196),
    [anon_sym_LT_PIPE] = ACTIONS(194),
    [anon_sym_AMP_AMP] = ACTIONS(194),
    [anon_sym_PIPE_PIPE] = ACTIONS(194),
    [anon_sym_QMARK_QMARK] = ACTIONS(194),
    [anon_sym_QMARK_COLON] = ACTIONS(194),
    [anon_sym_BANG_EQ] = ACTIONS(194),
    [anon_sym_EQ_EQ] = ACTIONS(194),
    [anon_sym_QMARK_EQ] = ACTIONS(194),
    [anon_sym_STAR_EQ] = ACTIONS(194),
    [anon_sym_TILDE] = ACTIONS(194),
    [anon_sym_BANG_TILDE] = ACTIONS(194),
    [anon_sym_STAR_TILDE] = ACTIONS(194),
    [anon_sym_LT_EQ] = ACTIONS(194),
    [anon_sym_GT_EQ] = ACTIONS(194),
    [anon_sym_PLUS] = ACTIONS(196),
    [anon_sym_PLUS_EQ] = ACTIONS(194),
    [anon_sym_DASH_EQ] = ACTIONS(194),
    [anon_sym_u00d7] = ACTIONS(194),
    [anon_sym_SLASH] = ACTIONS(196),
    [anon_sym_u00f7] = ACTIONS(194),
    [anon_sym_STAR_STAR] = ACTIONS(194),
    [anon_sym_u220b] = ACTIONS(194),
    [anon_sym_u220c] = ACTIONS(194),
    [anon_sym_u2287] = ACTIONS(194),
    [anon_sym_u2283] = ACTIONS(194),
    [anon_sym_u2285] = ACTIONS(194),
    [anon_sym_u2208] = ACTIONS(194),
    [anon_sym_u2209] = ACTIONS(194),
    [anon_sym_u2286] = ACTIONS(194),
    [anon_sym_u2282] = ACTIONS(194),
    [anon_sym_u2284] = ACTIONS(194),
    [anon_sym_AT_AT] = ACTIONS(194),
  },
  [298] = {
    [ts_builtin_sym_end] = ACTIONS(126),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(126),
    [sym_keyword_explain] = ACTIONS(126),
    [sym_keyword_parallel] = ACTIONS(126),
    [sym_keyword_timeout] = ACTIONS(126),
    [sym_keyword_fetch] = ACTIONS(126),
    [sym_keyword_limit] = ACTIONS(126),
    [sym_keyword_order] = ACTIONS(126),
    [sym_keyword_with] = ACTIONS(126),
    [sym_keyword_where] = ACTIONS(126),
    [sym_keyword_split] = ACTIONS(126),
    [sym_keyword_group] = ACTIONS(126),
    [sym_keyword_and] = ACTIONS(126),
    [sym_keyword_or] = ACTIONS(128),
    [sym_keyword_is] = ACTIONS(126),
    [sym_keyword_not] = ACTIONS(128),
    [sym_keyword_contains] = ACTIONS(126),
    [sym_keyword_contains_not] = ACTIONS(126),
    [sym_keyword_contains_all] = ACTIONS(126),
    [sym_keyword_contains_any] = ACTIONS(126),
    [sym_keyword_contains_none] = ACTIONS(126),
    [sym_keyword_inside] = ACTIONS(126),
    [sym_keyword_in] = ACTIONS(128),
    [sym_keyword_not_inside] = ACTIONS(126),
    [sym_keyword_all_inside] = ACTIONS(126),
    [sym_keyword_any_inside] = ACTIONS(126),
    [sym_keyword_none_inside] = ACTIONS(126),
    [sym_keyword_outside] = ACTIONS(126),
    [sym_keyword_intersects] = ACTIONS(126),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_DASH_GT] = ACTIONS(126),
    [anon_sym_LBRACK] = ACTIONS(126),
    [anon_sym_LT_DASH] = ACTIONS(128),
    [anon_sym_LT_DASH_GT] = ACTIONS(126),
    [anon_sym_STAR] = ACTIONS(128),
    [anon_sym_DOT] = ACTIONS(128),
    [anon_sym_LT] = ACTIONS(128),
    [anon_sym_GT] = ACTIONS(128),
    [anon_sym_DOT_DOT] = ACTIONS(126),
    [anon_sym_EQ] = ACTIONS(128),
    [anon_sym_DASH] = ACTIONS(128),
    [anon_sym_AT] = ACTIONS(128),
    [anon_sym_LT_PIPE] = ACTIONS(126),
    [anon_sym_AMP_AMP] = ACTIONS(126),
    [anon_sym_PIPE_PIPE] = ACTIONS(126),
    [anon_sym_QMARK_QMARK] = ACTIONS(126),
    [anon_sym_QMARK_COLON] = ACTIONS(126),
    [anon_sym_BANG_EQ] = ACTIONS(126),
    [anon_sym_EQ_EQ] = ACTIONS(126),
    [anon_sym_QMARK_EQ] = ACTIONS(126),
    [anon_sym_STAR_EQ] = ACTIONS(126),
    [anon_sym_TILDE] = ACTIONS(126),
    [anon_sym_BANG_TILDE] = ACTIONS(126),
    [anon_sym_STAR_TILDE] = ACTIONS(126),
    [anon_sym_LT_EQ] = ACTIONS(126),
    [anon_sym_GT_EQ] = ACTIONS(126),
    [anon_sym_PLUS] = ACTIONS(128),
    [anon_sym_PLUS_EQ] = ACTIONS(126),
    [anon_sym_DASH_EQ] = ACTIONS(126),
    [anon_sym_u00d7] = ACTIONS(126),
    [anon_sym_SLASH] = ACTIONS(128),
    [anon_sym_u00f7] = ACTIONS(126),
    [anon_sym_STAR_STAR] = ACTIONS(126),
    [anon_sym_u220b] = ACTIONS(126),
    [anon_sym_u220c] = ACTIONS(126),
    [anon_sym_u2287] = ACTIONS(126),
    [anon_sym_u2283] = ACTIONS(126),
    [anon_sym_u2285] = ACTIONS(126),
    [anon_sym_u2208] = ACTIONS(126),
    [anon_sym_u2209] = ACTIONS(126),
    [anon_sym_u2286] = ACTIONS(126),
    [anon_sym_u2282] = ACTIONS(126),
    [anon_sym_u2284] = ACTIONS(126),
    [anon_sym_AT_AT] = ACTIONS(126),
  },
  [299] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(95),
    [sym_keyword_explain] = ACTIONS(95),
    [sym_keyword_parallel] = ACTIONS(95),
    [sym_keyword_timeout] = ACTIONS(95),
    [sym_keyword_fetch] = ACTIONS(95),
    [sym_keyword_limit] = ACTIONS(95),
    [sym_keyword_order] = ACTIONS(95),
    [sym_keyword_with] = ACTIONS(95),
    [sym_keyword_where] = ACTIONS(95),
    [sym_keyword_split] = ACTIONS(95),
    [sym_keyword_group] = ACTIONS(95),
    [sym_keyword_and] = ACTIONS(95),
    [sym_keyword_or] = ACTIONS(97),
    [sym_keyword_is] = ACTIONS(95),
    [sym_keyword_not] = ACTIONS(97),
    [sym_keyword_contains] = ACTIONS(95),
    [sym_keyword_contains_not] = ACTIONS(95),
    [sym_keyword_contains_all] = ACTIONS(95),
    [sym_keyword_contains_any] = ACTIONS(95),
    [sym_keyword_contains_none] = ACTIONS(95),
    [sym_keyword_inside] = ACTIONS(95),
    [sym_keyword_in] = ACTIONS(97),
    [sym_keyword_not_inside] = ACTIONS(95),
    [sym_keyword_all_inside] = ACTIONS(95),
    [sym_keyword_any_inside] = ACTIONS(95),
    [sym_keyword_none_inside] = ACTIONS(95),
    [sym_keyword_outside] = ACTIONS(95),
    [sym_keyword_intersects] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(95),
    [anon_sym_DASH_GT] = ACTIONS(95),
    [anon_sym_LBRACK] = ACTIONS(95),
    [anon_sym_RPAREN] = ACTIONS(95),
    [anon_sym_RBRACE] = ACTIONS(95),
    [anon_sym_LT_DASH] = ACTIONS(97),
    [anon_sym_LT_DASH_GT] = ACTIONS(95),
    [anon_sym_STAR] = ACTIONS(97),
    [anon_sym_DOT] = ACTIONS(95),
    [anon_sym_LT] = ACTIONS(97),
    [anon_sym_GT] = ACTIONS(97),
    [anon_sym_EQ] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_LT_PIPE] = ACTIONS(95),
    [anon_sym_AMP_AMP] = ACTIONS(95),
    [anon_sym_PIPE_PIPE] = ACTIONS(95),
    [anon_sym_QMARK_QMARK] = ACTIONS(95),
    [anon_sym_QMARK_COLON] = ACTIONS(95),
    [anon_sym_BANG_EQ] = ACTIONS(95),
    [anon_sym_EQ_EQ] = ACTIONS(95),
    [anon_sym_QMARK_EQ] = ACTIONS(95),
    [anon_sym_STAR_EQ] = ACTIONS(95),
    [anon_sym_TILDE] = ACTIONS(95),
    [anon_sym_BANG_TILDE] = ACTIONS(95),
    [anon_sym_STAR_TILDE] = ACTIONS(95),
    [anon_sym_LT_EQ] = ACTIONS(95),
    [anon_sym_GT_EQ] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_PLUS_EQ] = ACTIONS(95),
    [anon_sym_DASH_EQ] = ACTIONS(95),
    [anon_sym_u00d7] = ACTIONS(95),
    [anon_sym_SLASH] = ACTIONS(97),
    [anon_sym_u00f7] = ACTIONS(95),
    [anon_sym_STAR_STAR] = ACTIONS(95),
    [anon_sym_u220b] = ACTIONS(95),
    [anon_sym_u220c] = ACTIONS(95),
    [anon_sym_u2287] = ACTIONS(95),
    [anon_sym_u2283] = ACTIONS(95),
    [anon_sym_u2285] = ACTIONS(95),
    [anon_sym_u2208] = ACTIONS(95),
    [anon_sym_u2209] = ACTIONS(95),
    [anon_sym_u2286] = ACTIONS(95),
    [anon_sym_u2282] = ACTIONS(95),
    [anon_sym_u2284] = ACTIONS(95),
    [anon_sym_AT_AT] = ACTIONS(95),
  },
  [300] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(154),
    [sym_keyword_explain] = ACTIONS(154),
    [sym_keyword_parallel] = ACTIONS(154),
    [sym_keyword_timeout] = ACTIONS(154),
    [sym_keyword_fetch] = ACTIONS(154),
    [sym_keyword_limit] = ACTIONS(154),
    [sym_keyword_order] = ACTIONS(154),
    [sym_keyword_with] = ACTIONS(154),
    [sym_keyword_where] = ACTIONS(154),
    [sym_keyword_split] = ACTIONS(154),
    [sym_keyword_group] = ACTIONS(154),
    [sym_keyword_and] = ACTIONS(154),
    [sym_keyword_or] = ACTIONS(156),
    [sym_keyword_is] = ACTIONS(154),
    [sym_keyword_not] = ACTIONS(156),
    [sym_keyword_contains] = ACTIONS(154),
    [sym_keyword_contains_not] = ACTIONS(154),
    [sym_keyword_contains_all] = ACTIONS(154),
    [sym_keyword_contains_any] = ACTIONS(154),
    [sym_keyword_contains_none] = ACTIONS(154),
    [sym_keyword_inside] = ACTIONS(154),
    [sym_keyword_in] = ACTIONS(156),
    [sym_keyword_not_inside] = ACTIONS(154),
    [sym_keyword_all_inside] = ACTIONS(154),
    [sym_keyword_any_inside] = ACTIONS(154),
    [sym_keyword_none_inside] = ACTIONS(154),
    [sym_keyword_outside] = ACTIONS(154),
    [sym_keyword_intersects] = ACTIONS(154),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_DASH_GT] = ACTIONS(154),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_LT_DASH] = ACTIONS(156),
    [anon_sym_LT_DASH_GT] = ACTIONS(154),
    [anon_sym_STAR] = ACTIONS(156),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_LT] = ACTIONS(156),
    [anon_sym_GT] = ACTIONS(156),
    [anon_sym_EQ] = ACTIONS(156),
    [anon_sym_DASH] = ACTIONS(156),
    [anon_sym_AT] = ACTIONS(156),
    [anon_sym_LT_PIPE] = ACTIONS(154),
    [anon_sym_AMP_AMP] = ACTIONS(154),
    [anon_sym_PIPE_PIPE] = ACTIONS(154),
    [anon_sym_QMARK_QMARK] = ACTIONS(154),
    [anon_sym_QMARK_COLON] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(154),
    [anon_sym_QMARK_EQ] = ACTIONS(154),
    [anon_sym_STAR_EQ] = ACTIONS(154),
    [anon_sym_TILDE] = ACTIONS(154),
    [anon_sym_BANG_TILDE] = ACTIONS(154),
    [anon_sym_STAR_TILDE] = ACTIONS(154),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_PLUS] = ACTIONS(156),
    [anon_sym_PLUS_EQ] = ACTIONS(154),
    [anon_sym_DASH_EQ] = ACTIONS(154),
    [anon_sym_u00d7] = ACTIONS(154),
    [anon_sym_SLASH] = ACTIONS(156),
    [anon_sym_u00f7] = ACTIONS(154),
    [anon_sym_STAR_STAR] = ACTIONS(154),
    [anon_sym_u220b] = ACTIONS(154),
    [anon_sym_u220c] = ACTIONS(154),
    [anon_sym_u2287] = ACTIONS(154),
    [anon_sym_u2283] = ACTIONS(154),
    [anon_sym_u2285] = ACTIONS(154),
    [anon_sym_u2208] = ACTIONS(154),
    [anon_sym_u2209] = ACTIONS(154),
    [anon_sym_u2286] = ACTIONS(154),
    [anon_sym_u2282] = ACTIONS(154),
    [anon_sym_u2284] = ACTIONS(154),
    [anon_sym_AT_AT] = ACTIONS(154),
  },
  [301] = {
    [ts_builtin_sym_end] = ACTIONS(95),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(95),
    [sym_keyword_explain] = ACTIONS(95),
    [sym_keyword_parallel] = ACTIONS(95),
    [sym_keyword_timeout] = ACTIONS(95),
    [sym_keyword_fetch] = ACTIONS(95),
    [sym_keyword_limit] = ACTIONS(95),
    [sym_keyword_order] = ACTIONS(95),
    [sym_keyword_with] = ACTIONS(95),
    [sym_keyword_where] = ACTIONS(95),
    [sym_keyword_split] = ACTIONS(95),
    [sym_keyword_group] = ACTIONS(95),
    [sym_keyword_and] = ACTIONS(95),
    [sym_keyword_or] = ACTIONS(97),
    [sym_keyword_is] = ACTIONS(95),
    [sym_keyword_not] = ACTIONS(97),
    [sym_keyword_contains] = ACTIONS(95),
    [sym_keyword_contains_not] = ACTIONS(95),
    [sym_keyword_contains_all] = ACTIONS(95),
    [sym_keyword_contains_any] = ACTIONS(95),
    [sym_keyword_contains_none] = ACTIONS(95),
    [sym_keyword_inside] = ACTIONS(95),
    [sym_keyword_in] = ACTIONS(97),
    [sym_keyword_not_inside] = ACTIONS(95),
    [sym_keyword_all_inside] = ACTIONS(95),
    [sym_keyword_any_inside] = ACTIONS(95),
    [sym_keyword_none_inside] = ACTIONS(95),
    [sym_keyword_outside] = ACTIONS(95),
    [sym_keyword_intersects] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(95),
    [anon_sym_DASH_GT] = ACTIONS(95),
    [anon_sym_LBRACK] = ACTIONS(95),
    [anon_sym_LT_DASH] = ACTIONS(97),
    [anon_sym_LT_DASH_GT] = ACTIONS(95),
    [anon_sym_STAR] = ACTIONS(97),
    [anon_sym_DOT] = ACTIONS(95),
    [anon_sym_LT] = ACTIONS(97),
    [anon_sym_GT] = ACTIONS(97),
    [anon_sym_EQ] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_LT_PIPE] = ACTIONS(95),
    [anon_sym_AMP_AMP] = ACTIONS(95),
    [anon_sym_PIPE_PIPE] = ACTIONS(95),
    [anon_sym_QMARK_QMARK] = ACTIONS(95),
    [anon_sym_QMARK_COLON] = ACTIONS(95),
    [anon_sym_BANG_EQ] = ACTIONS(95),
    [anon_sym_EQ_EQ] = ACTIONS(95),
    [anon_sym_QMARK_EQ] = ACTIONS(95),
    [anon_sym_STAR_EQ] = ACTIONS(95),
    [anon_sym_TILDE] = ACTIONS(95),
    [anon_sym_BANG_TILDE] = ACTIONS(95),
    [anon_sym_STAR_TILDE] = ACTIONS(95),
    [anon_sym_LT_EQ] = ACTIONS(95),
    [anon_sym_GT_EQ] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_PLUS_EQ] = ACTIONS(95),
    [anon_sym_DASH_EQ] = ACTIONS(95),
    [anon_sym_u00d7] = ACTIONS(95),
    [anon_sym_SLASH] = ACTIONS(97),
    [anon_sym_u00f7] = ACTIONS(95),
    [anon_sym_STAR_STAR] = ACTIONS(95),
    [anon_sym_u220b] = ACTIONS(95),
    [anon_sym_u220c] = ACTIONS(95),
    [anon_sym_u2287] = ACTIONS(95),
    [anon_sym_u2283] = ACTIONS(95),
    [anon_sym_u2285] = ACTIONS(95),
    [anon_sym_u2208] = ACTIONS(95),
    [anon_sym_u2209] = ACTIONS(95),
    [anon_sym_u2286] = ACTIONS(95),
    [anon_sym_u2282] = ACTIONS(95),
    [anon_sym_u2284] = ACTIONS(95),
    [anon_sym_AT_AT] = ACTIONS(95),
  },
  [302] = {
    [sym_expression] = STATE(1567),
    [sym_statement] = STATE(1384),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(591),
    [sym_function_call] = STATE(99),
    [sym_base_value] = STATE(168),
    [sym_binary_expression] = STATE(99),
    [sym_path] = STATE(99),
    [sym_graph_path] = STATE(162),
    [sym_number] = STATE(58),
    [sym_identifier] = STATE(58),
    [sym_array] = STATE(58),
    [sym_object] = STATE(58),
    [sym_object_key] = STATE(1827),
    [sym_record_id] = STATE(58),
    [sym_sub_query] = STATE(58),
    [sym_duration] = STATE(58),
    [sym_point] = STATE(58),
    [aux_sym_duration_repeat1] = STATE(52),
    [ts_builtin_sym_end] = ACTIONS(540),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(5),
    [sym_keyword_rand] = ACTIONS(7),
    [sym_keyword_true] = ACTIONS(11),
    [sym_keyword_false] = ACTIONS(11),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(11),
    [sym_keyword_null] = ACTIONS(11),
    [sym_keyword_define] = ACTIONS(19),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(23),
    [sym_keyword_delete] = ACTIONS(25),
    [sym_keyword_update] = ACTIONS(27),
    [sym_keyword_insert] = ACTIONS(29),
    [sym_keyword_relate] = ACTIONS(31),
    [sym_keyword_count] = ACTIONS(33),
    [anon_sym_DASH_GT] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(43),
    [anon_sym_LT_DASH_GT] = ACTIONS(35),
    [aux_sym_type_name_token1] = ACTIONS(45),
    [sym_string] = ACTIONS(47),
    [sym_prefixed_string] = ACTIONS(47),
    [sym_int] = ACTIONS(49),
    [sym_float] = ACTIONS(49),
    [sym_decimal] = ACTIONS(51),
    [sym_variable_name] = ACTIONS(47),
    [sym_custom_function_name] = ACTIONS(7),
    [sym_function_name] = ACTIONS(7),
    [sym_duration_part] = ACTIONS(53),
  },
  [303] = {
    [ts_builtin_sym_end] = ACTIONS(166),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(166),
    [sym_keyword_explain] = ACTIONS(166),
    [sym_keyword_parallel] = ACTIONS(166),
    [sym_keyword_timeout] = ACTIONS(166),
    [sym_keyword_fetch] = ACTIONS(166),
    [sym_keyword_limit] = ACTIONS(166),
    [sym_keyword_order] = ACTIONS(166),
    [sym_keyword_with] = ACTIONS(166),
    [sym_keyword_where] = ACTIONS(166),
    [sym_keyword_split] = ACTIONS(166),
    [sym_keyword_group] = ACTIONS(166),
    [sym_keyword_and] = ACTIONS(166),
    [sym_keyword_or] = ACTIONS(168),
    [sym_keyword_is] = ACTIONS(166),
    [sym_keyword_not] = ACTIONS(168),
    [sym_keyword_contains] = ACTIONS(166),
    [sym_keyword_contains_not] = ACTIONS(166),
    [sym_keyword_contains_all] = ACTIONS(166),
    [sym_keyword_contains_any] = ACTIONS(166),
    [sym_keyword_contains_none] = ACTIONS(166),
    [sym_keyword_inside] = ACTIONS(166),
    [sym_keyword_in] = ACTIONS(168),
    [sym_keyword_not_inside] = ACTIONS(166),
    [sym_keyword_all_inside] = ACTIONS(166),
    [sym_keyword_any_inside] = ACTIONS(166),
    [sym_keyword_none_inside] = ACTIONS(166),
    [sym_keyword_outside] = ACTIONS(166),
    [sym_keyword_intersects] = ACTIONS(166),
    [anon_sym_COMMA] = ACTIONS(166),
    [anon_sym_DASH_GT] = ACTIONS(166),
    [anon_sym_LBRACK] = ACTIONS(166),
    [anon_sym_LT_DASH] = ACTIONS(168),
    [anon_sym_LT_DASH_GT] = ACTIONS(166),
    [anon_sym_STAR] = ACTIONS(168),
    [anon_sym_DOT] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [anon_sym_GT] = ACTIONS(168),
    [anon_sym_EQ] = ACTIONS(168),
    [anon_sym_DASH] = ACTIONS(168),
    [anon_sym_AT] = ACTIONS(168),
    [anon_sym_LT_PIPE] = ACTIONS(166),
    [anon_sym_AMP_AMP] = ACTIONS(166),
    [anon_sym_PIPE_PIPE] = ACTIONS(166),
    [anon_sym_QMARK_QMARK] = ACTIONS(166),
    [anon_sym_QMARK_COLON] = ACTIONS(166),
    [anon_sym_BANG_EQ] = ACTIONS(166),
    [anon_sym_EQ_EQ] = ACTIONS(166),
    [anon_sym_QMARK_EQ] = ACTIONS(166),
    [anon_sym_STAR_EQ] = ACTIONS(166),
    [anon_sym_TILDE] = ACTIONS(166),
    [anon_sym_BANG_TILDE] = ACTIONS(166),
    [anon_sym_STAR_TILDE] = ACTIONS(166),
    [anon_sym_LT_EQ] = ACTIONS(166),
    [anon_sym_GT_EQ] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(168),
    [anon_sym_PLUS_EQ] = ACTIONS(166),
    [anon_sym_DASH_EQ] = ACTIONS(166),
    [anon_sym_u00d7] = ACTIONS(166),
    [anon_sym_SLASH] = ACTIONS(168),
    [anon_sym_u00f7] = ACTIONS(166),
    [anon_sym_STAR_STAR] = ACTIONS(166),
    [anon_sym_u220b] = ACTIONS(166),
    [anon_sym_u220c] = ACTIONS(166),
    [anon_sym_u2287] = ACTIONS(166),
    [anon_sym_u2283] = ACTIONS(166),
    [anon_sym_u2285] = ACTIONS(166),
    [anon_sym_u2208] = ACTIONS(166),
    [anon_sym_u2209] = ACTIONS(166),
    [anon_sym_u2286] = ACTIONS(166),
    [anon_sym_u2282] = ACTIONS(166),
    [anon_sym_u2284] = ACTIONS(166),
    [anon_sym_AT_AT] = ACTIONS(166),
  },
  [304] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(45),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_return] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_RPAREN] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [305] = {
    [ts_builtin_sym_end] = ACTIONS(182),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_explain] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_fetch] = ACTIONS(182),
    [sym_keyword_limit] = ACTIONS(182),
    [sym_keyword_order] = ACTIONS(182),
    [sym_keyword_with] = ACTIONS(182),
    [sym_keyword_where] = ACTIONS(182),
    [sym_keyword_split] = ACTIONS(182),
    [sym_keyword_group] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(184),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(182),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [306] = {
    [sym_where_clause] = STATE(881),
    [sym_group_clause] = STATE(957),
    [sym_operator] = STATE(672),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(852),
    [ts_builtin_sym_end] = ACTIONS(490),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(490),
    [sym_keyword_as] = ACTIONS(490),
    [sym_keyword_where] = ACTIONS(542),
    [sym_keyword_group] = ACTIONS(494),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_drop] = ACTIONS(490),
    [sym_keyword_schemafull] = ACTIONS(490),
    [sym_keyword_schemaless] = ACTIONS(490),
    [sym_keyword_changefeed] = ACTIONS(490),
    [sym_keyword_type] = ACTIONS(490),
    [sym_keyword_permissions] = ACTIONS(490),
    [sym_keyword_comment] = ACTIONS(490),
    [anon_sym_COMMA] = ACTIONS(544),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [307] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(36),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_return] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [308] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(33),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_return] = ACTIONS(180),
    [sym_keyword_parallel] = ACTIONS(180),
    [sym_keyword_timeout] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [309] = {
    [ts_builtin_sym_end] = ACTIONS(194),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(194),
    [sym_keyword_explain] = ACTIONS(194),
    [sym_keyword_parallel] = ACTIONS(194),
    [sym_keyword_timeout] = ACTIONS(194),
    [sym_keyword_fetch] = ACTIONS(194),
    [sym_keyword_limit] = ACTIONS(194),
    [sym_keyword_order] = ACTIONS(194),
    [sym_keyword_with] = ACTIONS(194),
    [sym_keyword_where] = ACTIONS(194),
    [sym_keyword_split] = ACTIONS(194),
    [sym_keyword_group] = ACTIONS(194),
    [sym_keyword_and] = ACTIONS(194),
    [sym_keyword_or] = ACTIONS(196),
    [sym_keyword_is] = ACTIONS(194),
    [sym_keyword_not] = ACTIONS(196),
    [sym_keyword_contains] = ACTIONS(194),
    [sym_keyword_contains_not] = ACTIONS(194),
    [sym_keyword_contains_all] = ACTIONS(194),
    [sym_keyword_contains_any] = ACTIONS(194),
    [sym_keyword_contains_none] = ACTIONS(194),
    [sym_keyword_inside] = ACTIONS(194),
    [sym_keyword_in] = ACTIONS(196),
    [sym_keyword_not_inside] = ACTIONS(194),
    [sym_keyword_all_inside] = ACTIONS(194),
    [sym_keyword_any_inside] = ACTIONS(194),
    [sym_keyword_none_inside] = ACTIONS(194),
    [sym_keyword_outside] = ACTIONS(194),
    [sym_keyword_intersects] = ACTIONS(194),
    [anon_sym_COMMA] = ACTIONS(194),
    [anon_sym_DASH_GT] = ACTIONS(194),
    [anon_sym_LBRACK] = ACTIONS(194),
    [anon_sym_LT_DASH] = ACTIONS(196),
    [anon_sym_LT_DASH_GT] = ACTIONS(194),
    [anon_sym_STAR] = ACTIONS(196),
    [anon_sym_DOT] = ACTIONS(194),
    [anon_sym_LT] = ACTIONS(196),
    [anon_sym_GT] = ACTIONS(196),
    [anon_sym_EQ] = ACTIONS(196),
    [anon_sym_DASH] = ACTIONS(196),
    [anon_sym_AT] = ACTIONS(196),
    [anon_sym_LT_PIPE] = ACTIONS(194),
    [anon_sym_AMP_AMP] = ACTIONS(194),
    [anon_sym_PIPE_PIPE] = ACTIONS(194),
    [anon_sym_QMARK_QMARK] = ACTIONS(194),
    [anon_sym_QMARK_COLON] = ACTIONS(194),
    [anon_sym_BANG_EQ] = ACTIONS(194),
    [anon_sym_EQ_EQ] = ACTIONS(194),
    [anon_sym_QMARK_EQ] = ACTIONS(194),
    [anon_sym_STAR_EQ] = ACTIONS(194),
    [anon_sym_TILDE] = ACTIONS(194),
    [anon_sym_BANG_TILDE] = ACTIONS(194),
    [anon_sym_STAR_TILDE] = ACTIONS(194),
    [anon_sym_LT_EQ] = ACTIONS(194),
    [anon_sym_GT_EQ] = ACTIONS(194),
    [anon_sym_PLUS] = ACTIONS(196),
    [anon_sym_PLUS_EQ] = ACTIONS(194),
    [anon_sym_DASH_EQ] = ACTIONS(194),
    [anon_sym_u00d7] = ACTIONS(194),
    [anon_sym_SLASH] = ACTIONS(196),
    [anon_sym_u00f7] = ACTIONS(194),
    [anon_sym_STAR_STAR] = ACTIONS(194),
    [anon_sym_u220b] = ACTIONS(194),
    [anon_sym_u220c] = ACTIONS(194),
    [anon_sym_u2287] = ACTIONS(194),
    [anon_sym_u2283] = ACTIONS(194),
    [anon_sym_u2285] = ACTIONS(194),
    [anon_sym_u2208] = ACTIONS(194),
    [anon_sym_u2209] = ACTIONS(194),
    [anon_sym_u2286] = ACTIONS(194),
    [anon_sym_u2282] = ACTIONS(194),
    [anon_sym_u2284] = ACTIONS(194),
    [anon_sym_AT_AT] = ACTIONS(194),
  },
  [310] = {
    [ts_builtin_sym_end] = ACTIONS(202),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(202),
    [sym_keyword_explain] = ACTIONS(202),
    [sym_keyword_parallel] = ACTIONS(202),
    [sym_keyword_timeout] = ACTIONS(202),
    [sym_keyword_fetch] = ACTIONS(202),
    [sym_keyword_limit] = ACTIONS(202),
    [sym_keyword_order] = ACTIONS(202),
    [sym_keyword_with] = ACTIONS(202),
    [sym_keyword_where] = ACTIONS(202),
    [sym_keyword_split] = ACTIONS(202),
    [sym_keyword_group] = ACTIONS(202),
    [sym_keyword_and] = ACTIONS(202),
    [sym_keyword_or] = ACTIONS(204),
    [sym_keyword_is] = ACTIONS(202),
    [sym_keyword_not] = ACTIONS(204),
    [sym_keyword_contains] = ACTIONS(202),
    [sym_keyword_contains_not] = ACTIONS(202),
    [sym_keyword_contains_all] = ACTIONS(202),
    [sym_keyword_contains_any] = ACTIONS(202),
    [sym_keyword_contains_none] = ACTIONS(202),
    [sym_keyword_inside] = ACTIONS(202),
    [sym_keyword_in] = ACTIONS(204),
    [sym_keyword_not_inside] = ACTIONS(202),
    [sym_keyword_all_inside] = ACTIONS(202),
    [sym_keyword_any_inside] = ACTIONS(202),
    [sym_keyword_none_inside] = ACTIONS(202),
    [sym_keyword_outside] = ACTIONS(202),
    [sym_keyword_intersects] = ACTIONS(202),
    [anon_sym_COMMA] = ACTIONS(202),
    [anon_sym_DASH_GT] = ACTIONS(202),
    [anon_sym_LBRACK] = ACTIONS(202),
    [anon_sym_LT_DASH] = ACTIONS(204),
    [anon_sym_LT_DASH_GT] = ACTIONS(202),
    [anon_sym_STAR] = ACTIONS(204),
    [anon_sym_DOT] = ACTIONS(202),
    [anon_sym_LT] = ACTIONS(204),
    [anon_sym_GT] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(204),
    [anon_sym_DASH] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(204),
    [anon_sym_LT_PIPE] = ACTIONS(202),
    [anon_sym_AMP_AMP] = ACTIONS(202),
    [anon_sym_PIPE_PIPE] = ACTIONS(202),
    [anon_sym_QMARK_QMARK] = ACTIONS(202),
    [anon_sym_QMARK_COLON] = ACTIONS(202),
    [anon_sym_BANG_EQ] = ACTIONS(202),
    [anon_sym_EQ_EQ] = ACTIONS(202),
    [anon_sym_QMARK_EQ] = ACTIONS(202),
    [anon_sym_STAR_EQ] = ACTIONS(202),
    [anon_sym_TILDE] = ACTIONS(202),
    [anon_sym_BANG_TILDE] = ACTIONS(202),
    [anon_sym_STAR_TILDE] = ACTIONS(202),
    [anon_sym_LT_EQ] = ACTIONS(202),
    [anon_sym_GT_EQ] = ACTIONS(202),
    [anon_sym_PLUS] = ACTIONS(204),
    [anon_sym_PLUS_EQ] = ACTIONS(202),
    [anon_sym_DASH_EQ] = ACTIONS(202),
    [anon_sym_u00d7] = ACTIONS(202),
    [anon_sym_SLASH] = ACTIONS(204),
    [anon_sym_u00f7] = ACTIONS(202),
    [anon_sym_STAR_STAR] = ACTIONS(202),
    [anon_sym_u220b] = ACTIONS(202),
    [anon_sym_u220c] = ACTIONS(202),
    [anon_sym_u2287] = ACTIONS(202),
    [anon_sym_u2283] = ACTIONS(202),
    [anon_sym_u2285] = ACTIONS(202),
    [anon_sym_u2208] = ACTIONS(202),
    [anon_sym_u2209] = ACTIONS(202),
    [anon_sym_u2286] = ACTIONS(202),
    [anon_sym_u2282] = ACTIONS(202),
    [anon_sym_u2284] = ACTIONS(202),
    [anon_sym_AT_AT] = ACTIONS(202),
  },
  [311] = {
    [ts_builtin_sym_end] = ACTIONS(142),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(142),
    [sym_keyword_explain] = ACTIONS(142),
    [sym_keyword_parallel] = ACTIONS(142),
    [sym_keyword_timeout] = ACTIONS(142),
    [sym_keyword_fetch] = ACTIONS(142),
    [sym_keyword_limit] = ACTIONS(142),
    [sym_keyword_order] = ACTIONS(142),
    [sym_keyword_with] = ACTIONS(142),
    [sym_keyword_where] = ACTIONS(142),
    [sym_keyword_split] = ACTIONS(142),
    [sym_keyword_group] = ACTIONS(142),
    [sym_keyword_and] = ACTIONS(142),
    [sym_keyword_or] = ACTIONS(144),
    [sym_keyword_is] = ACTIONS(142),
    [sym_keyword_not] = ACTIONS(144),
    [sym_keyword_contains] = ACTIONS(142),
    [sym_keyword_contains_not] = ACTIONS(142),
    [sym_keyword_contains_all] = ACTIONS(142),
    [sym_keyword_contains_any] = ACTIONS(142),
    [sym_keyword_contains_none] = ACTIONS(142),
    [sym_keyword_inside] = ACTIONS(142),
    [sym_keyword_in] = ACTIONS(144),
    [sym_keyword_not_inside] = ACTIONS(142),
    [sym_keyword_all_inside] = ACTIONS(142),
    [sym_keyword_any_inside] = ACTIONS(142),
    [sym_keyword_none_inside] = ACTIONS(142),
    [sym_keyword_outside] = ACTIONS(142),
    [sym_keyword_intersects] = ACTIONS(142),
    [anon_sym_COMMA] = ACTIONS(142),
    [anon_sym_DASH_GT] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(142),
    [anon_sym_LT_DASH] = ACTIONS(144),
    [anon_sym_LT_DASH_GT] = ACTIONS(142),
    [anon_sym_STAR] = ACTIONS(144),
    [anon_sym_DOT] = ACTIONS(142),
    [anon_sym_LT] = ACTIONS(144),
    [anon_sym_GT] = ACTIONS(144),
    [anon_sym_EQ] = ACTIONS(144),
    [anon_sym_DASH] = ACTIONS(144),
    [anon_sym_AT] = ACTIONS(144),
    [anon_sym_LT_PIPE] = ACTIONS(142),
    [anon_sym_AMP_AMP] = ACTIONS(142),
    [anon_sym_PIPE_PIPE] = ACTIONS(142),
    [anon_sym_QMARK_QMARK] = ACTIONS(142),
    [anon_sym_QMARK_COLON] = ACTIONS(142),
    [anon_sym_BANG_EQ] = ACTIONS(142),
    [anon_sym_EQ_EQ] = ACTIONS(142),
    [anon_sym_QMARK_EQ] = ACTIONS(142),
    [anon_sym_STAR_EQ] = ACTIONS(142),
    [anon_sym_TILDE] = ACTIONS(142),
    [anon_sym_BANG_TILDE] = ACTIONS(142),
    [anon_sym_STAR_TILDE] = ACTIONS(142),
    [anon_sym_LT_EQ] = ACTIONS(142),
    [anon_sym_GT_EQ] = ACTIONS(142),
    [anon_sym_PLUS] = ACTIONS(144),
    [anon_sym_PLUS_EQ] = ACTIONS(142),
    [anon_sym_DASH_EQ] = ACTIONS(142),
    [anon_sym_u00d7] = ACTIONS(142),
    [anon_sym_SLASH] = ACTIONS(144),
    [anon_sym_u00f7] = ACTIONS(142),
    [anon_sym_STAR_STAR] = ACTIONS(142),
    [anon_sym_u220b] = ACTIONS(142),
    [anon_sym_u220c] = ACTIONS(142),
    [anon_sym_u2287] = ACTIONS(142),
    [anon_sym_u2283] = ACTIONS(142),
    [anon_sym_u2285] = ACTIONS(142),
    [anon_sym_u2208] = ACTIONS(142),
    [anon_sym_u2209] = ACTIONS(142),
    [anon_sym_u2286] = ACTIONS(142),
    [anon_sym_u2282] = ACTIONS(142),
    [anon_sym_u2284] = ACTIONS(142),
    [anon_sym_AT_AT] = ACTIONS(142),
  },
  [312] = {
    [ts_builtin_sym_end] = ACTIONS(210),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_explain] = ACTIONS(210),
    [sym_keyword_parallel] = ACTIONS(210),
    [sym_keyword_timeout] = ACTIONS(210),
    [sym_keyword_fetch] = ACTIONS(210),
    [sym_keyword_limit] = ACTIONS(210),
    [sym_keyword_order] = ACTIONS(210),
    [sym_keyword_with] = ACTIONS(210),
    [sym_keyword_where] = ACTIONS(210),
    [sym_keyword_split] = ACTIONS(210),
    [sym_keyword_group] = ACTIONS(210),
    [sym_keyword_and] = ACTIONS(210),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(210),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(210),
    [sym_keyword_contains_not] = ACTIONS(210),
    [sym_keyword_contains_all] = ACTIONS(210),
    [sym_keyword_contains_any] = ACTIONS(210),
    [sym_keyword_contains_none] = ACTIONS(210),
    [sym_keyword_inside] = ACTIONS(210),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(210),
    [sym_keyword_all_inside] = ACTIONS(210),
    [sym_keyword_any_inside] = ACTIONS(210),
    [sym_keyword_none_inside] = ACTIONS(210),
    [sym_keyword_outside] = ACTIONS(210),
    [sym_keyword_intersects] = ACTIONS(210),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [313] = {
    [ts_builtin_sym_end] = ACTIONS(190),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(190),
    [sym_keyword_explain] = ACTIONS(190),
    [sym_keyword_parallel] = ACTIONS(190),
    [sym_keyword_timeout] = ACTIONS(190),
    [sym_keyword_fetch] = ACTIONS(190),
    [sym_keyword_limit] = ACTIONS(190),
    [sym_keyword_order] = ACTIONS(190),
    [sym_keyword_with] = ACTIONS(190),
    [sym_keyword_where] = ACTIONS(190),
    [sym_keyword_split] = ACTIONS(190),
    [sym_keyword_group] = ACTIONS(190),
    [sym_keyword_and] = ACTIONS(190),
    [sym_keyword_or] = ACTIONS(192),
    [sym_keyword_is] = ACTIONS(190),
    [sym_keyword_not] = ACTIONS(192),
    [sym_keyword_contains] = ACTIONS(190),
    [sym_keyword_contains_not] = ACTIONS(190),
    [sym_keyword_contains_all] = ACTIONS(190),
    [sym_keyword_contains_any] = ACTIONS(190),
    [sym_keyword_contains_none] = ACTIONS(190),
    [sym_keyword_inside] = ACTIONS(190),
    [sym_keyword_in] = ACTIONS(192),
    [sym_keyword_not_inside] = ACTIONS(190),
    [sym_keyword_all_inside] = ACTIONS(190),
    [sym_keyword_any_inside] = ACTIONS(190),
    [sym_keyword_none_inside] = ACTIONS(190),
    [sym_keyword_outside] = ACTIONS(190),
    [sym_keyword_intersects] = ACTIONS(190),
    [anon_sym_COMMA] = ACTIONS(190),
    [anon_sym_DASH_GT] = ACTIONS(190),
    [anon_sym_LBRACK] = ACTIONS(190),
    [anon_sym_LT_DASH] = ACTIONS(192),
    [anon_sym_LT_DASH_GT] = ACTIONS(190),
    [anon_sym_STAR] = ACTIONS(192),
    [anon_sym_DOT] = ACTIONS(190),
    [anon_sym_LT] = ACTIONS(192),
    [anon_sym_GT] = ACTIONS(192),
    [anon_sym_EQ] = ACTIONS(192),
    [anon_sym_DASH] = ACTIONS(192),
    [anon_sym_AT] = ACTIONS(192),
    [anon_sym_LT_PIPE] = ACTIONS(190),
    [anon_sym_AMP_AMP] = ACTIONS(190),
    [anon_sym_PIPE_PIPE] = ACTIONS(190),
    [anon_sym_QMARK_QMARK] = ACTIONS(190),
    [anon_sym_QMARK_COLON] = ACTIONS(190),
    [anon_sym_BANG_EQ] = ACTIONS(190),
    [anon_sym_EQ_EQ] = ACTIONS(190),
    [anon_sym_QMARK_EQ] = ACTIONS(190),
    [anon_sym_STAR_EQ] = ACTIONS(190),
    [anon_sym_TILDE] = ACTIONS(190),
    [anon_sym_BANG_TILDE] = ACTIONS(190),
    [anon_sym_STAR_TILDE] = ACTIONS(190),
    [anon_sym_LT_EQ] = ACTIONS(190),
    [anon_sym_GT_EQ] = ACTIONS(190),
    [anon_sym_PLUS] = ACTIONS(192),
    [anon_sym_PLUS_EQ] = ACTIONS(190),
    [anon_sym_DASH_EQ] = ACTIONS(190),
    [anon_sym_u00d7] = ACTIONS(190),
    [anon_sym_SLASH] = ACTIONS(192),
    [anon_sym_u00f7] = ACTIONS(190),
    [anon_sym_STAR_STAR] = ACTIONS(190),
    [anon_sym_u220b] = ACTIONS(190),
    [anon_sym_u220c] = ACTIONS(190),
    [anon_sym_u2287] = ACTIONS(190),
    [anon_sym_u2283] = ACTIONS(190),
    [anon_sym_u2285] = ACTIONS(190),
    [anon_sym_u2208] = ACTIONS(190),
    [anon_sym_u2209] = ACTIONS(190),
    [anon_sym_u2286] = ACTIONS(190),
    [anon_sym_u2282] = ACTIONS(190),
    [anon_sym_u2284] = ACTIONS(190),
    [anon_sym_AT_AT] = ACTIONS(190),
  },
  [314] = {
    [ts_builtin_sym_end] = ACTIONS(138),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(138),
    [sym_keyword_explain] = ACTIONS(138),
    [sym_keyword_parallel] = ACTIONS(138),
    [sym_keyword_timeout] = ACTIONS(138),
    [sym_keyword_fetch] = ACTIONS(138),
    [sym_keyword_limit] = ACTIONS(138),
    [sym_keyword_order] = ACTIONS(138),
    [sym_keyword_with] = ACTIONS(138),
    [sym_keyword_where] = ACTIONS(138),
    [sym_keyword_split] = ACTIONS(138),
    [sym_keyword_group] = ACTIONS(138),
    [sym_keyword_and] = ACTIONS(138),
    [sym_keyword_or] = ACTIONS(140),
    [sym_keyword_is] = ACTIONS(138),
    [sym_keyword_not] = ACTIONS(140),
    [sym_keyword_contains] = ACTIONS(138),
    [sym_keyword_contains_not] = ACTIONS(138),
    [sym_keyword_contains_all] = ACTIONS(138),
    [sym_keyword_contains_any] = ACTIONS(138),
    [sym_keyword_contains_none] = ACTIONS(138),
    [sym_keyword_inside] = ACTIONS(138),
    [sym_keyword_in] = ACTIONS(140),
    [sym_keyword_not_inside] = ACTIONS(138),
    [sym_keyword_all_inside] = ACTIONS(138),
    [sym_keyword_any_inside] = ACTIONS(138),
    [sym_keyword_none_inside] = ACTIONS(138),
    [sym_keyword_outside] = ACTIONS(138),
    [sym_keyword_intersects] = ACTIONS(138),
    [anon_sym_COMMA] = ACTIONS(138),
    [anon_sym_DASH_GT] = ACTIONS(138),
    [anon_sym_LBRACK] = ACTIONS(138),
    [anon_sym_LT_DASH] = ACTIONS(140),
    [anon_sym_LT_DASH_GT] = ACTIONS(138),
    [anon_sym_STAR] = ACTIONS(140),
    [anon_sym_DOT] = ACTIONS(138),
    [anon_sym_LT] = ACTIONS(140),
    [anon_sym_GT] = ACTIONS(140),
    [anon_sym_EQ] = ACTIONS(140),
    [anon_sym_DASH] = ACTIONS(140),
    [anon_sym_AT] = ACTIONS(140),
    [anon_sym_LT_PIPE] = ACTIONS(138),
    [anon_sym_AMP_AMP] = ACTIONS(138),
    [anon_sym_PIPE_PIPE] = ACTIONS(138),
    [anon_sym_QMARK_QMARK] = ACTIONS(138),
    [anon_sym_QMARK_COLON] = ACTIONS(138),
    [anon_sym_BANG_EQ] = ACTIONS(138),
    [anon_sym_EQ_EQ] = ACTIONS(138),
    [anon_sym_QMARK_EQ] = ACTIONS(138),
    [anon_sym_STAR_EQ] = ACTIONS(138),
    [anon_sym_TILDE] = ACTIONS(138),
    [anon_sym_BANG_TILDE] = ACTIONS(138),
    [anon_sym_STAR_TILDE] = ACTIONS(138),
    [anon_sym_LT_EQ] = ACTIONS(138),
    [anon_sym_GT_EQ] = ACTIONS(138),
    [anon_sym_PLUS] = ACTIONS(140),
    [anon_sym_PLUS_EQ] = ACTIONS(138),
    [anon_sym_DASH_EQ] = ACTIONS(138),
    [anon_sym_u00d7] = ACTIONS(138),
    [anon_sym_SLASH] = ACTIONS(140),
    [anon_sym_u00f7] = ACTIONS(138),
    [anon_sym_STAR_STAR] = ACTIONS(138),
    [anon_sym_u220b] = ACTIONS(138),
    [anon_sym_u220c] = ACTIONS(138),
    [anon_sym_u2287] = ACTIONS(138),
    [anon_sym_u2283] = ACTIONS(138),
    [anon_sym_u2285] = ACTIONS(138),
    [anon_sym_u2208] = ACTIONS(138),
    [anon_sym_u2209] = ACTIONS(138),
    [anon_sym_u2286] = ACTIONS(138),
    [anon_sym_u2282] = ACTIONS(138),
    [anon_sym_u2284] = ACTIONS(138),
    [anon_sym_AT_AT] = ACTIONS(138),
  },
  [315] = {
    [ts_builtin_sym_end] = ACTIONS(198),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(198),
    [sym_keyword_explain] = ACTIONS(198),
    [sym_keyword_parallel] = ACTIONS(198),
    [sym_keyword_timeout] = ACTIONS(198),
    [sym_keyword_fetch] = ACTIONS(198),
    [sym_keyword_limit] = ACTIONS(198),
    [sym_keyword_order] = ACTIONS(198),
    [sym_keyword_with] = ACTIONS(198),
    [sym_keyword_where] = ACTIONS(198),
    [sym_keyword_split] = ACTIONS(198),
    [sym_keyword_group] = ACTIONS(198),
    [sym_keyword_and] = ACTIONS(198),
    [sym_keyword_or] = ACTIONS(200),
    [sym_keyword_is] = ACTIONS(198),
    [sym_keyword_not] = ACTIONS(200),
    [sym_keyword_contains] = ACTIONS(198),
    [sym_keyword_contains_not] = ACTIONS(198),
    [sym_keyword_contains_all] = ACTIONS(198),
    [sym_keyword_contains_any] = ACTIONS(198),
    [sym_keyword_contains_none] = ACTIONS(198),
    [sym_keyword_inside] = ACTIONS(198),
    [sym_keyword_in] = ACTIONS(200),
    [sym_keyword_not_inside] = ACTIONS(198),
    [sym_keyword_all_inside] = ACTIONS(198),
    [sym_keyword_any_inside] = ACTIONS(198),
    [sym_keyword_none_inside] = ACTIONS(198),
    [sym_keyword_outside] = ACTIONS(198),
    [sym_keyword_intersects] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(198),
    [anon_sym_DASH_GT] = ACTIONS(198),
    [anon_sym_LBRACK] = ACTIONS(198),
    [anon_sym_LT_DASH] = ACTIONS(200),
    [anon_sym_LT_DASH_GT] = ACTIONS(198),
    [anon_sym_STAR] = ACTIONS(200),
    [anon_sym_DOT] = ACTIONS(198),
    [anon_sym_LT] = ACTIONS(200),
    [anon_sym_GT] = ACTIONS(200),
    [anon_sym_EQ] = ACTIONS(200),
    [anon_sym_DASH] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(200),
    [anon_sym_LT_PIPE] = ACTIONS(198),
    [anon_sym_AMP_AMP] = ACTIONS(198),
    [anon_sym_PIPE_PIPE] = ACTIONS(198),
    [anon_sym_QMARK_QMARK] = ACTIONS(198),
    [anon_sym_QMARK_COLON] = ACTIONS(198),
    [anon_sym_BANG_EQ] = ACTIONS(198),
    [anon_sym_EQ_EQ] = ACTIONS(198),
    [anon_sym_QMARK_EQ] = ACTIONS(198),
    [anon_sym_STAR_EQ] = ACTIONS(198),
    [anon_sym_TILDE] = ACTIONS(198),
    [anon_sym_BANG_TILDE] = ACTIONS(198),
    [anon_sym_STAR_TILDE] = ACTIONS(198),
    [anon_sym_LT_EQ] = ACTIONS(198),
    [anon_sym_GT_EQ] = ACTIONS(198),
    [anon_sym_PLUS] = ACTIONS(200),
    [anon_sym_PLUS_EQ] = ACTIONS(198),
    [anon_sym_DASH_EQ] = ACTIONS(198),
    [anon_sym_u00d7] = ACTIONS(198),
    [anon_sym_SLASH] = ACTIONS(200),
    [anon_sym_u00f7] = ACTIONS(198),
    [anon_sym_STAR_STAR] = ACTIONS(198),
    [anon_sym_u220b] = ACTIONS(198),
    [anon_sym_u220c] = ACTIONS(198),
    [anon_sym_u2287] = ACTIONS(198),
    [anon_sym_u2283] = ACTIONS(198),
    [anon_sym_u2285] = ACTIONS(198),
    [anon_sym_u2208] = ACTIONS(198),
    [anon_sym_u2209] = ACTIONS(198),
    [anon_sym_u2286] = ACTIONS(198),
    [anon_sym_u2282] = ACTIONS(198),
    [anon_sym_u2284] = ACTIONS(198),
    [anon_sym_AT_AT] = ACTIONS(198),
  },
  [316] = {
    [ts_builtin_sym_end] = ACTIONS(186),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(186),
    [sym_keyword_explain] = ACTIONS(186),
    [sym_keyword_parallel] = ACTIONS(186),
    [sym_keyword_timeout] = ACTIONS(186),
    [sym_keyword_fetch] = ACTIONS(186),
    [sym_keyword_limit] = ACTIONS(186),
    [sym_keyword_order] = ACTIONS(186),
    [sym_keyword_with] = ACTIONS(186),
    [sym_keyword_where] = ACTIONS(186),
    [sym_keyword_split] = ACTIONS(186),
    [sym_keyword_group] = ACTIONS(186),
    [sym_keyword_and] = ACTIONS(186),
    [sym_keyword_or] = ACTIONS(188),
    [sym_keyword_is] = ACTIONS(186),
    [sym_keyword_not] = ACTIONS(188),
    [sym_keyword_contains] = ACTIONS(186),
    [sym_keyword_contains_not] = ACTIONS(186),
    [sym_keyword_contains_all] = ACTIONS(186),
    [sym_keyword_contains_any] = ACTIONS(186),
    [sym_keyword_contains_none] = ACTIONS(186),
    [sym_keyword_inside] = ACTIONS(186),
    [sym_keyword_in] = ACTIONS(188),
    [sym_keyword_not_inside] = ACTIONS(186),
    [sym_keyword_all_inside] = ACTIONS(186),
    [sym_keyword_any_inside] = ACTIONS(186),
    [sym_keyword_none_inside] = ACTIONS(186),
    [sym_keyword_outside] = ACTIONS(186),
    [sym_keyword_intersects] = ACTIONS(186),
    [anon_sym_COMMA] = ACTIONS(186),
    [anon_sym_DASH_GT] = ACTIONS(186),
    [anon_sym_LBRACK] = ACTIONS(186),
    [anon_sym_LT_DASH] = ACTIONS(188),
    [anon_sym_LT_DASH_GT] = ACTIONS(186),
    [anon_sym_STAR] = ACTIONS(188),
    [anon_sym_DOT] = ACTIONS(186),
    [anon_sym_LT] = ACTIONS(188),
    [anon_sym_GT] = ACTIONS(188),
    [anon_sym_EQ] = ACTIONS(188),
    [anon_sym_DASH] = ACTIONS(188),
    [anon_sym_AT] = ACTIONS(188),
    [anon_sym_LT_PIPE] = ACTIONS(186),
    [anon_sym_AMP_AMP] = ACTIONS(186),
    [anon_sym_PIPE_PIPE] = ACTIONS(186),
    [anon_sym_QMARK_QMARK] = ACTIONS(186),
    [anon_sym_QMARK_COLON] = ACTIONS(186),
    [anon_sym_BANG_EQ] = ACTIONS(186),
    [anon_sym_EQ_EQ] = ACTIONS(186),
    [anon_sym_QMARK_EQ] = ACTIONS(186),
    [anon_sym_STAR_EQ] = ACTIONS(186),
    [anon_sym_TILDE] = ACTIONS(186),
    [anon_sym_BANG_TILDE] = ACTIONS(186),
    [anon_sym_STAR_TILDE] = ACTIONS(186),
    [anon_sym_LT_EQ] = ACTIONS(186),
    [anon_sym_GT_EQ] = ACTIONS(186),
    [anon_sym_PLUS] = ACTIONS(188),
    [anon_sym_PLUS_EQ] = ACTIONS(186),
    [anon_sym_DASH_EQ] = ACTIONS(186),
    [anon_sym_u00d7] = ACTIONS(186),
    [anon_sym_SLASH] = ACTIONS(188),
    [anon_sym_u00f7] = ACTIONS(186),
    [anon_sym_STAR_STAR] = ACTIONS(186),
    [anon_sym_u220b] = ACTIONS(186),
    [anon_sym_u220c] = ACTIONS(186),
    [anon_sym_u2287] = ACTIONS(186),
    [anon_sym_u2283] = ACTIONS(186),
    [anon_sym_u2285] = ACTIONS(186),
    [anon_sym_u2208] = ACTIONS(186),
    [anon_sym_u2209] = ACTIONS(186),
    [anon_sym_u2286] = ACTIONS(186),
    [anon_sym_u2282] = ACTIONS(186),
    [anon_sym_u2284] = ACTIONS(186),
    [anon_sym_AT_AT] = ACTIONS(186),
  },
  [317] = {
    [ts_builtin_sym_end] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_explain] = ACTIONS(178),
    [sym_keyword_parallel] = ACTIONS(178),
    [sym_keyword_timeout] = ACTIONS(178),
    [sym_keyword_fetch] = ACTIONS(178),
    [sym_keyword_limit] = ACTIONS(178),
    [sym_keyword_order] = ACTIONS(178),
    [sym_keyword_with] = ACTIONS(178),
    [sym_keyword_where] = ACTIONS(178),
    [sym_keyword_split] = ACTIONS(178),
    [sym_keyword_group] = ACTIONS(178),
    [sym_keyword_and] = ACTIONS(178),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(178),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(178),
    [sym_keyword_contains_not] = ACTIONS(178),
    [sym_keyword_contains_all] = ACTIONS(178),
    [sym_keyword_contains_any] = ACTIONS(178),
    [sym_keyword_contains_none] = ACTIONS(178),
    [sym_keyword_inside] = ACTIONS(178),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(178),
    [sym_keyword_all_inside] = ACTIONS(178),
    [sym_keyword_any_inside] = ACTIONS(178),
    [sym_keyword_none_inside] = ACTIONS(178),
    [sym_keyword_outside] = ACTIONS(178),
    [sym_keyword_intersects] = ACTIONS(178),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [318] = {
    [ts_builtin_sym_end] = ACTIONS(174),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(174),
    [sym_keyword_explain] = ACTIONS(174),
    [sym_keyword_parallel] = ACTIONS(174),
    [sym_keyword_timeout] = ACTIONS(174),
    [sym_keyword_fetch] = ACTIONS(174),
    [sym_keyword_limit] = ACTIONS(174),
    [sym_keyword_order] = ACTIONS(174),
    [sym_keyword_with] = ACTIONS(174),
    [sym_keyword_where] = ACTIONS(174),
    [sym_keyword_split] = ACTIONS(174),
    [sym_keyword_group] = ACTIONS(174),
    [sym_keyword_and] = ACTIONS(174),
    [sym_keyword_or] = ACTIONS(176),
    [sym_keyword_is] = ACTIONS(174),
    [sym_keyword_not] = ACTIONS(176),
    [sym_keyword_contains] = ACTIONS(174),
    [sym_keyword_contains_not] = ACTIONS(174),
    [sym_keyword_contains_all] = ACTIONS(174),
    [sym_keyword_contains_any] = ACTIONS(174),
    [sym_keyword_contains_none] = ACTIONS(174),
    [sym_keyword_inside] = ACTIONS(174),
    [sym_keyword_in] = ACTIONS(176),
    [sym_keyword_not_inside] = ACTIONS(174),
    [sym_keyword_all_inside] = ACTIONS(174),
    [sym_keyword_any_inside] = ACTIONS(174),
    [sym_keyword_none_inside] = ACTIONS(174),
    [sym_keyword_outside] = ACTIONS(174),
    [sym_keyword_intersects] = ACTIONS(174),
    [anon_sym_COMMA] = ACTIONS(174),
    [anon_sym_DASH_GT] = ACTIONS(174),
    [anon_sym_LBRACK] = ACTIONS(174),
    [anon_sym_LT_DASH] = ACTIONS(176),
    [anon_sym_LT_DASH_GT] = ACTIONS(174),
    [anon_sym_STAR] = ACTIONS(176),
    [anon_sym_DOT] = ACTIONS(174),
    [anon_sym_LT] = ACTIONS(176),
    [anon_sym_GT] = ACTIONS(176),
    [anon_sym_EQ] = ACTIONS(176),
    [anon_sym_DASH] = ACTIONS(176),
    [anon_sym_AT] = ACTIONS(176),
    [anon_sym_LT_PIPE] = ACTIONS(174),
    [anon_sym_AMP_AMP] = ACTIONS(174),
    [anon_sym_PIPE_PIPE] = ACTIONS(174),
    [anon_sym_QMARK_QMARK] = ACTIONS(174),
    [anon_sym_QMARK_COLON] = ACTIONS(174),
    [anon_sym_BANG_EQ] = ACTIONS(174),
    [anon_sym_EQ_EQ] = ACTIONS(174),
    [anon_sym_QMARK_EQ] = ACTIONS(174),
    [anon_sym_STAR_EQ] = ACTIONS(174),
    [anon_sym_TILDE] = ACTIONS(174),
    [anon_sym_BANG_TILDE] = ACTIONS(174),
    [anon_sym_STAR_TILDE] = ACTIONS(174),
    [anon_sym_LT_EQ] = ACTIONS(174),
    [anon_sym_GT_EQ] = ACTIONS(174),
    [anon_sym_PLUS] = ACTIONS(176),
    [anon_sym_PLUS_EQ] = ACTIONS(174),
    [anon_sym_DASH_EQ] = ACTIONS(174),
    [anon_sym_u00d7] = ACTIONS(174),
    [anon_sym_SLASH] = ACTIONS(176),
    [anon_sym_u00f7] = ACTIONS(174),
    [anon_sym_STAR_STAR] = ACTIONS(174),
    [anon_sym_u220b] = ACTIONS(174),
    [anon_sym_u220c] = ACTIONS(174),
    [anon_sym_u2287] = ACTIONS(174),
    [anon_sym_u2283] = ACTIONS(174),
    [anon_sym_u2285] = ACTIONS(174),
    [anon_sym_u2208] = ACTIONS(174),
    [anon_sym_u2209] = ACTIONS(174),
    [anon_sym_u2286] = ACTIONS(174),
    [anon_sym_u2282] = ACTIONS(174),
    [anon_sym_u2284] = ACTIONS(174),
    [anon_sym_AT_AT] = ACTIONS(174),
  },
  [319] = {
    [sym_expression] = STATE(1567),
    [sym_statement] = STATE(1384),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(576),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1780),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(540),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(532),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [320] = {
    [ts_builtin_sym_end] = ACTIONS(170),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(170),
    [sym_keyword_explain] = ACTIONS(170),
    [sym_keyword_parallel] = ACTIONS(170),
    [sym_keyword_timeout] = ACTIONS(170),
    [sym_keyword_fetch] = ACTIONS(170),
    [sym_keyword_limit] = ACTIONS(170),
    [sym_keyword_order] = ACTIONS(170),
    [sym_keyword_with] = ACTIONS(170),
    [sym_keyword_where] = ACTIONS(170),
    [sym_keyword_split] = ACTIONS(170),
    [sym_keyword_group] = ACTIONS(170),
    [sym_keyword_and] = ACTIONS(170),
    [sym_keyword_or] = ACTIONS(172),
    [sym_keyword_is] = ACTIONS(170),
    [sym_keyword_not] = ACTIONS(172),
    [sym_keyword_contains] = ACTIONS(170),
    [sym_keyword_contains_not] = ACTIONS(170),
    [sym_keyword_contains_all] = ACTIONS(170),
    [sym_keyword_contains_any] = ACTIONS(170),
    [sym_keyword_contains_none] = ACTIONS(170),
    [sym_keyword_inside] = ACTIONS(170),
    [sym_keyword_in] = ACTIONS(172),
    [sym_keyword_not_inside] = ACTIONS(170),
    [sym_keyword_all_inside] = ACTIONS(170),
    [sym_keyword_any_inside] = ACTIONS(170),
    [sym_keyword_none_inside] = ACTIONS(170),
    [sym_keyword_outside] = ACTIONS(170),
    [sym_keyword_intersects] = ACTIONS(170),
    [anon_sym_COMMA] = ACTIONS(170),
    [anon_sym_DASH_GT] = ACTIONS(170),
    [anon_sym_LBRACK] = ACTIONS(170),
    [anon_sym_LT_DASH] = ACTIONS(172),
    [anon_sym_LT_DASH_GT] = ACTIONS(170),
    [anon_sym_STAR] = ACTIONS(172),
    [anon_sym_DOT] = ACTIONS(170),
    [anon_sym_LT] = ACTIONS(172),
    [anon_sym_GT] = ACTIONS(172),
    [anon_sym_EQ] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [anon_sym_AT] = ACTIONS(172),
    [anon_sym_LT_PIPE] = ACTIONS(170),
    [anon_sym_AMP_AMP] = ACTIONS(170),
    [anon_sym_PIPE_PIPE] = ACTIONS(170),
    [anon_sym_QMARK_QMARK] = ACTIONS(170),
    [anon_sym_QMARK_COLON] = ACTIONS(170),
    [anon_sym_BANG_EQ] = ACTIONS(170),
    [anon_sym_EQ_EQ] = ACTIONS(170),
    [anon_sym_QMARK_EQ] = ACTIONS(170),
    [anon_sym_STAR_EQ] = ACTIONS(170),
    [anon_sym_TILDE] = ACTIONS(170),
    [anon_sym_BANG_TILDE] = ACTIONS(170),
    [anon_sym_STAR_TILDE] = ACTIONS(170),
    [anon_sym_LT_EQ] = ACTIONS(170),
    [anon_sym_GT_EQ] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_PLUS_EQ] = ACTIONS(170),
    [anon_sym_DASH_EQ] = ACTIONS(170),
    [anon_sym_u00d7] = ACTIONS(170),
    [anon_sym_SLASH] = ACTIONS(172),
    [anon_sym_u00f7] = ACTIONS(170),
    [anon_sym_STAR_STAR] = ACTIONS(170),
    [anon_sym_u220b] = ACTIONS(170),
    [anon_sym_u220c] = ACTIONS(170),
    [anon_sym_u2287] = ACTIONS(170),
    [anon_sym_u2283] = ACTIONS(170),
    [anon_sym_u2285] = ACTIONS(170),
    [anon_sym_u2208] = ACTIONS(170),
    [anon_sym_u2209] = ACTIONS(170),
    [anon_sym_u2286] = ACTIONS(170),
    [anon_sym_u2282] = ACTIONS(170),
    [anon_sym_u2284] = ACTIONS(170),
    [anon_sym_AT_AT] = ACTIONS(170),
  },
  [321] = {
    [ts_builtin_sym_end] = ACTIONS(162),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(162),
    [sym_keyword_explain] = ACTIONS(162),
    [sym_keyword_parallel] = ACTIONS(162),
    [sym_keyword_timeout] = ACTIONS(162),
    [sym_keyword_fetch] = ACTIONS(162),
    [sym_keyword_limit] = ACTIONS(162),
    [sym_keyword_order] = ACTIONS(162),
    [sym_keyword_with] = ACTIONS(162),
    [sym_keyword_where] = ACTIONS(162),
    [sym_keyword_split] = ACTIONS(162),
    [sym_keyword_group] = ACTIONS(162),
    [sym_keyword_and] = ACTIONS(162),
    [sym_keyword_or] = ACTIONS(164),
    [sym_keyword_is] = ACTIONS(162),
    [sym_keyword_not] = ACTIONS(164),
    [sym_keyword_contains] = ACTIONS(162),
    [sym_keyword_contains_not] = ACTIONS(162),
    [sym_keyword_contains_all] = ACTIONS(162),
    [sym_keyword_contains_any] = ACTIONS(162),
    [sym_keyword_contains_none] = ACTIONS(162),
    [sym_keyword_inside] = ACTIONS(162),
    [sym_keyword_in] = ACTIONS(164),
    [sym_keyword_not_inside] = ACTIONS(162),
    [sym_keyword_all_inside] = ACTIONS(162),
    [sym_keyword_any_inside] = ACTIONS(162),
    [sym_keyword_none_inside] = ACTIONS(162),
    [sym_keyword_outside] = ACTIONS(162),
    [sym_keyword_intersects] = ACTIONS(162),
    [anon_sym_COMMA] = ACTIONS(162),
    [anon_sym_DASH_GT] = ACTIONS(162),
    [anon_sym_LBRACK] = ACTIONS(162),
    [anon_sym_LT_DASH] = ACTIONS(164),
    [anon_sym_LT_DASH_GT] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_DOT] = ACTIONS(162),
    [anon_sym_LT] = ACTIONS(164),
    [anon_sym_GT] = ACTIONS(164),
    [anon_sym_EQ] = ACTIONS(164),
    [anon_sym_DASH] = ACTIONS(164),
    [anon_sym_AT] = ACTIONS(164),
    [anon_sym_LT_PIPE] = ACTIONS(162),
    [anon_sym_AMP_AMP] = ACTIONS(162),
    [anon_sym_PIPE_PIPE] = ACTIONS(162),
    [anon_sym_QMARK_QMARK] = ACTIONS(162),
    [anon_sym_QMARK_COLON] = ACTIONS(162),
    [anon_sym_BANG_EQ] = ACTIONS(162),
    [anon_sym_EQ_EQ] = ACTIONS(162),
    [anon_sym_QMARK_EQ] = ACTIONS(162),
    [anon_sym_STAR_EQ] = ACTIONS(162),
    [anon_sym_TILDE] = ACTIONS(162),
    [anon_sym_BANG_TILDE] = ACTIONS(162),
    [anon_sym_STAR_TILDE] = ACTIONS(162),
    [anon_sym_LT_EQ] = ACTIONS(162),
    [anon_sym_GT_EQ] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(164),
    [anon_sym_PLUS_EQ] = ACTIONS(162),
    [anon_sym_DASH_EQ] = ACTIONS(162),
    [anon_sym_u00d7] = ACTIONS(162),
    [anon_sym_SLASH] = ACTIONS(164),
    [anon_sym_u00f7] = ACTIONS(162),
    [anon_sym_STAR_STAR] = ACTIONS(162),
    [anon_sym_u220b] = ACTIONS(162),
    [anon_sym_u220c] = ACTIONS(162),
    [anon_sym_u2287] = ACTIONS(162),
    [anon_sym_u2283] = ACTIONS(162),
    [anon_sym_u2285] = ACTIONS(162),
    [anon_sym_u2208] = ACTIONS(162),
    [anon_sym_u2209] = ACTIONS(162),
    [anon_sym_u2286] = ACTIONS(162),
    [anon_sym_u2282] = ACTIONS(162),
    [anon_sym_u2284] = ACTIONS(162),
    [anon_sym_AT_AT] = ACTIONS(162),
  },
  [322] = {
    [ts_builtin_sym_end] = ACTIONS(150),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(150),
    [sym_keyword_explain] = ACTIONS(150),
    [sym_keyword_parallel] = ACTIONS(150),
    [sym_keyword_timeout] = ACTIONS(150),
    [sym_keyword_fetch] = ACTIONS(150),
    [sym_keyword_limit] = ACTIONS(150),
    [sym_keyword_order] = ACTIONS(150),
    [sym_keyword_with] = ACTIONS(150),
    [sym_keyword_where] = ACTIONS(150),
    [sym_keyword_split] = ACTIONS(150),
    [sym_keyword_group] = ACTIONS(150),
    [sym_keyword_and] = ACTIONS(150),
    [sym_keyword_or] = ACTIONS(152),
    [sym_keyword_is] = ACTIONS(150),
    [sym_keyword_not] = ACTIONS(152),
    [sym_keyword_contains] = ACTIONS(150),
    [sym_keyword_contains_not] = ACTIONS(150),
    [sym_keyword_contains_all] = ACTIONS(150),
    [sym_keyword_contains_any] = ACTIONS(150),
    [sym_keyword_contains_none] = ACTIONS(150),
    [sym_keyword_inside] = ACTIONS(150),
    [sym_keyword_in] = ACTIONS(152),
    [sym_keyword_not_inside] = ACTIONS(150),
    [sym_keyword_all_inside] = ACTIONS(150),
    [sym_keyword_any_inside] = ACTIONS(150),
    [sym_keyword_none_inside] = ACTIONS(150),
    [sym_keyword_outside] = ACTIONS(150),
    [sym_keyword_intersects] = ACTIONS(150),
    [anon_sym_COMMA] = ACTIONS(150),
    [anon_sym_DASH_GT] = ACTIONS(150),
    [anon_sym_LBRACK] = ACTIONS(150),
    [anon_sym_LT_DASH] = ACTIONS(152),
    [anon_sym_LT_DASH_GT] = ACTIONS(150),
    [anon_sym_STAR] = ACTIONS(152),
    [anon_sym_DOT] = ACTIONS(150),
    [anon_sym_LT] = ACTIONS(152),
    [anon_sym_GT] = ACTIONS(152),
    [anon_sym_EQ] = ACTIONS(152),
    [anon_sym_DASH] = ACTIONS(152),
    [anon_sym_AT] = ACTIONS(152),
    [anon_sym_LT_PIPE] = ACTIONS(150),
    [anon_sym_AMP_AMP] = ACTIONS(150),
    [anon_sym_PIPE_PIPE] = ACTIONS(150),
    [anon_sym_QMARK_QMARK] = ACTIONS(150),
    [anon_sym_QMARK_COLON] = ACTIONS(150),
    [anon_sym_BANG_EQ] = ACTIONS(150),
    [anon_sym_EQ_EQ] = ACTIONS(150),
    [anon_sym_QMARK_EQ] = ACTIONS(150),
    [anon_sym_STAR_EQ] = ACTIONS(150),
    [anon_sym_TILDE] = ACTIONS(150),
    [anon_sym_BANG_TILDE] = ACTIONS(150),
    [anon_sym_STAR_TILDE] = ACTIONS(150),
    [anon_sym_LT_EQ] = ACTIONS(150),
    [anon_sym_GT_EQ] = ACTIONS(150),
    [anon_sym_PLUS] = ACTIONS(152),
    [anon_sym_PLUS_EQ] = ACTIONS(150),
    [anon_sym_DASH_EQ] = ACTIONS(150),
    [anon_sym_u00d7] = ACTIONS(150),
    [anon_sym_SLASH] = ACTIONS(152),
    [anon_sym_u00f7] = ACTIONS(150),
    [anon_sym_STAR_STAR] = ACTIONS(150),
    [anon_sym_u220b] = ACTIONS(150),
    [anon_sym_u220c] = ACTIONS(150),
    [anon_sym_u2287] = ACTIONS(150),
    [anon_sym_u2283] = ACTIONS(150),
    [anon_sym_u2285] = ACTIONS(150),
    [anon_sym_u2208] = ACTIONS(150),
    [anon_sym_u2209] = ACTIONS(150),
    [anon_sym_u2286] = ACTIONS(150),
    [anon_sym_u2282] = ACTIONS(150),
    [anon_sym_u2284] = ACTIONS(150),
    [anon_sym_AT_AT] = ACTIONS(150),
  },
  [323] = {
    [sym_expression] = STATE(1567),
    [sym_statement] = STATE(1384),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(576),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1780),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(546),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(532),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [324] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_as] = ACTIONS(182),
    [sym_keyword_group] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_drop] = ACTIONS(182),
    [sym_keyword_schemafull] = ACTIONS(182),
    [sym_keyword_schemaless] = ACTIONS(182),
    [sym_keyword_changefeed] = ACTIONS(182),
    [sym_keyword_type] = ACTIONS(182),
    [sym_keyword_permissions] = ACTIONS(182),
    [sym_keyword_comment] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(548),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [325] = {
    [sym_expression] = STATE(1567),
    [sym_statement] = STATE(1384),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(591),
    [sym_function_call] = STATE(99),
    [sym_base_value] = STATE(168),
    [sym_binary_expression] = STATE(99),
    [sym_path] = STATE(99),
    [sym_graph_path] = STATE(162),
    [sym_number] = STATE(58),
    [sym_identifier] = STATE(58),
    [sym_array] = STATE(58),
    [sym_object] = STATE(58),
    [sym_object_key] = STATE(1827),
    [sym_record_id] = STATE(58),
    [sym_sub_query] = STATE(58),
    [sym_duration] = STATE(58),
    [sym_point] = STATE(58),
    [aux_sym_duration_repeat1] = STATE(52),
    [ts_builtin_sym_end] = ACTIONS(546),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(5),
    [sym_keyword_rand] = ACTIONS(7),
    [sym_keyword_true] = ACTIONS(11),
    [sym_keyword_false] = ACTIONS(11),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(11),
    [sym_keyword_null] = ACTIONS(11),
    [sym_keyword_define] = ACTIONS(19),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(23),
    [sym_keyword_delete] = ACTIONS(25),
    [sym_keyword_update] = ACTIONS(27),
    [sym_keyword_insert] = ACTIONS(29),
    [sym_keyword_relate] = ACTIONS(31),
    [sym_keyword_count] = ACTIONS(33),
    [anon_sym_DASH_GT] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(43),
    [anon_sym_LT_DASH_GT] = ACTIONS(35),
    [aux_sym_type_name_token1] = ACTIONS(45),
    [sym_string] = ACTIONS(47),
    [sym_prefixed_string] = ACTIONS(47),
    [sym_int] = ACTIONS(49),
    [sym_float] = ACTIONS(49),
    [sym_decimal] = ACTIONS(51),
    [sym_variable_name] = ACTIONS(47),
    [sym_custom_function_name] = ACTIONS(7),
    [sym_function_name] = ACTIONS(7),
    [sym_duration_part] = ACTIONS(53),
  },
  [326] = {
    [sym_where_clause] = STATE(889),
    [sym_group_clause] = STATE(973),
    [sym_operator] = STATE(672),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(843),
    [ts_builtin_sym_end] = ACTIONS(498),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(498),
    [sym_keyword_as] = ACTIONS(498),
    [sym_keyword_where] = ACTIONS(542),
    [sym_keyword_group] = ACTIONS(494),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_drop] = ACTIONS(498),
    [sym_keyword_schemafull] = ACTIONS(498),
    [sym_keyword_schemaless] = ACTIONS(498),
    [sym_keyword_changefeed] = ACTIONS(498),
    [sym_keyword_type] = ACTIONS(498),
    [sym_keyword_permissions] = ACTIONS(498),
    [sym_keyword_comment] = ACTIONS(498),
    [anon_sym_COMMA] = ACTIONS(544),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [327] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_as] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_drop] = ACTIONS(182),
    [sym_keyword_schemafull] = ACTIONS(182),
    [sym_keyword_schemaless] = ACTIONS(182),
    [sym_keyword_changefeed] = ACTIONS(182),
    [sym_keyword_type] = ACTIONS(182),
    [sym_keyword_permissions] = ACTIONS(182),
    [sym_keyword_for] = ACTIONS(182),
    [sym_keyword_comment] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(550),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [328] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(48),
    [ts_builtin_sym_end] = ACTIONS(367),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_return] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_where] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [329] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_value] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_flexible] = ACTIONS(182),
    [sym_keyword_readonly] = ACTIONS(182),
    [sym_keyword_type] = ACTIONS(182),
    [sym_keyword_default] = ACTIONS(182),
    [sym_keyword_assert] = ACTIONS(182),
    [sym_keyword_permissions] = ACTIONS(182),
    [sym_keyword_for] = ACTIONS(182),
    [sym_keyword_comment] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(552),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [330] = {
    [ts_builtin_sym_end] = ACTIONS(182),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_explain] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_fetch] = ACTIONS(182),
    [sym_keyword_limit] = ACTIONS(182),
    [sym_keyword_order] = ACTIONS(182),
    [sym_keyword_where] = ACTIONS(182),
    [sym_keyword_split] = ACTIONS(182),
    [sym_keyword_group] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(184),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(554),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [331] = {
    [ts_builtin_sym_end] = ACTIONS(182),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_return] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_where] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_content] = ACTIONS(182),
    [sym_keyword_merge] = ACTIONS(182),
    [sym_keyword_patch] = ACTIONS(182),
    [sym_keyword_set] = ACTIONS(182),
    [sym_keyword_unset] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(556),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [332] = {
    [ts_builtin_sym_end] = ACTIONS(154),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(154),
    [sym_keyword_explain] = ACTIONS(154),
    [sym_keyword_parallel] = ACTIONS(154),
    [sym_keyword_timeout] = ACTIONS(154),
    [sym_keyword_fetch] = ACTIONS(154),
    [sym_keyword_limit] = ACTIONS(154),
    [sym_keyword_order] = ACTIONS(154),
    [sym_keyword_with] = ACTIONS(154),
    [sym_keyword_where] = ACTIONS(154),
    [sym_keyword_split] = ACTIONS(154),
    [sym_keyword_group] = ACTIONS(154),
    [sym_keyword_and] = ACTIONS(154),
    [sym_keyword_or] = ACTIONS(156),
    [sym_keyword_is] = ACTIONS(154),
    [sym_keyword_not] = ACTIONS(156),
    [sym_keyword_contains] = ACTIONS(154),
    [sym_keyword_contains_not] = ACTIONS(154),
    [sym_keyword_contains_all] = ACTIONS(154),
    [sym_keyword_contains_any] = ACTIONS(154),
    [sym_keyword_contains_none] = ACTIONS(154),
    [sym_keyword_inside] = ACTIONS(154),
    [sym_keyword_in] = ACTIONS(156),
    [sym_keyword_not_inside] = ACTIONS(154),
    [sym_keyword_all_inside] = ACTIONS(154),
    [sym_keyword_any_inside] = ACTIONS(154),
    [sym_keyword_none_inside] = ACTIONS(154),
    [sym_keyword_outside] = ACTIONS(154),
    [sym_keyword_intersects] = ACTIONS(154),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_DASH_GT] = ACTIONS(154),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_LT_DASH] = ACTIONS(156),
    [anon_sym_LT_DASH_GT] = ACTIONS(154),
    [anon_sym_STAR] = ACTIONS(156),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_LT] = ACTIONS(156),
    [anon_sym_GT] = ACTIONS(156),
    [anon_sym_EQ] = ACTIONS(156),
    [anon_sym_DASH] = ACTIONS(156),
    [anon_sym_AT] = ACTIONS(156),
    [anon_sym_LT_PIPE] = ACTIONS(154),
    [anon_sym_AMP_AMP] = ACTIONS(154),
    [anon_sym_PIPE_PIPE] = ACTIONS(154),
    [anon_sym_QMARK_QMARK] = ACTIONS(154),
    [anon_sym_QMARK_COLON] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(154),
    [anon_sym_QMARK_EQ] = ACTIONS(154),
    [anon_sym_STAR_EQ] = ACTIONS(154),
    [anon_sym_TILDE] = ACTIONS(154),
    [anon_sym_BANG_TILDE] = ACTIONS(154),
    [anon_sym_STAR_TILDE] = ACTIONS(154),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_PLUS] = ACTIONS(156),
    [anon_sym_PLUS_EQ] = ACTIONS(154),
    [anon_sym_DASH_EQ] = ACTIONS(154),
    [anon_sym_u00d7] = ACTIONS(154),
    [anon_sym_SLASH] = ACTIONS(156),
    [anon_sym_u00f7] = ACTIONS(154),
    [anon_sym_STAR_STAR] = ACTIONS(154),
    [anon_sym_u220b] = ACTIONS(154),
    [anon_sym_u220c] = ACTIONS(154),
    [anon_sym_u2287] = ACTIONS(154),
    [anon_sym_u2283] = ACTIONS(154),
    [anon_sym_u2285] = ACTIONS(154),
    [anon_sym_u2208] = ACTIONS(154),
    [anon_sym_u2209] = ACTIONS(154),
    [anon_sym_u2286] = ACTIONS(154),
    [anon_sym_u2282] = ACTIONS(154),
    [anon_sym_u2284] = ACTIONS(154),
    [anon_sym_AT_AT] = ACTIONS(154),
  },
  [333] = {
    [ts_builtin_sym_end] = ACTIONS(158),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(158),
    [sym_keyword_explain] = ACTIONS(158),
    [sym_keyword_parallel] = ACTIONS(158),
    [sym_keyword_timeout] = ACTIONS(158),
    [sym_keyword_fetch] = ACTIONS(158),
    [sym_keyword_limit] = ACTIONS(158),
    [sym_keyword_order] = ACTIONS(158),
    [sym_keyword_with] = ACTIONS(158),
    [sym_keyword_where] = ACTIONS(158),
    [sym_keyword_split] = ACTIONS(158),
    [sym_keyword_group] = ACTIONS(158),
    [sym_keyword_and] = ACTIONS(158),
    [sym_keyword_or] = ACTIONS(160),
    [sym_keyword_is] = ACTIONS(158),
    [sym_keyword_not] = ACTIONS(160),
    [sym_keyword_contains] = ACTIONS(158),
    [sym_keyword_contains_not] = ACTIONS(158),
    [sym_keyword_contains_all] = ACTIONS(158),
    [sym_keyword_contains_any] = ACTIONS(158),
    [sym_keyword_contains_none] = ACTIONS(158),
    [sym_keyword_inside] = ACTIONS(158),
    [sym_keyword_in] = ACTIONS(160),
    [sym_keyword_not_inside] = ACTIONS(158),
    [sym_keyword_all_inside] = ACTIONS(158),
    [sym_keyword_any_inside] = ACTIONS(158),
    [sym_keyword_none_inside] = ACTIONS(158),
    [sym_keyword_outside] = ACTIONS(158),
    [sym_keyword_intersects] = ACTIONS(158),
    [anon_sym_COMMA] = ACTIONS(158),
    [anon_sym_DASH_GT] = ACTIONS(158),
    [anon_sym_LBRACK] = ACTIONS(158),
    [anon_sym_LT_DASH] = ACTIONS(160),
    [anon_sym_LT_DASH_GT] = ACTIONS(158),
    [anon_sym_STAR] = ACTIONS(160),
    [anon_sym_DOT] = ACTIONS(158),
    [anon_sym_LT] = ACTIONS(160),
    [anon_sym_GT] = ACTIONS(160),
    [anon_sym_EQ] = ACTIONS(160),
    [anon_sym_DASH] = ACTIONS(160),
    [anon_sym_AT] = ACTIONS(160),
    [anon_sym_LT_PIPE] = ACTIONS(158),
    [anon_sym_AMP_AMP] = ACTIONS(158),
    [anon_sym_PIPE_PIPE] = ACTIONS(158),
    [anon_sym_QMARK_QMARK] = ACTIONS(158),
    [anon_sym_QMARK_COLON] = ACTIONS(158),
    [anon_sym_BANG_EQ] = ACTIONS(158),
    [anon_sym_EQ_EQ] = ACTIONS(158),
    [anon_sym_QMARK_EQ] = ACTIONS(158),
    [anon_sym_STAR_EQ] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(158),
    [anon_sym_BANG_TILDE] = ACTIONS(158),
    [anon_sym_STAR_TILDE] = ACTIONS(158),
    [anon_sym_LT_EQ] = ACTIONS(158),
    [anon_sym_GT_EQ] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(160),
    [anon_sym_PLUS_EQ] = ACTIONS(158),
    [anon_sym_DASH_EQ] = ACTIONS(158),
    [anon_sym_u00d7] = ACTIONS(158),
    [anon_sym_SLASH] = ACTIONS(160),
    [anon_sym_u00f7] = ACTIONS(158),
    [anon_sym_STAR_STAR] = ACTIONS(158),
    [anon_sym_u220b] = ACTIONS(158),
    [anon_sym_u220c] = ACTIONS(158),
    [anon_sym_u2287] = ACTIONS(158),
    [anon_sym_u2283] = ACTIONS(158),
    [anon_sym_u2285] = ACTIONS(158),
    [anon_sym_u2208] = ACTIONS(158),
    [anon_sym_u2209] = ACTIONS(158),
    [anon_sym_u2286] = ACTIONS(158),
    [anon_sym_u2282] = ACTIONS(158),
    [anon_sym_u2284] = ACTIONS(158),
    [anon_sym_AT_AT] = ACTIONS(158),
  },
  [334] = {
    [ts_builtin_sym_end] = ACTIONS(146),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(146),
    [sym_keyword_explain] = ACTIONS(146),
    [sym_keyword_parallel] = ACTIONS(146),
    [sym_keyword_timeout] = ACTIONS(146),
    [sym_keyword_fetch] = ACTIONS(146),
    [sym_keyword_limit] = ACTIONS(146),
    [sym_keyword_order] = ACTIONS(146),
    [sym_keyword_with] = ACTIONS(146),
    [sym_keyword_where] = ACTIONS(146),
    [sym_keyword_split] = ACTIONS(146),
    [sym_keyword_group] = ACTIONS(146),
    [sym_keyword_and] = ACTIONS(146),
    [sym_keyword_or] = ACTIONS(148),
    [sym_keyword_is] = ACTIONS(146),
    [sym_keyword_not] = ACTIONS(148),
    [sym_keyword_contains] = ACTIONS(146),
    [sym_keyword_contains_not] = ACTIONS(146),
    [sym_keyword_contains_all] = ACTIONS(146),
    [sym_keyword_contains_any] = ACTIONS(146),
    [sym_keyword_contains_none] = ACTIONS(146),
    [sym_keyword_inside] = ACTIONS(146),
    [sym_keyword_in] = ACTIONS(148),
    [sym_keyword_not_inside] = ACTIONS(146),
    [sym_keyword_all_inside] = ACTIONS(146),
    [sym_keyword_any_inside] = ACTIONS(146),
    [sym_keyword_none_inside] = ACTIONS(146),
    [sym_keyword_outside] = ACTIONS(146),
    [sym_keyword_intersects] = ACTIONS(146),
    [anon_sym_COMMA] = ACTIONS(146),
    [anon_sym_DASH_GT] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(146),
    [anon_sym_LT_DASH] = ACTIONS(148),
    [anon_sym_LT_DASH_GT] = ACTIONS(146),
    [anon_sym_STAR] = ACTIONS(148),
    [anon_sym_DOT] = ACTIONS(146),
    [anon_sym_LT] = ACTIONS(148),
    [anon_sym_GT] = ACTIONS(148),
    [anon_sym_EQ] = ACTIONS(148),
    [anon_sym_DASH] = ACTIONS(148),
    [anon_sym_AT] = ACTIONS(148),
    [anon_sym_LT_PIPE] = ACTIONS(146),
    [anon_sym_AMP_AMP] = ACTIONS(146),
    [anon_sym_PIPE_PIPE] = ACTIONS(146),
    [anon_sym_QMARK_QMARK] = ACTIONS(146),
    [anon_sym_QMARK_COLON] = ACTIONS(146),
    [anon_sym_BANG_EQ] = ACTIONS(146),
    [anon_sym_EQ_EQ] = ACTIONS(146),
    [anon_sym_QMARK_EQ] = ACTIONS(146),
    [anon_sym_STAR_EQ] = ACTIONS(146),
    [anon_sym_TILDE] = ACTIONS(146),
    [anon_sym_BANG_TILDE] = ACTIONS(146),
    [anon_sym_STAR_TILDE] = ACTIONS(146),
    [anon_sym_LT_EQ] = ACTIONS(146),
    [anon_sym_GT_EQ] = ACTIONS(146),
    [anon_sym_PLUS] = ACTIONS(148),
    [anon_sym_PLUS_EQ] = ACTIONS(146),
    [anon_sym_DASH_EQ] = ACTIONS(146),
    [anon_sym_u00d7] = ACTIONS(146),
    [anon_sym_SLASH] = ACTIONS(148),
    [anon_sym_u00f7] = ACTIONS(146),
    [anon_sym_STAR_STAR] = ACTIONS(146),
    [anon_sym_u220b] = ACTIONS(146),
    [anon_sym_u220c] = ACTIONS(146),
    [anon_sym_u2287] = ACTIONS(146),
    [anon_sym_u2283] = ACTIONS(146),
    [anon_sym_u2285] = ACTIONS(146),
    [anon_sym_u2208] = ACTIONS(146),
    [anon_sym_u2209] = ACTIONS(146),
    [anon_sym_u2286] = ACTIONS(146),
    [anon_sym_u2282] = ACTIONS(146),
    [anon_sym_u2284] = ACTIONS(146),
    [anon_sym_AT_AT] = ACTIONS(146),
  },
  [335] = {
    [ts_builtin_sym_end] = ACTIONS(206),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(206),
    [sym_keyword_explain] = ACTIONS(206),
    [sym_keyword_parallel] = ACTIONS(206),
    [sym_keyword_timeout] = ACTIONS(206),
    [sym_keyword_fetch] = ACTIONS(206),
    [sym_keyword_limit] = ACTIONS(206),
    [sym_keyword_order] = ACTIONS(206),
    [sym_keyword_with] = ACTIONS(206),
    [sym_keyword_where] = ACTIONS(206),
    [sym_keyword_split] = ACTIONS(206),
    [sym_keyword_group] = ACTIONS(206),
    [sym_keyword_and] = ACTIONS(206),
    [sym_keyword_or] = ACTIONS(208),
    [sym_keyword_is] = ACTIONS(206),
    [sym_keyword_not] = ACTIONS(208),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(206),
    [sym_keyword_contains_all] = ACTIONS(206),
    [sym_keyword_contains_any] = ACTIONS(206),
    [sym_keyword_contains_none] = ACTIONS(206),
    [sym_keyword_inside] = ACTIONS(206),
    [sym_keyword_in] = ACTIONS(208),
    [sym_keyword_not_inside] = ACTIONS(206),
    [sym_keyword_all_inside] = ACTIONS(206),
    [sym_keyword_any_inside] = ACTIONS(206),
    [sym_keyword_none_inside] = ACTIONS(206),
    [sym_keyword_outside] = ACTIONS(206),
    [sym_keyword_intersects] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(206),
    [anon_sym_DASH_GT] = ACTIONS(206),
    [anon_sym_LBRACK] = ACTIONS(206),
    [anon_sym_LT_DASH] = ACTIONS(208),
    [anon_sym_LT_DASH_GT] = ACTIONS(206),
    [anon_sym_STAR] = ACTIONS(208),
    [anon_sym_DOT] = ACTIONS(206),
    [anon_sym_LT] = ACTIONS(208),
    [anon_sym_GT] = ACTIONS(208),
    [anon_sym_EQ] = ACTIONS(208),
    [anon_sym_DASH] = ACTIONS(208),
    [anon_sym_AT] = ACTIONS(208),
    [anon_sym_LT_PIPE] = ACTIONS(206),
    [anon_sym_AMP_AMP] = ACTIONS(206),
    [anon_sym_PIPE_PIPE] = ACTIONS(206),
    [anon_sym_QMARK_QMARK] = ACTIONS(206),
    [anon_sym_QMARK_COLON] = ACTIONS(206),
    [anon_sym_BANG_EQ] = ACTIONS(206),
    [anon_sym_EQ_EQ] = ACTIONS(206),
    [anon_sym_QMARK_EQ] = ACTIONS(206),
    [anon_sym_STAR_EQ] = ACTIONS(206),
    [anon_sym_TILDE] = ACTIONS(206),
    [anon_sym_BANG_TILDE] = ACTIONS(206),
    [anon_sym_STAR_TILDE] = ACTIONS(206),
    [anon_sym_LT_EQ] = ACTIONS(206),
    [anon_sym_GT_EQ] = ACTIONS(206),
    [anon_sym_PLUS] = ACTIONS(208),
    [anon_sym_PLUS_EQ] = ACTIONS(206),
    [anon_sym_DASH_EQ] = ACTIONS(206),
    [anon_sym_u00d7] = ACTIONS(206),
    [anon_sym_SLASH] = ACTIONS(208),
    [anon_sym_u00f7] = ACTIONS(206),
    [anon_sym_STAR_STAR] = ACTIONS(206),
    [anon_sym_u220b] = ACTIONS(206),
    [anon_sym_u220c] = ACTIONS(206),
    [anon_sym_u2287] = ACTIONS(206),
    [anon_sym_u2283] = ACTIONS(206),
    [anon_sym_u2285] = ACTIONS(206),
    [anon_sym_u2208] = ACTIONS(206),
    [anon_sym_u2209] = ACTIONS(206),
    [anon_sym_u2286] = ACTIONS(206),
    [anon_sym_u2282] = ACTIONS(206),
    [anon_sym_u2284] = ACTIONS(206),
    [anon_sym_AT_AT] = ACTIONS(206),
  },
  [336] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(49),
    [ts_builtin_sym_end] = ACTIONS(210),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_return] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_where] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [337] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(50),
    [ts_builtin_sym_end] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_return] = ACTIONS(180),
    [sym_keyword_parallel] = ACTIONS(180),
    [sym_keyword_timeout] = ACTIONS(180),
    [sym_keyword_where] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [338] = {
    [sym_expression] = STATE(1778),
    [sym_statement] = STATE(1384),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(576),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1780),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(532),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [339] = {
    [sym_statement] = STATE(1708),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(571),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1780),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_RPAREN] = ACTIONS(558),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(532),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [340] = {
    [sym_statement] = STATE(1327),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(132),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1762),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_only] = ACTIONS(560),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(532),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [341] = {
    [sym_expression] = STATE(1721),
    [sym_statement] = STATE(1384),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(576),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1780),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(562),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [342] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_explain] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_fetch] = ACTIONS(182),
    [sym_keyword_limit] = ACTIONS(182),
    [sym_keyword_order] = ACTIONS(182),
    [sym_keyword_split] = ACTIONS(182),
    [sym_keyword_group] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(184),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(564),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [343] = {
    [ts_builtin_sym_end] = ACTIONS(182),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_value] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_flexible] = ACTIONS(182),
    [sym_keyword_readonly] = ACTIONS(182),
    [sym_keyword_type] = ACTIONS(182),
    [sym_keyword_default] = ACTIONS(182),
    [sym_keyword_assert] = ACTIONS(182),
    [sym_keyword_permissions] = ACTIONS(182),
    [sym_keyword_for] = ACTIONS(182),
    [sym_keyword_comment] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(566),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [344] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_value] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_flexible] = ACTIONS(182),
    [sym_keyword_readonly] = ACTIONS(182),
    [sym_keyword_type] = ACTIONS(182),
    [sym_keyword_default] = ACTIONS(182),
    [sym_keyword_assert] = ACTIONS(182),
    [sym_keyword_permissions] = ACTIONS(182),
    [sym_keyword_comment] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(568),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [345] = {
    [ts_builtin_sym_end] = ACTIONS(182),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_as] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_drop] = ACTIONS(182),
    [sym_keyword_schemafull] = ACTIONS(182),
    [sym_keyword_schemaless] = ACTIONS(182),
    [sym_keyword_changefeed] = ACTIONS(182),
    [sym_keyword_type] = ACTIONS(182),
    [sym_keyword_permissions] = ACTIONS(182),
    [sym_keyword_for] = ACTIONS(182),
    [sym_keyword_comment] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(570),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [346] = {
    [sym_statement] = STATE(1847),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(579),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1780),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_RPAREN] = ACTIONS(572),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(532),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [347] = {
    [sym_expression] = STATE(1768),
    [sym_statement] = STATE(1384),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(576),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1780),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(574),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [348] = {
    [sym_expression] = STATE(1825),
    [sym_statement] = STATE(1384),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(576),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1780),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(576),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [349] = {
    [sym_statement] = STATE(1328),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(421),
    [sym_function_call] = STATE(99),
    [sym_base_value] = STATE(168),
    [sym_binary_expression] = STATE(99),
    [sym_path] = STATE(99),
    [sym_graph_path] = STATE(162),
    [sym_number] = STATE(58),
    [sym_identifier] = STATE(58),
    [sym_array] = STATE(58),
    [sym_object] = STATE(58),
    [sym_object_key] = STATE(1796),
    [sym_record_id] = STATE(58),
    [sym_sub_query] = STATE(58),
    [sym_duration] = STATE(58),
    [sym_point] = STATE(58),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(5),
    [sym_keyword_only] = ACTIONS(578),
    [sym_keyword_rand] = ACTIONS(7),
    [sym_keyword_true] = ACTIONS(11),
    [sym_keyword_false] = ACTIONS(11),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(11),
    [sym_keyword_null] = ACTIONS(11),
    [sym_keyword_define] = ACTIONS(19),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(23),
    [sym_keyword_delete] = ACTIONS(25),
    [sym_keyword_update] = ACTIONS(27),
    [sym_keyword_insert] = ACTIONS(29),
    [sym_keyword_relate] = ACTIONS(31),
    [sym_keyword_count] = ACTIONS(33),
    [anon_sym_DASH_GT] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(43),
    [anon_sym_LT_DASH_GT] = ACTIONS(35),
    [aux_sym_type_name_token1] = ACTIONS(45),
    [sym_string] = ACTIONS(47),
    [sym_prefixed_string] = ACTIONS(47),
    [sym_int] = ACTIONS(49),
    [sym_float] = ACTIONS(49),
    [sym_decimal] = ACTIONS(51),
    [sym_variable_name] = ACTIONS(47),
    [sym_custom_function_name] = ACTIONS(7),
    [sym_function_name] = ACTIONS(7),
    [sym_duration_part] = ACTIONS(53),
  },
  [350] = {
    [sym_statement] = STATE(1764),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(544),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1780),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_RPAREN] = ACTIONS(580),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(532),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [351] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(48),
    [ts_builtin_sym_end] = ACTIONS(367),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_return] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [352] = {
    [sym_statement] = STATE(1305),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(130),
    [sym_function_call] = STATE(478),
    [sym_base_value] = STATE(185),
    [sym_binary_expression] = STATE(478),
    [sym_path] = STATE(478),
    [sym_graph_path] = STATE(175),
    [sym_number] = STATE(332),
    [sym_identifier] = STATE(332),
    [sym_array] = STATE(332),
    [sym_object] = STATE(332),
    [sym_object_key] = STATE(1761),
    [sym_record_id] = STATE(332),
    [sym_sub_query] = STATE(332),
    [sym_duration] = STATE(332),
    [sym_point] = STATE(332),
    [aux_sym_duration_repeat1] = STATE(240),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(5),
    [sym_keyword_only] = ACTIONS(582),
    [sym_keyword_rand] = ACTIONS(584),
    [sym_keyword_true] = ACTIONS(586),
    [sym_keyword_false] = ACTIONS(586),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(586),
    [sym_keyword_null] = ACTIONS(586),
    [sym_keyword_define] = ACTIONS(19),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(23),
    [sym_keyword_delete] = ACTIONS(25),
    [sym_keyword_update] = ACTIONS(27),
    [sym_keyword_insert] = ACTIONS(29),
    [sym_keyword_relate] = ACTIONS(31),
    [sym_keyword_count] = ACTIONS(588),
    [anon_sym_DASH_GT] = ACTIONS(448),
    [anon_sym_LBRACK] = ACTIONS(590),
    [anon_sym_LPAREN] = ACTIONS(592),
    [anon_sym_LBRACE] = ACTIONS(442),
    [anon_sym_LT_DASH] = ACTIONS(452),
    [anon_sym_LT_DASH_GT] = ACTIONS(448),
    [aux_sym_type_name_token1] = ACTIONS(594),
    [sym_string] = ACTIONS(596),
    [sym_prefixed_string] = ACTIONS(596),
    [sym_int] = ACTIONS(598),
    [sym_float] = ACTIONS(598),
    [sym_decimal] = ACTIONS(600),
    [sym_variable_name] = ACTIONS(596),
    [sym_custom_function_name] = ACTIONS(584),
    [sym_function_name] = ACTIONS(584),
    [sym_duration_part] = ACTIONS(602),
  },
  [353] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(49),
    [ts_builtin_sym_end] = ACTIONS(210),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_return] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [354] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(50),
    [ts_builtin_sym_end] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_return] = ACTIONS(180),
    [sym_keyword_parallel] = ACTIONS(180),
    [sym_keyword_timeout] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [355] = {
    [sym_statement] = STATE(1279),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(129),
    [sym_function_call] = STATE(478),
    [sym_base_value] = STATE(185),
    [sym_binary_expression] = STATE(478),
    [sym_path] = STATE(478),
    [sym_graph_path] = STATE(175),
    [sym_number] = STATE(332),
    [sym_identifier] = STATE(332),
    [sym_array] = STATE(332),
    [sym_object] = STATE(332),
    [sym_object_key] = STATE(1761),
    [sym_record_id] = STATE(332),
    [sym_sub_query] = STATE(332),
    [sym_duration] = STATE(332),
    [sym_point] = STATE(332),
    [aux_sym_duration_repeat1] = STATE(240),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(5),
    [sym_keyword_only] = ACTIONS(604),
    [sym_keyword_rand] = ACTIONS(584),
    [sym_keyword_true] = ACTIONS(586),
    [sym_keyword_false] = ACTIONS(586),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(586),
    [sym_keyword_null] = ACTIONS(586),
    [sym_keyword_define] = ACTIONS(19),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(23),
    [sym_keyword_delete] = ACTIONS(25),
    [sym_keyword_update] = ACTIONS(27),
    [sym_keyword_insert] = ACTIONS(29),
    [sym_keyword_relate] = ACTIONS(31),
    [sym_keyword_count] = ACTIONS(588),
    [anon_sym_DASH_GT] = ACTIONS(448),
    [anon_sym_LBRACK] = ACTIONS(590),
    [anon_sym_LPAREN] = ACTIONS(592),
    [anon_sym_LBRACE] = ACTIONS(442),
    [anon_sym_LT_DASH] = ACTIONS(452),
    [anon_sym_LT_DASH_GT] = ACTIONS(448),
    [aux_sym_type_name_token1] = ACTIONS(594),
    [sym_string] = ACTIONS(596),
    [sym_prefixed_string] = ACTIONS(596),
    [sym_int] = ACTIONS(598),
    [sym_float] = ACTIONS(598),
    [sym_decimal] = ACTIONS(600),
    [sym_variable_name] = ACTIONS(596),
    [sym_custom_function_name] = ACTIONS(584),
    [sym_function_name] = ACTIONS(584),
    [sym_duration_part] = ACTIONS(602),
  },
  [356] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(45),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_RPAREN] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [357] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(36),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [358] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(33),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_parallel] = ACTIONS(180),
    [sym_keyword_timeout] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [359] = {
    [sym_expression] = STATE(1841),
    [sym_statement] = STATE(1384),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(576),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1780),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(606),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [360] = {
    [sym_statement] = STATE(1327),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(154),
    [sym_function_call] = STATE(99),
    [sym_base_value] = STATE(168),
    [sym_binary_expression] = STATE(99),
    [sym_path] = STATE(99),
    [sym_graph_path] = STATE(162),
    [sym_number] = STATE(58),
    [sym_identifier] = STATE(58),
    [sym_array] = STATE(58),
    [sym_object] = STATE(58),
    [sym_object_key] = STATE(1789),
    [sym_record_id] = STATE(58),
    [sym_sub_query] = STATE(58),
    [sym_duration] = STATE(58),
    [sym_point] = STATE(58),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(5),
    [sym_keyword_only] = ACTIONS(608),
    [sym_keyword_rand] = ACTIONS(7),
    [sym_keyword_true] = ACTIONS(11),
    [sym_keyword_false] = ACTIONS(11),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(11),
    [sym_keyword_null] = ACTIONS(11),
    [sym_keyword_define] = ACTIONS(19),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(23),
    [sym_keyword_delete] = ACTIONS(25),
    [sym_keyword_update] = ACTIONS(27),
    [sym_keyword_insert] = ACTIONS(29),
    [sym_keyword_relate] = ACTIONS(31),
    [sym_keyword_count] = ACTIONS(33),
    [anon_sym_DASH_GT] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(43),
    [anon_sym_LT_DASH_GT] = ACTIONS(35),
    [aux_sym_type_name_token1] = ACTIONS(45),
    [sym_string] = ACTIONS(47),
    [sym_prefixed_string] = ACTIONS(47),
    [sym_int] = ACTIONS(49),
    [sym_float] = ACTIONS(49),
    [sym_decimal] = ACTIONS(51),
    [sym_variable_name] = ACTIONS(47),
    [sym_custom_function_name] = ACTIONS(7),
    [sym_function_name] = ACTIONS(7),
    [sym_duration_part] = ACTIONS(53),
  },
  [361] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(33),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_QMARK] = ACTIONS(180),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [362] = {
    [sym_statement] = STATE(1820),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(554),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1780),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_RPAREN] = ACTIONS(610),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(532),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [363] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(36),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_QMARK] = ACTIONS(212),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [364] = {
    [sym_statement] = STATE(1328),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(417),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1772),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_only] = ACTIONS(612),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(532),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [365] = {
    [sym_expression] = STATE(1567),
    [sym_statement] = STATE(1384),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(591),
    [sym_function_call] = STATE(99),
    [sym_base_value] = STATE(168),
    [sym_binary_expression] = STATE(99),
    [sym_path] = STATE(99),
    [sym_graph_path] = STATE(162),
    [sym_number] = STATE(58),
    [sym_identifier] = STATE(58),
    [sym_array] = STATE(58),
    [sym_object] = STATE(58),
    [sym_object_key] = STATE(1827),
    [sym_record_id] = STATE(58),
    [sym_sub_query] = STATE(58),
    [sym_duration] = STATE(58),
    [sym_point] = STATE(58),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(5),
    [sym_keyword_rand] = ACTIONS(7),
    [sym_keyword_true] = ACTIONS(11),
    [sym_keyword_false] = ACTIONS(11),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(11),
    [sym_keyword_null] = ACTIONS(11),
    [sym_keyword_define] = ACTIONS(19),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(23),
    [sym_keyword_delete] = ACTIONS(25),
    [sym_keyword_update] = ACTIONS(27),
    [sym_keyword_insert] = ACTIONS(29),
    [sym_keyword_relate] = ACTIONS(31),
    [sym_keyword_count] = ACTIONS(33),
    [anon_sym_DASH_GT] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(43),
    [anon_sym_LT_DASH_GT] = ACTIONS(35),
    [aux_sym_type_name_token1] = ACTIONS(45),
    [sym_string] = ACTIONS(47),
    [sym_prefixed_string] = ACTIONS(47),
    [sym_int] = ACTIONS(49),
    [sym_float] = ACTIONS(49),
    [sym_decimal] = ACTIONS(51),
    [sym_variable_name] = ACTIONS(47),
    [sym_custom_function_name] = ACTIONS(7),
    [sym_function_name] = ACTIONS(7),
    [sym_duration_part] = ACTIONS(53),
  },
  [366] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(45),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_RBRACK] = ACTIONS(367),
    [anon_sym_RPAREN] = ACTIONS(367),
    [anon_sym_QMARK] = ACTIONS(369),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [367] = {
    [sym_expression] = STATE(1778),
    [sym_statement] = STATE(1384),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(576),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1780),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(614),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [368] = {
    [ts_builtin_sym_end] = ACTIONS(182),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_as] = ACTIONS(182),
    [sym_keyword_group] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_drop] = ACTIONS(182),
    [sym_keyword_schemafull] = ACTIONS(182),
    [sym_keyword_schemaless] = ACTIONS(182),
    [sym_keyword_changefeed] = ACTIONS(182),
    [sym_keyword_type] = ACTIONS(182),
    [sym_keyword_permissions] = ACTIONS(182),
    [sym_keyword_comment] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(616),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [369] = {
    [sym_statement] = STATE(1279),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(128),
    [sym_function_call] = STATE(455),
    [sym_base_value] = STATE(157),
    [sym_binary_expression] = STATE(455),
    [sym_path] = STATE(455),
    [sym_graph_path] = STATE(155),
    [sym_number] = STATE(300),
    [sym_identifier] = STATE(300),
    [sym_array] = STATE(300),
    [sym_object] = STATE(300),
    [sym_object_key] = STATE(1754),
    [sym_record_id] = STATE(300),
    [sym_sub_query] = STATE(300),
    [sym_duration] = STATE(300),
    [sym_point] = STATE(300),
    [aux_sym_duration_repeat1] = STATE(220),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_only] = ACTIONS(618),
    [sym_keyword_rand] = ACTIONS(620),
    [sym_keyword_true] = ACTIONS(622),
    [sym_keyword_false] = ACTIONS(622),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(622),
    [sym_keyword_null] = ACTIONS(622),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(624),
    [anon_sym_DASH_GT] = ACTIONS(416),
    [anon_sym_LBRACK] = ACTIONS(626),
    [anon_sym_LPAREN] = ACTIONS(628),
    [anon_sym_LBRACE] = ACTIONS(363),
    [anon_sym_LT_DASH] = ACTIONS(420),
    [anon_sym_LT_DASH_GT] = ACTIONS(416),
    [aux_sym_type_name_token1] = ACTIONS(630),
    [sym_string] = ACTIONS(632),
    [sym_prefixed_string] = ACTIONS(632),
    [sym_int] = ACTIONS(634),
    [sym_float] = ACTIONS(634),
    [sym_decimal] = ACTIONS(636),
    [sym_variable_name] = ACTIONS(632),
    [sym_custom_function_name] = ACTIONS(620),
    [sym_function_name] = ACTIONS(620),
    [sym_duration_part] = ACTIONS(638),
  },
  [370] = {
    [sym_statement] = STATE(1305),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(127),
    [sym_function_call] = STATE(455),
    [sym_base_value] = STATE(157),
    [sym_binary_expression] = STATE(455),
    [sym_path] = STATE(455),
    [sym_graph_path] = STATE(155),
    [sym_number] = STATE(300),
    [sym_identifier] = STATE(300),
    [sym_array] = STATE(300),
    [sym_object] = STATE(300),
    [sym_object_key] = STATE(1754),
    [sym_record_id] = STATE(300),
    [sym_sub_query] = STATE(300),
    [sym_duration] = STATE(300),
    [sym_point] = STATE(300),
    [aux_sym_duration_repeat1] = STATE(220),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_only] = ACTIONS(640),
    [sym_keyword_rand] = ACTIONS(620),
    [sym_keyword_true] = ACTIONS(622),
    [sym_keyword_false] = ACTIONS(622),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(622),
    [sym_keyword_null] = ACTIONS(622),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(624),
    [anon_sym_DASH_GT] = ACTIONS(416),
    [anon_sym_LBRACK] = ACTIONS(626),
    [anon_sym_LPAREN] = ACTIONS(628),
    [anon_sym_LBRACE] = ACTIONS(363),
    [anon_sym_LT_DASH] = ACTIONS(420),
    [anon_sym_LT_DASH_GT] = ACTIONS(416),
    [aux_sym_type_name_token1] = ACTIONS(630),
    [sym_string] = ACTIONS(632),
    [sym_prefixed_string] = ACTIONS(632),
    [sym_int] = ACTIONS(634),
    [sym_float] = ACTIONS(634),
    [sym_decimal] = ACTIONS(636),
    [sym_variable_name] = ACTIONS(632),
    [sym_custom_function_name] = ACTIONS(620),
    [sym_function_name] = ACTIONS(620),
    [sym_duration_part] = ACTIONS(638),
  },
  [371] = {
    [sym_expression] = STATE(1567),
    [sym_statement] = STATE(1384),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(576),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1780),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(532),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [372] = {
    [sym_statement] = STATE(1821),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(563),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1780),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_RPAREN] = ACTIONS(642),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(532),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [373] = {
    [sym_statement] = STATE(1817),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(547),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1780),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_RPAREN] = ACTIONS(644),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(532),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [374] = {
    [sym_expression] = STATE(1797),
    [sym_statement] = STATE(1384),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(576),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1780),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(646),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [375] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(50),
    [ts_builtin_sym_end] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_parallel] = ACTIONS(180),
    [sym_keyword_timeout] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [376] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(36),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_permissions] = ACTIONS(212),
    [sym_keyword_comment] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [377] = {
    [sym_statement] = STATE(1382),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(125),
    [sym_function_call] = STATE(455),
    [sym_base_value] = STATE(157),
    [sym_binary_expression] = STATE(455),
    [sym_path] = STATE(455),
    [sym_graph_path] = STATE(155),
    [sym_number] = STATE(300),
    [sym_identifier] = STATE(300),
    [sym_array] = STATE(300),
    [sym_object] = STATE(300),
    [sym_object_key] = STATE(1754),
    [sym_record_id] = STATE(300),
    [sym_sub_query] = STATE(300),
    [sym_duration] = STATE(300),
    [sym_point] = STATE(300),
    [aux_sym_duration_repeat1] = STATE(220),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(620),
    [sym_keyword_true] = ACTIONS(622),
    [sym_keyword_false] = ACTIONS(622),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(622),
    [sym_keyword_null] = ACTIONS(622),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(624),
    [anon_sym_DASH_GT] = ACTIONS(416),
    [anon_sym_LBRACK] = ACTIONS(626),
    [anon_sym_LPAREN] = ACTIONS(628),
    [anon_sym_LBRACE] = ACTIONS(363),
    [anon_sym_LT_DASH] = ACTIONS(420),
    [anon_sym_LT_DASH_GT] = ACTIONS(416),
    [aux_sym_type_name_token1] = ACTIONS(630),
    [sym_string] = ACTIONS(632),
    [sym_prefixed_string] = ACTIONS(632),
    [sym_int] = ACTIONS(634),
    [sym_float] = ACTIONS(634),
    [sym_decimal] = ACTIONS(636),
    [sym_variable_name] = ACTIONS(632),
    [sym_custom_function_name] = ACTIONS(620),
    [sym_function_name] = ACTIONS(620),
    [sym_duration_part] = ACTIONS(638),
  },
  [378] = {
    [sym_operator] = STATE(659),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_explain] = ACTIONS(648),
    [sym_keyword_parallel] = ACTIONS(648),
    [sym_keyword_timeout] = ACTIONS(648),
    [sym_keyword_fetch] = ACTIONS(648),
    [sym_keyword_limit] = ACTIONS(648),
    [sym_keyword_order] = ACTIONS(648),
    [sym_keyword_with] = ACTIONS(648),
    [sym_keyword_where] = ACTIONS(648),
    [sym_keyword_split] = ACTIONS(648),
    [sym_keyword_group] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(650),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [anon_sym_COMMA] = ACTIONS(648),
    [anon_sym_RPAREN] = ACTIONS(648),
    [anon_sym_RBRACE] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [379] = {
    [sym_statement] = STATE(1305),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(127),
    [sym_function_call] = STATE(455),
    [sym_base_value] = STATE(157),
    [sym_binary_expression] = STATE(455),
    [sym_path] = STATE(455),
    [sym_graph_path] = STATE(155),
    [sym_number] = STATE(300),
    [sym_identifier] = STATE(300),
    [sym_array] = STATE(300),
    [sym_object] = STATE(300),
    [sym_object_key] = STATE(1754),
    [sym_record_id] = STATE(300),
    [sym_sub_query] = STATE(300),
    [sym_duration] = STATE(300),
    [sym_point] = STATE(300),
    [aux_sym_duration_repeat1] = STATE(220),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(620),
    [sym_keyword_true] = ACTIONS(622),
    [sym_keyword_false] = ACTIONS(622),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(622),
    [sym_keyword_null] = ACTIONS(622),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(624),
    [anon_sym_DASH_GT] = ACTIONS(416),
    [anon_sym_LBRACK] = ACTIONS(626),
    [anon_sym_LPAREN] = ACTIONS(628),
    [anon_sym_LBRACE] = ACTIONS(363),
    [anon_sym_LT_DASH] = ACTIONS(420),
    [anon_sym_LT_DASH_GT] = ACTIONS(416),
    [aux_sym_type_name_token1] = ACTIONS(630),
    [sym_string] = ACTIONS(632),
    [sym_prefixed_string] = ACTIONS(632),
    [sym_int] = ACTIONS(634),
    [sym_float] = ACTIONS(634),
    [sym_decimal] = ACTIONS(636),
    [sym_variable_name] = ACTIONS(632),
    [sym_custom_function_name] = ACTIONS(620),
    [sym_function_name] = ACTIONS(620),
    [sym_duration_part] = ACTIONS(638),
  },
  [380] = {
    [sym_operator] = STATE(690),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(652),
    [sym_keyword_explain] = ACTIONS(652),
    [sym_keyword_parallel] = ACTIONS(652),
    [sym_keyword_timeout] = ACTIONS(652),
    [sym_keyword_fetch] = ACTIONS(652),
    [sym_keyword_limit] = ACTIONS(652),
    [sym_keyword_rand] = ACTIONS(654),
    [sym_keyword_collate] = ACTIONS(654),
    [sym_keyword_numeric] = ACTIONS(654),
    [sym_keyword_asc] = ACTIONS(656),
    [sym_keyword_desc] = ACTIONS(656),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(652),
    [anon_sym_RPAREN] = ACTIONS(652),
    [anon_sym_RBRACE] = ACTIONS(652),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [381] = {
    [sym_statement] = STATE(1382),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(131),
    [sym_function_call] = STATE(478),
    [sym_base_value] = STATE(185),
    [sym_binary_expression] = STATE(478),
    [sym_path] = STATE(478),
    [sym_graph_path] = STATE(175),
    [sym_number] = STATE(332),
    [sym_identifier] = STATE(332),
    [sym_array] = STATE(332),
    [sym_object] = STATE(332),
    [sym_object_key] = STATE(1761),
    [sym_record_id] = STATE(332),
    [sym_sub_query] = STATE(332),
    [sym_duration] = STATE(332),
    [sym_point] = STATE(332),
    [aux_sym_duration_repeat1] = STATE(240),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(5),
    [sym_keyword_rand] = ACTIONS(584),
    [sym_keyword_true] = ACTIONS(586),
    [sym_keyword_false] = ACTIONS(586),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(586),
    [sym_keyword_null] = ACTIONS(586),
    [sym_keyword_define] = ACTIONS(19),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(23),
    [sym_keyword_delete] = ACTIONS(25),
    [sym_keyword_update] = ACTIONS(27),
    [sym_keyword_insert] = ACTIONS(29),
    [sym_keyword_relate] = ACTIONS(31),
    [sym_keyword_count] = ACTIONS(588),
    [anon_sym_DASH_GT] = ACTIONS(448),
    [anon_sym_LBRACK] = ACTIONS(590),
    [anon_sym_LPAREN] = ACTIONS(592),
    [anon_sym_LBRACE] = ACTIONS(442),
    [anon_sym_LT_DASH] = ACTIONS(452),
    [anon_sym_LT_DASH_GT] = ACTIONS(448),
    [aux_sym_type_name_token1] = ACTIONS(594),
    [sym_string] = ACTIONS(596),
    [sym_prefixed_string] = ACTIONS(596),
    [sym_int] = ACTIONS(598),
    [sym_float] = ACTIONS(598),
    [sym_decimal] = ACTIONS(600),
    [sym_variable_name] = ACTIONS(596),
    [sym_custom_function_name] = ACTIONS(584),
    [sym_function_name] = ACTIONS(584),
    [sym_duration_part] = ACTIONS(602),
  },
  [382] = {
    [sym_operator] = STATE(702),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(658),
    [sym_keyword_as] = ACTIONS(658),
    [sym_keyword_where] = ACTIONS(658),
    [sym_keyword_group] = ACTIONS(658),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_drop] = ACTIONS(658),
    [sym_keyword_schemafull] = ACTIONS(658),
    [sym_keyword_schemaless] = ACTIONS(658),
    [sym_keyword_changefeed] = ACTIONS(658),
    [sym_keyword_type] = ACTIONS(658),
    [sym_keyword_permissions] = ACTIONS(658),
    [sym_keyword_comment] = ACTIONS(658),
    [anon_sym_COMMA] = ACTIONS(658),
    [anon_sym_RPAREN] = ACTIONS(658),
    [anon_sym_RBRACE] = ACTIONS(658),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [383] = {
    [sym_statement] = STATE(1300),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(419),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1772),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(532),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [384] = {
    [ts_builtin_sym_end] = ACTIONS(182),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_value] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_flexible] = ACTIONS(182),
    [sym_keyword_readonly] = ACTIONS(182),
    [sym_keyword_type] = ACTIONS(182),
    [sym_keyword_default] = ACTIONS(182),
    [sym_keyword_assert] = ACTIONS(182),
    [sym_keyword_permissions] = ACTIONS(182),
    [sym_keyword_comment] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(660),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [385] = {
    [sym_statement] = STATE(1312),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(164),
    [sym_function_call] = STATE(99),
    [sym_base_value] = STATE(168),
    [sym_binary_expression] = STATE(99),
    [sym_path] = STATE(99),
    [sym_graph_path] = STATE(162),
    [sym_number] = STATE(58),
    [sym_identifier] = STATE(58),
    [sym_array] = STATE(58),
    [sym_object] = STATE(58),
    [sym_object_key] = STATE(1789),
    [sym_record_id] = STATE(58),
    [sym_sub_query] = STATE(58),
    [sym_duration] = STATE(58),
    [sym_point] = STATE(58),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(5),
    [sym_keyword_rand] = ACTIONS(7),
    [sym_keyword_true] = ACTIONS(11),
    [sym_keyword_false] = ACTIONS(11),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(11),
    [sym_keyword_null] = ACTIONS(11),
    [sym_keyword_define] = ACTIONS(19),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(23),
    [sym_keyword_delete] = ACTIONS(25),
    [sym_keyword_update] = ACTIONS(27),
    [sym_keyword_insert] = ACTIONS(29),
    [sym_keyword_relate] = ACTIONS(31),
    [sym_keyword_count] = ACTIONS(33),
    [anon_sym_DASH_GT] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(43),
    [anon_sym_LT_DASH_GT] = ACTIONS(35),
    [aux_sym_type_name_token1] = ACTIONS(45),
    [sym_string] = ACTIONS(47),
    [sym_prefixed_string] = ACTIONS(47),
    [sym_int] = ACTIONS(49),
    [sym_float] = ACTIONS(49),
    [sym_decimal] = ACTIONS(51),
    [sym_variable_name] = ACTIONS(47),
    [sym_custom_function_name] = ACTIONS(7),
    [sym_function_name] = ACTIONS(7),
    [sym_duration_part] = ACTIONS(53),
  },
  [386] = {
    [sym_operator] = STATE(659),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(658),
    [sym_keyword_explain] = ACTIONS(658),
    [sym_keyword_parallel] = ACTIONS(658),
    [sym_keyword_timeout] = ACTIONS(658),
    [sym_keyword_fetch] = ACTIONS(658),
    [sym_keyword_limit] = ACTIONS(658),
    [sym_keyword_order] = ACTIONS(658),
    [sym_keyword_with] = ACTIONS(658),
    [sym_keyword_where] = ACTIONS(658),
    [sym_keyword_split] = ACTIONS(658),
    [sym_keyword_group] = ACTIONS(658),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(313),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(658),
    [anon_sym_RPAREN] = ACTIONS(658),
    [anon_sym_RBRACE] = ACTIONS(658),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [387] = {
    [sym_statement] = STATE(1300),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(433),
    [sym_function_call] = STATE(99),
    [sym_base_value] = STATE(168),
    [sym_binary_expression] = STATE(99),
    [sym_path] = STATE(99),
    [sym_graph_path] = STATE(162),
    [sym_number] = STATE(58),
    [sym_identifier] = STATE(58),
    [sym_array] = STATE(58),
    [sym_object] = STATE(58),
    [sym_object_key] = STATE(1796),
    [sym_record_id] = STATE(58),
    [sym_sub_query] = STATE(58),
    [sym_duration] = STATE(58),
    [sym_point] = STATE(58),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(5),
    [sym_keyword_rand] = ACTIONS(7),
    [sym_keyword_true] = ACTIONS(11),
    [sym_keyword_false] = ACTIONS(11),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(11),
    [sym_keyword_null] = ACTIONS(11),
    [sym_keyword_define] = ACTIONS(19),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(23),
    [sym_keyword_delete] = ACTIONS(25),
    [sym_keyword_update] = ACTIONS(27),
    [sym_keyword_insert] = ACTIONS(29),
    [sym_keyword_relate] = ACTIONS(31),
    [sym_keyword_count] = ACTIONS(33),
    [anon_sym_DASH_GT] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(43),
    [anon_sym_LT_DASH_GT] = ACTIONS(35),
    [aux_sym_type_name_token1] = ACTIONS(45),
    [sym_string] = ACTIONS(47),
    [sym_prefixed_string] = ACTIONS(47),
    [sym_int] = ACTIONS(49),
    [sym_float] = ACTIONS(49),
    [sym_decimal] = ACTIONS(51),
    [sym_variable_name] = ACTIONS(47),
    [sym_custom_function_name] = ACTIONS(7),
    [sym_function_name] = ACTIONS(7),
    [sym_duration_part] = ACTIONS(53),
  },
  [388] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(45),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_permissions] = ACTIONS(369),
    [sym_keyword_comment] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_RPAREN] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [389] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(33),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [sym_keyword_permissions] = ACTIONS(180),
    [sym_keyword_comment] = ACTIONS(180),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [390] = {
    [ts_builtin_sym_end] = ACTIONS(182),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_explain] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_fetch] = ACTIONS(182),
    [sym_keyword_limit] = ACTIONS(182),
    [sym_keyword_order] = ACTIONS(182),
    [sym_keyword_split] = ACTIONS(182),
    [sym_keyword_group] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(184),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(662),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [391] = {
    [sym_statement] = STATE(1312),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(137),
    [sym_function_call] = STATE(86),
    [sym_base_value] = STATE(3),
    [sym_binary_expression] = STATE(86),
    [sym_path] = STATE(86),
    [sym_graph_path] = STATE(4),
    [sym_number] = STATE(25),
    [sym_identifier] = STATE(25),
    [sym_array] = STATE(25),
    [sym_object] = STATE(25),
    [sym_object_key] = STATE(1762),
    [sym_record_id] = STATE(25),
    [sym_sub_query] = STATE(25),
    [sym_duration] = STATE(25),
    [sym_point] = STATE(25),
    [aux_sym_duration_repeat1] = STATE(8),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(500),
    [sym_keyword_rand] = ACTIONS(502),
    [sym_keyword_true] = ACTIONS(504),
    [sym_keyword_false] = ACTIONS(504),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(504),
    [sym_keyword_null] = ACTIONS(504),
    [sym_keyword_define] = ACTIONS(506),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(508),
    [sym_keyword_delete] = ACTIONS(510),
    [sym_keyword_update] = ACTIONS(512),
    [sym_keyword_insert] = ACTIONS(514),
    [sym_keyword_relate] = ACTIONS(516),
    [sym_keyword_count] = ACTIONS(518),
    [anon_sym_DASH_GT] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH_GT] = ACTIONS(63),
    [aux_sym_type_name_token1] = ACTIONS(526),
    [sym_string] = ACTIONS(528),
    [sym_prefixed_string] = ACTIONS(528),
    [sym_int] = ACTIONS(530),
    [sym_float] = ACTIONS(530),
    [sym_decimal] = ACTIONS(532),
    [sym_variable_name] = ACTIONS(528),
    [sym_custom_function_name] = ACTIONS(502),
    [sym_function_name] = ACTIONS(502),
    [sym_duration_part] = ACTIONS(534),
  },
  [392] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(48),
    [ts_builtin_sym_end] = ACTIONS(367),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [393] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(49),
    [ts_builtin_sym_end] = ACTIONS(210),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [394] = {
    [sym_statement] = STATE(1305),
    [sym_begin_statement] = STATE(1380),
    [sym_cancel_statement] = STATE(1380),
    [sym_commit_statement] = STATE(1380),
    [sym_define_analyzer_statement] = STATE(1380),
    [sym_define_event_statement] = STATE(1380),
    [sym_define_field_statement] = STATE(1380),
    [sym_define_function_statement] = STATE(1380),
    [sym_define_index_statement] = STATE(1380),
    [sym_define_namespace_statement] = STATE(1380),
    [sym_define_param_statement] = STATE(1380),
    [sym_define_scope_statement] = STATE(1380),
    [sym_define_table_statement] = STATE(1380),
    [sym_define_token_statement] = STATE(1380),
    [sym_define_user_statement] = STATE(1380),
    [sym_remove_statement] = STATE(1380),
    [sym_create_statement] = STATE(1380),
    [sym_update_statement] = STATE(1380),
    [sym_relate_statement] = STATE(1380),
    [sym_delete_statement] = STATE(1380),
    [sym_insert_statement] = STATE(1380),
    [sym_select_statement] = STATE(1380),
    [sym_value] = STATE(130),
    [sym_function_call] = STATE(478),
    [sym_base_value] = STATE(185),
    [sym_binary_expression] = STATE(478),
    [sym_path] = STATE(478),
    [sym_graph_path] = STATE(175),
    [sym_number] = STATE(332),
    [sym_identifier] = STATE(332),
    [sym_array] = STATE(332),
    [sym_object] = STATE(332),
    [sym_object_key] = STATE(1761),
    [sym_record_id] = STATE(332),
    [sym_sub_query] = STATE(332),
    [sym_duration] = STATE(332),
    [sym_point] = STATE(332),
    [aux_sym_duration_repeat1] = STATE(240),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_select] = ACTIONS(5),
    [sym_keyword_rand] = ACTIONS(584),
    [sym_keyword_true] = ACTIONS(586),
    [sym_keyword_false] = ACTIONS(586),
    [sym_keyword_begin] = ACTIONS(13),
    [sym_keyword_cancel] = ACTIONS(15),
    [sym_keyword_commit] = ACTIONS(17),
    [sym_keyword_none] = ACTIONS(586),
    [sym_keyword_null] = ACTIONS(586),
    [sym_keyword_define] = ACTIONS(19),
    [sym_keyword_remove] = ACTIONS(21),
    [sym_keyword_create] = ACTIONS(23),
    [sym_keyword_delete] = ACTIONS(25),
    [sym_keyword_update] = ACTIONS(27),
    [sym_keyword_insert] = ACTIONS(29),
    [sym_keyword_relate] = ACTIONS(31),
    [sym_keyword_count] = ACTIONS(588),
    [anon_sym_DASH_GT] = ACTIONS(448),
    [anon_sym_LBRACK] = ACTIONS(590),
    [anon_sym_LPAREN] = ACTIONS(592),
    [anon_sym_LBRACE] = ACTIONS(442),
    [anon_sym_LT_DASH] = ACTIONS(452),
    [anon_sym_LT_DASH_GT] = ACTIONS(448),
    [aux_sym_type_name_token1] = ACTIONS(594),
    [sym_string] = ACTIONS(596),
    [sym_prefixed_string] = ACTIONS(596),
    [sym_int] = ACTIONS(598),
    [sym_float] = ACTIONS(598),
    [sym_decimal] = ACTIONS(600),
    [sym_variable_name] = ACTIONS(596),
    [sym_custom_function_name] = ACTIONS(584),
    [sym_function_name] = ACTIONS(584),
    [sym_duration_part] = ACTIONS(602),
  },
  [395] = {
    [sym_operator] = STATE(702),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_as] = ACTIONS(648),
    [sym_keyword_where] = ACTIONS(648),
    [sym_keyword_group] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(648),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [sym_keyword_drop] = ACTIONS(648),
    [sym_keyword_schemafull] = ACTIONS(648),
    [sym_keyword_schemaless] = ACTIONS(648),
    [sym_keyword_changefeed] = ACTIONS(648),
    [sym_keyword_type] = ACTIONS(648),
    [sym_keyword_permissions] = ACTIONS(648),
    [sym_keyword_comment] = ACTIONS(648),
    [anon_sym_COMMA] = ACTIONS(648),
    [anon_sym_RPAREN] = ACTIONS(648),
    [anon_sym_RBRACE] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [396] = {
    [sym_operator] = STATE(690),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_explain] = ACTIONS(648),
    [sym_keyword_parallel] = ACTIONS(648),
    [sym_keyword_timeout] = ACTIONS(648),
    [sym_keyword_fetch] = ACTIONS(648),
    [sym_keyword_limit] = ACTIONS(648),
    [sym_keyword_rand] = ACTIONS(648),
    [sym_keyword_collate] = ACTIONS(648),
    [sym_keyword_numeric] = ACTIONS(648),
    [sym_keyword_asc] = ACTIONS(648),
    [sym_keyword_desc] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(648),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [anon_sym_COMMA] = ACTIONS(648),
    [anon_sym_RPAREN] = ACTIONS(648),
    [anon_sym_RBRACE] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [397] = {
    [sym_operator] = STATE(742),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(899),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(664),
    [sym_keyword_explain] = ACTIONS(664),
    [sym_keyword_parallel] = ACTIONS(664),
    [sym_keyword_timeout] = ACTIONS(664),
    [sym_keyword_fetch] = ACTIONS(664),
    [sym_keyword_limit] = ACTIONS(664),
    [sym_keyword_order] = ACTIONS(664),
    [sym_keyword_where] = ACTIONS(664),
    [sym_keyword_split] = ACTIONS(664),
    [sym_keyword_group] = ACTIONS(664),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(313),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(666),
    [anon_sym_RPAREN] = ACTIONS(664),
    [anon_sym_RBRACE] = ACTIONS(664),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [398] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(49),
    [ts_builtin_sym_end] = ACTIONS(210),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_permissions] = ACTIONS(212),
    [sym_keyword_comment] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [399] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(48),
    [ts_builtin_sym_end] = ACTIONS(367),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_permissions] = ACTIONS(369),
    [sym_keyword_comment] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [400] = {
    [sym_operator] = STATE(673),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(658),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(658),
    [sym_keyword_explain] = ACTIONS(658),
    [sym_keyword_parallel] = ACTIONS(658),
    [sym_keyword_timeout] = ACTIONS(658),
    [sym_keyword_fetch] = ACTIONS(658),
    [sym_keyword_limit] = ACTIONS(658),
    [sym_keyword_order] = ACTIONS(658),
    [sym_keyword_with] = ACTIONS(658),
    [sym_keyword_where] = ACTIONS(658),
    [sym_keyword_split] = ACTIONS(658),
    [sym_keyword_group] = ACTIONS(658),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(313),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(658),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [401] = {
    [sym_operator] = STATE(721),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(648),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_explain] = ACTIONS(648),
    [sym_keyword_parallel] = ACTIONS(648),
    [sym_keyword_timeout] = ACTIONS(648),
    [sym_keyword_fetch] = ACTIONS(648),
    [sym_keyword_limit] = ACTIONS(648),
    [sym_keyword_rand] = ACTIONS(648),
    [sym_keyword_collate] = ACTIONS(648),
    [sym_keyword_numeric] = ACTIONS(648),
    [sym_keyword_asc] = ACTIONS(648),
    [sym_keyword_desc] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(648),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [anon_sym_COMMA] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [402] = {
    [sym_operator] = STATE(742),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_explain] = ACTIONS(648),
    [sym_keyword_parallel] = ACTIONS(648),
    [sym_keyword_timeout] = ACTIONS(648),
    [sym_keyword_fetch] = ACTIONS(648),
    [sym_keyword_limit] = ACTIONS(648),
    [sym_keyword_order] = ACTIONS(648),
    [sym_keyword_where] = ACTIONS(648),
    [sym_keyword_split] = ACTIONS(648),
    [sym_keyword_group] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(650),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [anon_sym_COMMA] = ACTIONS(648),
    [anon_sym_RPAREN] = ACTIONS(648),
    [anon_sym_RBRACE] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [403] = {
    [sym_operator] = STATE(731),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(658),
    [sym_keyword_return] = ACTIONS(658),
    [sym_keyword_parallel] = ACTIONS(658),
    [sym_keyword_timeout] = ACTIONS(658),
    [sym_keyword_where] = ACTIONS(658),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_content] = ACTIONS(658),
    [sym_keyword_merge] = ACTIONS(658),
    [sym_keyword_patch] = ACTIONS(658),
    [sym_keyword_set] = ACTIONS(658),
    [sym_keyword_unset] = ACTIONS(658),
    [anon_sym_COMMA] = ACTIONS(658),
    [anon_sym_RPAREN] = ACTIONS(658),
    [anon_sym_RBRACE] = ACTIONS(658),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [404] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(36),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_as] = ACTIONS(212),
    [sym_keyword_where] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [405] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(33),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_as] = ACTIONS(180),
    [sym_keyword_where] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [406] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(50),
    [ts_builtin_sym_end] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [sym_keyword_permissions] = ACTIONS(180),
    [sym_keyword_comment] = ACTIONS(180),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [407] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(45),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_as] = ACTIONS(369),
    [sym_keyword_where] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_RPAREN] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [408] = {
    [sym_operator] = STATE(731),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_return] = ACTIONS(648),
    [sym_keyword_parallel] = ACTIONS(648),
    [sym_keyword_timeout] = ACTIONS(648),
    [sym_keyword_where] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(648),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [sym_keyword_content] = ACTIONS(648),
    [sym_keyword_merge] = ACTIONS(648),
    [sym_keyword_patch] = ACTIONS(648),
    [sym_keyword_set] = ACTIONS(648),
    [sym_keyword_unset] = ACTIONS(648),
    [anon_sym_COMMA] = ACTIONS(648),
    [anon_sym_RPAREN] = ACTIONS(648),
    [anon_sym_RBRACE] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [409] = {
    [sym_operator] = STATE(745),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(916),
    [ts_builtin_sym_end] = ACTIONS(664),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(664),
    [sym_keyword_explain] = ACTIONS(664),
    [sym_keyword_parallel] = ACTIONS(664),
    [sym_keyword_timeout] = ACTIONS(664),
    [sym_keyword_fetch] = ACTIONS(664),
    [sym_keyword_limit] = ACTIONS(664),
    [sym_keyword_order] = ACTIONS(664),
    [sym_keyword_where] = ACTIONS(664),
    [sym_keyword_split] = ACTIONS(664),
    [sym_keyword_group] = ACTIONS(664),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(313),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(668),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [410] = {
    [sym_operator] = STATE(672),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(658),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(658),
    [sym_keyword_as] = ACTIONS(658),
    [sym_keyword_where] = ACTIONS(658),
    [sym_keyword_group] = ACTIONS(658),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_drop] = ACTIONS(658),
    [sym_keyword_schemafull] = ACTIONS(658),
    [sym_keyword_schemaless] = ACTIONS(658),
    [sym_keyword_changefeed] = ACTIONS(658),
    [sym_keyword_type] = ACTIONS(658),
    [sym_keyword_permissions] = ACTIONS(658),
    [sym_keyword_comment] = ACTIONS(658),
    [anon_sym_COMMA] = ACTIONS(658),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [411] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(45),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_permissions] = ACTIONS(369),
    [sym_keyword_comment] = ACTIONS(369),
    [sym_keyword_if] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(373),
    [sym_custom_function_name] = ACTIONS(369),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [412] = {
    [sym_operator] = STATE(721),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(652),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(652),
    [sym_keyword_explain] = ACTIONS(652),
    [sym_keyword_parallel] = ACTIONS(652),
    [sym_keyword_timeout] = ACTIONS(652),
    [sym_keyword_fetch] = ACTIONS(652),
    [sym_keyword_limit] = ACTIONS(652),
    [sym_keyword_rand] = ACTIONS(654),
    [sym_keyword_collate] = ACTIONS(654),
    [sym_keyword_numeric] = ACTIONS(654),
    [sym_keyword_asc] = ACTIONS(656),
    [sym_keyword_desc] = ACTIONS(656),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(652),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [413] = {
    [sym_operator] = STATE(742),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(658),
    [sym_keyword_explain] = ACTIONS(658),
    [sym_keyword_parallel] = ACTIONS(658),
    [sym_keyword_timeout] = ACTIONS(658),
    [sym_keyword_fetch] = ACTIONS(658),
    [sym_keyword_limit] = ACTIONS(658),
    [sym_keyword_order] = ACTIONS(658),
    [sym_keyword_where] = ACTIONS(658),
    [sym_keyword_split] = ACTIONS(658),
    [sym_keyword_group] = ACTIONS(658),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(313),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(658),
    [anon_sym_RPAREN] = ACTIONS(658),
    [anon_sym_RBRACE] = ACTIONS(658),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [414] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(36),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_permissions] = ACTIONS(212),
    [sym_keyword_comment] = ACTIONS(212),
    [sym_keyword_if] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(373),
    [sym_custom_function_name] = ACTIONS(212),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [415] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(33),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [sym_keyword_permissions] = ACTIONS(180),
    [sym_keyword_comment] = ACTIONS(180),
    [sym_keyword_if] = ACTIONS(180),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(373),
    [sym_custom_function_name] = ACTIONS(180),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [416] = {
    [sym_operator] = STATE(673),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(648),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_explain] = ACTIONS(648),
    [sym_keyword_parallel] = ACTIONS(648),
    [sym_keyword_timeout] = ACTIONS(648),
    [sym_keyword_fetch] = ACTIONS(648),
    [sym_keyword_limit] = ACTIONS(648),
    [sym_keyword_order] = ACTIONS(648),
    [sym_keyword_with] = ACTIONS(648),
    [sym_keyword_where] = ACTIONS(648),
    [sym_keyword_split] = ACTIONS(648),
    [sym_keyword_group] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(650),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [anon_sym_COMMA] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [417] = {
    [sym_where_clause] = STATE(1076),
    [sym_timeout_clause] = STATE(1223),
    [sym_parallel_clause] = STATE(1300),
    [sym_return_clause] = STATE(1139),
    [sym_operator] = STATE(711),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(947),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(670),
    [sym_keyword_return] = ACTIONS(343),
    [sym_keyword_parallel] = ACTIONS(293),
    [sym_keyword_timeout] = ACTIONS(295),
    [sym_keyword_where] = ACTIONS(345),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(672),
    [anon_sym_RPAREN] = ACTIONS(670),
    [anon_sym_RBRACE] = ACTIONS(670),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [418] = {
    [sym_operator] = STATE(672),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(648),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_as] = ACTIONS(648),
    [sym_keyword_where] = ACTIONS(648),
    [sym_keyword_group] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(648),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [sym_keyword_drop] = ACTIONS(648),
    [sym_keyword_schemafull] = ACTIONS(648),
    [sym_keyword_schemaless] = ACTIONS(648),
    [sym_keyword_changefeed] = ACTIONS(648),
    [sym_keyword_type] = ACTIONS(648),
    [sym_keyword_permissions] = ACTIONS(648),
    [sym_keyword_comment] = ACTIONS(648),
    [anon_sym_COMMA] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [419] = {
    [sym_where_clause] = STATE(1087),
    [sym_timeout_clause] = STATE(1207),
    [sym_parallel_clause] = STATE(1409),
    [sym_return_clause] = STATE(1109),
    [sym_operator] = STATE(711),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(928),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(674),
    [sym_keyword_return] = ACTIONS(343),
    [sym_keyword_parallel] = ACTIONS(293),
    [sym_keyword_timeout] = ACTIONS(295),
    [sym_keyword_where] = ACTIONS(345),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(672),
    [anon_sym_RPAREN] = ACTIONS(674),
    [anon_sym_RBRACE] = ACTIONS(674),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [420] = {
    [ts_builtin_sym_end] = ACTIONS(59),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(59),
    [sym_keyword_as] = ACTIONS(59),
    [sym_keyword_where] = ACTIONS(59),
    [sym_keyword_group] = ACTIONS(59),
    [sym_keyword_and] = ACTIONS(59),
    [sym_keyword_or] = ACTIONS(59),
    [sym_keyword_is] = ACTIONS(59),
    [sym_keyword_not] = ACTIONS(61),
    [sym_keyword_contains] = ACTIONS(59),
    [sym_keyword_contains_not] = ACTIONS(59),
    [sym_keyword_contains_all] = ACTIONS(59),
    [sym_keyword_contains_any] = ACTIONS(59),
    [sym_keyword_contains_none] = ACTIONS(59),
    [sym_keyword_inside] = ACTIONS(59),
    [sym_keyword_in] = ACTIONS(61),
    [sym_keyword_not_inside] = ACTIONS(59),
    [sym_keyword_all_inside] = ACTIONS(59),
    [sym_keyword_any_inside] = ACTIONS(59),
    [sym_keyword_none_inside] = ACTIONS(59),
    [sym_keyword_outside] = ACTIONS(59),
    [sym_keyword_intersects] = ACTIONS(59),
    [sym_keyword_drop] = ACTIONS(59),
    [sym_keyword_schemafull] = ACTIONS(59),
    [sym_keyword_schemaless] = ACTIONS(59),
    [sym_keyword_changefeed] = ACTIONS(59),
    [sym_keyword_type] = ACTIONS(59),
    [sym_keyword_permissions] = ACTIONS(59),
    [sym_keyword_for] = ACTIONS(59),
    [sym_keyword_comment] = ACTIONS(59),
    [anon_sym_COMMA] = ACTIONS(59),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(61),
    [anon_sym_LT_PIPE] = ACTIONS(59),
    [anon_sym_AMP_AMP] = ACTIONS(59),
    [anon_sym_PIPE_PIPE] = ACTIONS(59),
    [anon_sym_QMARK_QMARK] = ACTIONS(59),
    [anon_sym_QMARK_COLON] = ACTIONS(59),
    [anon_sym_BANG_EQ] = ACTIONS(59),
    [anon_sym_EQ_EQ] = ACTIONS(59),
    [anon_sym_QMARK_EQ] = ACTIONS(59),
    [anon_sym_STAR_EQ] = ACTIONS(59),
    [anon_sym_TILDE] = ACTIONS(59),
    [anon_sym_BANG_TILDE] = ACTIONS(59),
    [anon_sym_STAR_TILDE] = ACTIONS(59),
    [anon_sym_LT_EQ] = ACTIONS(59),
    [anon_sym_GT_EQ] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_PLUS_EQ] = ACTIONS(59),
    [anon_sym_DASH_EQ] = ACTIONS(59),
    [anon_sym_u00d7] = ACTIONS(59),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_u00f7] = ACTIONS(59),
    [anon_sym_STAR_STAR] = ACTIONS(59),
    [anon_sym_u220b] = ACTIONS(59),
    [anon_sym_u220c] = ACTIONS(59),
    [anon_sym_u2287] = ACTIONS(59),
    [anon_sym_u2283] = ACTIONS(59),
    [anon_sym_u2285] = ACTIONS(59),
    [anon_sym_u2208] = ACTIONS(59),
    [anon_sym_u2209] = ACTIONS(59),
    [anon_sym_u2286] = ACTIONS(59),
    [anon_sym_u2282] = ACTIONS(59),
    [anon_sym_u2284] = ACTIONS(59),
    [anon_sym_AT_AT] = ACTIONS(59),
  },
  [421] = {
    [sym_where_clause] = STATE(1155),
    [sym_timeout_clause] = STATE(1223),
    [sym_parallel_clause] = STATE(1300),
    [sym_return_clause] = STATE(1139),
    [sym_operator] = STATE(669),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(967),
    [ts_builtin_sym_end] = ACTIONS(670),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(670),
    [sym_keyword_return] = ACTIONS(424),
    [sym_keyword_parallel] = ACTIONS(293),
    [sym_keyword_timeout] = ACTIONS(295),
    [sym_keyword_where] = ACTIONS(426),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(676),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [422] = {
    [sym_operator] = STATE(653),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(678),
    [sym_keyword_as] = ACTIONS(678),
    [sym_keyword_group] = ACTIONS(678),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_drop] = ACTIONS(678),
    [sym_keyword_schemafull] = ACTIONS(678),
    [sym_keyword_schemaless] = ACTIONS(678),
    [sym_keyword_changefeed] = ACTIONS(678),
    [sym_keyword_type] = ACTIONS(678),
    [sym_keyword_permissions] = ACTIONS(678),
    [sym_keyword_comment] = ACTIONS(678),
    [anon_sym_RPAREN] = ACTIONS(678),
    [anon_sym_RBRACE] = ACTIONS(678),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [423] = {
    [ts_builtin_sym_end] = ACTIONS(138),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(138),
    [sym_keyword_as] = ACTIONS(138),
    [sym_keyword_where] = ACTIONS(138),
    [sym_keyword_group] = ACTIONS(138),
    [sym_keyword_and] = ACTIONS(138),
    [sym_keyword_or] = ACTIONS(138),
    [sym_keyword_is] = ACTIONS(138),
    [sym_keyword_not] = ACTIONS(140),
    [sym_keyword_contains] = ACTIONS(138),
    [sym_keyword_contains_not] = ACTIONS(138),
    [sym_keyword_contains_all] = ACTIONS(138),
    [sym_keyword_contains_any] = ACTIONS(138),
    [sym_keyword_contains_none] = ACTIONS(138),
    [sym_keyword_inside] = ACTIONS(138),
    [sym_keyword_in] = ACTIONS(140),
    [sym_keyword_not_inside] = ACTIONS(138),
    [sym_keyword_all_inside] = ACTIONS(138),
    [sym_keyword_any_inside] = ACTIONS(138),
    [sym_keyword_none_inside] = ACTIONS(138),
    [sym_keyword_outside] = ACTIONS(138),
    [sym_keyword_intersects] = ACTIONS(138),
    [sym_keyword_drop] = ACTIONS(138),
    [sym_keyword_schemafull] = ACTIONS(138),
    [sym_keyword_schemaless] = ACTIONS(138),
    [sym_keyword_changefeed] = ACTIONS(138),
    [sym_keyword_type] = ACTIONS(138),
    [sym_keyword_permissions] = ACTIONS(138),
    [sym_keyword_for] = ACTIONS(138),
    [sym_keyword_comment] = ACTIONS(138),
    [anon_sym_COMMA] = ACTIONS(138),
    [anon_sym_STAR] = ACTIONS(140),
    [anon_sym_LT] = ACTIONS(140),
    [anon_sym_GT] = ACTIONS(140),
    [anon_sym_EQ] = ACTIONS(140),
    [anon_sym_DASH] = ACTIONS(140),
    [anon_sym_AT] = ACTIONS(140),
    [anon_sym_LT_PIPE] = ACTIONS(138),
    [anon_sym_AMP_AMP] = ACTIONS(138),
    [anon_sym_PIPE_PIPE] = ACTIONS(138),
    [anon_sym_QMARK_QMARK] = ACTIONS(138),
    [anon_sym_QMARK_COLON] = ACTIONS(138),
    [anon_sym_BANG_EQ] = ACTIONS(138),
    [anon_sym_EQ_EQ] = ACTIONS(138),
    [anon_sym_QMARK_EQ] = ACTIONS(138),
    [anon_sym_STAR_EQ] = ACTIONS(138),
    [anon_sym_TILDE] = ACTIONS(138),
    [anon_sym_BANG_TILDE] = ACTIONS(138),
    [anon_sym_STAR_TILDE] = ACTIONS(138),
    [anon_sym_LT_EQ] = ACTIONS(138),
    [anon_sym_GT_EQ] = ACTIONS(138),
    [anon_sym_PLUS] = ACTIONS(140),
    [anon_sym_PLUS_EQ] = ACTIONS(138),
    [anon_sym_DASH_EQ] = ACTIONS(138),
    [anon_sym_u00d7] = ACTIONS(138),
    [anon_sym_SLASH] = ACTIONS(140),
    [anon_sym_u00f7] = ACTIONS(138),
    [anon_sym_STAR_STAR] = ACTIONS(138),
    [anon_sym_u220b] = ACTIONS(138),
    [anon_sym_u220c] = ACTIONS(138),
    [anon_sym_u2287] = ACTIONS(138),
    [anon_sym_u2283] = ACTIONS(138),
    [anon_sym_u2285] = ACTIONS(138),
    [anon_sym_u2208] = ACTIONS(138),
    [anon_sym_u2209] = ACTIONS(138),
    [anon_sym_u2286] = ACTIONS(138),
    [anon_sym_u2282] = ACTIONS(138),
    [anon_sym_u2284] = ACTIONS(138),
    [anon_sym_AT_AT] = ACTIONS(138),
  },
  [424] = {
    [sym_operator] = STATE(704),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(678),
    [sym_keyword_as] = ACTIONS(678),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_drop] = ACTIONS(678),
    [sym_keyword_schemafull] = ACTIONS(678),
    [sym_keyword_schemaless] = ACTIONS(678),
    [sym_keyword_changefeed] = ACTIONS(678),
    [sym_keyword_type] = ACTIONS(678),
    [sym_keyword_permissions] = ACTIONS(678),
    [sym_keyword_for] = ACTIONS(678),
    [sym_keyword_comment] = ACTIONS(678),
    [anon_sym_RPAREN] = ACTIONS(678),
    [anon_sym_RBRACE] = ACTIONS(678),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [425] = {
    [ts_builtin_sym_end] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(251),
    [sym_keyword_as] = ACTIONS(251),
    [sym_keyword_where] = ACTIONS(251),
    [sym_keyword_group] = ACTIONS(251),
    [sym_keyword_and] = ACTIONS(251),
    [sym_keyword_or] = ACTIONS(251),
    [sym_keyword_is] = ACTIONS(251),
    [sym_keyword_not] = ACTIONS(253),
    [sym_keyword_contains] = ACTIONS(251),
    [sym_keyword_contains_not] = ACTIONS(251),
    [sym_keyword_contains_all] = ACTIONS(251),
    [sym_keyword_contains_any] = ACTIONS(251),
    [sym_keyword_contains_none] = ACTIONS(251),
    [sym_keyword_inside] = ACTIONS(251),
    [sym_keyword_in] = ACTIONS(253),
    [sym_keyword_not_inside] = ACTIONS(251),
    [sym_keyword_all_inside] = ACTIONS(251),
    [sym_keyword_any_inside] = ACTIONS(251),
    [sym_keyword_none_inside] = ACTIONS(251),
    [sym_keyword_outside] = ACTIONS(251),
    [sym_keyword_intersects] = ACTIONS(251),
    [sym_keyword_drop] = ACTIONS(251),
    [sym_keyword_schemafull] = ACTIONS(251),
    [sym_keyword_schemaless] = ACTIONS(251),
    [sym_keyword_changefeed] = ACTIONS(251),
    [sym_keyword_type] = ACTIONS(251),
    [sym_keyword_permissions] = ACTIONS(251),
    [sym_keyword_for] = ACTIONS(251),
    [sym_keyword_comment] = ACTIONS(251),
    [anon_sym_COMMA] = ACTIONS(251),
    [anon_sym_STAR] = ACTIONS(253),
    [anon_sym_LT] = ACTIONS(253),
    [anon_sym_GT] = ACTIONS(253),
    [anon_sym_EQ] = ACTIONS(253),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_AT] = ACTIONS(253),
    [anon_sym_LT_PIPE] = ACTIONS(251),
    [anon_sym_AMP_AMP] = ACTIONS(251),
    [anon_sym_PIPE_PIPE] = ACTIONS(251),
    [anon_sym_QMARK_QMARK] = ACTIONS(251),
    [anon_sym_QMARK_COLON] = ACTIONS(251),
    [anon_sym_BANG_EQ] = ACTIONS(251),
    [anon_sym_EQ_EQ] = ACTIONS(251),
    [anon_sym_QMARK_EQ] = ACTIONS(251),
    [anon_sym_STAR_EQ] = ACTIONS(251),
    [anon_sym_TILDE] = ACTIONS(251),
    [anon_sym_BANG_TILDE] = ACTIONS(251),
    [anon_sym_STAR_TILDE] = ACTIONS(251),
    [anon_sym_LT_EQ] = ACTIONS(251),
    [anon_sym_GT_EQ] = ACTIONS(251),
    [anon_sym_PLUS] = ACTIONS(253),
    [anon_sym_PLUS_EQ] = ACTIONS(251),
    [anon_sym_DASH_EQ] = ACTIONS(251),
    [anon_sym_u00d7] = ACTIONS(251),
    [anon_sym_SLASH] = ACTIONS(253),
    [anon_sym_u00f7] = ACTIONS(251),
    [anon_sym_STAR_STAR] = ACTIONS(251),
    [anon_sym_u220b] = ACTIONS(251),
    [anon_sym_u220c] = ACTIONS(251),
    [anon_sym_u2287] = ACTIONS(251),
    [anon_sym_u2283] = ACTIONS(251),
    [anon_sym_u2285] = ACTIONS(251),
    [anon_sym_u2208] = ACTIONS(251),
    [anon_sym_u2209] = ACTIONS(251),
    [anon_sym_u2286] = ACTIONS(251),
    [anon_sym_u2282] = ACTIONS(251),
    [anon_sym_u2284] = ACTIONS(251),
    [anon_sym_AT_AT] = ACTIONS(251),
  },
  [426] = {
    [ts_builtin_sym_end] = ACTIONS(198),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(198),
    [sym_keyword_as] = ACTIONS(198),
    [sym_keyword_where] = ACTIONS(198),
    [sym_keyword_group] = ACTIONS(198),
    [sym_keyword_and] = ACTIONS(198),
    [sym_keyword_or] = ACTIONS(198),
    [sym_keyword_is] = ACTIONS(198),
    [sym_keyword_not] = ACTIONS(200),
    [sym_keyword_contains] = ACTIONS(198),
    [sym_keyword_contains_not] = ACTIONS(198),
    [sym_keyword_contains_all] = ACTIONS(198),
    [sym_keyword_contains_any] = ACTIONS(198),
    [sym_keyword_contains_none] = ACTIONS(198),
    [sym_keyword_inside] = ACTIONS(198),
    [sym_keyword_in] = ACTIONS(200),
    [sym_keyword_not_inside] = ACTIONS(198),
    [sym_keyword_all_inside] = ACTIONS(198),
    [sym_keyword_any_inside] = ACTIONS(198),
    [sym_keyword_none_inside] = ACTIONS(198),
    [sym_keyword_outside] = ACTIONS(198),
    [sym_keyword_intersects] = ACTIONS(198),
    [sym_keyword_drop] = ACTIONS(198),
    [sym_keyword_schemafull] = ACTIONS(198),
    [sym_keyword_schemaless] = ACTIONS(198),
    [sym_keyword_changefeed] = ACTIONS(198),
    [sym_keyword_type] = ACTIONS(198),
    [sym_keyword_permissions] = ACTIONS(198),
    [sym_keyword_for] = ACTIONS(198),
    [sym_keyword_comment] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(198),
    [anon_sym_STAR] = ACTIONS(200),
    [anon_sym_LT] = ACTIONS(200),
    [anon_sym_GT] = ACTIONS(200),
    [anon_sym_EQ] = ACTIONS(200),
    [anon_sym_DASH] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(200),
    [anon_sym_LT_PIPE] = ACTIONS(198),
    [anon_sym_AMP_AMP] = ACTIONS(198),
    [anon_sym_PIPE_PIPE] = ACTIONS(198),
    [anon_sym_QMARK_QMARK] = ACTIONS(198),
    [anon_sym_QMARK_COLON] = ACTIONS(198),
    [anon_sym_BANG_EQ] = ACTIONS(198),
    [anon_sym_EQ_EQ] = ACTIONS(198),
    [anon_sym_QMARK_EQ] = ACTIONS(198),
    [anon_sym_STAR_EQ] = ACTIONS(198),
    [anon_sym_TILDE] = ACTIONS(198),
    [anon_sym_BANG_TILDE] = ACTIONS(198),
    [anon_sym_STAR_TILDE] = ACTIONS(198),
    [anon_sym_LT_EQ] = ACTIONS(198),
    [anon_sym_GT_EQ] = ACTIONS(198),
    [anon_sym_PLUS] = ACTIONS(200),
    [anon_sym_PLUS_EQ] = ACTIONS(198),
    [anon_sym_DASH_EQ] = ACTIONS(198),
    [anon_sym_u00d7] = ACTIONS(198),
    [anon_sym_SLASH] = ACTIONS(200),
    [anon_sym_u00f7] = ACTIONS(198),
    [anon_sym_STAR_STAR] = ACTIONS(198),
    [anon_sym_u220b] = ACTIONS(198),
    [anon_sym_u220c] = ACTIONS(198),
    [anon_sym_u2287] = ACTIONS(198),
    [anon_sym_u2283] = ACTIONS(198),
    [anon_sym_u2285] = ACTIONS(198),
    [anon_sym_u2208] = ACTIONS(198),
    [anon_sym_u2209] = ACTIONS(198),
    [anon_sym_u2286] = ACTIONS(198),
    [anon_sym_u2282] = ACTIONS(198),
    [anon_sym_u2284] = ACTIONS(198),
    [anon_sym_AT_AT] = ACTIONS(198),
  },
  [427] = {
    [sym_operator] = STATE(738),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_value] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(648),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [sym_keyword_flexible] = ACTIONS(648),
    [sym_keyword_readonly] = ACTIONS(648),
    [sym_keyword_type] = ACTIONS(648),
    [sym_keyword_default] = ACTIONS(648),
    [sym_keyword_assert] = ACTIONS(648),
    [sym_keyword_permissions] = ACTIONS(648),
    [sym_keyword_for] = ACTIONS(648),
    [sym_keyword_comment] = ACTIONS(648),
    [anon_sym_RPAREN] = ACTIONS(648),
    [anon_sym_RBRACE] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [428] = {
    [ts_builtin_sym_end] = ACTIONS(150),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(150),
    [sym_keyword_as] = ACTIONS(150),
    [sym_keyword_where] = ACTIONS(150),
    [sym_keyword_group] = ACTIONS(150),
    [sym_keyword_and] = ACTIONS(150),
    [sym_keyword_or] = ACTIONS(150),
    [sym_keyword_is] = ACTIONS(150),
    [sym_keyword_not] = ACTIONS(152),
    [sym_keyword_contains] = ACTIONS(150),
    [sym_keyword_contains_not] = ACTIONS(150),
    [sym_keyword_contains_all] = ACTIONS(150),
    [sym_keyword_contains_any] = ACTIONS(150),
    [sym_keyword_contains_none] = ACTIONS(150),
    [sym_keyword_inside] = ACTIONS(150),
    [sym_keyword_in] = ACTIONS(152),
    [sym_keyword_not_inside] = ACTIONS(150),
    [sym_keyword_all_inside] = ACTIONS(150),
    [sym_keyword_any_inside] = ACTIONS(150),
    [sym_keyword_none_inside] = ACTIONS(150),
    [sym_keyword_outside] = ACTIONS(150),
    [sym_keyword_intersects] = ACTIONS(150),
    [sym_keyword_drop] = ACTIONS(150),
    [sym_keyword_schemafull] = ACTIONS(150),
    [sym_keyword_schemaless] = ACTIONS(150),
    [sym_keyword_changefeed] = ACTIONS(150),
    [sym_keyword_type] = ACTIONS(150),
    [sym_keyword_permissions] = ACTIONS(150),
    [sym_keyword_for] = ACTIONS(150),
    [sym_keyword_comment] = ACTIONS(150),
    [anon_sym_COMMA] = ACTIONS(150),
    [anon_sym_STAR] = ACTIONS(152),
    [anon_sym_LT] = ACTIONS(152),
    [anon_sym_GT] = ACTIONS(152),
    [anon_sym_EQ] = ACTIONS(152),
    [anon_sym_DASH] = ACTIONS(152),
    [anon_sym_AT] = ACTIONS(152),
    [anon_sym_LT_PIPE] = ACTIONS(150),
    [anon_sym_AMP_AMP] = ACTIONS(150),
    [anon_sym_PIPE_PIPE] = ACTIONS(150),
    [anon_sym_QMARK_QMARK] = ACTIONS(150),
    [anon_sym_QMARK_COLON] = ACTIONS(150),
    [anon_sym_BANG_EQ] = ACTIONS(150),
    [anon_sym_EQ_EQ] = ACTIONS(150),
    [anon_sym_QMARK_EQ] = ACTIONS(150),
    [anon_sym_STAR_EQ] = ACTIONS(150),
    [anon_sym_TILDE] = ACTIONS(150),
    [anon_sym_BANG_TILDE] = ACTIONS(150),
    [anon_sym_STAR_TILDE] = ACTIONS(150),
    [anon_sym_LT_EQ] = ACTIONS(150),
    [anon_sym_GT_EQ] = ACTIONS(150),
    [anon_sym_PLUS] = ACTIONS(152),
    [anon_sym_PLUS_EQ] = ACTIONS(150),
    [anon_sym_DASH_EQ] = ACTIONS(150),
    [anon_sym_u00d7] = ACTIONS(150),
    [anon_sym_SLASH] = ACTIONS(152),
    [anon_sym_u00f7] = ACTIONS(150),
    [anon_sym_STAR_STAR] = ACTIONS(150),
    [anon_sym_u220b] = ACTIONS(150),
    [anon_sym_u220c] = ACTIONS(150),
    [anon_sym_u2287] = ACTIONS(150),
    [anon_sym_u2283] = ACTIONS(150),
    [anon_sym_u2285] = ACTIONS(150),
    [anon_sym_u2208] = ACTIONS(150),
    [anon_sym_u2209] = ACTIONS(150),
    [anon_sym_u2286] = ACTIONS(150),
    [anon_sym_u2282] = ACTIONS(150),
    [anon_sym_u2284] = ACTIONS(150),
    [anon_sym_AT_AT] = ACTIONS(150),
  },
  [429] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_return] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_where] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(680),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [430] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(48),
    [ts_builtin_sym_end] = ACTIONS(367),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(367),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [431] = {
    [ts_builtin_sym_end] = ACTIONS(255),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(255),
    [sym_keyword_as] = ACTIONS(255),
    [sym_keyword_where] = ACTIONS(255),
    [sym_keyword_group] = ACTIONS(255),
    [sym_keyword_and] = ACTIONS(255),
    [sym_keyword_or] = ACTIONS(255),
    [sym_keyword_is] = ACTIONS(255),
    [sym_keyword_not] = ACTIONS(257),
    [sym_keyword_contains] = ACTIONS(255),
    [sym_keyword_contains_not] = ACTIONS(255),
    [sym_keyword_contains_all] = ACTIONS(255),
    [sym_keyword_contains_any] = ACTIONS(255),
    [sym_keyword_contains_none] = ACTIONS(255),
    [sym_keyword_inside] = ACTIONS(255),
    [sym_keyword_in] = ACTIONS(257),
    [sym_keyword_not_inside] = ACTIONS(255),
    [sym_keyword_all_inside] = ACTIONS(255),
    [sym_keyword_any_inside] = ACTIONS(255),
    [sym_keyword_none_inside] = ACTIONS(255),
    [sym_keyword_outside] = ACTIONS(255),
    [sym_keyword_intersects] = ACTIONS(255),
    [sym_keyword_drop] = ACTIONS(255),
    [sym_keyword_schemafull] = ACTIONS(255),
    [sym_keyword_schemaless] = ACTIONS(255),
    [sym_keyword_changefeed] = ACTIONS(255),
    [sym_keyword_type] = ACTIONS(255),
    [sym_keyword_permissions] = ACTIONS(255),
    [sym_keyword_for] = ACTIONS(255),
    [sym_keyword_comment] = ACTIONS(255),
    [anon_sym_COMMA] = ACTIONS(255),
    [anon_sym_STAR] = ACTIONS(257),
    [anon_sym_LT] = ACTIONS(257),
    [anon_sym_GT] = ACTIONS(257),
    [anon_sym_EQ] = ACTIONS(257),
    [anon_sym_DASH] = ACTIONS(257),
    [anon_sym_AT] = ACTIONS(257),
    [anon_sym_LT_PIPE] = ACTIONS(255),
    [anon_sym_AMP_AMP] = ACTIONS(255),
    [anon_sym_PIPE_PIPE] = ACTIONS(255),
    [anon_sym_QMARK_QMARK] = ACTIONS(255),
    [anon_sym_QMARK_COLON] = ACTIONS(255),
    [anon_sym_BANG_EQ] = ACTIONS(255),
    [anon_sym_EQ_EQ] = ACTIONS(255),
    [anon_sym_QMARK_EQ] = ACTIONS(255),
    [anon_sym_STAR_EQ] = ACTIONS(255),
    [anon_sym_TILDE] = ACTIONS(255),
    [anon_sym_BANG_TILDE] = ACTIONS(255),
    [anon_sym_STAR_TILDE] = ACTIONS(255),
    [anon_sym_LT_EQ] = ACTIONS(255),
    [anon_sym_GT_EQ] = ACTIONS(255),
    [anon_sym_PLUS] = ACTIONS(257),
    [anon_sym_PLUS_EQ] = ACTIONS(255),
    [anon_sym_DASH_EQ] = ACTIONS(255),
    [anon_sym_u00d7] = ACTIONS(255),
    [anon_sym_SLASH] = ACTIONS(257),
    [anon_sym_u00f7] = ACTIONS(255),
    [anon_sym_STAR_STAR] = ACTIONS(255),
    [anon_sym_u220b] = ACTIONS(255),
    [anon_sym_u220c] = ACTIONS(255),
    [anon_sym_u2287] = ACTIONS(255),
    [anon_sym_u2283] = ACTIONS(255),
    [anon_sym_u2285] = ACTIONS(255),
    [anon_sym_u2208] = ACTIONS(255),
    [anon_sym_u2209] = ACTIONS(255),
    [anon_sym_u2286] = ACTIONS(255),
    [anon_sym_u2282] = ACTIONS(255),
    [anon_sym_u2284] = ACTIONS(255),
    [anon_sym_AT_AT] = ACTIONS(255),
  },
  [432] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(198),
    [sym_keyword_explain] = ACTIONS(198),
    [sym_keyword_parallel] = ACTIONS(198),
    [sym_keyword_timeout] = ACTIONS(198),
    [sym_keyword_fetch] = ACTIONS(198),
    [sym_keyword_limit] = ACTIONS(198),
    [sym_keyword_order] = ACTIONS(198),
    [sym_keyword_with] = ACTIONS(198),
    [sym_keyword_where] = ACTIONS(198),
    [sym_keyword_split] = ACTIONS(198),
    [sym_keyword_group] = ACTIONS(198),
    [sym_keyword_and] = ACTIONS(198),
    [sym_keyword_or] = ACTIONS(200),
    [sym_keyword_is] = ACTIONS(198),
    [sym_keyword_not] = ACTIONS(200),
    [sym_keyword_contains] = ACTIONS(198),
    [sym_keyword_contains_not] = ACTIONS(198),
    [sym_keyword_contains_all] = ACTIONS(198),
    [sym_keyword_contains_any] = ACTIONS(198),
    [sym_keyword_contains_none] = ACTIONS(198),
    [sym_keyword_inside] = ACTIONS(198),
    [sym_keyword_in] = ACTIONS(200),
    [sym_keyword_not_inside] = ACTIONS(198),
    [sym_keyword_all_inside] = ACTIONS(198),
    [sym_keyword_any_inside] = ACTIONS(198),
    [sym_keyword_none_inside] = ACTIONS(198),
    [sym_keyword_outside] = ACTIONS(198),
    [sym_keyword_intersects] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(198),
    [anon_sym_RPAREN] = ACTIONS(198),
    [anon_sym_RBRACE] = ACTIONS(198),
    [anon_sym_STAR] = ACTIONS(200),
    [anon_sym_LT] = ACTIONS(200),
    [anon_sym_GT] = ACTIONS(200),
    [anon_sym_EQ] = ACTIONS(200),
    [anon_sym_DASH] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(200),
    [anon_sym_LT_PIPE] = ACTIONS(198),
    [anon_sym_AMP_AMP] = ACTIONS(198),
    [anon_sym_PIPE_PIPE] = ACTIONS(198),
    [anon_sym_QMARK_QMARK] = ACTIONS(198),
    [anon_sym_QMARK_COLON] = ACTIONS(198),
    [anon_sym_BANG_EQ] = ACTIONS(198),
    [anon_sym_EQ_EQ] = ACTIONS(198),
    [anon_sym_QMARK_EQ] = ACTIONS(198),
    [anon_sym_STAR_EQ] = ACTIONS(198),
    [anon_sym_TILDE] = ACTIONS(198),
    [anon_sym_BANG_TILDE] = ACTIONS(198),
    [anon_sym_STAR_TILDE] = ACTIONS(198),
    [anon_sym_LT_EQ] = ACTIONS(198),
    [anon_sym_GT_EQ] = ACTIONS(198),
    [anon_sym_PLUS] = ACTIONS(200),
    [anon_sym_PLUS_EQ] = ACTIONS(198),
    [anon_sym_DASH_EQ] = ACTIONS(198),
    [anon_sym_u00d7] = ACTIONS(198),
    [anon_sym_SLASH] = ACTIONS(200),
    [anon_sym_u00f7] = ACTIONS(198),
    [anon_sym_STAR_STAR] = ACTIONS(198),
    [anon_sym_u220b] = ACTIONS(198),
    [anon_sym_u220c] = ACTIONS(198),
    [anon_sym_u2287] = ACTIONS(198),
    [anon_sym_u2283] = ACTIONS(198),
    [anon_sym_u2285] = ACTIONS(198),
    [anon_sym_u2208] = ACTIONS(198),
    [anon_sym_u2209] = ACTIONS(198),
    [anon_sym_u2286] = ACTIONS(198),
    [anon_sym_u2282] = ACTIONS(198),
    [anon_sym_u2284] = ACTIONS(198),
    [anon_sym_AT_AT] = ACTIONS(198),
  },
  [433] = {
    [sym_where_clause] = STATE(1134),
    [sym_timeout_clause] = STATE(1207),
    [sym_parallel_clause] = STATE(1409),
    [sym_return_clause] = STATE(1109),
    [sym_operator] = STATE(669),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(964),
    [ts_builtin_sym_end] = ACTIONS(674),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(674),
    [sym_keyword_return] = ACTIONS(424),
    [sym_keyword_parallel] = ACTIONS(293),
    [sym_keyword_timeout] = ACTIONS(295),
    [sym_keyword_where] = ACTIONS(426),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(676),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [434] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(45),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_from] = ACTIONS(369),
    [sym_keyword_as] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [435] = {
    [sym_operator] = STATE(752),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(658),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(658),
    [sym_keyword_return] = ACTIONS(658),
    [sym_keyword_parallel] = ACTIONS(658),
    [sym_keyword_timeout] = ACTIONS(658),
    [sym_keyword_where] = ACTIONS(658),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_content] = ACTIONS(658),
    [sym_keyword_merge] = ACTIONS(658),
    [sym_keyword_patch] = ACTIONS(658),
    [sym_keyword_set] = ACTIONS(658),
    [sym_keyword_unset] = ACTIONS(658),
    [anon_sym_COMMA] = ACTIONS(658),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [436] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(50),
    [ts_builtin_sym_end] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(178),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [437] = {
    [sym_operator] = STATE(653),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_as] = ACTIONS(648),
    [sym_keyword_group] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(648),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [sym_keyword_drop] = ACTIONS(648),
    [sym_keyword_schemafull] = ACTIONS(648),
    [sym_keyword_schemaless] = ACTIONS(648),
    [sym_keyword_changefeed] = ACTIONS(648),
    [sym_keyword_type] = ACTIONS(648),
    [sym_keyword_permissions] = ACTIONS(648),
    [sym_keyword_comment] = ACTIONS(648),
    [anon_sym_RPAREN] = ACTIONS(648),
    [anon_sym_RBRACE] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [438] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(36),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_from] = ACTIONS(212),
    [sym_keyword_as] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [439] = {
    [sym_operator] = STATE(704),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_as] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(648),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [sym_keyword_drop] = ACTIONS(648),
    [sym_keyword_schemafull] = ACTIONS(648),
    [sym_keyword_schemaless] = ACTIONS(648),
    [sym_keyword_changefeed] = ACTIONS(648),
    [sym_keyword_type] = ACTIONS(648),
    [sym_keyword_permissions] = ACTIONS(648),
    [sym_keyword_for] = ACTIONS(648),
    [sym_keyword_comment] = ACTIONS(648),
    [anon_sym_RPAREN] = ACTIONS(648),
    [anon_sym_RBRACE] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [440] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(33),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_from] = ACTIONS(180),
    [sym_keyword_as] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [441] = {
    [ts_builtin_sym_end] = ACTIONS(239),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(239),
    [sym_keyword_as] = ACTIONS(239),
    [sym_keyword_where] = ACTIONS(239),
    [sym_keyword_group] = ACTIONS(239),
    [sym_keyword_and] = ACTIONS(239),
    [sym_keyword_or] = ACTIONS(239),
    [sym_keyword_is] = ACTIONS(239),
    [sym_keyword_not] = ACTIONS(241),
    [sym_keyword_contains] = ACTIONS(239),
    [sym_keyword_contains_not] = ACTIONS(239),
    [sym_keyword_contains_all] = ACTIONS(239),
    [sym_keyword_contains_any] = ACTIONS(239),
    [sym_keyword_contains_none] = ACTIONS(239),
    [sym_keyword_inside] = ACTIONS(239),
    [sym_keyword_in] = ACTIONS(241),
    [sym_keyword_not_inside] = ACTIONS(239),
    [sym_keyword_all_inside] = ACTIONS(239),
    [sym_keyword_any_inside] = ACTIONS(239),
    [sym_keyword_none_inside] = ACTIONS(239),
    [sym_keyword_outside] = ACTIONS(239),
    [sym_keyword_intersects] = ACTIONS(239),
    [sym_keyword_drop] = ACTIONS(239),
    [sym_keyword_schemafull] = ACTIONS(239),
    [sym_keyword_schemaless] = ACTIONS(239),
    [sym_keyword_changefeed] = ACTIONS(239),
    [sym_keyword_type] = ACTIONS(239),
    [sym_keyword_permissions] = ACTIONS(239),
    [sym_keyword_for] = ACTIONS(239),
    [sym_keyword_comment] = ACTIONS(239),
    [anon_sym_COMMA] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(241),
    [anon_sym_LT] = ACTIONS(241),
    [anon_sym_GT] = ACTIONS(241),
    [anon_sym_EQ] = ACTIONS(241),
    [anon_sym_DASH] = ACTIONS(241),
    [anon_sym_AT] = ACTIONS(241),
    [anon_sym_LT_PIPE] = ACTIONS(239),
    [anon_sym_AMP_AMP] = ACTIONS(239),
    [anon_sym_PIPE_PIPE] = ACTIONS(239),
    [anon_sym_QMARK_QMARK] = ACTIONS(239),
    [anon_sym_QMARK_COLON] = ACTIONS(239),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(239),
    [anon_sym_QMARK_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_TILDE] = ACTIONS(239),
    [anon_sym_BANG_TILDE] = ACTIONS(239),
    [anon_sym_STAR_TILDE] = ACTIONS(239),
    [anon_sym_LT_EQ] = ACTIONS(239),
    [anon_sym_GT_EQ] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(241),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_u00d7] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(241),
    [anon_sym_u00f7] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_u220b] = ACTIONS(239),
    [anon_sym_u220c] = ACTIONS(239),
    [anon_sym_u2287] = ACTIONS(239),
    [anon_sym_u2283] = ACTIONS(239),
    [anon_sym_u2285] = ACTIONS(239),
    [anon_sym_u2208] = ACTIONS(239),
    [anon_sym_u2209] = ACTIONS(239),
    [anon_sym_u2286] = ACTIONS(239),
    [anon_sym_u2282] = ACTIONS(239),
    [anon_sym_u2284] = ACTIONS(239),
    [anon_sym_AT_AT] = ACTIONS(239),
  },
  [442] = {
    [sym_operator] = STATE(752),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(648),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_return] = ACTIONS(648),
    [sym_keyword_parallel] = ACTIONS(648),
    [sym_keyword_timeout] = ACTIONS(648),
    [sym_keyword_where] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(648),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [sym_keyword_content] = ACTIONS(648),
    [sym_keyword_merge] = ACTIONS(648),
    [sym_keyword_patch] = ACTIONS(648),
    [sym_keyword_set] = ACTIONS(648),
    [sym_keyword_unset] = ACTIONS(648),
    [anon_sym_COMMA] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [443] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(33),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_as] = ACTIONS(180),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [anon_sym_COMMA] = ACTIONS(178),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_RPAREN] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [444] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(36),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_as] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_RPAREN] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [445] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(45),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_as] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(367),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_RPAREN] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [446] = {
    [sym_operator] = STATE(745),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(658),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(658),
    [sym_keyword_explain] = ACTIONS(658),
    [sym_keyword_parallel] = ACTIONS(658),
    [sym_keyword_timeout] = ACTIONS(658),
    [sym_keyword_fetch] = ACTIONS(658),
    [sym_keyword_limit] = ACTIONS(658),
    [sym_keyword_order] = ACTIONS(658),
    [sym_keyword_where] = ACTIONS(658),
    [sym_keyword_split] = ACTIONS(658),
    [sym_keyword_group] = ACTIONS(658),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(313),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(658),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [447] = {
    [sym_operator] = STATE(745),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(648),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_explain] = ACTIONS(648),
    [sym_keyword_parallel] = ACTIONS(648),
    [sym_keyword_timeout] = ACTIONS(648),
    [sym_keyword_fetch] = ACTIONS(648),
    [sym_keyword_limit] = ACTIONS(648),
    [sym_keyword_order] = ACTIONS(648),
    [sym_keyword_where] = ACTIONS(648),
    [sym_keyword_split] = ACTIONS(648),
    [sym_keyword_group] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(650),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [anon_sym_COMMA] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [448] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(138),
    [sym_keyword_explain] = ACTIONS(138),
    [sym_keyword_parallel] = ACTIONS(138),
    [sym_keyword_timeout] = ACTIONS(138),
    [sym_keyword_fetch] = ACTIONS(138),
    [sym_keyword_limit] = ACTIONS(138),
    [sym_keyword_order] = ACTIONS(138),
    [sym_keyword_with] = ACTIONS(138),
    [sym_keyword_where] = ACTIONS(138),
    [sym_keyword_split] = ACTIONS(138),
    [sym_keyword_group] = ACTIONS(138),
    [sym_keyword_and] = ACTIONS(138),
    [sym_keyword_or] = ACTIONS(140),
    [sym_keyword_is] = ACTIONS(138),
    [sym_keyword_not] = ACTIONS(140),
    [sym_keyword_contains] = ACTIONS(138),
    [sym_keyword_contains_not] = ACTIONS(138),
    [sym_keyword_contains_all] = ACTIONS(138),
    [sym_keyword_contains_any] = ACTIONS(138),
    [sym_keyword_contains_none] = ACTIONS(138),
    [sym_keyword_inside] = ACTIONS(138),
    [sym_keyword_in] = ACTIONS(140),
    [sym_keyword_not_inside] = ACTIONS(138),
    [sym_keyword_all_inside] = ACTIONS(138),
    [sym_keyword_any_inside] = ACTIONS(138),
    [sym_keyword_none_inside] = ACTIONS(138),
    [sym_keyword_outside] = ACTIONS(138),
    [sym_keyword_intersects] = ACTIONS(138),
    [anon_sym_COMMA] = ACTIONS(138),
    [anon_sym_RPAREN] = ACTIONS(138),
    [anon_sym_RBRACE] = ACTIONS(138),
    [anon_sym_STAR] = ACTIONS(140),
    [anon_sym_LT] = ACTIONS(140),
    [anon_sym_GT] = ACTIONS(140),
    [anon_sym_EQ] = ACTIONS(140),
    [anon_sym_DASH] = ACTIONS(140),
    [anon_sym_AT] = ACTIONS(140),
    [anon_sym_LT_PIPE] = ACTIONS(138),
    [anon_sym_AMP_AMP] = ACTIONS(138),
    [anon_sym_PIPE_PIPE] = ACTIONS(138),
    [anon_sym_QMARK_QMARK] = ACTIONS(138),
    [anon_sym_QMARK_COLON] = ACTIONS(138),
    [anon_sym_BANG_EQ] = ACTIONS(138),
    [anon_sym_EQ_EQ] = ACTIONS(138),
    [anon_sym_QMARK_EQ] = ACTIONS(138),
    [anon_sym_STAR_EQ] = ACTIONS(138),
    [anon_sym_TILDE] = ACTIONS(138),
    [anon_sym_BANG_TILDE] = ACTIONS(138),
    [anon_sym_STAR_TILDE] = ACTIONS(138),
    [anon_sym_LT_EQ] = ACTIONS(138),
    [anon_sym_GT_EQ] = ACTIONS(138),
    [anon_sym_PLUS] = ACTIONS(140),
    [anon_sym_PLUS_EQ] = ACTIONS(138),
    [anon_sym_DASH_EQ] = ACTIONS(138),
    [anon_sym_u00d7] = ACTIONS(138),
    [anon_sym_SLASH] = ACTIONS(140),
    [anon_sym_u00f7] = ACTIONS(138),
    [anon_sym_STAR_STAR] = ACTIONS(138),
    [anon_sym_u220b] = ACTIONS(138),
    [anon_sym_u220c] = ACTIONS(138),
    [anon_sym_u2287] = ACTIONS(138),
    [anon_sym_u2283] = ACTIONS(138),
    [anon_sym_u2285] = ACTIONS(138),
    [anon_sym_u2208] = ACTIONS(138),
    [anon_sym_u2209] = ACTIONS(138),
    [anon_sym_u2286] = ACTIONS(138),
    [anon_sym_u2282] = ACTIONS(138),
    [anon_sym_u2284] = ACTIONS(138),
    [anon_sym_AT_AT] = ACTIONS(138),
  },
  [449] = {
    [ts_builtin_sym_end] = ACTIONS(259),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(259),
    [sym_keyword_as] = ACTIONS(259),
    [sym_keyword_where] = ACTIONS(259),
    [sym_keyword_group] = ACTIONS(259),
    [sym_keyword_and] = ACTIONS(259),
    [sym_keyword_or] = ACTIONS(259),
    [sym_keyword_is] = ACTIONS(259),
    [sym_keyword_not] = ACTIONS(261),
    [sym_keyword_contains] = ACTIONS(259),
    [sym_keyword_contains_not] = ACTIONS(259),
    [sym_keyword_contains_all] = ACTIONS(259),
    [sym_keyword_contains_any] = ACTIONS(259),
    [sym_keyword_contains_none] = ACTIONS(259),
    [sym_keyword_inside] = ACTIONS(259),
    [sym_keyword_in] = ACTIONS(261),
    [sym_keyword_not_inside] = ACTIONS(259),
    [sym_keyword_all_inside] = ACTIONS(259),
    [sym_keyword_any_inside] = ACTIONS(259),
    [sym_keyword_none_inside] = ACTIONS(259),
    [sym_keyword_outside] = ACTIONS(259),
    [sym_keyword_intersects] = ACTIONS(259),
    [sym_keyword_drop] = ACTIONS(259),
    [sym_keyword_schemafull] = ACTIONS(259),
    [sym_keyword_schemaless] = ACTIONS(259),
    [sym_keyword_changefeed] = ACTIONS(259),
    [sym_keyword_type] = ACTIONS(259),
    [sym_keyword_permissions] = ACTIONS(259),
    [sym_keyword_for] = ACTIONS(259),
    [sym_keyword_comment] = ACTIONS(259),
    [anon_sym_COMMA] = ACTIONS(259),
    [anon_sym_STAR] = ACTIONS(261),
    [anon_sym_LT] = ACTIONS(261),
    [anon_sym_GT] = ACTIONS(261),
    [anon_sym_EQ] = ACTIONS(261),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_AT] = ACTIONS(261),
    [anon_sym_LT_PIPE] = ACTIONS(259),
    [anon_sym_AMP_AMP] = ACTIONS(259),
    [anon_sym_PIPE_PIPE] = ACTIONS(259),
    [anon_sym_QMARK_QMARK] = ACTIONS(259),
    [anon_sym_QMARK_COLON] = ACTIONS(259),
    [anon_sym_BANG_EQ] = ACTIONS(259),
    [anon_sym_EQ_EQ] = ACTIONS(259),
    [anon_sym_QMARK_EQ] = ACTIONS(259),
    [anon_sym_STAR_EQ] = ACTIONS(259),
    [anon_sym_TILDE] = ACTIONS(259),
    [anon_sym_BANG_TILDE] = ACTIONS(259),
    [anon_sym_STAR_TILDE] = ACTIONS(259),
    [anon_sym_LT_EQ] = ACTIONS(259),
    [anon_sym_GT_EQ] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(261),
    [anon_sym_PLUS_EQ] = ACTIONS(259),
    [anon_sym_DASH_EQ] = ACTIONS(259),
    [anon_sym_u00d7] = ACTIONS(259),
    [anon_sym_SLASH] = ACTIONS(261),
    [anon_sym_u00f7] = ACTIONS(259),
    [anon_sym_STAR_STAR] = ACTIONS(259),
    [anon_sym_u220b] = ACTIONS(259),
    [anon_sym_u220c] = ACTIONS(259),
    [anon_sym_u2287] = ACTIONS(259),
    [anon_sym_u2283] = ACTIONS(259),
    [anon_sym_u2285] = ACTIONS(259),
    [anon_sym_u2208] = ACTIONS(259),
    [anon_sym_u2209] = ACTIONS(259),
    [anon_sym_u2286] = ACTIONS(259),
    [anon_sym_u2282] = ACTIONS(259),
    [anon_sym_u2284] = ACTIONS(259),
    [anon_sym_AT_AT] = ACTIONS(259),
  },
  [450] = {
    [ts_builtin_sym_end] = ACTIONS(275),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(275),
    [sym_keyword_as] = ACTIONS(275),
    [sym_keyword_where] = ACTIONS(275),
    [sym_keyword_group] = ACTIONS(275),
    [sym_keyword_and] = ACTIONS(275),
    [sym_keyword_or] = ACTIONS(275),
    [sym_keyword_is] = ACTIONS(275),
    [sym_keyword_not] = ACTIONS(277),
    [sym_keyword_contains] = ACTIONS(275),
    [sym_keyword_contains_not] = ACTIONS(275),
    [sym_keyword_contains_all] = ACTIONS(275),
    [sym_keyword_contains_any] = ACTIONS(275),
    [sym_keyword_contains_none] = ACTIONS(275),
    [sym_keyword_inside] = ACTIONS(275),
    [sym_keyword_in] = ACTIONS(277),
    [sym_keyword_not_inside] = ACTIONS(275),
    [sym_keyword_all_inside] = ACTIONS(275),
    [sym_keyword_any_inside] = ACTIONS(275),
    [sym_keyword_none_inside] = ACTIONS(275),
    [sym_keyword_outside] = ACTIONS(275),
    [sym_keyword_intersects] = ACTIONS(275),
    [sym_keyword_drop] = ACTIONS(275),
    [sym_keyword_schemafull] = ACTIONS(275),
    [sym_keyword_schemaless] = ACTIONS(275),
    [sym_keyword_changefeed] = ACTIONS(275),
    [sym_keyword_type] = ACTIONS(275),
    [sym_keyword_permissions] = ACTIONS(275),
    [sym_keyword_for] = ACTIONS(275),
    [sym_keyword_comment] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(275),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LT] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(277),
    [anon_sym_EQ] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_LT_PIPE] = ACTIONS(275),
    [anon_sym_AMP_AMP] = ACTIONS(275),
    [anon_sym_PIPE_PIPE] = ACTIONS(275),
    [anon_sym_QMARK_QMARK] = ACTIONS(275),
    [anon_sym_QMARK_COLON] = ACTIONS(275),
    [anon_sym_BANG_EQ] = ACTIONS(275),
    [anon_sym_EQ_EQ] = ACTIONS(275),
    [anon_sym_QMARK_EQ] = ACTIONS(275),
    [anon_sym_STAR_EQ] = ACTIONS(275),
    [anon_sym_TILDE] = ACTIONS(275),
    [anon_sym_BANG_TILDE] = ACTIONS(275),
    [anon_sym_STAR_TILDE] = ACTIONS(275),
    [anon_sym_LT_EQ] = ACTIONS(275),
    [anon_sym_GT_EQ] = ACTIONS(275),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_PLUS_EQ] = ACTIONS(275),
    [anon_sym_DASH_EQ] = ACTIONS(275),
    [anon_sym_u00d7] = ACTIONS(275),
    [anon_sym_SLASH] = ACTIONS(277),
    [anon_sym_u00f7] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(275),
    [anon_sym_u220b] = ACTIONS(275),
    [anon_sym_u220c] = ACTIONS(275),
    [anon_sym_u2287] = ACTIONS(275),
    [anon_sym_u2283] = ACTIONS(275),
    [anon_sym_u2285] = ACTIONS(275),
    [anon_sym_u2208] = ACTIONS(275),
    [anon_sym_u2209] = ACTIONS(275),
    [anon_sym_u2286] = ACTIONS(275),
    [anon_sym_u2282] = ACTIONS(275),
    [anon_sym_u2284] = ACTIONS(275),
    [anon_sym_AT_AT] = ACTIONS(275),
  },
  [451] = {
    [sym_operator] = STATE(738),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(678),
    [sym_keyword_value] = ACTIONS(678),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_flexible] = ACTIONS(678),
    [sym_keyword_readonly] = ACTIONS(678),
    [sym_keyword_type] = ACTIONS(678),
    [sym_keyword_default] = ACTIONS(678),
    [sym_keyword_assert] = ACTIONS(678),
    [sym_keyword_permissions] = ACTIONS(678),
    [sym_keyword_for] = ACTIONS(678),
    [sym_keyword_comment] = ACTIONS(678),
    [anon_sym_RPAREN] = ACTIONS(678),
    [anon_sym_RBRACE] = ACTIONS(678),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [452] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(259),
    [sym_keyword_explain] = ACTIONS(259),
    [sym_keyword_parallel] = ACTIONS(259),
    [sym_keyword_timeout] = ACTIONS(259),
    [sym_keyword_fetch] = ACTIONS(259),
    [sym_keyword_limit] = ACTIONS(259),
    [sym_keyword_order] = ACTIONS(259),
    [sym_keyword_with] = ACTIONS(259),
    [sym_keyword_where] = ACTIONS(259),
    [sym_keyword_split] = ACTIONS(259),
    [sym_keyword_group] = ACTIONS(259),
    [sym_keyword_and] = ACTIONS(259),
    [sym_keyword_or] = ACTIONS(261),
    [sym_keyword_is] = ACTIONS(259),
    [sym_keyword_not] = ACTIONS(261),
    [sym_keyword_contains] = ACTIONS(259),
    [sym_keyword_contains_not] = ACTIONS(259),
    [sym_keyword_contains_all] = ACTIONS(259),
    [sym_keyword_contains_any] = ACTIONS(259),
    [sym_keyword_contains_none] = ACTIONS(259),
    [sym_keyword_inside] = ACTIONS(259),
    [sym_keyword_in] = ACTIONS(261),
    [sym_keyword_not_inside] = ACTIONS(259),
    [sym_keyword_all_inside] = ACTIONS(259),
    [sym_keyword_any_inside] = ACTIONS(259),
    [sym_keyword_none_inside] = ACTIONS(259),
    [sym_keyword_outside] = ACTIONS(259),
    [sym_keyword_intersects] = ACTIONS(259),
    [anon_sym_COMMA] = ACTIONS(259),
    [anon_sym_RPAREN] = ACTIONS(259),
    [anon_sym_RBRACE] = ACTIONS(259),
    [anon_sym_STAR] = ACTIONS(261),
    [anon_sym_LT] = ACTIONS(261),
    [anon_sym_GT] = ACTIONS(261),
    [anon_sym_EQ] = ACTIONS(261),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_AT] = ACTIONS(261),
    [anon_sym_LT_PIPE] = ACTIONS(259),
    [anon_sym_AMP_AMP] = ACTIONS(259),
    [anon_sym_PIPE_PIPE] = ACTIONS(259),
    [anon_sym_QMARK_QMARK] = ACTIONS(259),
    [anon_sym_QMARK_COLON] = ACTIONS(259),
    [anon_sym_BANG_EQ] = ACTIONS(259),
    [anon_sym_EQ_EQ] = ACTIONS(259),
    [anon_sym_QMARK_EQ] = ACTIONS(259),
    [anon_sym_STAR_EQ] = ACTIONS(259),
    [anon_sym_TILDE] = ACTIONS(259),
    [anon_sym_BANG_TILDE] = ACTIONS(259),
    [anon_sym_STAR_TILDE] = ACTIONS(259),
    [anon_sym_LT_EQ] = ACTIONS(259),
    [anon_sym_GT_EQ] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(261),
    [anon_sym_PLUS_EQ] = ACTIONS(259),
    [anon_sym_DASH_EQ] = ACTIONS(259),
    [anon_sym_u00d7] = ACTIONS(259),
    [anon_sym_SLASH] = ACTIONS(261),
    [anon_sym_u00f7] = ACTIONS(259),
    [anon_sym_STAR_STAR] = ACTIONS(259),
    [anon_sym_u220b] = ACTIONS(259),
    [anon_sym_u220c] = ACTIONS(259),
    [anon_sym_u2287] = ACTIONS(259),
    [anon_sym_u2283] = ACTIONS(259),
    [anon_sym_u2285] = ACTIONS(259),
    [anon_sym_u2208] = ACTIONS(259),
    [anon_sym_u2209] = ACTIONS(259),
    [anon_sym_u2286] = ACTIONS(259),
    [anon_sym_u2282] = ACTIONS(259),
    [anon_sym_u2284] = ACTIONS(259),
    [anon_sym_AT_AT] = ACTIONS(259),
  },
  [453] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(239),
    [sym_keyword_explain] = ACTIONS(239),
    [sym_keyword_parallel] = ACTIONS(239),
    [sym_keyword_timeout] = ACTIONS(239),
    [sym_keyword_fetch] = ACTIONS(239),
    [sym_keyword_limit] = ACTIONS(239),
    [sym_keyword_order] = ACTIONS(239),
    [sym_keyword_with] = ACTIONS(239),
    [sym_keyword_where] = ACTIONS(239),
    [sym_keyword_split] = ACTIONS(239),
    [sym_keyword_group] = ACTIONS(239),
    [sym_keyword_and] = ACTIONS(239),
    [sym_keyword_or] = ACTIONS(241),
    [sym_keyword_is] = ACTIONS(239),
    [sym_keyword_not] = ACTIONS(241),
    [sym_keyword_contains] = ACTIONS(239),
    [sym_keyword_contains_not] = ACTIONS(239),
    [sym_keyword_contains_all] = ACTIONS(239),
    [sym_keyword_contains_any] = ACTIONS(239),
    [sym_keyword_contains_none] = ACTIONS(239),
    [sym_keyword_inside] = ACTIONS(239),
    [sym_keyword_in] = ACTIONS(241),
    [sym_keyword_not_inside] = ACTIONS(239),
    [sym_keyword_all_inside] = ACTIONS(239),
    [sym_keyword_any_inside] = ACTIONS(239),
    [sym_keyword_none_inside] = ACTIONS(239),
    [sym_keyword_outside] = ACTIONS(239),
    [sym_keyword_intersects] = ACTIONS(239),
    [anon_sym_COMMA] = ACTIONS(239),
    [anon_sym_RPAREN] = ACTIONS(239),
    [anon_sym_RBRACE] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(241),
    [anon_sym_LT] = ACTIONS(241),
    [anon_sym_GT] = ACTIONS(241),
    [anon_sym_EQ] = ACTIONS(241),
    [anon_sym_DASH] = ACTIONS(241),
    [anon_sym_AT] = ACTIONS(241),
    [anon_sym_LT_PIPE] = ACTIONS(239),
    [anon_sym_AMP_AMP] = ACTIONS(239),
    [anon_sym_PIPE_PIPE] = ACTIONS(239),
    [anon_sym_QMARK_QMARK] = ACTIONS(239),
    [anon_sym_QMARK_COLON] = ACTIONS(239),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(239),
    [anon_sym_QMARK_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_TILDE] = ACTIONS(239),
    [anon_sym_BANG_TILDE] = ACTIONS(239),
    [anon_sym_STAR_TILDE] = ACTIONS(239),
    [anon_sym_LT_EQ] = ACTIONS(239),
    [anon_sym_GT_EQ] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(241),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_u00d7] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(241),
    [anon_sym_u00f7] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_u220b] = ACTIONS(239),
    [anon_sym_u220c] = ACTIONS(239),
    [anon_sym_u2287] = ACTIONS(239),
    [anon_sym_u2283] = ACTIONS(239),
    [anon_sym_u2285] = ACTIONS(239),
    [anon_sym_u2208] = ACTIONS(239),
    [anon_sym_u2209] = ACTIONS(239),
    [anon_sym_u2286] = ACTIONS(239),
    [anon_sym_u2282] = ACTIONS(239),
    [anon_sym_u2284] = ACTIONS(239),
    [anon_sym_AT_AT] = ACTIONS(239),
  },
  [454] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(255),
    [sym_keyword_explain] = ACTIONS(255),
    [sym_keyword_parallel] = ACTIONS(255),
    [sym_keyword_timeout] = ACTIONS(255),
    [sym_keyword_fetch] = ACTIONS(255),
    [sym_keyword_limit] = ACTIONS(255),
    [sym_keyword_order] = ACTIONS(255),
    [sym_keyword_with] = ACTIONS(255),
    [sym_keyword_where] = ACTIONS(255),
    [sym_keyword_split] = ACTIONS(255),
    [sym_keyword_group] = ACTIONS(255),
    [sym_keyword_and] = ACTIONS(255),
    [sym_keyword_or] = ACTIONS(257),
    [sym_keyword_is] = ACTIONS(255),
    [sym_keyword_not] = ACTIONS(257),
    [sym_keyword_contains] = ACTIONS(255),
    [sym_keyword_contains_not] = ACTIONS(255),
    [sym_keyword_contains_all] = ACTIONS(255),
    [sym_keyword_contains_any] = ACTIONS(255),
    [sym_keyword_contains_none] = ACTIONS(255),
    [sym_keyword_inside] = ACTIONS(255),
    [sym_keyword_in] = ACTIONS(257),
    [sym_keyword_not_inside] = ACTIONS(255),
    [sym_keyword_all_inside] = ACTIONS(255),
    [sym_keyword_any_inside] = ACTIONS(255),
    [sym_keyword_none_inside] = ACTIONS(255),
    [sym_keyword_outside] = ACTIONS(255),
    [sym_keyword_intersects] = ACTIONS(255),
    [anon_sym_COMMA] = ACTIONS(255),
    [anon_sym_RPAREN] = ACTIONS(255),
    [anon_sym_RBRACE] = ACTIONS(255),
    [anon_sym_STAR] = ACTIONS(257),
    [anon_sym_LT] = ACTIONS(257),
    [anon_sym_GT] = ACTIONS(257),
    [anon_sym_EQ] = ACTIONS(257),
    [anon_sym_DASH] = ACTIONS(257),
    [anon_sym_AT] = ACTIONS(257),
    [anon_sym_LT_PIPE] = ACTIONS(255),
    [anon_sym_AMP_AMP] = ACTIONS(255),
    [anon_sym_PIPE_PIPE] = ACTIONS(255),
    [anon_sym_QMARK_QMARK] = ACTIONS(255),
    [anon_sym_QMARK_COLON] = ACTIONS(255),
    [anon_sym_BANG_EQ] = ACTIONS(255),
    [anon_sym_EQ_EQ] = ACTIONS(255),
    [anon_sym_QMARK_EQ] = ACTIONS(255),
    [anon_sym_STAR_EQ] = ACTIONS(255),
    [anon_sym_TILDE] = ACTIONS(255),
    [anon_sym_BANG_TILDE] = ACTIONS(255),
    [anon_sym_STAR_TILDE] = ACTIONS(255),
    [anon_sym_LT_EQ] = ACTIONS(255),
    [anon_sym_GT_EQ] = ACTIONS(255),
    [anon_sym_PLUS] = ACTIONS(257),
    [anon_sym_PLUS_EQ] = ACTIONS(255),
    [anon_sym_DASH_EQ] = ACTIONS(255),
    [anon_sym_u00d7] = ACTIONS(255),
    [anon_sym_SLASH] = ACTIONS(257),
    [anon_sym_u00f7] = ACTIONS(255),
    [anon_sym_STAR_STAR] = ACTIONS(255),
    [anon_sym_u220b] = ACTIONS(255),
    [anon_sym_u220c] = ACTIONS(255),
    [anon_sym_u2287] = ACTIONS(255),
    [anon_sym_u2283] = ACTIONS(255),
    [anon_sym_u2285] = ACTIONS(255),
    [anon_sym_u2208] = ACTIONS(255),
    [anon_sym_u2209] = ACTIONS(255),
    [anon_sym_u2286] = ACTIONS(255),
    [anon_sym_u2282] = ACTIONS(255),
    [anon_sym_u2284] = ACTIONS(255),
    [anon_sym_AT_AT] = ACTIONS(255),
  },
  [455] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(59),
    [sym_keyword_explain] = ACTIONS(59),
    [sym_keyword_parallel] = ACTIONS(59),
    [sym_keyword_timeout] = ACTIONS(59),
    [sym_keyword_fetch] = ACTIONS(59),
    [sym_keyword_limit] = ACTIONS(59),
    [sym_keyword_order] = ACTIONS(59),
    [sym_keyword_with] = ACTIONS(59),
    [sym_keyword_where] = ACTIONS(59),
    [sym_keyword_split] = ACTIONS(59),
    [sym_keyword_group] = ACTIONS(59),
    [sym_keyword_and] = ACTIONS(59),
    [sym_keyword_or] = ACTIONS(61),
    [sym_keyword_is] = ACTIONS(59),
    [sym_keyword_not] = ACTIONS(61),
    [sym_keyword_contains] = ACTIONS(59),
    [sym_keyword_contains_not] = ACTIONS(59),
    [sym_keyword_contains_all] = ACTIONS(59),
    [sym_keyword_contains_any] = ACTIONS(59),
    [sym_keyword_contains_none] = ACTIONS(59),
    [sym_keyword_inside] = ACTIONS(59),
    [sym_keyword_in] = ACTIONS(61),
    [sym_keyword_not_inside] = ACTIONS(59),
    [sym_keyword_all_inside] = ACTIONS(59),
    [sym_keyword_any_inside] = ACTIONS(59),
    [sym_keyword_none_inside] = ACTIONS(59),
    [sym_keyword_outside] = ACTIONS(59),
    [sym_keyword_intersects] = ACTIONS(59),
    [anon_sym_COMMA] = ACTIONS(59),
    [anon_sym_RPAREN] = ACTIONS(59),
    [anon_sym_RBRACE] = ACTIONS(59),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(61),
    [anon_sym_LT_PIPE] = ACTIONS(59),
    [anon_sym_AMP_AMP] = ACTIONS(59),
    [anon_sym_PIPE_PIPE] = ACTIONS(59),
    [anon_sym_QMARK_QMARK] = ACTIONS(59),
    [anon_sym_QMARK_COLON] = ACTIONS(59),
    [anon_sym_BANG_EQ] = ACTIONS(59),
    [anon_sym_EQ_EQ] = ACTIONS(59),
    [anon_sym_QMARK_EQ] = ACTIONS(59),
    [anon_sym_STAR_EQ] = ACTIONS(59),
    [anon_sym_TILDE] = ACTIONS(59),
    [anon_sym_BANG_TILDE] = ACTIONS(59),
    [anon_sym_STAR_TILDE] = ACTIONS(59),
    [anon_sym_LT_EQ] = ACTIONS(59),
    [anon_sym_GT_EQ] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_PLUS_EQ] = ACTIONS(59),
    [anon_sym_DASH_EQ] = ACTIONS(59),
    [anon_sym_u00d7] = ACTIONS(59),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_u00f7] = ACTIONS(59),
    [anon_sym_STAR_STAR] = ACTIONS(59),
    [anon_sym_u220b] = ACTIONS(59),
    [anon_sym_u220c] = ACTIONS(59),
    [anon_sym_u2287] = ACTIONS(59),
    [anon_sym_u2283] = ACTIONS(59),
    [anon_sym_u2285] = ACTIONS(59),
    [anon_sym_u2208] = ACTIONS(59),
    [anon_sym_u2209] = ACTIONS(59),
    [anon_sym_u2286] = ACTIONS(59),
    [anon_sym_u2282] = ACTIONS(59),
    [anon_sym_u2284] = ACTIONS(59),
    [anon_sym_AT_AT] = ACTIONS(59),
  },
  [456] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(150),
    [sym_keyword_explain] = ACTIONS(150),
    [sym_keyword_parallel] = ACTIONS(150),
    [sym_keyword_timeout] = ACTIONS(150),
    [sym_keyword_fetch] = ACTIONS(150),
    [sym_keyword_limit] = ACTIONS(150),
    [sym_keyword_order] = ACTIONS(150),
    [sym_keyword_with] = ACTIONS(150),
    [sym_keyword_where] = ACTIONS(150),
    [sym_keyword_split] = ACTIONS(150),
    [sym_keyword_group] = ACTIONS(150),
    [sym_keyword_and] = ACTIONS(150),
    [sym_keyword_or] = ACTIONS(152),
    [sym_keyword_is] = ACTIONS(150),
    [sym_keyword_not] = ACTIONS(152),
    [sym_keyword_contains] = ACTIONS(150),
    [sym_keyword_contains_not] = ACTIONS(150),
    [sym_keyword_contains_all] = ACTIONS(150),
    [sym_keyword_contains_any] = ACTIONS(150),
    [sym_keyword_contains_none] = ACTIONS(150),
    [sym_keyword_inside] = ACTIONS(150),
    [sym_keyword_in] = ACTIONS(152),
    [sym_keyword_not_inside] = ACTIONS(150),
    [sym_keyword_all_inside] = ACTIONS(150),
    [sym_keyword_any_inside] = ACTIONS(150),
    [sym_keyword_none_inside] = ACTIONS(150),
    [sym_keyword_outside] = ACTIONS(150),
    [sym_keyword_intersects] = ACTIONS(150),
    [anon_sym_COMMA] = ACTIONS(150),
    [anon_sym_RPAREN] = ACTIONS(150),
    [anon_sym_RBRACE] = ACTIONS(150),
    [anon_sym_STAR] = ACTIONS(152),
    [anon_sym_LT] = ACTIONS(152),
    [anon_sym_GT] = ACTIONS(152),
    [anon_sym_EQ] = ACTIONS(152),
    [anon_sym_DASH] = ACTIONS(152),
    [anon_sym_AT] = ACTIONS(152),
    [anon_sym_LT_PIPE] = ACTIONS(150),
    [anon_sym_AMP_AMP] = ACTIONS(150),
    [anon_sym_PIPE_PIPE] = ACTIONS(150),
    [anon_sym_QMARK_QMARK] = ACTIONS(150),
    [anon_sym_QMARK_COLON] = ACTIONS(150),
    [anon_sym_BANG_EQ] = ACTIONS(150),
    [anon_sym_EQ_EQ] = ACTIONS(150),
    [anon_sym_QMARK_EQ] = ACTIONS(150),
    [anon_sym_STAR_EQ] = ACTIONS(150),
    [anon_sym_TILDE] = ACTIONS(150),
    [anon_sym_BANG_TILDE] = ACTIONS(150),
    [anon_sym_STAR_TILDE] = ACTIONS(150),
    [anon_sym_LT_EQ] = ACTIONS(150),
    [anon_sym_GT_EQ] = ACTIONS(150),
    [anon_sym_PLUS] = ACTIONS(152),
    [anon_sym_PLUS_EQ] = ACTIONS(150),
    [anon_sym_DASH_EQ] = ACTIONS(150),
    [anon_sym_u00d7] = ACTIONS(150),
    [anon_sym_SLASH] = ACTIONS(152),
    [anon_sym_u00f7] = ACTIONS(150),
    [anon_sym_STAR_STAR] = ACTIONS(150),
    [anon_sym_u220b] = ACTIONS(150),
    [anon_sym_u220c] = ACTIONS(150),
    [anon_sym_u2287] = ACTIONS(150),
    [anon_sym_u2283] = ACTIONS(150),
    [anon_sym_u2285] = ACTIONS(150),
    [anon_sym_u2208] = ACTIONS(150),
    [anon_sym_u2209] = ACTIONS(150),
    [anon_sym_u2286] = ACTIONS(150),
    [anon_sym_u2282] = ACTIONS(150),
    [anon_sym_u2284] = ACTIONS(150),
    [anon_sym_AT_AT] = ACTIONS(150),
  },
  [457] = {
    [sym_array] = STATE(29),
    [sym_object] = STATE(29),
    [sym_record_id_value] = STATE(49),
    [ts_builtin_sym_end] = ACTIONS(210),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(210),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_COMMA] = ACTIONS(210),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(41),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(446),
    [sym_record_id_ident] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [458] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(275),
    [sym_keyword_explain] = ACTIONS(275),
    [sym_keyword_parallel] = ACTIONS(275),
    [sym_keyword_timeout] = ACTIONS(275),
    [sym_keyword_fetch] = ACTIONS(275),
    [sym_keyword_limit] = ACTIONS(275),
    [sym_keyword_order] = ACTIONS(275),
    [sym_keyword_with] = ACTIONS(275),
    [sym_keyword_where] = ACTIONS(275),
    [sym_keyword_split] = ACTIONS(275),
    [sym_keyword_group] = ACTIONS(275),
    [sym_keyword_and] = ACTIONS(275),
    [sym_keyword_or] = ACTIONS(277),
    [sym_keyword_is] = ACTIONS(275),
    [sym_keyword_not] = ACTIONS(277),
    [sym_keyword_contains] = ACTIONS(275),
    [sym_keyword_contains_not] = ACTIONS(275),
    [sym_keyword_contains_all] = ACTIONS(275),
    [sym_keyword_contains_any] = ACTIONS(275),
    [sym_keyword_contains_none] = ACTIONS(275),
    [sym_keyword_inside] = ACTIONS(275),
    [sym_keyword_in] = ACTIONS(277),
    [sym_keyword_not_inside] = ACTIONS(275),
    [sym_keyword_all_inside] = ACTIONS(275),
    [sym_keyword_any_inside] = ACTIONS(275),
    [sym_keyword_none_inside] = ACTIONS(275),
    [sym_keyword_outside] = ACTIONS(275),
    [sym_keyword_intersects] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(275),
    [anon_sym_RPAREN] = ACTIONS(275),
    [anon_sym_RBRACE] = ACTIONS(275),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LT] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(277),
    [anon_sym_EQ] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_LT_PIPE] = ACTIONS(275),
    [anon_sym_AMP_AMP] = ACTIONS(275),
    [anon_sym_PIPE_PIPE] = ACTIONS(275),
    [anon_sym_QMARK_QMARK] = ACTIONS(275),
    [anon_sym_QMARK_COLON] = ACTIONS(275),
    [anon_sym_BANG_EQ] = ACTIONS(275),
    [anon_sym_EQ_EQ] = ACTIONS(275),
    [anon_sym_QMARK_EQ] = ACTIONS(275),
    [anon_sym_STAR_EQ] = ACTIONS(275),
    [anon_sym_TILDE] = ACTIONS(275),
    [anon_sym_BANG_TILDE] = ACTIONS(275),
    [anon_sym_STAR_TILDE] = ACTIONS(275),
    [anon_sym_LT_EQ] = ACTIONS(275),
    [anon_sym_GT_EQ] = ACTIONS(275),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_PLUS_EQ] = ACTIONS(275),
    [anon_sym_DASH_EQ] = ACTIONS(275),
    [anon_sym_u00d7] = ACTIONS(275),
    [anon_sym_SLASH] = ACTIONS(277),
    [anon_sym_u00f7] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(275),
    [anon_sym_u220b] = ACTIONS(275),
    [anon_sym_u220c] = ACTIONS(275),
    [anon_sym_u2287] = ACTIONS(275),
    [anon_sym_u2283] = ACTIONS(275),
    [anon_sym_u2285] = ACTIONS(275),
    [anon_sym_u2208] = ACTIONS(275),
    [anon_sym_u2209] = ACTIONS(275),
    [anon_sym_u2286] = ACTIONS(275),
    [anon_sym_u2282] = ACTIONS(275),
    [anon_sym_u2284] = ACTIONS(275),
    [anon_sym_AT_AT] = ACTIONS(275),
  },
  [459] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(251),
    [sym_keyword_explain] = ACTIONS(251),
    [sym_keyword_parallel] = ACTIONS(251),
    [sym_keyword_timeout] = ACTIONS(251),
    [sym_keyword_fetch] = ACTIONS(251),
    [sym_keyword_limit] = ACTIONS(251),
    [sym_keyword_order] = ACTIONS(251),
    [sym_keyword_with] = ACTIONS(251),
    [sym_keyword_where] = ACTIONS(251),
    [sym_keyword_split] = ACTIONS(251),
    [sym_keyword_group] = ACTIONS(251),
    [sym_keyword_and] = ACTIONS(251),
    [sym_keyword_or] = ACTIONS(253),
    [sym_keyword_is] = ACTIONS(251),
    [sym_keyword_not] = ACTIONS(253),
    [sym_keyword_contains] = ACTIONS(251),
    [sym_keyword_contains_not] = ACTIONS(251),
    [sym_keyword_contains_all] = ACTIONS(251),
    [sym_keyword_contains_any] = ACTIONS(251),
    [sym_keyword_contains_none] = ACTIONS(251),
    [sym_keyword_inside] = ACTIONS(251),
    [sym_keyword_in] = ACTIONS(253),
    [sym_keyword_not_inside] = ACTIONS(251),
    [sym_keyword_all_inside] = ACTIONS(251),
    [sym_keyword_any_inside] = ACTIONS(251),
    [sym_keyword_none_inside] = ACTIONS(251),
    [sym_keyword_outside] = ACTIONS(251),
    [sym_keyword_intersects] = ACTIONS(251),
    [anon_sym_COMMA] = ACTIONS(251),
    [anon_sym_RPAREN] = ACTIONS(251),
    [anon_sym_RBRACE] = ACTIONS(251),
    [anon_sym_STAR] = ACTIONS(253),
    [anon_sym_LT] = ACTIONS(253),
    [anon_sym_GT] = ACTIONS(253),
    [anon_sym_EQ] = ACTIONS(253),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_AT] = ACTIONS(253),
    [anon_sym_LT_PIPE] = ACTIONS(251),
    [anon_sym_AMP_AMP] = ACTIONS(251),
    [anon_sym_PIPE_PIPE] = ACTIONS(251),
    [anon_sym_QMARK_QMARK] = ACTIONS(251),
    [anon_sym_QMARK_COLON] = ACTIONS(251),
    [anon_sym_BANG_EQ] = ACTIONS(251),
    [anon_sym_EQ_EQ] = ACTIONS(251),
    [anon_sym_QMARK_EQ] = ACTIONS(251),
    [anon_sym_STAR_EQ] = ACTIONS(251),
    [anon_sym_TILDE] = ACTIONS(251),
    [anon_sym_BANG_TILDE] = ACTIONS(251),
    [anon_sym_STAR_TILDE] = ACTIONS(251),
    [anon_sym_LT_EQ] = ACTIONS(251),
    [anon_sym_GT_EQ] = ACTIONS(251),
    [anon_sym_PLUS] = ACTIONS(253),
    [anon_sym_PLUS_EQ] = ACTIONS(251),
    [anon_sym_DASH_EQ] = ACTIONS(251),
    [anon_sym_u00d7] = ACTIONS(251),
    [anon_sym_SLASH] = ACTIONS(253),
    [anon_sym_u00f7] = ACTIONS(251),
    [anon_sym_STAR_STAR] = ACTIONS(251),
    [anon_sym_u220b] = ACTIONS(251),
    [anon_sym_u220c] = ACTIONS(251),
    [anon_sym_u2287] = ACTIONS(251),
    [anon_sym_u2283] = ACTIONS(251),
    [anon_sym_u2285] = ACTIONS(251),
    [anon_sym_u2208] = ACTIONS(251),
    [anon_sym_u2209] = ACTIONS(251),
    [anon_sym_u2286] = ACTIONS(251),
    [anon_sym_u2282] = ACTIONS(251),
    [anon_sym_u2284] = ACTIONS(251),
    [anon_sym_AT_AT] = ACTIONS(251),
  },
  [460] = {
    [sym_operator] = STATE(705),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(678),
    [sym_keyword_explain] = ACTIONS(678),
    [sym_keyword_parallel] = ACTIONS(678),
    [sym_keyword_timeout] = ACTIONS(678),
    [sym_keyword_fetch] = ACTIONS(678),
    [sym_keyword_limit] = ACTIONS(678),
    [sym_keyword_order] = ACTIONS(678),
    [sym_keyword_split] = ACTIONS(678),
    [sym_keyword_group] = ACTIONS(678),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(313),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_RPAREN] = ACTIONS(678),
    [anon_sym_RBRACE] = ACTIONS(678),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [461] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(45),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_if] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(373),
    [sym_variable_name] = ACTIONS(367),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [462] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(36),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_if] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(373),
    [sym_variable_name] = ACTIONS(210),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [463] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(33),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [sym_keyword_if] = ACTIONS(180),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(373),
    [sym_variable_name] = ACTIONS(178),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [464] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(45),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(369),
    [sym_keyword_contains] = ACTIONS(369),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(369),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_then] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(367),
    [anon_sym_LPAREN] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(369),
    [anon_sym_LT_DASH_GT] = ACTIONS(367),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(369),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(369),
    [anon_sym_LT_PIPE] = ACTIONS(367),
    [anon_sym_AMP_AMP] = ACTIONS(367),
    [anon_sym_PIPE_PIPE] = ACTIONS(367),
    [anon_sym_QMARK_QMARK] = ACTIONS(367),
    [anon_sym_QMARK_COLON] = ACTIONS(367),
    [anon_sym_BANG_EQ] = ACTIONS(367),
    [anon_sym_EQ_EQ] = ACTIONS(367),
    [anon_sym_QMARK_EQ] = ACTIONS(367),
    [anon_sym_STAR_EQ] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(367),
    [anon_sym_BANG_TILDE] = ACTIONS(367),
    [anon_sym_STAR_TILDE] = ACTIONS(367),
    [anon_sym_LT_EQ] = ACTIONS(367),
    [anon_sym_GT_EQ] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_PLUS_EQ] = ACTIONS(367),
    [anon_sym_DASH_EQ] = ACTIONS(367),
    [anon_sym_u00d7] = ACTIONS(367),
    [anon_sym_SLASH] = ACTIONS(369),
    [anon_sym_u00f7] = ACTIONS(367),
    [anon_sym_STAR_STAR] = ACTIONS(367),
    [anon_sym_u220b] = ACTIONS(367),
    [anon_sym_u220c] = ACTIONS(367),
    [anon_sym_u2287] = ACTIONS(367),
    [anon_sym_u2283] = ACTIONS(367),
    [anon_sym_u2285] = ACTIONS(367),
    [anon_sym_u2208] = ACTIONS(367),
    [anon_sym_u2209] = ACTIONS(367),
    [anon_sym_u2286] = ACTIONS(367),
    [anon_sym_u2282] = ACTIONS(367),
    [anon_sym_u2284] = ACTIONS(367),
    [anon_sym_AT_AT] = ACTIONS(367),
  },
  [465] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(36),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(212),
    [sym_keyword_contains] = ACTIONS(212),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(212),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_then] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(210),
    [anon_sym_LBRACK] = ACTIONS(210),
    [anon_sym_LPAREN] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(212),
    [anon_sym_LT_DASH_GT] = ACTIONS(210),
    [anon_sym_STAR] = ACTIONS(212),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_LT] = ACTIONS(212),
    [anon_sym_GT] = ACTIONS(212),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(212),
    [anon_sym_DASH] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(212),
    [anon_sym_LT_PIPE] = ACTIONS(210),
    [anon_sym_AMP_AMP] = ACTIONS(210),
    [anon_sym_PIPE_PIPE] = ACTIONS(210),
    [anon_sym_QMARK_QMARK] = ACTIONS(210),
    [anon_sym_QMARK_COLON] = ACTIONS(210),
    [anon_sym_BANG_EQ] = ACTIONS(210),
    [anon_sym_EQ_EQ] = ACTIONS(210),
    [anon_sym_QMARK_EQ] = ACTIONS(210),
    [anon_sym_STAR_EQ] = ACTIONS(210),
    [anon_sym_TILDE] = ACTIONS(210),
    [anon_sym_BANG_TILDE] = ACTIONS(210),
    [anon_sym_STAR_TILDE] = ACTIONS(210),
    [anon_sym_LT_EQ] = ACTIONS(210),
    [anon_sym_GT_EQ] = ACTIONS(210),
    [anon_sym_PLUS] = ACTIONS(212),
    [anon_sym_PLUS_EQ] = ACTIONS(210),
    [anon_sym_DASH_EQ] = ACTIONS(210),
    [anon_sym_u00d7] = ACTIONS(210),
    [anon_sym_SLASH] = ACTIONS(212),
    [anon_sym_u00f7] = ACTIONS(210),
    [anon_sym_STAR_STAR] = ACTIONS(210),
    [anon_sym_u220b] = ACTIONS(210),
    [anon_sym_u220c] = ACTIONS(210),
    [anon_sym_u2287] = ACTIONS(210),
    [anon_sym_u2283] = ACTIONS(210),
    [anon_sym_u2285] = ACTIONS(210),
    [anon_sym_u2208] = ACTIONS(210),
    [anon_sym_u2209] = ACTIONS(210),
    [anon_sym_u2286] = ACTIONS(210),
    [anon_sym_u2282] = ACTIONS(210),
    [anon_sym_u2284] = ACTIONS(210),
    [anon_sym_AT_AT] = ACTIONS(210),
  },
  [466] = {
    [sym_operator] = STATE(746),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(678),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(678),
    [sym_keyword_as] = ACTIONS(678),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_drop] = ACTIONS(678),
    [sym_keyword_schemafull] = ACTIONS(678),
    [sym_keyword_schemaless] = ACTIONS(678),
    [sym_keyword_changefeed] = ACTIONS(678),
    [sym_keyword_type] = ACTIONS(678),
    [sym_keyword_permissions] = ACTIONS(678),
    [sym_keyword_for] = ACTIONS(678),
    [sym_keyword_comment] = ACTIONS(678),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [467] = {
    [ts_builtin_sym_end] = ACTIONS(259),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(259),
    [sym_keyword_explain] = ACTIONS(259),
    [sym_keyword_parallel] = ACTIONS(259),
    [sym_keyword_timeout] = ACTIONS(259),
    [sym_keyword_fetch] = ACTIONS(259),
    [sym_keyword_limit] = ACTIONS(259),
    [sym_keyword_order] = ACTIONS(259),
    [sym_keyword_with] = ACTIONS(259),
    [sym_keyword_where] = ACTIONS(259),
    [sym_keyword_split] = ACTIONS(259),
    [sym_keyword_group] = ACTIONS(259),
    [sym_keyword_and] = ACTIONS(259),
    [sym_keyword_or] = ACTIONS(261),
    [sym_keyword_is] = ACTIONS(259),
    [sym_keyword_not] = ACTIONS(261),
    [sym_keyword_contains] = ACTIONS(259),
    [sym_keyword_contains_not] = ACTIONS(259),
    [sym_keyword_contains_all] = ACTIONS(259),
    [sym_keyword_contains_any] = ACTIONS(259),
    [sym_keyword_contains_none] = ACTIONS(259),
    [sym_keyword_inside] = ACTIONS(259),
    [sym_keyword_in] = ACTIONS(261),
    [sym_keyword_not_inside] = ACTIONS(259),
    [sym_keyword_all_inside] = ACTIONS(259),
    [sym_keyword_any_inside] = ACTIONS(259),
    [sym_keyword_none_inside] = ACTIONS(259),
    [sym_keyword_outside] = ACTIONS(259),
    [sym_keyword_intersects] = ACTIONS(259),
    [anon_sym_COMMA] = ACTIONS(259),
    [anon_sym_STAR] = ACTIONS(261),
    [anon_sym_LT] = ACTIONS(261),
    [anon_sym_GT] = ACTIONS(261),
    [anon_sym_EQ] = ACTIONS(261),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_AT] = ACTIONS(261),
    [anon_sym_LT_PIPE] = ACTIONS(259),
    [anon_sym_AMP_AMP] = ACTIONS(259),
    [anon_sym_PIPE_PIPE] = ACTIONS(259),
    [anon_sym_QMARK_QMARK] = ACTIONS(259),
    [anon_sym_QMARK_COLON] = ACTIONS(259),
    [anon_sym_BANG_EQ] = ACTIONS(259),
    [anon_sym_EQ_EQ] = ACTIONS(259),
    [anon_sym_QMARK_EQ] = ACTIONS(259),
    [anon_sym_STAR_EQ] = ACTIONS(259),
    [anon_sym_TILDE] = ACTIONS(259),
    [anon_sym_BANG_TILDE] = ACTIONS(259),
    [anon_sym_STAR_TILDE] = ACTIONS(259),
    [anon_sym_LT_EQ] = ACTIONS(259),
    [anon_sym_GT_EQ] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(261),
    [anon_sym_PLUS_EQ] = ACTIONS(259),
    [anon_sym_DASH_EQ] = ACTIONS(259),
    [anon_sym_u00d7] = ACTIONS(259),
    [anon_sym_SLASH] = ACTIONS(261),
    [anon_sym_u00f7] = ACTIONS(259),
    [anon_sym_STAR_STAR] = ACTIONS(259),
    [anon_sym_u220b] = ACTIONS(259),
    [anon_sym_u220c] = ACTIONS(259),
    [anon_sym_u2287] = ACTIONS(259),
    [anon_sym_u2283] = ACTIONS(259),
    [anon_sym_u2285] = ACTIONS(259),
    [anon_sym_u2208] = ACTIONS(259),
    [anon_sym_u2209] = ACTIONS(259),
    [anon_sym_u2286] = ACTIONS(259),
    [anon_sym_u2282] = ACTIONS(259),
    [anon_sym_u2284] = ACTIONS(259),
    [anon_sym_AT_AT] = ACTIONS(259),
  },
  [468] = {
    [sym_array] = STATE(18),
    [sym_object] = STATE(18),
    [sym_record_id_value] = STATE(33),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_and] = ACTIONS(180),
    [sym_keyword_or] = ACTIONS(180),
    [sym_keyword_is] = ACTIONS(180),
    [sym_keyword_not] = ACTIONS(180),
    [sym_keyword_contains] = ACTIONS(180),
    [sym_keyword_contains_not] = ACTIONS(180),
    [sym_keyword_contains_all] = ACTIONS(180),
    [sym_keyword_contains_any] = ACTIONS(180),
    [sym_keyword_contains_none] = ACTIONS(180),
    [sym_keyword_inside] = ACTIONS(180),
    [sym_keyword_in] = ACTIONS(180),
    [sym_keyword_not_inside] = ACTIONS(180),
    [sym_keyword_all_inside] = ACTIONS(180),
    [sym_keyword_any_inside] = ACTIONS(180),
    [sym_keyword_none_inside] = ACTIONS(180),
    [sym_keyword_outside] = ACTIONS(180),
    [sym_keyword_intersects] = ACTIONS(180),
    [sym_keyword_then] = ACTIONS(180),
    [anon_sym_DASH_GT] = ACTIONS(178),
    [anon_sym_LBRACK] = ACTIONS(178),
    [anon_sym_LPAREN] = ACTIONS(178),
    [anon_sym_LBRACE] = ACTIONS(178),
    [anon_sym_LT_DASH] = ACTIONS(180),
    [anon_sym_LT_DASH_GT] = ACTIONS(178),
    [anon_sym_STAR] = ACTIONS(180),
    [anon_sym_DOT] = ACTIONS(178),
    [anon_sym_LT] = ACTIONS(180),
    [anon_sym_GT] = ACTIONS(180),
    [sym_int] = ACTIONS(373),
    [sym_record_id_ident] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(180),
    [anon_sym_DASH] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(180),
    [anon_sym_LT_PIPE] = ACTIONS(178),
    [anon_sym_AMP_AMP] = ACTIONS(178),
    [anon_sym_PIPE_PIPE] = ACTIONS(178),
    [anon_sym_QMARK_QMARK] = ACTIONS(178),
    [anon_sym_QMARK_COLON] = ACTIONS(178),
    [anon_sym_BANG_EQ] = ACTIONS(178),
    [anon_sym_EQ_EQ] = ACTIONS(178),
    [anon_sym_QMARK_EQ] = ACTIONS(178),
    [anon_sym_STAR_EQ] = ACTIONS(178),
    [anon_sym_TILDE] = ACTIONS(178),
    [anon_sym_BANG_TILDE] = ACTIONS(178),
    [anon_sym_STAR_TILDE] = ACTIONS(178),
    [anon_sym_LT_EQ] = ACTIONS(178),
    [anon_sym_GT_EQ] = ACTIONS(178),
    [anon_sym_PLUS] = ACTIONS(180),
    [anon_sym_PLUS_EQ] = ACTIONS(178),
    [anon_sym_DASH_EQ] = ACTIONS(178),
    [anon_sym_u00d7] = ACTIONS(178),
    [anon_sym_SLASH] = ACTIONS(180),
    [anon_sym_u00f7] = ACTIONS(178),
    [anon_sym_STAR_STAR] = ACTIONS(178),
    [anon_sym_u220b] = ACTIONS(178),
    [anon_sym_u220c] = ACTIONS(178),
    [anon_sym_u2287] = ACTIONS(178),
    [anon_sym_u2283] = ACTIONS(178),
    [anon_sym_u2285] = ACTIONS(178),
    [anon_sym_u2208] = ACTIONS(178),
    [anon_sym_u2209] = ACTIONS(178),
    [anon_sym_u2286] = ACTIONS(178),
    [anon_sym_u2282] = ACTIONS(178),
    [anon_sym_u2284] = ACTIONS(178),
    [anon_sym_AT_AT] = ACTIONS(178),
  },
  [469] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_return] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(682),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [470] = {
    [ts_builtin_sym_end] = ACTIONS(239),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(239),
    [sym_keyword_explain] = ACTIONS(239),
    [sym_keyword_parallel] = ACTIONS(239),
    [sym_keyword_timeout] = ACTIONS(239),
    [sym_keyword_fetch] = ACTIONS(239),
    [sym_keyword_limit] = ACTIONS(239),
    [sym_keyword_order] = ACTIONS(239),
    [sym_keyword_with] = ACTIONS(239),
    [sym_keyword_where] = ACTIONS(239),
    [sym_keyword_split] = ACTIONS(239),
    [sym_keyword_group] = ACTIONS(239),
    [sym_keyword_and] = ACTIONS(239),
    [sym_keyword_or] = ACTIONS(241),
    [sym_keyword_is] = ACTIONS(239),
    [sym_keyword_not] = ACTIONS(241),
    [sym_keyword_contains] = ACTIONS(239),
    [sym_keyword_contains_not] = ACTIONS(239),
    [sym_keyword_contains_all] = ACTIONS(239),
    [sym_keyword_contains_any] = ACTIONS(239),
    [sym_keyword_contains_none] = ACTIONS(239),
    [sym_keyword_inside] = ACTIONS(239),
    [sym_keyword_in] = ACTIONS(241),
    [sym_keyword_not_inside] = ACTIONS(239),
    [sym_keyword_all_inside] = ACTIONS(239),
    [sym_keyword_any_inside] = ACTIONS(239),
    [sym_keyword_none_inside] = ACTIONS(239),
    [sym_keyword_outside] = ACTIONS(239),
    [sym_keyword_intersects] = ACTIONS(239),
    [anon_sym_COMMA] = ACTIONS(239),
    [anon_sym_STAR] = ACTIONS(241),
    [anon_sym_LT] = ACTIONS(241),
    [anon_sym_GT] = ACTIONS(241),
    [anon_sym_EQ] = ACTIONS(241),
    [anon_sym_DASH] = ACTIONS(241),
    [anon_sym_AT] = ACTIONS(241),
    [anon_sym_LT_PIPE] = ACTIONS(239),
    [anon_sym_AMP_AMP] = ACTIONS(239),
    [anon_sym_PIPE_PIPE] = ACTIONS(239),
    [anon_sym_QMARK_QMARK] = ACTIONS(239),
    [anon_sym_QMARK_COLON] = ACTIONS(239),
    [anon_sym_BANG_EQ] = ACTIONS(239),
    [anon_sym_EQ_EQ] = ACTIONS(239),
    [anon_sym_QMARK_EQ] = ACTIONS(239),
    [anon_sym_STAR_EQ] = ACTIONS(239),
    [anon_sym_TILDE] = ACTIONS(239),
    [anon_sym_BANG_TILDE] = ACTIONS(239),
    [anon_sym_STAR_TILDE] = ACTIONS(239),
    [anon_sym_LT_EQ] = ACTIONS(239),
    [anon_sym_GT_EQ] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(241),
    [anon_sym_PLUS_EQ] = ACTIONS(239),
    [anon_sym_DASH_EQ] = ACTIONS(239),
    [anon_sym_u00d7] = ACTIONS(239),
    [anon_sym_SLASH] = ACTIONS(241),
    [anon_sym_u00f7] = ACTIONS(239),
    [anon_sym_STAR_STAR] = ACTIONS(239),
    [anon_sym_u220b] = ACTIONS(239),
    [anon_sym_u220c] = ACTIONS(239),
    [anon_sym_u2287] = ACTIONS(239),
    [anon_sym_u2283] = ACTIONS(239),
    [anon_sym_u2285] = ACTIONS(239),
    [anon_sym_u2208] = ACTIONS(239),
    [anon_sym_u2209] = ACTIONS(239),
    [anon_sym_u2286] = ACTIONS(239),
    [anon_sym_u2282] = ACTIONS(239),
    [anon_sym_u2284] = ACTIONS(239),
    [anon_sym_AT_AT] = ACTIONS(239),
  },
  [471] = {
    [sym_operator] = STATE(739),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(678),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(678),
    [sym_keyword_value] = ACTIONS(678),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_flexible] = ACTIONS(678),
    [sym_keyword_readonly] = ACTIONS(678),
    [sym_keyword_type] = ACTIONS(678),
    [sym_keyword_default] = ACTIONS(678),
    [sym_keyword_assert] = ACTIONS(678),
    [sym_keyword_permissions] = ACTIONS(678),
    [sym_keyword_for] = ACTIONS(678),
    [sym_keyword_comment] = ACTIONS(678),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [472] = {
    [sym_operator] = STATE(739),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(648),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_value] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(648),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [sym_keyword_flexible] = ACTIONS(648),
    [sym_keyword_readonly] = ACTIONS(648),
    [sym_keyword_type] = ACTIONS(648),
    [sym_keyword_default] = ACTIONS(648),
    [sym_keyword_assert] = ACTIONS(648),
    [sym_keyword_permissions] = ACTIONS(648),
    [sym_keyword_for] = ACTIONS(648),
    [sym_keyword_comment] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [473] = {
    [ts_builtin_sym_end] = ACTIONS(150),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(150),
    [sym_keyword_explain] = ACTIONS(150),
    [sym_keyword_parallel] = ACTIONS(150),
    [sym_keyword_timeout] = ACTIONS(150),
    [sym_keyword_fetch] = ACTIONS(150),
    [sym_keyword_limit] = ACTIONS(150),
    [sym_keyword_order] = ACTIONS(150),
    [sym_keyword_with] = ACTIONS(150),
    [sym_keyword_where] = ACTIONS(150),
    [sym_keyword_split] = ACTIONS(150),
    [sym_keyword_group] = ACTIONS(150),
    [sym_keyword_and] = ACTIONS(150),
    [sym_keyword_or] = ACTIONS(152),
    [sym_keyword_is] = ACTIONS(150),
    [sym_keyword_not] = ACTIONS(152),
    [sym_keyword_contains] = ACTIONS(150),
    [sym_keyword_contains_not] = ACTIONS(150),
    [sym_keyword_contains_all] = ACTIONS(150),
    [sym_keyword_contains_any] = ACTIONS(150),
    [sym_keyword_contains_none] = ACTIONS(150),
    [sym_keyword_inside] = ACTIONS(150),
    [sym_keyword_in] = ACTIONS(152),
    [sym_keyword_not_inside] = ACTIONS(150),
    [sym_keyword_all_inside] = ACTIONS(150),
    [sym_keyword_any_inside] = ACTIONS(150),
    [sym_keyword_none_inside] = ACTIONS(150),
    [sym_keyword_outside] = ACTIONS(150),
    [sym_keyword_intersects] = ACTIONS(150),
    [anon_sym_COMMA] = ACTIONS(150),
    [anon_sym_STAR] = ACTIONS(152),
    [anon_sym_LT] = ACTIONS(152),
    [anon_sym_GT] = ACTIONS(152),
    [anon_sym_EQ] = ACTIONS(152),
    [anon_sym_DASH] = ACTIONS(152),
    [anon_sym_AT] = ACTIONS(152),
    [anon_sym_LT_PIPE] = ACTIONS(150),
    [anon_sym_AMP_AMP] = ACTIONS(150),
    [anon_sym_PIPE_PIPE] = ACTIONS(150),
    [anon_sym_QMARK_QMARK] = ACTIONS(150),
    [anon_sym_QMARK_COLON] = ACTIONS(150),
    [anon_sym_BANG_EQ] = ACTIONS(150),
    [anon_sym_EQ_EQ] = ACTIONS(150),
    [anon_sym_QMARK_EQ] = ACTIONS(150),
    [anon_sym_STAR_EQ] = ACTIONS(150),
    [anon_sym_TILDE] = ACTIONS(150),
    [anon_sym_BANG_TILDE] = ACTIONS(150),
    [anon_sym_STAR_TILDE] = ACTIONS(150),
    [anon_sym_LT_EQ] = ACTIONS(150),
    [anon_sym_GT_EQ] = ACTIONS(150),
    [anon_sym_PLUS] = ACTIONS(152),
    [anon_sym_PLUS_EQ] = ACTIONS(150),
    [anon_sym_DASH_EQ] = ACTIONS(150),
    [anon_sym_u00d7] = ACTIONS(150),
    [anon_sym_SLASH] = ACTIONS(152),
    [anon_sym_u00f7] = ACTIONS(150),
    [anon_sym_STAR_STAR] = ACTIONS(150),
    [anon_sym_u220b] = ACTIONS(150),
    [anon_sym_u220c] = ACTIONS(150),
    [anon_sym_u2287] = ACTIONS(150),
    [anon_sym_u2283] = ACTIONS(150),
    [anon_sym_u2285] = ACTIONS(150),
    [anon_sym_u2208] = ACTIONS(150),
    [anon_sym_u2209] = ACTIONS(150),
    [anon_sym_u2286] = ACTIONS(150),
    [anon_sym_u2282] = ACTIONS(150),
    [anon_sym_u2284] = ACTIONS(150),
    [anon_sym_AT_AT] = ACTIONS(150),
  },
  [474] = {
    [ts_builtin_sym_end] = ACTIONS(182),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_return] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_where] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(684),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [475] = {
    [ts_builtin_sym_end] = ACTIONS(255),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(255),
    [sym_keyword_explain] = ACTIONS(255),
    [sym_keyword_parallel] = ACTIONS(255),
    [sym_keyword_timeout] = ACTIONS(255),
    [sym_keyword_fetch] = ACTIONS(255),
    [sym_keyword_limit] = ACTIONS(255),
    [sym_keyword_order] = ACTIONS(255),
    [sym_keyword_with] = ACTIONS(255),
    [sym_keyword_where] = ACTIONS(255),
    [sym_keyword_split] = ACTIONS(255),
    [sym_keyword_group] = ACTIONS(255),
    [sym_keyword_and] = ACTIONS(255),
    [sym_keyword_or] = ACTIONS(257),
    [sym_keyword_is] = ACTIONS(255),
    [sym_keyword_not] = ACTIONS(257),
    [sym_keyword_contains] = ACTIONS(255),
    [sym_keyword_contains_not] = ACTIONS(255),
    [sym_keyword_contains_all] = ACTIONS(255),
    [sym_keyword_contains_any] = ACTIONS(255),
    [sym_keyword_contains_none] = ACTIONS(255),
    [sym_keyword_inside] = ACTIONS(255),
    [sym_keyword_in] = ACTIONS(257),
    [sym_keyword_not_inside] = ACTIONS(255),
    [sym_keyword_all_inside] = ACTIONS(255),
    [sym_keyword_any_inside] = ACTIONS(255),
    [sym_keyword_none_inside] = ACTIONS(255),
    [sym_keyword_outside] = ACTIONS(255),
    [sym_keyword_intersects] = ACTIONS(255),
    [anon_sym_COMMA] = ACTIONS(255),
    [anon_sym_STAR] = ACTIONS(257),
    [anon_sym_LT] = ACTIONS(257),
    [anon_sym_GT] = ACTIONS(257),
    [anon_sym_EQ] = ACTIONS(257),
    [anon_sym_DASH] = ACTIONS(257),
    [anon_sym_AT] = ACTIONS(257),
    [anon_sym_LT_PIPE] = ACTIONS(255),
    [anon_sym_AMP_AMP] = ACTIONS(255),
    [anon_sym_PIPE_PIPE] = ACTIONS(255),
    [anon_sym_QMARK_QMARK] = ACTIONS(255),
    [anon_sym_QMARK_COLON] = ACTIONS(255),
    [anon_sym_BANG_EQ] = ACTIONS(255),
    [anon_sym_EQ_EQ] = ACTIONS(255),
    [anon_sym_QMARK_EQ] = ACTIONS(255),
    [anon_sym_STAR_EQ] = ACTIONS(255),
    [anon_sym_TILDE] = ACTIONS(255),
    [anon_sym_BANG_TILDE] = ACTIONS(255),
    [anon_sym_STAR_TILDE] = ACTIONS(255),
    [anon_sym_LT_EQ] = ACTIONS(255),
    [anon_sym_GT_EQ] = ACTIONS(255),
    [anon_sym_PLUS] = ACTIONS(257),
    [anon_sym_PLUS_EQ] = ACTIONS(255),
    [anon_sym_DASH_EQ] = ACTIONS(255),
    [anon_sym_u00d7] = ACTIONS(255),
    [anon_sym_SLASH] = ACTIONS(257),
    [anon_sym_u00f7] = ACTIONS(255),
    [anon_sym_STAR_STAR] = ACTIONS(255),
    [anon_sym_u220b] = ACTIONS(255),
    [anon_sym_u220c] = ACTIONS(255),
    [anon_sym_u2287] = ACTIONS(255),
    [anon_sym_u2283] = ACTIONS(255),
    [anon_sym_u2285] = ACTIONS(255),
    [anon_sym_u2208] = ACTIONS(255),
    [anon_sym_u2209] = ACTIONS(255),
    [anon_sym_u2286] = ACTIONS(255),
    [anon_sym_u2282] = ACTIONS(255),
    [anon_sym_u2284] = ACTIONS(255),
    [anon_sym_AT_AT] = ACTIONS(255),
  },
  [476] = {
    [ts_builtin_sym_end] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(251),
    [sym_keyword_explain] = ACTIONS(251),
    [sym_keyword_parallel] = ACTIONS(251),
    [sym_keyword_timeout] = ACTIONS(251),
    [sym_keyword_fetch] = ACTIONS(251),
    [sym_keyword_limit] = ACTIONS(251),
    [sym_keyword_order] = ACTIONS(251),
    [sym_keyword_with] = ACTIONS(251),
    [sym_keyword_where] = ACTIONS(251),
    [sym_keyword_split] = ACTIONS(251),
    [sym_keyword_group] = ACTIONS(251),
    [sym_keyword_and] = ACTIONS(251),
    [sym_keyword_or] = ACTIONS(253),
    [sym_keyword_is] = ACTIONS(251),
    [sym_keyword_not] = ACTIONS(253),
    [sym_keyword_contains] = ACTIONS(251),
    [sym_keyword_contains_not] = ACTIONS(251),
    [sym_keyword_contains_all] = ACTIONS(251),
    [sym_keyword_contains_any] = ACTIONS(251),
    [sym_keyword_contains_none] = ACTIONS(251),
    [sym_keyword_inside] = ACTIONS(251),
    [sym_keyword_in] = ACTIONS(253),
    [sym_keyword_not_inside] = ACTIONS(251),
    [sym_keyword_all_inside] = ACTIONS(251),
    [sym_keyword_any_inside] = ACTIONS(251),
    [sym_keyword_none_inside] = ACTIONS(251),
    [sym_keyword_outside] = ACTIONS(251),
    [sym_keyword_intersects] = ACTIONS(251),
    [anon_sym_COMMA] = ACTIONS(251),
    [anon_sym_STAR] = ACTIONS(253),
    [anon_sym_LT] = ACTIONS(253),
    [anon_sym_GT] = ACTIONS(253),
    [anon_sym_EQ] = ACTIONS(253),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_AT] = ACTIONS(253),
    [anon_sym_LT_PIPE] = ACTIONS(251),
    [anon_sym_AMP_AMP] = ACTIONS(251),
    [anon_sym_PIPE_PIPE] = ACTIONS(251),
    [anon_sym_QMARK_QMARK] = ACTIONS(251),
    [anon_sym_QMARK_COLON] = ACTIONS(251),
    [anon_sym_BANG_EQ] = ACTIONS(251),
    [anon_sym_EQ_EQ] = ACTIONS(251),
    [anon_sym_QMARK_EQ] = ACTIONS(251),
    [anon_sym_STAR_EQ] = ACTIONS(251),
    [anon_sym_TILDE] = ACTIONS(251),
    [anon_sym_BANG_TILDE] = ACTIONS(251),
    [anon_sym_STAR_TILDE] = ACTIONS(251),
    [anon_sym_LT_EQ] = ACTIONS(251),
    [anon_sym_GT_EQ] = ACTIONS(251),
    [anon_sym_PLUS] = ACTIONS(253),
    [anon_sym_PLUS_EQ] = ACTIONS(251),
    [anon_sym_DASH_EQ] = ACTIONS(251),
    [anon_sym_u00d7] = ACTIONS(251),
    [anon_sym_SLASH] = ACTIONS(253),
    [anon_sym_u00f7] = ACTIONS(251),
    [anon_sym_STAR_STAR] = ACTIONS(251),
    [anon_sym_u220b] = ACTIONS(251),
    [anon_sym_u220c] = ACTIONS(251),
    [anon_sym_u2287] = ACTIONS(251),
    [anon_sym_u2283] = ACTIONS(251),
    [anon_sym_u2285] = ACTIONS(251),
    [anon_sym_u2208] = ACTIONS(251),
    [anon_sym_u2209] = ACTIONS(251),
    [anon_sym_u2286] = ACTIONS(251),
    [anon_sym_u2282] = ACTIONS(251),
    [anon_sym_u2284] = ACTIONS(251),
    [anon_sym_AT_AT] = ACTIONS(251),
  },
  [477] = {
    [ts_builtin_sym_end] = ACTIONS(275),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(275),
    [sym_keyword_explain] = ACTIONS(275),
    [sym_keyword_parallel] = ACTIONS(275),
    [sym_keyword_timeout] = ACTIONS(275),
    [sym_keyword_fetch] = ACTIONS(275),
    [sym_keyword_limit] = ACTIONS(275),
    [sym_keyword_order] = ACTIONS(275),
    [sym_keyword_with] = ACTIONS(275),
    [sym_keyword_where] = ACTIONS(275),
    [sym_keyword_split] = ACTIONS(275),
    [sym_keyword_group] = ACTIONS(275),
    [sym_keyword_and] = ACTIONS(275),
    [sym_keyword_or] = ACTIONS(277),
    [sym_keyword_is] = ACTIONS(275),
    [sym_keyword_not] = ACTIONS(277),
    [sym_keyword_contains] = ACTIONS(275),
    [sym_keyword_contains_not] = ACTIONS(275),
    [sym_keyword_contains_all] = ACTIONS(275),
    [sym_keyword_contains_any] = ACTIONS(275),
    [sym_keyword_contains_none] = ACTIONS(275),
    [sym_keyword_inside] = ACTIONS(275),
    [sym_keyword_in] = ACTIONS(277),
    [sym_keyword_not_inside] = ACTIONS(275),
    [sym_keyword_all_inside] = ACTIONS(275),
    [sym_keyword_any_inside] = ACTIONS(275),
    [sym_keyword_none_inside] = ACTIONS(275),
    [sym_keyword_outside] = ACTIONS(275),
    [sym_keyword_intersects] = ACTIONS(275),
    [anon_sym_COMMA] = ACTIONS(275),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LT] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(277),
    [anon_sym_EQ] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_LT_PIPE] = ACTIONS(275),
    [anon_sym_AMP_AMP] = ACTIONS(275),
    [anon_sym_PIPE_PIPE] = ACTIONS(275),
    [anon_sym_QMARK_QMARK] = ACTIONS(275),
    [anon_sym_QMARK_COLON] = ACTIONS(275),
    [anon_sym_BANG_EQ] = ACTIONS(275),
    [anon_sym_EQ_EQ] = ACTIONS(275),
    [anon_sym_QMARK_EQ] = ACTIONS(275),
    [anon_sym_STAR_EQ] = ACTIONS(275),
    [anon_sym_TILDE] = ACTIONS(275),
    [anon_sym_BANG_TILDE] = ACTIONS(275),
    [anon_sym_STAR_TILDE] = ACTIONS(275),
    [anon_sym_LT_EQ] = ACTIONS(275),
    [anon_sym_GT_EQ] = ACTIONS(275),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_PLUS_EQ] = ACTIONS(275),
    [anon_sym_DASH_EQ] = ACTIONS(275),
    [anon_sym_u00d7] = ACTIONS(275),
    [anon_sym_SLASH] = ACTIONS(277),
    [anon_sym_u00f7] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(275),
    [anon_sym_u220b] = ACTIONS(275),
    [anon_sym_u220c] = ACTIONS(275),
    [anon_sym_u2287] = ACTIONS(275),
    [anon_sym_u2283] = ACTIONS(275),
    [anon_sym_u2285] = ACTIONS(275),
    [anon_sym_u2208] = ACTIONS(275),
    [anon_sym_u2209] = ACTIONS(275),
    [anon_sym_u2286] = ACTIONS(275),
    [anon_sym_u2282] = ACTIONS(275),
    [anon_sym_u2284] = ACTIONS(275),
    [anon_sym_AT_AT] = ACTIONS(275),
  },
  [478] = {
    [ts_builtin_sym_end] = ACTIONS(59),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(59),
    [sym_keyword_explain] = ACTIONS(59),
    [sym_keyword_parallel] = ACTIONS(59),
    [sym_keyword_timeout] = ACTIONS(59),
    [sym_keyword_fetch] = ACTIONS(59),
    [sym_keyword_limit] = ACTIONS(59),
    [sym_keyword_order] = ACTIONS(59),
    [sym_keyword_with] = ACTIONS(59),
    [sym_keyword_where] = ACTIONS(59),
    [sym_keyword_split] = ACTIONS(59),
    [sym_keyword_group] = ACTIONS(59),
    [sym_keyword_and] = ACTIONS(59),
    [sym_keyword_or] = ACTIONS(61),
    [sym_keyword_is] = ACTIONS(59),
    [sym_keyword_not] = ACTIONS(61),
    [sym_keyword_contains] = ACTIONS(59),
    [sym_keyword_contains_not] = ACTIONS(59),
    [sym_keyword_contains_all] = ACTIONS(59),
    [sym_keyword_contains_any] = ACTIONS(59),
    [sym_keyword_contains_none] = ACTIONS(59),
    [sym_keyword_inside] = ACTIONS(59),
    [sym_keyword_in] = ACTIONS(61),
    [sym_keyword_not_inside] = ACTIONS(59),
    [sym_keyword_all_inside] = ACTIONS(59),
    [sym_keyword_any_inside] = ACTIONS(59),
    [sym_keyword_none_inside] = ACTIONS(59),
    [sym_keyword_outside] = ACTIONS(59),
    [sym_keyword_intersects] = ACTIONS(59),
    [anon_sym_COMMA] = ACTIONS(59),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(61),
    [anon_sym_LT_PIPE] = ACTIONS(59),
    [anon_sym_AMP_AMP] = ACTIONS(59),
    [anon_sym_PIPE_PIPE] = ACTIONS(59),
    [anon_sym_QMARK_QMARK] = ACTIONS(59),
    [anon_sym_QMARK_COLON] = ACTIONS(59),
    [anon_sym_BANG_EQ] = ACTIONS(59),
    [anon_sym_EQ_EQ] = ACTIONS(59),
    [anon_sym_QMARK_EQ] = ACTIONS(59),
    [anon_sym_STAR_EQ] = ACTIONS(59),
    [anon_sym_TILDE] = ACTIONS(59),
    [anon_sym_BANG_TILDE] = ACTIONS(59),
    [anon_sym_STAR_TILDE] = ACTIONS(59),
    [anon_sym_LT_EQ] = ACTIONS(59),
    [anon_sym_GT_EQ] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_PLUS_EQ] = ACTIONS(59),
    [anon_sym_DASH_EQ] = ACTIONS(59),
    [anon_sym_u00d7] = ACTIONS(59),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_u00f7] = ACTIONS(59),
    [anon_sym_STAR_STAR] = ACTIONS(59),
    [anon_sym_u220b] = ACTIONS(59),
    [anon_sym_u220c] = ACTIONS(59),
    [anon_sym_u2287] = ACTIONS(59),
    [anon_sym_u2283] = ACTIONS(59),
    [anon_sym_u2285] = ACTIONS(59),
    [anon_sym_u2208] = ACTIONS(59),
    [anon_sym_u2209] = ACTIONS(59),
    [anon_sym_u2286] = ACTIONS(59),
    [anon_sym_u2282] = ACTIONS(59),
    [anon_sym_u2284] = ACTIONS(59),
    [anon_sym_AT_AT] = ACTIONS(59),
  },
  [479] = {
    [sym_operator] = STATE(744),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(686),
    [sym_keyword_value] = ACTIONS(686),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_flexible] = ACTIONS(686),
    [sym_keyword_readonly] = ACTIONS(686),
    [sym_keyword_type] = ACTIONS(686),
    [sym_keyword_default] = ACTIONS(686),
    [sym_keyword_assert] = ACTIONS(686),
    [sym_keyword_permissions] = ACTIONS(686),
    [sym_keyword_comment] = ACTIONS(686),
    [anon_sym_RPAREN] = ACTIONS(686),
    [anon_sym_RBRACE] = ACTIONS(686),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [480] = {
    [ts_builtin_sym_end] = ACTIONS(138),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(138),
    [sym_keyword_explain] = ACTIONS(138),
    [sym_keyword_parallel] = ACTIONS(138),
    [sym_keyword_timeout] = ACTIONS(138),
    [sym_keyword_fetch] = ACTIONS(138),
    [sym_keyword_limit] = ACTIONS(138),
    [sym_keyword_order] = ACTIONS(138),
    [sym_keyword_with] = ACTIONS(138),
    [sym_keyword_where] = ACTIONS(138),
    [sym_keyword_split] = ACTIONS(138),
    [sym_keyword_group] = ACTIONS(138),
    [sym_keyword_and] = ACTIONS(138),
    [sym_keyword_or] = ACTIONS(140),
    [sym_keyword_is] = ACTIONS(138),
    [sym_keyword_not] = ACTIONS(140),
    [sym_keyword_contains] = ACTIONS(138),
    [sym_keyword_contains_not] = ACTIONS(138),
    [sym_keyword_contains_all] = ACTIONS(138),
    [sym_keyword_contains_any] = ACTIONS(138),
    [sym_keyword_contains_none] = ACTIONS(138),
    [sym_keyword_inside] = ACTIONS(138),
    [sym_keyword_in] = ACTIONS(140),
    [sym_keyword_not_inside] = ACTIONS(138),
    [sym_keyword_all_inside] = ACTIONS(138),
    [sym_keyword_any_inside] = ACTIONS(138),
    [sym_keyword_none_inside] = ACTIONS(138),
    [sym_keyword_outside] = ACTIONS(138),
    [sym_keyword_intersects] = ACTIONS(138),
    [anon_sym_COMMA] = ACTIONS(138),
    [anon_sym_STAR] = ACTIONS(140),
    [anon_sym_LT] = ACTIONS(140),
    [anon_sym_GT] = ACTIONS(140),
    [anon_sym_EQ] = ACTIONS(140),
    [anon_sym_DASH] = ACTIONS(140),
    [anon_sym_AT] = ACTIONS(140),
    [anon_sym_LT_PIPE] = ACTIONS(138),
    [anon_sym_AMP_AMP] = ACTIONS(138),
    [anon_sym_PIPE_PIPE] = ACTIONS(138),
    [anon_sym_QMARK_QMARK] = ACTIONS(138),
    [anon_sym_QMARK_COLON] = ACTIONS(138),
    [anon_sym_BANG_EQ] = ACTIONS(138),
    [anon_sym_EQ_EQ] = ACTIONS(138),
    [anon_sym_QMARK_EQ] = ACTIONS(138),
    [anon_sym_STAR_EQ] = ACTIONS(138),
    [anon_sym_TILDE] = ACTIONS(138),
    [anon_sym_BANG_TILDE] = ACTIONS(138),
    [anon_sym_STAR_TILDE] = ACTIONS(138),
    [anon_sym_LT_EQ] = ACTIONS(138),
    [anon_sym_GT_EQ] = ACTIONS(138),
    [anon_sym_PLUS] = ACTIONS(140),
    [anon_sym_PLUS_EQ] = ACTIONS(138),
    [anon_sym_DASH_EQ] = ACTIONS(138),
    [anon_sym_u00d7] = ACTIONS(138),
    [anon_sym_SLASH] = ACTIONS(140),
    [anon_sym_u00f7] = ACTIONS(138),
    [anon_sym_STAR_STAR] = ACTIONS(138),
    [anon_sym_u220b] = ACTIONS(138),
    [anon_sym_u220c] = ACTIONS(138),
    [anon_sym_u2287] = ACTIONS(138),
    [anon_sym_u2283] = ACTIONS(138),
    [anon_sym_u2285] = ACTIONS(138),
    [anon_sym_u2208] = ACTIONS(138),
    [anon_sym_u2209] = ACTIONS(138),
    [anon_sym_u2286] = ACTIONS(138),
    [anon_sym_u2282] = ACTIONS(138),
    [anon_sym_u2284] = ACTIONS(138),
    [anon_sym_AT_AT] = ACTIONS(138),
  },
  [481] = {
    [sym_operator] = STATE(705),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_explain] = ACTIONS(648),
    [sym_keyword_parallel] = ACTIONS(648),
    [sym_keyword_timeout] = ACTIONS(648),
    [sym_keyword_fetch] = ACTIONS(648),
    [sym_keyword_limit] = ACTIONS(648),
    [sym_keyword_order] = ACTIONS(648),
    [sym_keyword_split] = ACTIONS(648),
    [sym_keyword_group] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(650),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [anon_sym_RPAREN] = ACTIONS(648),
    [anon_sym_RBRACE] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [482] = {
    [ts_builtin_sym_end] = ACTIONS(198),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(198),
    [sym_keyword_explain] = ACTIONS(198),
    [sym_keyword_parallel] = ACTIONS(198),
    [sym_keyword_timeout] = ACTIONS(198),
    [sym_keyword_fetch] = ACTIONS(198),
    [sym_keyword_limit] = ACTIONS(198),
    [sym_keyword_order] = ACTIONS(198),
    [sym_keyword_with] = ACTIONS(198),
    [sym_keyword_where] = ACTIONS(198),
    [sym_keyword_split] = ACTIONS(198),
    [sym_keyword_group] = ACTIONS(198),
    [sym_keyword_and] = ACTIONS(198),
    [sym_keyword_or] = ACTIONS(200),
    [sym_keyword_is] = ACTIONS(198),
    [sym_keyword_not] = ACTIONS(200),
    [sym_keyword_contains] = ACTIONS(198),
    [sym_keyword_contains_not] = ACTIONS(198),
    [sym_keyword_contains_all] = ACTIONS(198),
    [sym_keyword_contains_any] = ACTIONS(198),
    [sym_keyword_contains_none] = ACTIONS(198),
    [sym_keyword_inside] = ACTIONS(198),
    [sym_keyword_in] = ACTIONS(200),
    [sym_keyword_not_inside] = ACTIONS(198),
    [sym_keyword_all_inside] = ACTIONS(198),
    [sym_keyword_any_inside] = ACTIONS(198),
    [sym_keyword_none_inside] = ACTIONS(198),
    [sym_keyword_outside] = ACTIONS(198),
    [sym_keyword_intersects] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(198),
    [anon_sym_STAR] = ACTIONS(200),
    [anon_sym_LT] = ACTIONS(200),
    [anon_sym_GT] = ACTIONS(200),
    [anon_sym_EQ] = ACTIONS(200),
    [anon_sym_DASH] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(200),
    [anon_sym_LT_PIPE] = ACTIONS(198),
    [anon_sym_AMP_AMP] = ACTIONS(198),
    [anon_sym_PIPE_PIPE] = ACTIONS(198),
    [anon_sym_QMARK_QMARK] = ACTIONS(198),
    [anon_sym_QMARK_COLON] = ACTIONS(198),
    [anon_sym_BANG_EQ] = ACTIONS(198),
    [anon_sym_EQ_EQ] = ACTIONS(198),
    [anon_sym_QMARK_EQ] = ACTIONS(198),
    [anon_sym_STAR_EQ] = ACTIONS(198),
    [anon_sym_TILDE] = ACTIONS(198),
    [anon_sym_BANG_TILDE] = ACTIONS(198),
    [anon_sym_STAR_TILDE] = ACTIONS(198),
    [anon_sym_LT_EQ] = ACTIONS(198),
    [anon_sym_GT_EQ] = ACTIONS(198),
    [anon_sym_PLUS] = ACTIONS(200),
    [anon_sym_PLUS_EQ] = ACTIONS(198),
    [anon_sym_DASH_EQ] = ACTIONS(198),
    [anon_sym_u00d7] = ACTIONS(198),
    [anon_sym_SLASH] = ACTIONS(200),
    [anon_sym_u00f7] = ACTIONS(198),
    [anon_sym_STAR_STAR] = ACTIONS(198),
    [anon_sym_u220b] = ACTIONS(198),
    [anon_sym_u220c] = ACTIONS(198),
    [anon_sym_u2287] = ACTIONS(198),
    [anon_sym_u2283] = ACTIONS(198),
    [anon_sym_u2285] = ACTIONS(198),
    [anon_sym_u2208] = ACTIONS(198),
    [anon_sym_u2209] = ACTIONS(198),
    [anon_sym_u2286] = ACTIONS(198),
    [anon_sym_u2282] = ACTIONS(198),
    [anon_sym_u2284] = ACTIONS(198),
    [anon_sym_AT_AT] = ACTIONS(198),
  },
  [483] = {
    [sym_operator] = STATE(744),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(688),
    [sym_keyword_value] = ACTIONS(688),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_flexible] = ACTIONS(688),
    [sym_keyword_readonly] = ACTIONS(688),
    [sym_keyword_type] = ACTIONS(688),
    [sym_keyword_default] = ACTIONS(688),
    [sym_keyword_assert] = ACTIONS(688),
    [sym_keyword_permissions] = ACTIONS(688),
    [sym_keyword_comment] = ACTIONS(688),
    [anon_sym_RPAREN] = ACTIONS(688),
    [anon_sym_RBRACE] = ACTIONS(688),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [484] = {
    [sym_operator] = STATE(744),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(690),
    [sym_keyword_value] = ACTIONS(690),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_flexible] = ACTIONS(690),
    [sym_keyword_readonly] = ACTIONS(690),
    [sym_keyword_type] = ACTIONS(690),
    [sym_keyword_default] = ACTIONS(690),
    [sym_keyword_assert] = ACTIONS(690),
    [sym_keyword_permissions] = ACTIONS(690),
    [sym_keyword_comment] = ACTIONS(690),
    [anon_sym_RPAREN] = ACTIONS(690),
    [anon_sym_RBRACE] = ACTIONS(690),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [485] = {
    [sym_operator] = STATE(744),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_value] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(648),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [sym_keyword_flexible] = ACTIONS(648),
    [sym_keyword_readonly] = ACTIONS(648),
    [sym_keyword_type] = ACTIONS(648),
    [sym_keyword_default] = ACTIONS(648),
    [sym_keyword_assert] = ACTIONS(648),
    [sym_keyword_permissions] = ACTIONS(648),
    [sym_keyword_comment] = ACTIONS(648),
    [anon_sym_RPAREN] = ACTIONS(648),
    [anon_sym_RBRACE] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [486] = {
    [sym_operator] = STATE(746),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(648),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_as] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(648),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [sym_keyword_drop] = ACTIONS(648),
    [sym_keyword_schemafull] = ACTIONS(648),
    [sym_keyword_schemaless] = ACTIONS(648),
    [sym_keyword_changefeed] = ACTIONS(648),
    [sym_keyword_type] = ACTIONS(648),
    [sym_keyword_permissions] = ACTIONS(648),
    [sym_keyword_for] = ACTIONS(648),
    [sym_keyword_comment] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [487] = {
    [sym_operator] = STATE(732),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(678),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(678),
    [sym_keyword_as] = ACTIONS(678),
    [sym_keyword_group] = ACTIONS(678),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_drop] = ACTIONS(678),
    [sym_keyword_schemafull] = ACTIONS(678),
    [sym_keyword_schemaless] = ACTIONS(678),
    [sym_keyword_changefeed] = ACTIONS(678),
    [sym_keyword_type] = ACTIONS(678),
    [sym_keyword_permissions] = ACTIONS(678),
    [sym_keyword_comment] = ACTIONS(678),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [488] = {
    [sym_operator] = STATE(732),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(648),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_as] = ACTIONS(648),
    [sym_keyword_group] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(648),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [sym_keyword_drop] = ACTIONS(648),
    [sym_keyword_schemafull] = ACTIONS(648),
    [sym_keyword_schemaless] = ACTIONS(648),
    [sym_keyword_changefeed] = ACTIONS(648),
    [sym_keyword_type] = ACTIONS(648),
    [sym_keyword_permissions] = ACTIONS(648),
    [sym_keyword_comment] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [489] = {
    [sym_operator] = STATE(698),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(648),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_explain] = ACTIONS(648),
    [sym_keyword_parallel] = ACTIONS(648),
    [sym_keyword_timeout] = ACTIONS(648),
    [sym_keyword_fetch] = ACTIONS(648),
    [sym_keyword_limit] = ACTIONS(648),
    [sym_keyword_order] = ACTIONS(648),
    [sym_keyword_split] = ACTIONS(648),
    [sym_keyword_group] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(650),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [490] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(692),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [491] = {
    [sym_operator] = STATE(737),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(648),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_value] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(648),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [sym_keyword_flexible] = ACTIONS(648),
    [sym_keyword_readonly] = ACTIONS(648),
    [sym_keyword_type] = ACTIONS(648),
    [sym_keyword_default] = ACTIONS(648),
    [sym_keyword_assert] = ACTIONS(648),
    [sym_keyword_permissions] = ACTIONS(648),
    [sym_keyword_comment] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [492] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_QMARK] = ACTIONS(184),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(694),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [493] = {
    [sym_operator] = STATE(698),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(678),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(678),
    [sym_keyword_explain] = ACTIONS(678),
    [sym_keyword_parallel] = ACTIONS(678),
    [sym_keyword_timeout] = ACTIONS(678),
    [sym_keyword_fetch] = ACTIONS(678),
    [sym_keyword_limit] = ACTIONS(678),
    [sym_keyword_order] = ACTIONS(678),
    [sym_keyword_split] = ACTIONS(678),
    [sym_keyword_group] = ACTIONS(678),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(313),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [494] = {
    [ts_builtin_sym_end] = ACTIONS(182),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_return] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(696),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [495] = {
    [sym_operator] = STATE(737),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(690),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(690),
    [sym_keyword_value] = ACTIONS(690),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_flexible] = ACTIONS(690),
    [sym_keyword_readonly] = ACTIONS(690),
    [sym_keyword_type] = ACTIONS(690),
    [sym_keyword_default] = ACTIONS(690),
    [sym_keyword_assert] = ACTIONS(690),
    [sym_keyword_permissions] = ACTIONS(690),
    [sym_keyword_comment] = ACTIONS(690),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [496] = {
    [sym_operator] = STATE(737),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(688),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(688),
    [sym_keyword_value] = ACTIONS(688),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_flexible] = ACTIONS(688),
    [sym_keyword_readonly] = ACTIONS(688),
    [sym_keyword_type] = ACTIONS(688),
    [sym_keyword_default] = ACTIONS(688),
    [sym_keyword_assert] = ACTIONS(688),
    [sym_keyword_permissions] = ACTIONS(688),
    [sym_keyword_comment] = ACTIONS(688),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [497] = {
    [sym_operator] = STATE(737),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(686),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(686),
    [sym_keyword_value] = ACTIONS(686),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [sym_keyword_flexible] = ACTIONS(686),
    [sym_keyword_readonly] = ACTIONS(686),
    [sym_keyword_type] = ACTIONS(686),
    [sym_keyword_default] = ACTIONS(686),
    [sym_keyword_assert] = ACTIONS(686),
    [sym_keyword_permissions] = ACTIONS(686),
    [sym_keyword_comment] = ACTIONS(686),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [498] = {
    [ts_builtin_sym_end] = ACTIONS(182),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_parallel] = ACTIONS(182),
    [sym_keyword_timeout] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(698),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [499] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_permissions] = ACTIONS(182),
    [sym_keyword_comment] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_RBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(700),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [500] = {
    [sym_operator] = STATE(711),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_return] = ACTIONS(648),
    [sym_keyword_parallel] = ACTIONS(648),
    [sym_keyword_timeout] = ACTIONS(648),
    [sym_keyword_where] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(648),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [anon_sym_COMMA] = ACTIONS(648),
    [anon_sym_RPAREN] = ACTIONS(648),
    [anon_sym_RBRACE] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [501] = {
    [sym_operator] = STATE(711),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(658),
    [sym_keyword_return] = ACTIONS(658),
    [sym_keyword_parallel] = ACTIONS(658),
    [sym_keyword_timeout] = ACTIONS(658),
    [sym_keyword_where] = ACTIONS(658),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(658),
    [anon_sym_RPAREN] = ACTIONS(658),
    [anon_sym_RBRACE] = ACTIONS(658),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [502] = {
    [sym_comment] = ACTIONS(3),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_permissions] = ACTIONS(182),
    [sym_keyword_comment] = ACTIONS(182),
    [sym_keyword_if] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [sym_custom_function_name] = ACTIONS(182),
    [anon_sym_DOT_DOT] = ACTIONS(702),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [503] = {
    [ts_builtin_sym_end] = ACTIONS(182),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_permissions] = ACTIONS(182),
    [sym_keyword_comment] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(704),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [504] = {
    [sym_operator] = STATE(711),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(706),
    [sym_keyword_return] = ACTIONS(706),
    [sym_keyword_parallel] = ACTIONS(706),
    [sym_keyword_timeout] = ACTIONS(706),
    [sym_keyword_where] = ACTIONS(706),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(706),
    [anon_sym_RPAREN] = ACTIONS(706),
    [anon_sym_RBRACE] = ACTIONS(706),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [505] = {
    [sym_comment] = ACTIONS(3),
    [sym_keyword_as] = ACTIONS(182),
    [sym_keyword_where] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(708),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [506] = {
    [sym_comment] = ACTIONS(3),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [sym_keyword_then] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LPAREN] = ACTIONS(182),
    [anon_sym_LBRACE] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(710),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [507] = {
    [sym_operator] = STATE(671),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(706),
    [sym_keyword_return] = ACTIONS(706),
    [sym_keyword_parallel] = ACTIONS(706),
    [sym_keyword_timeout] = ACTIONS(706),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(706),
    [anon_sym_RPAREN] = ACTIONS(706),
    [anon_sym_RBRACE] = ACTIONS(706),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [508] = {
    [sym_comment] = ACTIONS(3),
    [sym_keyword_from] = ACTIONS(182),
    [sym_keyword_as] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(712),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [509] = {
    [sym_operator] = STATE(669),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(706),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(706),
    [sym_keyword_return] = ACTIONS(706),
    [sym_keyword_parallel] = ACTIONS(706),
    [sym_keyword_timeout] = ACTIONS(706),
    [sym_keyword_where] = ACTIONS(706),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(706),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [510] = {
    [sym_operator] = STATE(669),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(658),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(658),
    [sym_keyword_return] = ACTIONS(658),
    [sym_keyword_parallel] = ACTIONS(658),
    [sym_keyword_timeout] = ACTIONS(658),
    [sym_keyword_where] = ACTIONS(658),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(658),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
  [511] = {
    [ts_builtin_sym_end] = ACTIONS(182),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(714),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [512] = {
    [sym_operator] = STATE(671),
    [sym_binary_operator] = STATE(771),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_return] = ACTIONS(648),
    [sym_keyword_parallel] = ACTIONS(648),
    [sym_keyword_timeout] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(648),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [anon_sym_COMMA] = ACTIONS(648),
    [anon_sym_RPAREN] = ACTIONS(648),
    [anon_sym_RBRACE] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [513] = {
    [sym_comment] = ACTIONS(3),
    [sym_keyword_as] = ACTIONS(182),
    [sym_keyword_and] = ACTIONS(182),
    [sym_keyword_or] = ACTIONS(182),
    [sym_keyword_is] = ACTIONS(182),
    [sym_keyword_not] = ACTIONS(184),
    [sym_keyword_contains] = ACTIONS(182),
    [sym_keyword_contains_not] = ACTIONS(182),
    [sym_keyword_contains_all] = ACTIONS(182),
    [sym_keyword_contains_any] = ACTIONS(182),
    [sym_keyword_contains_none] = ACTIONS(182),
    [sym_keyword_inside] = ACTIONS(182),
    [sym_keyword_in] = ACTIONS(184),
    [sym_keyword_not_inside] = ACTIONS(182),
    [sym_keyword_all_inside] = ACTIONS(182),
    [sym_keyword_any_inside] = ACTIONS(182),
    [sym_keyword_none_inside] = ACTIONS(182),
    [sym_keyword_outside] = ACTIONS(182),
    [sym_keyword_intersects] = ACTIONS(182),
    [anon_sym_COMMA] = ACTIONS(182),
    [anon_sym_DASH_GT] = ACTIONS(182),
    [anon_sym_LBRACK] = ACTIONS(182),
    [anon_sym_RPAREN] = ACTIONS(182),
    [anon_sym_LT_DASH] = ACTIONS(184),
    [anon_sym_LT_DASH_GT] = ACTIONS(182),
    [anon_sym_STAR] = ACTIONS(184),
    [anon_sym_DOT] = ACTIONS(184),
    [anon_sym_LT] = ACTIONS(184),
    [anon_sym_GT] = ACTIONS(184),
    [anon_sym_DOT_DOT] = ACTIONS(716),
    [anon_sym_EQ] = ACTIONS(184),
    [anon_sym_DASH] = ACTIONS(184),
    [anon_sym_AT] = ACTIONS(184),
    [anon_sym_LT_PIPE] = ACTIONS(182),
    [anon_sym_AMP_AMP] = ACTIONS(182),
    [anon_sym_PIPE_PIPE] = ACTIONS(182),
    [anon_sym_QMARK_QMARK] = ACTIONS(182),
    [anon_sym_QMARK_COLON] = ACTIONS(182),
    [anon_sym_BANG_EQ] = ACTIONS(182),
    [anon_sym_EQ_EQ] = ACTIONS(182),
    [anon_sym_QMARK_EQ] = ACTIONS(182),
    [anon_sym_STAR_EQ] = ACTIONS(182),
    [anon_sym_TILDE] = ACTIONS(182),
    [anon_sym_BANG_TILDE] = ACTIONS(182),
    [anon_sym_STAR_TILDE] = ACTIONS(182),
    [anon_sym_LT_EQ] = ACTIONS(182),
    [anon_sym_GT_EQ] = ACTIONS(182),
    [anon_sym_PLUS] = ACTIONS(184),
    [anon_sym_PLUS_EQ] = ACTIONS(182),
    [anon_sym_DASH_EQ] = ACTIONS(182),
    [anon_sym_u00d7] = ACTIONS(182),
    [anon_sym_SLASH] = ACTIONS(184),
    [anon_sym_u00f7] = ACTIONS(182),
    [anon_sym_STAR_STAR] = ACTIONS(182),
    [anon_sym_u220b] = ACTIONS(182),
    [anon_sym_u220c] = ACTIONS(182),
    [anon_sym_u2287] = ACTIONS(182),
    [anon_sym_u2283] = ACTIONS(182),
    [anon_sym_u2285] = ACTIONS(182),
    [anon_sym_u2208] = ACTIONS(182),
    [anon_sym_u2209] = ACTIONS(182),
    [anon_sym_u2286] = ACTIONS(182),
    [anon_sym_u2282] = ACTIONS(182),
    [anon_sym_u2284] = ACTIONS(182),
    [anon_sym_AT_AT] = ACTIONS(182),
  },
  [514] = {
    [sym_operator] = STATE(669),
    [sym_binary_operator] = STATE(771),
    [ts_builtin_sym_end] = ACTIONS(648),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(648),
    [sym_keyword_return] = ACTIONS(648),
    [sym_keyword_parallel] = ACTIONS(648),
    [sym_keyword_timeout] = ACTIONS(648),
    [sym_keyword_where] = ACTIONS(648),
    [sym_keyword_and] = ACTIONS(648),
    [sym_keyword_or] = ACTIONS(648),
    [sym_keyword_is] = ACTIONS(648),
    [sym_keyword_not] = ACTIONS(650),
    [sym_keyword_contains] = ACTIONS(648),
    [sym_keyword_contains_not] = ACTIONS(648),
    [sym_keyword_contains_all] = ACTIONS(648),
    [sym_keyword_contains_any] = ACTIONS(648),
    [sym_keyword_contains_none] = ACTIONS(648),
    [sym_keyword_inside] = ACTIONS(648),
    [sym_keyword_in] = ACTIONS(650),
    [sym_keyword_not_inside] = ACTIONS(648),
    [sym_keyword_all_inside] = ACTIONS(648),
    [sym_keyword_any_inside] = ACTIONS(648),
    [sym_keyword_none_inside] = ACTIONS(648),
    [sym_keyword_outside] = ACTIONS(648),
    [sym_keyword_intersects] = ACTIONS(648),
    [anon_sym_COMMA] = ACTIONS(648),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_AT] = ACTIONS(650),
    [anon_sym_LT_PIPE] = ACTIONS(648),
    [anon_sym_AMP_AMP] = ACTIONS(648),
    [anon_sym_PIPE_PIPE] = ACTIONS(648),
    [anon_sym_QMARK_QMARK] = ACTIONS(648),
    [anon_sym_QMARK_COLON] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_QMARK_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_TILDE] = ACTIONS(648),
    [anon_sym_BANG_TILDE] = ACTIONS(648),
    [anon_sym_STAR_TILDE] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_u00d7] = ACTIONS(648),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_u00f7] = ACTIONS(648),
    [anon_sym_STAR_STAR] = ACTIONS(648),
    [anon_sym_u220b] = ACTIONS(648),
    [anon_sym_u220c] = ACTIONS(648),
    [anon_sym_u2287] = ACTIONS(648),
    [anon_sym_u2283] = ACTIONS(648),
    [anon_sym_u2285] = ACTIONS(648),
    [anon_sym_u2208] = ACTIONS(648),
    [anon_sym_u2209] = ACTIONS(648),
    [anon_sym_u2286] = ACTIONS(648),
    [anon_sym_u2282] = ACTIONS(648),
    [anon_sym_u2284] = ACTIONS(648),
    [anon_sym_AT_AT] = ACTIONS(648),
  },
  [515] = {
    [sym_operator] = STATE(660),
    [sym_binary_operator] = STATE(771),
    [aux_sym_update_statement_repeat1] = STATE(1185),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(718),
    [sym_keyword_parallel] = ACTIONS(718),
    [sym_keyword_timeout] = ACTIONS(718),
    [sym_keyword_and] = ACTIONS(311),
    [sym_keyword_or] = ACTIONS(311),
    [sym_keyword_is] = ACTIONS(315),
    [sym_keyword_not] = ACTIONS(317),
    [sym_keyword_contains] = ACTIONS(311),
    [sym_keyword_contains_not] = ACTIONS(311),
    [sym_keyword_contains_all] = ACTIONS(311),
    [sym_keyword_contains_any] = ACTIONS(311),
    [sym_keyword_contains_none] = ACTIONS(311),
    [sym_keyword_inside] = ACTIONS(311),
    [sym_keyword_in] = ACTIONS(313),
    [sym_keyword_not_inside] = ACTIONS(311),
    [sym_keyword_all_inside] = ACTIONS(311),
    [sym_keyword_any_inside] = ACTIONS(311),
    [sym_keyword_none_inside] = ACTIONS(311),
    [sym_keyword_outside] = ACTIONS(311),
    [sym_keyword_intersects] = ACTIONS(311),
    [anon_sym_COMMA] = ACTIONS(720),
    [anon_sym_RPAREN] = ACTIONS(718),
    [anon_sym_RBRACE] = ACTIONS(718),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_EQ] = ACTIONS(313),
    [anon_sym_DASH] = ACTIONS(313),
    [anon_sym_AT] = ACTIONS(323),
    [anon_sym_LT_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_QMARK_QMARK] = ACTIONS(327),
    [anon_sym_QMARK_COLON] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_QMARK_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_BANG_TILDE] = ACTIONS(327),
    [anon_sym_STAR_TILDE] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_PLUS] = ACTIONS(321),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_u00d7] = ACTIONS(327),
    [anon_sym_SLASH] = ACTIONS(321),
    [anon_sym_u00f7] = ACTIONS(327),
    [anon_sym_STAR_STAR] = ACTIONS(327),
    [anon_sym_u220b] = ACTIONS(327),
    [anon_sym_u220c] = ACTIONS(327),
    [anon_sym_u2287] = ACTIONS(327),
    [anon_sym_u2283] = ACTIONS(327),
    [anon_sym_u2285] = ACTIONS(327),
    [anon_sym_u2208] = ACTIONS(327),
    [anon_sym_u2209] = ACTIONS(327),
    [anon_sym_u2286] = ACTIONS(327),
    [anon_sym_u2282] = ACTIONS(327),
    [anon_sym_u2284] = ACTIONS(327),
    [anon_sym_AT_AT] = ACTIONS(327),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(650), 11,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(648), 50,
      sym_semi_colon,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [75] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(660), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(658), 6,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [164] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(660), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(650), 10,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(648), 51,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [239] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(722), 1,
      anon_sym_COMMA,
    STATE(722), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1228), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(718), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [332] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(724), 1,
      anon_sym_DOT_DOT,
    ACTIONS(184), 12,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_LT_DASH,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(182), 50,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      sym_keyword_if,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LT_DASH_GT,
      sym_variable_name,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [405] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(682), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(706), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_COMMA,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [494] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(682), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(650), 10,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(648), 51,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [569] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(671), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(678), 6,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [658] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(722), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(650), 10,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(648), 50,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [732] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(706), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(650), 10,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(648), 50,
      sym_semi_colon,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [806] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(722), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(658), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_COMMA,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [894] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(726), 1,
      anon_sym_COMMA,
    ACTIONS(160), 11,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_LT_DASH,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(158), 50,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_LT_DASH_GT,
      anon_sym_DOT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [966] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(728), 1,
      sym_keyword_as,
    ACTIONS(730), 1,
      sym_keyword_where,
    STATE(750), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1485), 1,
      sym_where_clause,
    ACTIONS(732), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1060] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(734), 1,
      anon_sym_COMMA,
    ACTIONS(160), 11,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_LT_DASH,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(158), 50,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_LT_DASH_GT,
      anon_sym_DOT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1132] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(736), 1,
      anon_sym_COMMA,
    ACTIONS(160), 11,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_LT_DASH,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(158), 50,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_LT_DASH_GT,
      anon_sym_DOT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1204] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(738), 1,
      anon_sym_COMMA,
    ACTIONS(160), 11,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_LT_DASH,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(158), 50,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_LT_DASH_GT,
      anon_sym_DOT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1276] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(740), 1,
      anon_sym_COMMA,
    ACTIONS(160), 11,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_LT_DASH,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(158), 50,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_LT_DASH_GT,
      anon_sym_DOT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1348] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(742), 1,
      anon_sym_COMMA,
    ACTIONS(160), 11,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_LT_DASH,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(158), 50,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_LT_DASH_GT,
      anon_sym_DOT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1420] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(706), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(678), 5,
      sym_semi_colon,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1508] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(682), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(678), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1596] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(744), 1,
      sym_keyword_then,
    ACTIONS(746), 1,
      anon_sym_LPAREN,
    ACTIONS(748), 1,
      anon_sym_LBRACE,
    STATE(686), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1174), 2,
      sym_block,
      sym_sub_query,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1690] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(654), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(678), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_permissions,
      sym_keyword_comment,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1777] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(706), 4,
      sym_semi_colon,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1864] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(654), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(650), 10,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(648), 49,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1937] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(691), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(650), 10,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(648), 49,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_if,
      sym_custom_function_name,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2010] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(691), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(678), 4,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_if,
      sym_custom_function_name,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2097] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(750), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(650), 10,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(648), 49,
      sym_keyword_as,
      sym_keyword_where,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2170] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(729), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(650), 10,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(648), 48,
      sym_keyword_from,
      sym_keyword_as,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2242] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(752), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1482), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2332] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(754), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1540), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2422] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(715), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(678), 3,
      sym_keyword_as,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2508] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(756), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1454), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2598] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(715), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(650), 10,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(648), 48,
      sym_keyword_as,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2670] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(758), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1453), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2760] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(760), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1512), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2850] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(658), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2936] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(762), 1,
      anon_sym_RBRACK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1463), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3026] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(764), 1,
      anon_sym_RBRACK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1448), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3116] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(766), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1564), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3206] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(768), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1417), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3296] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(770), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1557), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3386] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(772), 1,
      anon_sym_RBRACK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1553), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3476] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(774), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1484), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3566] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(776), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1549), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3656] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(778), 1,
      anon_sym_RBRACK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1476), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3746] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(780), 1,
      anon_sym_RBRACK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1504), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3836] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(718), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(650), 10,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(648), 48,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3908] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(782), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1418), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3998] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(784), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4084] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(718), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(706), 3,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_COMMA,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4170] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(786), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1529), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4260] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(788), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1481), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4350] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(792), 1,
      sym_keyword_as,
    STATE(729), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(790), 2,
      sym_keyword_from,
      anon_sym_COMMA,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4438] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(794), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4524] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(796), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1505), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4614] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(798), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1510), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4704] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(800), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1544), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4794] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(686), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(650), 10,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(648), 48,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      sym_keyword_then,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4866] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(802), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1509), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4956] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(804), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1539), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5046] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(806), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5132] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(808), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1442), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5222] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(810), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1534), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5312] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(812), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1422), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5402] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(814), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1421), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5492] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(816), 1,
      anon_sym_RBRACK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1429), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5582] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(818), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1528), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5672] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(820), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1497), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5762] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(822), 1,
      anon_sym_RPAREN,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    STATE(1498), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5852] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(679), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(824), 2,
      sym_keyword_if,
      sym_variable_name,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5937] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(678), 1,
      anon_sym_RBRACK,
    ACTIONS(826), 1,
      anon_sym_QMARK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6024] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(679), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(828), 2,
      sym_keyword_if,
      sym_variable_name,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6109] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(718), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(794), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6194] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(718), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(784), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6279] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(679), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(650), 10,
      sym_keyword_not,
      sym_keyword_in,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(648), 47,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      sym_keyword_if,
      sym_variable_name,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6350] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(718), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(806), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6435] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(830), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6520] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(832), 1,
      anon_sym_RBRACK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6604] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(834), 1,
      anon_sym_RBRACK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6688] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(836), 1,
      anon_sym_RBRACK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6772] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(838), 1,
      anon_sym_RBRACK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6856] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(840), 1,
      anon_sym_RBRACK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6940] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(842), 1,
      anon_sym_RBRACK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7024] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(844), 1,
      anon_sym_RBRACK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7108] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(846), 1,
      anon_sym_RBRACK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7192] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(848), 1,
      anon_sym_RBRACK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7276] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(678), 1,
      ts_builtin_sym_end,
    STATE(718), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7360] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(850), 1,
      anon_sym_RBRACK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7444] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(852), 1,
      anon_sym_RBRACK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7528] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(315), 1,
      sym_keyword_is,
    ACTIONS(317), 1,
      sym_keyword_not,
    ACTIONS(323), 1,
      anon_sym_AT,
    ACTIONS(325), 1,
      anon_sym_LT_PIPE,
    ACTIONS(854), 1,
      anon_sym_RBRACK,
    STATE(677), 1,
      sym_operator,
    STATE(771), 1,
      sym_binary_operator,
    ACTIONS(321), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(313), 5,
      sym_keyword_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_DASH,
    ACTIONS(311), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
    ACTIONS(327), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7612] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(856), 1,
      sym_keyword_value,
    ACTIONS(858), 1,
      anon_sym_STAR,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(568), 1,
      sym_value,
    STATE(1525), 1,
      sym_inclusive_predicate,
    STATE(1599), 1,
      sym_predicate,
    STATE(1839), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [7706] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(858), 1,
      anon_sym_STAR,
    ACTIONS(860), 1,
      sym_keyword_value,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(568), 1,
      sym_value,
    STATE(1440), 1,
      sym_inclusive_predicate,
    STATE(1599), 1,
      sym_predicate,
    STATE(1839), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [7800] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(858), 1,
      anon_sym_STAR,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(568), 1,
      sym_value,
    STATE(1599), 1,
      sym_predicate,
    STATE(1619), 1,
      sym_inclusive_predicate,
    STATE(1839), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [7891] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(858), 1,
      anon_sym_STAR,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(568), 1,
      sym_value,
    STATE(1433), 1,
      sym_inclusive_predicate,
    STATE(1599), 1,
      sym_predicate,
    STATE(1839), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [7982] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_LT_DASH,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(162), 1,
      sym_graph_path,
    STATE(168), 1,
      sym_base_value,
    STATE(519), 1,
      sym_value,
    STATE(1758), 1,
      sym_object_key,
    ACTIONS(35), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(862), 3,
      sym_keyword_diff,
      sym_keyword_before,
      sym_keyword_after,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [8069] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(515), 1,
      sym_value,
    STATE(1752), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(862), 3,
      sym_keyword_diff,
      sym_keyword_before,
      sym_keyword_after,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [8156] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(858), 1,
      anon_sym_STAR,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(568), 1,
      sym_value,
    STATE(1518), 1,
      sym_inclusive_predicate,
    STATE(1599), 1,
      sym_predicate,
    STATE(1839), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [8247] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(864), 1,
      sym_keyword_where,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(598), 1,
      sym_value,
    STATE(1677), 1,
      sym_where_clause,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [8335] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(223), 1,
      anon_sym_LT_DASH,
    ACTIONS(359), 1,
      anon_sym_LBRACE,
    ACTIONS(866), 1,
      sym_keyword_by,
    ACTIONS(872), 1,
      sym_keyword_count,
    ACTIONS(874), 1,
      anon_sym_LBRACK,
    ACTIONS(876), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      aux_sym_type_name_token1,
    ACTIONS(884), 1,
      sym_decimal,
    ACTIONS(886), 1,
      sym_duration_part,
    STATE(67), 1,
      sym_base_value,
    STATE(69), 1,
      sym_graph_path,
    STATE(92), 1,
      aux_sym_duration_repeat1,
    STATE(380), 1,
      sym_value,
    STATE(1020), 1,
      sym_order_criteria,
    STATE(1733), 1,
      sym_object_key,
    ACTIONS(219), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(882), 2,
      sym_int,
      sym_float,
    ACTIONS(868), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(880), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(192), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(870), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(110), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [8423] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(888), 1,
      anon_sym_QMARK,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(528), 1,
      sym_value,
    STATE(1431), 1,
      sym_graph_predicate,
    STATE(1774), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [8511] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(888), 1,
      anon_sym_QMARK,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(528), 1,
      sym_value,
    STATE(1624), 1,
      sym_graph_predicate,
    STATE(1774), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [8599] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(864), 1,
      sym_keyword_where,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(596), 1,
      sym_value,
    STATE(1652), 1,
      sym_where_clause,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [8687] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(864), 1,
      sym_keyword_where,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(595), 1,
      sym_value,
    STATE(1654), 1,
      sym_where_clause,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [8775] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(888), 1,
      anon_sym_QMARK,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(528), 1,
      sym_value,
    STATE(1503), 1,
      sym_graph_predicate,
    STATE(1774), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [8863] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(888), 1,
      anon_sym_QMARK,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(528), 1,
      sym_value,
    STATE(1475), 1,
      sym_graph_predicate,
    STATE(1774), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [8951] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(864), 1,
      sym_keyword_where,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(605), 1,
      sym_value,
    STATE(1591), 1,
      sym_where_clause,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [9039] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(888), 1,
      anon_sym_QMARK,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(528), 1,
      sym_value,
    STATE(1565), 1,
      sym_graph_predicate,
    STATE(1774), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [9127] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(864), 1,
      sym_keyword_where,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(603), 1,
      sym_value,
    STATE(1614), 1,
      sym_where_clause,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [9215] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(247), 1,
      anon_sym_LT_DASH,
    ACTIONS(890), 1,
      sym_keyword_by,
    ACTIONS(892), 1,
      sym_duration_part,
    STATE(72), 1,
      sym_base_value,
    STATE(81), 1,
      sym_graph_path,
    STATE(100), 1,
      aux_sym_duration_repeat1,
    STATE(412), 1,
      sym_value,
    STATE(1053), 1,
      sym_order_criteria,
    STATE(1750), 1,
      sym_object_key,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(243), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [9303] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(888), 1,
      anon_sym_QMARK,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(528), 1,
      sym_value,
    STATE(1447), 1,
      sym_graph_predicate,
    STATE(1774), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [9391] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(864), 1,
      sym_keyword_where,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(597), 1,
      sym_value,
    STATE(1615), 1,
      sym_where_clause,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [9479] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(888), 1,
      anon_sym_QMARK,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(528), 1,
      sym_value,
    STATE(1559), 1,
      sym_graph_predicate,
    STATE(1774), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [9567] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(894), 1,
      anon_sym_RPAREN,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(574), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [9652] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(896), 1,
      anon_sym_RPAREN,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(555), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [9737] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(568), 1,
      sym_value,
    STATE(1805), 1,
      sym_predicate,
    STATE(1839), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [9822] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(898), 1,
      anon_sym_RPAREN,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(567), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [9907] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(900), 1,
      anon_sym_RPAREN,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(556), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [9992] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(902), 1,
      anon_sym_RBRACK,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(560), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [10077] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(904), 1,
      anon_sym_RPAREN,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(559), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [10162] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(906), 1,
      anon_sym_RBRACK,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(552), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [10247] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(568), 1,
      sym_value,
    STATE(1763), 1,
      sym_predicate,
    STATE(1839), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [10332] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(908), 1,
      anon_sym_RPAREN,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(545), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [10417] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(247), 1,
      anon_sym_LT_DASH,
    ACTIONS(892), 1,
      sym_duration_part,
    STATE(72), 1,
      sym_base_value,
    STATE(81), 1,
      sym_graph_path,
    STATE(100), 1,
      aux_sym_duration_repeat1,
    STATE(412), 1,
      sym_value,
    STATE(1019), 1,
      sym_order_criteria,
    STATE(1750), 1,
      sym_object_key,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(243), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [10502] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(910), 1,
      anon_sym_RPAREN,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(549), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [10587] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(912), 1,
      anon_sym_RPAREN,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(572), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [10672] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(914), 1,
      anon_sym_RBRACK,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(561), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [10757] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(916), 1,
      anon_sym_RBRACK,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(557), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [10842] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(247), 1,
      anon_sym_LT_DASH,
    ACTIONS(892), 1,
      sym_duration_part,
    STATE(72), 1,
      sym_base_value,
    STATE(81), 1,
      sym_graph_path,
    STATE(100), 1,
      aux_sym_duration_repeat1,
    STATE(412), 1,
      sym_value,
    STATE(1102), 1,
      sym_order_criteria,
    STATE(1750), 1,
      sym_object_key,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(243), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [10927] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(918), 1,
      anon_sym_RPAREN,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(582), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11012] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(920), 1,
      anon_sym_RBRACK,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(581), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11097] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(223), 1,
      anon_sym_LT_DASH,
    ACTIONS(359), 1,
      anon_sym_LBRACE,
    ACTIONS(872), 1,
      sym_keyword_count,
    ACTIONS(874), 1,
      anon_sym_LBRACK,
    ACTIONS(876), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      aux_sym_type_name_token1,
    ACTIONS(884), 1,
      sym_decimal,
    ACTIONS(886), 1,
      sym_duration_part,
    STATE(67), 1,
      sym_base_value,
    STATE(69), 1,
      sym_graph_path,
    STATE(92), 1,
      aux_sym_duration_repeat1,
    STATE(380), 1,
      sym_value,
    STATE(1021), 1,
      sym_order_criteria,
    STATE(1733), 1,
      sym_object_key,
    ACTIONS(219), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(882), 2,
      sym_int,
      sym_float,
    ACTIONS(868), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(880), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(192), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(870), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(110), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11182] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(922), 1,
      anon_sym_RPAREN,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(580), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11267] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(924), 1,
      anon_sym_RPAREN,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(578), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11352] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(926), 1,
      anon_sym_RPAREN,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(575), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11437] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    ACTIONS(928), 1,
      anon_sym_RBRACK,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(553), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11522] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(223), 1,
      anon_sym_LT_DASH,
    ACTIONS(359), 1,
      anon_sym_LBRACE,
    ACTIONS(872), 1,
      sym_keyword_count,
    ACTIONS(874), 1,
      anon_sym_LBRACK,
    ACTIONS(876), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      aux_sym_type_name_token1,
    ACTIONS(884), 1,
      sym_decimal,
    ACTIONS(886), 1,
      sym_duration_part,
    STATE(67), 1,
      sym_base_value,
    STATE(69), 1,
      sym_graph_path,
    STATE(92), 1,
      aux_sym_duration_repeat1,
    STATE(380), 1,
      sym_value,
    STATE(1019), 1,
      sym_order_criteria,
    STATE(1733), 1,
      sym_object_key,
    ACTIONS(219), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(882), 2,
      sym_int,
      sym_float,
    ACTIONS(868), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(880), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(192), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(870), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(110), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11607] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(550), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11689] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(437), 1,
      sym_value,
    STATE(1690), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11771] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_LT_DASH,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(162), 1,
      sym_graph_path,
    STATE(168), 1,
      sym_base_value,
    STATE(539), 1,
      sym_value,
    STATE(1720), 1,
      sym_object_key,
    ACTIONS(35), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11853] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(534), 1,
      sym_value,
    STATE(1707), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11935] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(247), 1,
      anon_sym_LT_DASH,
    ACTIONS(892), 1,
      sym_duration_part,
    STATE(72), 1,
      sym_base_value,
    STATE(81), 1,
      sym_graph_path,
    STATE(100), 1,
      aux_sym_duration_repeat1,
    STATE(471), 1,
      sym_value,
    STATE(1717), 1,
      sym_object_key,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(243), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12017] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_duration_part,
    ACTIONS(398), 1,
      anon_sym_LBRACE,
    ACTIONS(438), 1,
      anon_sym_LT_DASH,
    ACTIONS(934), 1,
      sym_keyword_count,
    ACTIONS(936), 1,
      anon_sym_LBRACK,
    ACTIONS(938), 1,
      anon_sym_LPAREN,
    ACTIONS(940), 1,
      aux_sym_type_name_token1,
    ACTIONS(946), 1,
      sym_decimal,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(158), 1,
      sym_graph_path,
    STATE(166), 1,
      sym_base_value,
    STATE(326), 1,
      sym_value,
    STATE(1727), 1,
      sym_object_key,
    ACTIONS(434), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(944), 2,
      sym_int,
      sym_float,
    ACTIONS(930), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(942), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(420), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(932), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(273), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12099] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(424), 1,
      sym_value,
    STATE(1711), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12181] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_LBRACE,
    ACTIONS(420), 1,
      anon_sym_LT_DASH,
    ACTIONS(624), 1,
      sym_keyword_count,
    ACTIONS(626), 1,
      anon_sym_LBRACK,
    ACTIONS(628), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      aux_sym_type_name_token1,
    ACTIONS(636), 1,
      sym_decimal,
    ACTIONS(638), 1,
      sym_duration_part,
    STATE(155), 1,
      sym_graph_path,
    STATE(157), 1,
      sym_base_value,
    STATE(220), 1,
      aux_sym_duration_repeat1,
    STATE(378), 1,
      sym_value,
    STATE(1754), 1,
      sym_object_key,
    ACTIONS(416), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(634), 2,
      sym_int,
      sym_float,
    ACTIONS(620), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(632), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(455), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(622), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(300), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12263] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(518), 1,
      sym_value,
    STATE(1752), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12345] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(586), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12427] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(382), 1,
      sym_value,
    STATE(1713), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12509] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_LBRACE,
    ACTIONS(420), 1,
      anon_sym_LT_DASH,
    ACTIONS(624), 1,
      sym_keyword_count,
    ACTIONS(626), 1,
      anon_sym_LBRACK,
    ACTIONS(628), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      aux_sym_type_name_token1,
    ACTIONS(636), 1,
      sym_decimal,
    ACTIONS(638), 1,
      sym_duration_part,
    STATE(155), 1,
      sym_graph_path,
    STATE(157), 1,
      sym_base_value,
    STATE(220), 1,
      aux_sym_duration_repeat1,
    STATE(397), 1,
      sym_value,
    STATE(1719), 1,
      sym_object_key,
    ACTIONS(416), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(634), 2,
      sym_int,
      sym_float,
    ACTIONS(620), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(632), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(455), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(622), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(300), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12591] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_LT_DASH,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(162), 1,
      sym_graph_path,
    STATE(168), 1,
      sym_base_value,
    STATE(602), 1,
      sym_value,
    STATE(1827), 1,
      sym_object_key,
    ACTIONS(35), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12673] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(592), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12755] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_LT_DASH,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(162), 1,
      sym_graph_path,
    STATE(168), 1,
      sym_base_value,
    STATE(565), 1,
      sym_value,
    STATE(1827), 1,
      sym_object_key,
    ACTIONS(35), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12837] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(442), 1,
      anon_sym_LBRACE,
    ACTIONS(452), 1,
      anon_sym_LT_DASH,
    ACTIONS(588), 1,
      sym_keyword_count,
    ACTIONS(590), 1,
      anon_sym_LBRACK,
    ACTIONS(592), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      aux_sym_type_name_token1,
    ACTIONS(600), 1,
      sym_decimal,
    ACTIONS(602), 1,
      sym_duration_part,
    STATE(175), 1,
      sym_graph_path,
    STATE(185), 1,
      sym_base_value,
    STATE(240), 1,
      aux_sym_duration_repeat1,
    STATE(400), 1,
      sym_value,
    STATE(1761), 1,
      sym_object_key,
    ACTIONS(448), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(598), 2,
      sym_int,
      sym_float,
    ACTIONS(584), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(596), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(478), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(586), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(332), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12919] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_LT_DASH,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(162), 1,
      sym_graph_path,
    STATE(168), 1,
      sym_base_value,
    STATE(535), 1,
      sym_value,
    STATE(1757), 1,
      sym_object_key,
    ACTIONS(35), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13001] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_LT_DASH,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(162), 1,
      sym_graph_path,
    STATE(168), 1,
      sym_base_value,
    STATE(514), 1,
      sym_value,
    STATE(1796), 1,
      sym_object_key,
    ACTIONS(35), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13083] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(422), 1,
      sym_value,
    STATE(1690), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13165] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(512), 1,
      sym_value,
    STATE(1751), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13247] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_duration_part,
    ACTIONS(398), 1,
      anon_sym_LBRACE,
    ACTIONS(438), 1,
      anon_sym_LT_DASH,
    ACTIONS(934), 1,
      sym_keyword_count,
    ACTIONS(936), 1,
      anon_sym_LBRACK,
    ACTIONS(938), 1,
      anon_sym_LPAREN,
    ACTIONS(940), 1,
      aux_sym_type_name_token1,
    ACTIONS(946), 1,
      sym_decimal,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(158), 1,
      sym_graph_path,
    STATE(166), 1,
      sym_base_value,
    STATE(418), 1,
      sym_value,
    STATE(1727), 1,
      sym_object_key,
    ACTIONS(434), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(944), 2,
      sym_int,
      sym_float,
    ACTIONS(930), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(942), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(420), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(932), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(273), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13329] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(442), 1,
      anon_sym_LBRACE,
    ACTIONS(452), 1,
      anon_sym_LT_DASH,
    ACTIONS(588), 1,
      sym_keyword_count,
    ACTIONS(590), 1,
      anon_sym_LBRACK,
    ACTIONS(592), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      aux_sym_type_name_token1,
    ACTIONS(600), 1,
      sym_decimal,
    ACTIONS(602), 1,
      sym_duration_part,
    STATE(175), 1,
      sym_graph_path,
    STATE(185), 1,
      sym_base_value,
    STATE(240), 1,
      aux_sym_duration_repeat1,
    STATE(416), 1,
      sym_value,
    STATE(1761), 1,
      sym_object_key,
    ACTIONS(448), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(598), 2,
      sym_int,
      sym_float,
    ACTIONS(584), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(596), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(478), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(586), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(332), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13411] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(566), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13493] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_LBRACE,
    ACTIONS(420), 1,
      anon_sym_LT_DASH,
    ACTIONS(624), 1,
      sym_keyword_count,
    ACTIONS(626), 1,
      anon_sym_LBRACK,
    ACTIONS(628), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      aux_sym_type_name_token1,
    ACTIONS(636), 1,
      sym_decimal,
    ACTIONS(638), 1,
      sym_duration_part,
    STATE(155), 1,
      sym_graph_path,
    STATE(157), 1,
      sym_base_value,
    STATE(220), 1,
      aux_sym_duration_repeat1,
    STATE(386), 1,
      sym_value,
    STATE(1754), 1,
      sym_object_key,
    ACTIONS(416), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(634), 2,
      sym_int,
      sym_float,
    ACTIONS(620), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(632), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(455), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(622), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(300), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13575] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_LT_DASH,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(162), 1,
      sym_graph_path,
    STATE(168), 1,
      sym_base_value,
    STATE(509), 1,
      sym_value,
    STATE(1796), 1,
      sym_object_key,
    ACTIONS(35), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13657] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(516), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13739] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(223), 1,
      anon_sym_LT_DASH,
    ACTIONS(359), 1,
      anon_sym_LBRACE,
    ACTIONS(872), 1,
      sym_keyword_count,
    ACTIONS(874), 1,
      anon_sym_LBRACK,
    ACTIONS(876), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      aux_sym_type_name_token1,
    ACTIONS(884), 1,
      sym_decimal,
    ACTIONS(886), 1,
      sym_duration_part,
    STATE(67), 1,
      sym_base_value,
    STATE(69), 1,
      sym_graph_path,
    STATE(92), 1,
      aux_sym_duration_repeat1,
    STATE(451), 1,
      sym_value,
    STATE(1781), 1,
      sym_object_key,
    ACTIONS(219), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(882), 2,
      sym_int,
      sym_float,
    ACTIONS(868), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(880), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(192), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(870), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(110), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13821] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(590), 1,
      sym_value,
    STATE(1747), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13903] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(247), 1,
      anon_sym_LT_DASH,
    ACTIONS(892), 1,
      sym_duration_part,
    STATE(72), 1,
      sym_base_value,
    STATE(81), 1,
      sym_graph_path,
    STATE(100), 1,
      aux_sym_duration_repeat1,
    STATE(497), 1,
      sym_value,
    STATE(1743), 1,
      sym_object_key,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(243), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13985] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(501), 1,
      sym_value,
    STATE(1772), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14067] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_LT_DASH,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(162), 1,
      sym_graph_path,
    STATE(168), 1,
      sym_base_value,
    STATE(522), 1,
      sym_value,
    STATE(1757), 1,
      sym_object_key,
    ACTIONS(35), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14149] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(272), 1,
      sym_value,
    STATE(1713), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14231] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(587), 1,
      sym_value,
    STATE(1747), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14313] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(504), 1,
      sym_value,
    STATE(1772), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14395] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(573), 1,
      sym_value,
    STATE(1702), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14477] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(271), 1,
      sym_value,
    STATE(1713), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14559] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_duration_part,
    ACTIONS(398), 1,
      anon_sym_LBRACE,
    ACTIONS(438), 1,
      anon_sym_LT_DASH,
    ACTIONS(934), 1,
      sym_keyword_count,
    ACTIONS(936), 1,
      anon_sym_LBRACK,
    ACTIONS(938), 1,
      anon_sym_LPAREN,
    ACTIONS(940), 1,
      aux_sym_type_name_token1,
    ACTIONS(946), 1,
      sym_decimal,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(158), 1,
      sym_graph_path,
    STATE(166), 1,
      sym_base_value,
    STATE(306), 1,
      sym_value,
    STATE(1727), 1,
      sym_object_key,
    ACTIONS(434), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(944), 2,
      sym_int,
      sym_float,
    ACTIONS(930), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(942), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(420), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(932), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(273), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14641] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(247), 1,
      anon_sym_LT_DASH,
    ACTIONS(892), 1,
      sym_duration_part,
    STATE(72), 1,
      sym_base_value,
    STATE(81), 1,
      sym_graph_path,
    STATE(100), 1,
      aux_sym_duration_repeat1,
    STATE(496), 1,
      sym_value,
    STATE(1743), 1,
      sym_object_key,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(243), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14723] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(223), 1,
      anon_sym_LT_DASH,
    ACTIONS(359), 1,
      anon_sym_LBRACE,
    ACTIONS(872), 1,
      sym_keyword_count,
    ACTIONS(874), 1,
      anon_sym_LBRACK,
    ACTIONS(876), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      aux_sym_type_name_token1,
    ACTIONS(884), 1,
      sym_decimal,
    ACTIONS(886), 1,
      sym_duration_part,
    STATE(67), 1,
      sym_base_value,
    STATE(69), 1,
      sym_graph_path,
    STATE(92), 1,
      aux_sym_duration_repeat1,
    STATE(396), 1,
      sym_value,
    STATE(1733), 1,
      sym_object_key,
    ACTIONS(219), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(882), 2,
      sym_int,
      sym_float,
    ACTIONS(868), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(880), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(192), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(870), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(110), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14805] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(540), 1,
      sym_value,
    STATE(1718), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14887] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(593), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14969] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(541), 1,
      sym_value,
    STATE(1718), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15051] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(585), 1,
      sym_value,
    STATE(1747), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15133] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(577), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15215] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(517), 1,
      sym_value,
    STATE(1752), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15297] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(594), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15379] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(442), 1,
      anon_sym_LBRACE,
    ACTIONS(452), 1,
      anon_sym_LT_DASH,
    ACTIONS(588), 1,
      sym_keyword_count,
    ACTIONS(590), 1,
      anon_sym_LBRACK,
    ACTIONS(592), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      aux_sym_type_name_token1,
    ACTIONS(600), 1,
      sym_decimal,
    ACTIONS(602), 1,
      sym_duration_part,
    STATE(175), 1,
      sym_graph_path,
    STATE(185), 1,
      sym_base_value,
    STATE(240), 1,
      aux_sym_duration_repeat1,
    STATE(489), 1,
      sym_value,
    STATE(1749), 1,
      sym_object_key,
    ACTIONS(448), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(598), 2,
      sym_int,
      sym_float,
    ACTIONS(584), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(596), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(478), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(586), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(332), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15461] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_LBRACE,
    ACTIONS(420), 1,
      anon_sym_LT_DASH,
    ACTIONS(624), 1,
      sym_keyword_count,
    ACTIONS(626), 1,
      anon_sym_LBRACK,
    ACTIONS(628), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      aux_sym_type_name_token1,
    ACTIONS(636), 1,
      sym_decimal,
    ACTIONS(638), 1,
      sym_duration_part,
    STATE(155), 1,
      sym_graph_path,
    STATE(157), 1,
      sym_base_value,
    STATE(220), 1,
      aux_sym_duration_repeat1,
    STATE(460), 1,
      sym_value,
    STATE(1731), 1,
      sym_object_key,
    ACTIONS(416), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(634), 2,
      sym_int,
      sym_float,
    ACTIONS(620), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(632), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(455), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(622), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(300), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15543] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(442), 1,
      anon_sym_LBRACE,
    ACTIONS(452), 1,
      anon_sym_LT_DASH,
    ACTIONS(588), 1,
      sym_keyword_count,
    ACTIONS(590), 1,
      anon_sym_LBRACK,
    ACTIONS(592), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      aux_sym_type_name_token1,
    ACTIONS(600), 1,
      sym_decimal,
    ACTIONS(602), 1,
      sym_duration_part,
    STATE(175), 1,
      sym_graph_path,
    STATE(185), 1,
      sym_base_value,
    STATE(240), 1,
      aux_sym_duration_repeat1,
    STATE(446), 1,
      sym_value,
    STATE(1738), 1,
      sym_object_key,
    ACTIONS(448), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(598), 2,
      sym_int,
      sym_float,
    ACTIONS(584), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(596), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(478), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(586), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(332), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15625] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(546), 1,
      sym_value,
    STATE(1755), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15707] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(395), 1,
      sym_value,
    STATE(1713), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15789] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(604), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15871] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(439), 1,
      sym_value,
    STATE(1711), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15953] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_LBRACE,
    ACTIONS(420), 1,
      anon_sym_LT_DASH,
    ACTIONS(624), 1,
      sym_keyword_count,
    ACTIONS(626), 1,
      anon_sym_LBRACK,
    ACTIONS(628), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      aux_sym_type_name_token1,
    ACTIONS(636), 1,
      sym_decimal,
    ACTIONS(638), 1,
      sym_duration_part,
    STATE(155), 1,
      sym_graph_path,
    STATE(157), 1,
      sym_base_value,
    STATE(220), 1,
      aux_sym_duration_repeat1,
    STATE(481), 1,
      sym_value,
    STATE(1731), 1,
      sym_object_key,
    ACTIONS(416), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(634), 2,
      sym_int,
      sym_float,
    ACTIONS(620), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(632), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(455), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(622), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(300), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16035] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(525), 1,
      sym_value,
    STATE(1707), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16117] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_LT_DASH,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(162), 1,
      sym_graph_path,
    STATE(168), 1,
      sym_base_value,
    STATE(435), 1,
      sym_value,
    STATE(1789), 1,
      sym_object_key,
    ACTIONS(35), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16199] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(442), 1,
      anon_sym_LBRACE,
    ACTIONS(452), 1,
      anon_sym_LT_DASH,
    ACTIONS(588), 1,
      sym_keyword_count,
    ACTIONS(590), 1,
      anon_sym_LBRACK,
    ACTIONS(592), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      aux_sym_type_name_token1,
    ACTIONS(600), 1,
      sym_decimal,
    ACTIONS(602), 1,
      sym_duration_part,
    STATE(175), 1,
      sym_graph_path,
    STATE(185), 1,
      sym_base_value,
    STATE(240), 1,
      aux_sym_duration_repeat1,
    STATE(409), 1,
      sym_value,
    STATE(1738), 1,
      sym_object_key,
    ACTIONS(448), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(598), 2,
      sym_int,
      sym_float,
    ACTIONS(584), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(596), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(478), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(586), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(332), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16281] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(507), 1,
      sym_value,
    STATE(1751), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16363] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(569), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16445] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(500), 1,
      sym_value,
    STATE(1772), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16527] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(223), 1,
      anon_sym_LT_DASH,
    ACTIONS(359), 1,
      anon_sym_LBRACE,
    ACTIONS(872), 1,
      sym_keyword_count,
    ACTIONS(874), 1,
      anon_sym_LBRACK,
    ACTIONS(876), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      aux_sym_type_name_token1,
    ACTIONS(884), 1,
      sym_decimal,
    ACTIONS(886), 1,
      sym_duration_part,
    STATE(67), 1,
      sym_base_value,
    STATE(69), 1,
      sym_graph_path,
    STATE(92), 1,
      aux_sym_duration_repeat1,
    STATE(479), 1,
      sym_value,
    STATE(1729), 1,
      sym_object_key,
    ACTIONS(219), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(882), 2,
      sym_int,
      sym_float,
    ACTIONS(868), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(880), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(192), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(870), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(110), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16609] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(223), 1,
      anon_sym_LT_DASH,
    ACTIONS(359), 1,
      anon_sym_LBRACE,
    ACTIONS(872), 1,
      sym_keyword_count,
    ACTIONS(874), 1,
      anon_sym_LBRACK,
    ACTIONS(876), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      aux_sym_type_name_token1,
    ACTIONS(884), 1,
      sym_decimal,
    ACTIONS(886), 1,
      sym_duration_part,
    STATE(67), 1,
      sym_base_value,
    STATE(69), 1,
      sym_graph_path,
    STATE(92), 1,
      aux_sym_duration_repeat1,
    STATE(483), 1,
      sym_value,
    STATE(1729), 1,
      sym_object_key,
    ACTIONS(219), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(882), 2,
      sym_int,
      sym_float,
    ACTIONS(868), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(880), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(192), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(870), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(110), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16691] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(223), 1,
      anon_sym_LT_DASH,
    ACTIONS(359), 1,
      anon_sym_LBRACE,
    ACTIONS(872), 1,
      sym_keyword_count,
    ACTIONS(874), 1,
      anon_sym_LBRACK,
    ACTIONS(876), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      aux_sym_type_name_token1,
    ACTIONS(884), 1,
      sym_decimal,
    ACTIONS(886), 1,
      sym_duration_part,
    STATE(67), 1,
      sym_base_value,
    STATE(69), 1,
      sym_graph_path,
    STATE(92), 1,
      aux_sym_duration_repeat1,
    STATE(484), 1,
      sym_value,
    STATE(1729), 1,
      sym_object_key,
    ACTIONS(219), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(882), 2,
      sym_int,
      sym_float,
    ACTIONS(868), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(880), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(192), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(870), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(110), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16773] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(548), 1,
      sym_value,
    STATE(1755), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16855] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_LT_DASH,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(162), 1,
      sym_graph_path,
    STATE(168), 1,
      sym_base_value,
    STATE(521), 1,
      sym_value,
    STATE(1757), 1,
      sym_object_key,
    ACTIONS(35), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16937] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(247), 1,
      anon_sym_LT_DASH,
    ACTIONS(892), 1,
      sym_duration_part,
    STATE(72), 1,
      sym_base_value,
    STATE(81), 1,
      sym_graph_path,
    STATE(100), 1,
      aux_sym_duration_repeat1,
    STATE(495), 1,
      sym_value,
    STATE(1743), 1,
      sym_object_key,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(243), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17019] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_LT_DASH,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(162), 1,
      sym_graph_path,
    STATE(168), 1,
      sym_base_value,
    STATE(562), 1,
      sym_value,
    STATE(1827), 1,
      sym_object_key,
    ACTIONS(35), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17101] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(601), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17183] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_duration_part,
    ACTIONS(398), 1,
      anon_sym_LBRACE,
    ACTIONS(438), 1,
      anon_sym_LT_DASH,
    ACTIONS(934), 1,
      sym_keyword_count,
    ACTIONS(936), 1,
      anon_sym_LBRACK,
    ACTIONS(938), 1,
      anon_sym_LPAREN,
    ACTIONS(940), 1,
      aux_sym_type_name_token1,
    ACTIONS(946), 1,
      sym_decimal,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(158), 1,
      sym_graph_path,
    STATE(166), 1,
      sym_base_value,
    STATE(466), 1,
      sym_value,
    STATE(1723), 1,
      sym_object_key,
    ACTIONS(434), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(944), 2,
      sym_int,
      sym_float,
    ACTIONS(930), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(942), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(420), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(932), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(273), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17265] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(247), 1,
      anon_sym_LT_DASH,
    ACTIONS(892), 1,
      sym_duration_part,
    STATE(72), 1,
      sym_base_value,
    STATE(81), 1,
      sym_graph_path,
    STATE(100), 1,
      aux_sym_duration_repeat1,
    STATE(401), 1,
      sym_value,
    STATE(1750), 1,
      sym_object_key,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(243), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17347] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_LT_DASH,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(162), 1,
      sym_graph_path,
    STATE(168), 1,
      sym_base_value,
    STATE(524), 1,
      sym_value,
    STATE(1758), 1,
      sym_object_key,
    ACTIONS(35), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17429] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_LT_DASH,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(162), 1,
      sym_graph_path,
    STATE(168), 1,
      sym_base_value,
    STATE(589), 1,
      sym_value,
    STATE(1827), 1,
      sym_object_key,
    ACTIONS(35), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17511] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_LBRACE,
    ACTIONS(420), 1,
      anon_sym_LT_DASH,
    ACTIONS(624), 1,
      sym_keyword_count,
    ACTIONS(626), 1,
      anon_sym_LBRACK,
    ACTIONS(628), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      aux_sym_type_name_token1,
    ACTIONS(636), 1,
      sym_decimal,
    ACTIONS(638), 1,
      sym_duration_part,
    STATE(155), 1,
      sym_graph_path,
    STATE(157), 1,
      sym_base_value,
    STATE(220), 1,
      aux_sym_duration_repeat1,
    STATE(413), 1,
      sym_value,
    STATE(1719), 1,
      sym_object_key,
    ACTIONS(416), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(634), 2,
      sym_int,
      sym_float,
    ACTIONS(620), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(632), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(455), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(622), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(300), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17593] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(523), 1,
      sym_value,
    STATE(1751), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17675] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_duration_part,
    ACTIONS(398), 1,
      anon_sym_LBRACE,
    ACTIONS(438), 1,
      anon_sym_LT_DASH,
    ACTIONS(934), 1,
      sym_keyword_count,
    ACTIONS(936), 1,
      anon_sym_LBRACK,
    ACTIONS(938), 1,
      anon_sym_LPAREN,
    ACTIONS(940), 1,
      aux_sym_type_name_token1,
    ACTIONS(946), 1,
      sym_decimal,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(158), 1,
      sym_graph_path,
    STATE(166), 1,
      sym_base_value,
    STATE(410), 1,
      sym_value,
    STATE(1727), 1,
      sym_object_key,
    ACTIONS(434), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(944), 2,
      sym_int,
      sym_float,
    ACTIONS(930), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(942), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(420), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(932), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(273), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17757] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(570), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17839] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(584), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17921] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(543), 1,
      sym_value,
    STATE(1839), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18003] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_LT_DASH,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(162), 1,
      sym_graph_path,
    STATE(168), 1,
      sym_base_value,
    STATE(588), 1,
      sym_value,
    STATE(1827), 1,
      sym_object_key,
    ACTIONS(35), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18085] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(408), 1,
      sym_value,
    STATE(1762), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18167] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_duration_part,
    ACTIONS(398), 1,
      anon_sym_LBRACE,
    ACTIONS(438), 1,
      anon_sym_LT_DASH,
    ACTIONS(934), 1,
      sym_keyword_count,
    ACTIONS(936), 1,
      anon_sym_LBRACK,
    ACTIONS(938), 1,
      anon_sym_LPAREN,
    ACTIONS(940), 1,
      aux_sym_type_name_token1,
    ACTIONS(946), 1,
      sym_decimal,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(158), 1,
      sym_graph_path,
    STATE(166), 1,
      sym_base_value,
    STATE(488), 1,
      sym_value,
    STATE(1705), 1,
      sym_object_key,
    ACTIONS(434), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(944), 2,
      sym_int,
      sym_float,
    ACTIONS(930), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(942), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(420), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(932), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(273), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18249] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(564), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18331] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(600), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18413] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(583), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18495] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(536), 1,
      sym_value,
    STATE(1702), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18577] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(247), 1,
      anon_sym_LT_DASH,
    ACTIONS(892), 1,
      sym_duration_part,
    STATE(72), 1,
      sym_base_value,
    STATE(81), 1,
      sym_graph_path,
    STATE(100), 1,
      aux_sym_duration_repeat1,
    STATE(491), 1,
      sym_value,
    STATE(1743), 1,
      sym_object_key,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(243), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18659] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(223), 1,
      anon_sym_LT_DASH,
    ACTIONS(359), 1,
      anon_sym_LBRACE,
    ACTIONS(872), 1,
      sym_keyword_count,
    ACTIONS(874), 1,
      anon_sym_LBRACK,
    ACTIONS(876), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      aux_sym_type_name_token1,
    ACTIONS(884), 1,
      sym_decimal,
    ACTIONS(886), 1,
      sym_duration_part,
    STATE(67), 1,
      sym_base_value,
    STATE(69), 1,
      sym_graph_path,
    STATE(92), 1,
      aux_sym_duration_repeat1,
    STATE(427), 1,
      sym_value,
    STATE(1781), 1,
      sym_object_key,
    ACTIONS(219), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(882), 2,
      sym_int,
      sym_float,
    ACTIONS(868), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(880), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(192), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(870), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(110), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18741] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(247), 1,
      anon_sym_LT_DASH,
    ACTIONS(892), 1,
      sym_duration_part,
    STATE(72), 1,
      sym_base_value,
    STATE(81), 1,
      sym_graph_path,
    STATE(100), 1,
      aux_sym_duration_repeat1,
    STATE(472), 1,
      sym_value,
    STATE(1717), 1,
      sym_object_key,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(243), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18823] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(599), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18905] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(442), 1,
      anon_sym_LBRACE,
    ACTIONS(452), 1,
      anon_sym_LT_DASH,
    ACTIONS(588), 1,
      sym_keyword_count,
    ACTIONS(590), 1,
      anon_sym_LBRACK,
    ACTIONS(592), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      aux_sym_type_name_token1,
    ACTIONS(600), 1,
      sym_decimal,
    ACTIONS(602), 1,
      sym_duration_part,
    STATE(175), 1,
      sym_graph_path,
    STATE(185), 1,
      sym_base_value,
    STATE(240), 1,
      aux_sym_duration_repeat1,
    STATE(493), 1,
      sym_value,
    STATE(1749), 1,
      sym_object_key,
    ACTIONS(448), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(598), 2,
      sym_int,
      sym_float,
    ACTIONS(584), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(596), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(478), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(586), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(332), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18987] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_LBRACE,
    ACTIONS(420), 1,
      anon_sym_LT_DASH,
    ACTIONS(624), 1,
      sym_keyword_count,
    ACTIONS(626), 1,
      anon_sym_LBRACK,
    ACTIONS(628), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      aux_sym_type_name_token1,
    ACTIONS(636), 1,
      sym_decimal,
    ACTIONS(638), 1,
      sym_duration_part,
    STATE(155), 1,
      sym_graph_path,
    STATE(157), 1,
      sym_base_value,
    STATE(220), 1,
      aux_sym_duration_repeat1,
    STATE(402), 1,
      sym_value,
    STATE(1719), 1,
      sym_object_key,
    ACTIONS(416), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(634), 2,
      sym_int,
      sym_float,
    ACTIONS(620), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(632), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(455), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(622), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(300), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19069] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(558), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19151] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(223), 1,
      anon_sym_LT_DASH,
    ACTIONS(359), 1,
      anon_sym_LBRACE,
    ACTIONS(872), 1,
      sym_keyword_count,
    ACTIONS(874), 1,
      anon_sym_LBRACK,
    ACTIONS(876), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      aux_sym_type_name_token1,
    ACTIONS(884), 1,
      sym_decimal,
    ACTIONS(886), 1,
      sym_duration_part,
    STATE(67), 1,
      sym_base_value,
    STATE(69), 1,
      sym_graph_path,
    STATE(92), 1,
      aux_sym_duration_repeat1,
    STATE(485), 1,
      sym_value,
    STATE(1729), 1,
      sym_object_key,
    ACTIONS(219), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(882), 2,
      sym_int,
      sym_float,
    ACTIONS(868), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(880), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(192), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(870), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(110), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19233] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(442), 1,
      anon_sym_LBRACE,
    ACTIONS(452), 1,
      anon_sym_LT_DASH,
    ACTIONS(588), 1,
      sym_keyword_count,
    ACTIONS(590), 1,
      anon_sym_LBRACK,
    ACTIONS(592), 1,
      anon_sym_LPAREN,
    ACTIONS(594), 1,
      aux_sym_type_name_token1,
    ACTIONS(600), 1,
      sym_decimal,
    ACTIONS(602), 1,
      sym_duration_part,
    STATE(175), 1,
      sym_graph_path,
    STATE(185), 1,
      sym_base_value,
    STATE(240), 1,
      aux_sym_duration_repeat1,
    STATE(447), 1,
      sym_value,
    STATE(1738), 1,
      sym_object_key,
    ACTIONS(448), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(598), 2,
      sym_int,
      sym_float,
    ACTIONS(584), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(596), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(478), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(586), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(332), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19315] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_duration_part,
    ACTIONS(398), 1,
      anon_sym_LBRACE,
    ACTIONS(438), 1,
      anon_sym_LT_DASH,
    ACTIONS(934), 1,
      sym_keyword_count,
    ACTIONS(936), 1,
      anon_sym_LBRACK,
    ACTIONS(938), 1,
      anon_sym_LPAREN,
    ACTIONS(940), 1,
      aux_sym_type_name_token1,
    ACTIONS(946), 1,
      sym_decimal,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(158), 1,
      sym_graph_path,
    STATE(166), 1,
      sym_base_value,
    STATE(486), 1,
      sym_value,
    STATE(1723), 1,
      sym_object_key,
    ACTIONS(434), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(944), 2,
      sym_int,
      sym_float,
    ACTIONS(930), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(942), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(420), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(932), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(273), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19397] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(538), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19479] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(403), 1,
      sym_value,
    STATE(1762), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19561] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_duration_part,
    ACTIONS(398), 1,
      anon_sym_LBRACE,
    ACTIONS(438), 1,
      anon_sym_LT_DASH,
    ACTIONS(934), 1,
      sym_keyword_count,
    ACTIONS(936), 1,
      anon_sym_LBRACK,
    ACTIONS(938), 1,
      anon_sym_LPAREN,
    ACTIONS(940), 1,
      aux_sym_type_name_token1,
    ACTIONS(946), 1,
      sym_decimal,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(158), 1,
      sym_graph_path,
    STATE(166), 1,
      sym_base_value,
    STATE(487), 1,
      sym_value,
    STATE(1705), 1,
      sym_object_key,
    ACTIONS(434), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(944), 2,
      sym_int,
      sym_float,
    ACTIONS(930), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(942), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(420), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(932), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(273), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19643] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(542), 1,
      sym_value,
    STATE(1774), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19725] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_LT_DASH,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(162), 1,
      sym_graph_path,
    STATE(168), 1,
      sym_base_value,
    STATE(510), 1,
      sym_value,
    STATE(1796), 1,
      sym_object_key,
    ACTIONS(35), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19807] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_LT_DASH,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(162), 1,
      sym_graph_path,
    STATE(168), 1,
      sym_base_value,
    STATE(442), 1,
      sym_value,
    STATE(1789), 1,
      sym_object_key,
    ACTIONS(35), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19889] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_LT_DASH,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(162), 1,
      sym_graph_path,
    STATE(168), 1,
      sym_base_value,
    STATE(526), 1,
      sym_value,
    STATE(1758), 1,
      sym_object_key,
    ACTIONS(35), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19971] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LT_DASH,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(518), 1,
      sym_keyword_count,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LPAREN,
    ACTIONS(526), 1,
      aux_sym_type_name_token1,
    ACTIONS(532), 1,
      sym_decimal,
    ACTIONS(534), 1,
      sym_duration_part,
    STATE(3), 1,
      sym_base_value,
    STATE(4), 1,
      sym_graph_path,
    STATE(8), 1,
      aux_sym_duration_repeat1,
    STATE(551), 1,
      sym_value,
    STATE(1780), 1,
      sym_object_key,
    ACTIONS(63), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(530), 2,
      sym_int,
      sym_float,
    ACTIONS(502), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(528), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(86), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(504), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(25), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [20053] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_LT_DASH,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(51), 1,
      sym_decimal,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(162), 1,
      sym_graph_path,
    STATE(168), 1,
      sym_base_value,
    STATE(537), 1,
      sym_value,
    STATE(1720), 1,
      sym_object_key,
    ACTIONS(35), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(47), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    STATE(99), 3,
      sym_function_call,
      sym_binary_expression,
      sym_path,
    ACTIONS(11), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(58), 8,
      sym_number,
      sym_identifier,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [20135] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(950), 1,
      sym_keyword_bm25,
    ACTIONS(952), 1,
      sym_keyword_doc_ids_cache,
    ACTIONS(954), 1,
      sym_keyword_doc_ids_order,
    ACTIONS(956), 1,
      sym_keyword_doc_lengths_cache,
    ACTIONS(958), 1,
      sym_keyword_doc_lengths_order,
    ACTIONS(960), 1,
      sym_keyword_postings_cache,
    ACTIONS(962), 1,
      sym_keyword_postings_order,
    ACTIONS(964), 1,
      sym_keyword_terms_cache,
    ACTIONS(966), 1,
      sym_keyword_terms_order,
    ACTIONS(968), 1,
      sym_keyword_highlights,
    ACTIONS(948), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(758), 10,
      sym_bm25_clause,
      sym_doc_ids_cache_clause,
      sym_doc_ids_order_clause,
      sym_doc_lengths_cache_clause,
      sym_doc_lengths_order_clause,
      sym_postings_cache_clause,
      sym_postings_order_clause,
      sym_terms_cache_clause,
      sym_terms_order_clause,
      aux_sym_search_analyzer_clause_repeat1,
  [20189] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(972), 1,
      sym_keyword_bm25,
    ACTIONS(975), 1,
      sym_keyword_doc_ids_cache,
    ACTIONS(978), 1,
      sym_keyword_doc_ids_order,
    ACTIONS(981), 1,
      sym_keyword_doc_lengths_cache,
    ACTIONS(984), 1,
      sym_keyword_doc_lengths_order,
    ACTIONS(987), 1,
      sym_keyword_postings_cache,
    ACTIONS(990), 1,
      sym_keyword_postings_order,
    ACTIONS(993), 1,
      sym_keyword_terms_cache,
    ACTIONS(996), 1,
      sym_keyword_terms_order,
    ACTIONS(999), 1,
      sym_keyword_highlights,
    ACTIONS(970), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(757), 10,
      sym_bm25_clause,
      sym_doc_ids_cache_clause,
      sym_doc_ids_order_clause,
      sym_doc_lengths_cache_clause,
      sym_doc_lengths_order_clause,
      sym_postings_cache_clause,
      sym_postings_order_clause,
      sym_terms_cache_clause,
      sym_terms_order_clause,
      aux_sym_search_analyzer_clause_repeat1,
  [20243] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(950), 1,
      sym_keyword_bm25,
    ACTIONS(952), 1,
      sym_keyword_doc_ids_cache,
    ACTIONS(954), 1,
      sym_keyword_doc_ids_order,
    ACTIONS(956), 1,
      sym_keyword_doc_lengths_cache,
    ACTIONS(958), 1,
      sym_keyword_doc_lengths_order,
    ACTIONS(960), 1,
      sym_keyword_postings_cache,
    ACTIONS(962), 1,
      sym_keyword_postings_order,
    ACTIONS(964), 1,
      sym_keyword_terms_cache,
    ACTIONS(966), 1,
      sym_keyword_terms_order,
    ACTIONS(1004), 1,
      sym_keyword_highlights,
    ACTIONS(1002), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(757), 10,
      sym_bm25_clause,
      sym_doc_ids_cache_clause,
      sym_doc_ids_order_clause,
      sym_doc_lengths_cache_clause,
      sym_doc_lengths_order_clause,
      sym_postings_cache_clause,
      sym_postings_order_clause,
      sym_terms_cache_clause,
      sym_terms_order_clause,
      aux_sym_search_analyzer_clause_repeat1,
  [20297] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    ACTIONS(303), 1,
      sym_keyword_with,
    ACTIONS(305), 1,
      sym_keyword_where,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(319), 1,
      anon_sym_COMMA,
    STATE(779), 1,
      sym_with_clause,
    STATE(794), 1,
      sym_where_clause,
    STATE(818), 1,
      sym_split_clause,
    STATE(858), 1,
      sym_group_clause,
    STATE(861), 1,
      aux_sym_update_statement_repeat1,
    STATE(879), 1,
      sym_order_clause,
    STATE(961), 1,
      sym_limit_clause,
    STATE(1003), 1,
      sym_fetch_clause,
    STATE(1145), 1,
      sym_timeout_clause,
    STATE(1203), 1,
      sym_parallel_clause,
    STATE(1382), 1,
      sym_explain_clause,
    ACTIONS(329), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [20372] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    ACTIONS(303), 1,
      sym_keyword_with,
    ACTIONS(305), 1,
      sym_keyword_where,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(319), 1,
      anon_sym_COMMA,
    STATE(781), 1,
      sym_with_clause,
    STATE(796), 1,
      sym_where_clause,
    STATE(813), 1,
      sym_split_clause,
    STATE(861), 1,
      aux_sym_update_statement_repeat1,
    STATE(864), 1,
      sym_group_clause,
    STATE(900), 1,
      sym_order_clause,
    STATE(956), 1,
      sym_limit_clause,
    STATE(1024), 1,
      sym_fetch_clause,
    STATE(1158), 1,
      sym_timeout_clause,
    STATE(1215), 1,
      sym_parallel_clause,
    STATE(1370), 1,
      sym_explain_clause,
    ACTIONS(1006), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [20447] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    ACTIONS(303), 1,
      sym_keyword_with,
    ACTIONS(305), 1,
      sym_keyword_where,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(319), 1,
      anon_sym_COMMA,
    STATE(780), 1,
      sym_with_clause,
    STATE(797), 1,
      sym_where_clause,
    STATE(820), 1,
      sym_split_clause,
    STATE(861), 1,
      aux_sym_update_statement_repeat1,
    STATE(862), 1,
      sym_group_clause,
    STATE(892), 1,
      sym_order_clause,
    STATE(974), 1,
      sym_limit_clause,
    STATE(1007), 1,
      sym_fetch_clause,
    STATE(1106), 1,
      sym_timeout_clause,
    STATE(1251), 1,
      sym_parallel_clause,
    STATE(1309), 1,
      sym_explain_clause,
    ACTIONS(289), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [20522] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1008), 24,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_group,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_out,
      sym_keyword_to,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_unique,
      sym_keyword_search,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [20552] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(333), 1,
      sym_keyword_order,
    ACTIONS(335), 1,
      sym_keyword_with,
    ACTIONS(337), 1,
      sym_keyword_where,
    ACTIONS(339), 1,
      anon_sym_COMMA,
    STATE(783), 1,
      sym_with_clause,
    STATE(798), 1,
      sym_where_clause,
    STATE(854), 1,
      sym_split_clause,
    STATE(879), 1,
      sym_order_clause,
    STATE(880), 1,
      sym_group_clause,
    STATE(896), 1,
      aux_sym_update_statement_repeat1,
    STATE(961), 1,
      sym_limit_clause,
    STATE(1003), 1,
      sym_fetch_clause,
    STATE(1145), 1,
      sym_timeout_clause,
    STATE(1203), 1,
      sym_parallel_clause,
    STATE(1382), 1,
      sym_explain_clause,
    ACTIONS(329), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [20626] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(333), 1,
      sym_keyword_order,
    ACTIONS(335), 1,
      sym_keyword_with,
    ACTIONS(337), 1,
      sym_keyword_where,
    ACTIONS(339), 1,
      anon_sym_COMMA,
    STATE(782), 1,
      sym_with_clause,
    STATE(806), 1,
      sym_where_clause,
    STATE(831), 1,
      sym_split_clause,
    STATE(896), 1,
      aux_sym_update_statement_repeat1,
    STATE(900), 1,
      sym_order_clause,
    STATE(901), 1,
      sym_group_clause,
    STATE(956), 1,
      sym_limit_clause,
    STATE(1024), 1,
      sym_fetch_clause,
    STATE(1158), 1,
      sym_timeout_clause,
    STATE(1215), 1,
      sym_parallel_clause,
    STATE(1370), 1,
      sym_explain_clause,
    ACTIONS(1006), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [20700] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(333), 1,
      sym_keyword_order,
    ACTIONS(335), 1,
      sym_keyword_with,
    ACTIONS(337), 1,
      sym_keyword_where,
    ACTIONS(339), 1,
      anon_sym_COMMA,
    STATE(786), 1,
      sym_with_clause,
    STATE(804), 1,
      sym_where_clause,
    STATE(842), 1,
      sym_split_clause,
    STATE(890), 1,
      sym_group_clause,
    STATE(892), 1,
      sym_order_clause,
    STATE(896), 1,
      aux_sym_update_statement_repeat1,
    STATE(974), 1,
      sym_limit_clause,
    STATE(1007), 1,
      sym_fetch_clause,
    STATE(1106), 1,
      sym_timeout_clause,
    STATE(1251), 1,
      sym_parallel_clause,
    STATE(1309), 1,
      sym_explain_clause,
    ACTIONS(289), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [20774] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1012), 1,
      sym_keyword_not,
    ACTIONS(1014), 10,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LT_DASH_GT,
      sym_string,
      sym_prefixed_string,
      sym_decimal,
      sym_variable_name,
      sym_duration_part,
    ACTIONS(1010), 12,
      sym_keyword_rand,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
      sym_keyword_count,
      anon_sym_LT_DASH,
      aux_sym_type_name_token1,
      sym_int,
      sym_float,
      sym_custom_function_name,
      sym_function_name,
  [20807] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    ACTIONS(345), 1,
      sym_keyword_where,
    ACTIONS(347), 1,
      sym_keyword_content,
    ACTIONS(349), 1,
      sym_keyword_merge,
    ACTIONS(351), 1,
      sym_keyword_patch,
    ACTIONS(353), 1,
      sym_keyword_set,
    ACTIONS(355), 1,
      sym_keyword_unset,
    ACTIONS(357), 1,
      anon_sym_COMMA,
    STATE(905), 1,
      aux_sym_update_statement_repeat1,
    STATE(1099), 1,
      sym_where_clause,
    STATE(1166), 1,
      sym_return_clause,
    STATE(1256), 1,
      sym_timeout_clause,
    STATE(1395), 1,
      sym_parallel_clause,
    ACTIONS(375), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(990), 5,
      sym_content_clause,
      sym_set_clause,
      sym_unset_clause,
      sym_merge_clause,
      sym_patch_clause,
  [20868] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    ACTIONS(345), 1,
      sym_keyword_where,
    ACTIONS(347), 1,
      sym_keyword_content,
    ACTIONS(349), 1,
      sym_keyword_merge,
    ACTIONS(351), 1,
      sym_keyword_patch,
    ACTIONS(353), 1,
      sym_keyword_set,
    ACTIONS(355), 1,
      sym_keyword_unset,
    ACTIONS(357), 1,
      anon_sym_COMMA,
    STATE(905), 1,
      aux_sym_update_statement_repeat1,
    STATE(1043), 1,
      sym_where_clause,
    STATE(1133), 1,
      sym_return_clause,
    STATE(1221), 1,
      sym_timeout_clause,
    STATE(1356), 1,
      sym_parallel_clause,
    ACTIONS(1016), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(992), 5,
      sym_content_clause,
      sym_set_clause,
      sym_unset_clause,
      sym_merge_clause,
      sym_patch_clause,
  [20929] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1020), 10,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LT_DASH_GT,
      sym_string,
      sym_prefixed_string,
      sym_decimal,
      sym_variable_name,
      sym_duration_part,
    ACTIONS(1018), 12,
      sym_keyword_rand,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
      sym_keyword_count,
      anon_sym_LT_DASH,
      aux_sym_type_name_token1,
      sym_int,
      sym_float,
      sym_custom_function_name,
      sym_function_name,
  [20959] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1024), 10,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LT_DASH_GT,
      sym_string,
      sym_prefixed_string,
      sym_decimal,
      sym_variable_name,
      sym_duration_part,
    ACTIONS(1022), 12,
      sym_keyword_rand,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
      sym_keyword_count,
      anon_sym_LT_DASH,
      aux_sym_type_name_token1,
      sym_int,
      sym_float,
      sym_custom_function_name,
      sym_function_name,
  [20989] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1014), 10,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LT_DASH_GT,
      sym_string,
      sym_prefixed_string,
      sym_decimal,
      sym_variable_name,
      sym_duration_part,
    ACTIONS(1010), 12,
      sym_keyword_rand,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
      sym_keyword_count,
      anon_sym_LT_DASH,
      aux_sym_type_name_token1,
      sym_int,
      sym_float,
      sym_custom_function_name,
      sym_function_name,
  [21019] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(347), 1,
      sym_keyword_content,
    ACTIONS(349), 1,
      sym_keyword_merge,
    ACTIONS(351), 1,
      sym_keyword_patch,
    ACTIONS(424), 1,
      sym_keyword_return,
    ACTIONS(426), 1,
      sym_keyword_where,
    ACTIONS(428), 1,
      sym_keyword_set,
    ACTIONS(430), 1,
      sym_keyword_unset,
    ACTIONS(432), 1,
      anon_sym_COMMA,
    STATE(937), 1,
      aux_sym_update_statement_repeat1,
    STATE(1166), 1,
      sym_return_clause,
    STATE(1167), 1,
      sym_where_clause,
    STATE(1256), 1,
      sym_timeout_clause,
    STATE(1395), 1,
      sym_parallel_clause,
    ACTIONS(375), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1017), 5,
      sym_content_clause,
      sym_set_clause,
      sym_unset_clause,
      sym_merge_clause,
      sym_patch_clause,
  [21079] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1028), 10,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LT_DASH_GT,
      sym_string,
      sym_prefixed_string,
      sym_decimal,
      sym_variable_name,
      sym_duration_part,
    ACTIONS(1026), 12,
      sym_keyword_rand,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
      sym_keyword_count,
      anon_sym_LT_DASH,
      aux_sym_type_name_token1,
      sym_int,
      sym_float,
      sym_custom_function_name,
      sym_function_name,
  [21109] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1032), 10,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LT_DASH_GT,
      sym_string,
      sym_prefixed_string,
      sym_decimal,
      sym_variable_name,
      sym_duration_part,
    ACTIONS(1030), 12,
      sym_keyword_rand,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
      sym_keyword_count,
      anon_sym_LT_DASH,
      aux_sym_type_name_token1,
      sym_int,
      sym_float,
      sym_custom_function_name,
      sym_function_name,
  [21139] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1036), 10,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LT_DASH_GT,
      sym_string,
      sym_prefixed_string,
      sym_decimal,
      sym_variable_name,
      sym_duration_part,
    ACTIONS(1034), 12,
      sym_keyword_rand,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
      sym_keyword_count,
      anon_sym_LT_DASH,
      aux_sym_type_name_token1,
      sym_int,
      sym_float,
      sym_custom_function_name,
      sym_function_name,
  [21169] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(347), 1,
      sym_keyword_content,
    ACTIONS(349), 1,
      sym_keyword_merge,
    ACTIONS(351), 1,
      sym_keyword_patch,
    ACTIONS(424), 1,
      sym_keyword_return,
    ACTIONS(426), 1,
      sym_keyword_where,
    ACTIONS(428), 1,
      sym_keyword_set,
    ACTIONS(430), 1,
      sym_keyword_unset,
    ACTIONS(432), 1,
      anon_sym_COMMA,
    STATE(937), 1,
      aux_sym_update_statement_repeat1,
    STATE(1133), 1,
      sym_return_clause,
    STATE(1135), 1,
      sym_where_clause,
    STATE(1221), 1,
      sym_timeout_clause,
    STATE(1356), 1,
      sym_parallel_clause,
    ACTIONS(1016), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1004), 5,
      sym_content_clause,
      sym_set_clause,
      sym_unset_clause,
      sym_merge_clause,
      sym_patch_clause,
  [21229] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1040), 10,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LT_DASH_GT,
      sym_string,
      sym_prefixed_string,
      sym_decimal,
      sym_variable_name,
      sym_duration_part,
    ACTIONS(1038), 12,
      sym_keyword_rand,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
      sym_keyword_count,
      anon_sym_LT_DASH,
      aux_sym_type_name_token1,
      sym_int,
      sym_float,
      sym_custom_function_name,
      sym_function_name,
  [21259] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    ACTIONS(305), 1,
      sym_keyword_where,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    STATE(794), 1,
      sym_where_clause,
    STATE(818), 1,
      sym_split_clause,
    STATE(858), 1,
      sym_group_clause,
    STATE(879), 1,
      sym_order_clause,
    STATE(961), 1,
      sym_limit_clause,
    STATE(1003), 1,
      sym_fetch_clause,
    STATE(1145), 1,
      sym_timeout_clause,
    STATE(1203), 1,
      sym_parallel_clause,
    STATE(1382), 1,
      sym_explain_clause,
    ACTIONS(329), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [21322] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    ACTIONS(305), 1,
      sym_keyword_where,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    STATE(797), 1,
      sym_where_clause,
    STATE(820), 1,
      sym_split_clause,
    STATE(862), 1,
      sym_group_clause,
    STATE(892), 1,
      sym_order_clause,
    STATE(974), 1,
      sym_limit_clause,
    STATE(1007), 1,
      sym_fetch_clause,
    STATE(1106), 1,
      sym_timeout_clause,
    STATE(1251), 1,
      sym_parallel_clause,
    STATE(1309), 1,
      sym_explain_clause,
    ACTIONS(289), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [21385] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    ACTIONS(305), 1,
      sym_keyword_where,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    STATE(796), 1,
      sym_where_clause,
    STATE(813), 1,
      sym_split_clause,
    STATE(864), 1,
      sym_group_clause,
    STATE(900), 1,
      sym_order_clause,
    STATE(956), 1,
      sym_limit_clause,
    STATE(1024), 1,
      sym_fetch_clause,
    STATE(1158), 1,
      sym_timeout_clause,
    STATE(1215), 1,
      sym_parallel_clause,
    STATE(1370), 1,
      sym_explain_clause,
    ACTIONS(1006), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [21448] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    ACTIONS(305), 1,
      sym_keyword_where,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    STATE(788), 1,
      sym_where_clause,
    STATE(824), 1,
      sym_split_clause,
    STATE(856), 1,
      sym_group_clause,
    STATE(894), 1,
      sym_order_clause,
    STATE(988), 1,
      sym_limit_clause,
    STATE(998), 1,
      sym_fetch_clause,
    STATE(1118), 1,
      sym_timeout_clause,
    STATE(1229), 1,
      sym_parallel_clause,
    STATE(1348), 1,
      sym_explain_clause,
    ACTIONS(1042), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [21511] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(333), 1,
      sym_keyword_order,
    ACTIONS(337), 1,
      sym_keyword_where,
    STATE(799), 1,
      sym_where_clause,
    STATE(837), 1,
      sym_split_clause,
    STATE(891), 1,
      sym_group_clause,
    STATE(894), 1,
      sym_order_clause,
    STATE(988), 1,
      sym_limit_clause,
    STATE(998), 1,
      sym_fetch_clause,
    STATE(1118), 1,
      sym_timeout_clause,
    STATE(1229), 1,
      sym_parallel_clause,
    STATE(1348), 1,
      sym_explain_clause,
    ACTIONS(1042), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [21573] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(333), 1,
      sym_keyword_order,
    ACTIONS(337), 1,
      sym_keyword_where,
    STATE(804), 1,
      sym_where_clause,
    STATE(842), 1,
      sym_split_clause,
    STATE(890), 1,
      sym_group_clause,
    STATE(892), 1,
      sym_order_clause,
    STATE(974), 1,
      sym_limit_clause,
    STATE(1007), 1,
      sym_fetch_clause,
    STATE(1106), 1,
      sym_timeout_clause,
    STATE(1251), 1,
      sym_parallel_clause,
    STATE(1309), 1,
      sym_explain_clause,
    ACTIONS(289), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [21635] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1044), 20,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_function,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_tokenizers,
      sym_keyword_filters,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_session,
      sym_keyword_signin,
      sym_keyword_signup,
      sym_keyword_if,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      sym_custom_function_name,
  [21661] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(333), 1,
      sym_keyword_order,
    ACTIONS(337), 1,
      sym_keyword_where,
    STATE(798), 1,
      sym_where_clause,
    STATE(854), 1,
      sym_split_clause,
    STATE(879), 1,
      sym_order_clause,
    STATE(880), 1,
      sym_group_clause,
    STATE(961), 1,
      sym_limit_clause,
    STATE(1003), 1,
      sym_fetch_clause,
    STATE(1145), 1,
      sym_timeout_clause,
    STATE(1203), 1,
      sym_parallel_clause,
    STATE(1382), 1,
      sym_explain_clause,
    ACTIONS(329), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [21723] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(333), 1,
      sym_keyword_order,
    ACTIONS(337), 1,
      sym_keyword_where,
    STATE(806), 1,
      sym_where_clause,
    STATE(831), 1,
      sym_split_clause,
    STATE(900), 1,
      sym_order_clause,
    STATE(901), 1,
      sym_group_clause,
    STATE(956), 1,
      sym_limit_clause,
    STATE(1024), 1,
      sym_fetch_clause,
    STATE(1158), 1,
      sym_timeout_clause,
    STATE(1215), 1,
      sym_parallel_clause,
    STATE(1370), 1,
      sym_explain_clause,
    ACTIONS(1006), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [21785] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1048), 1,
      sym_keyword_value,
    ACTIONS(1051), 1,
      sym_keyword_flexible,
    ACTIONS(1054), 1,
      sym_keyword_readonly,
    ACTIONS(1057), 1,
      sym_keyword_type,
    ACTIONS(1060), 1,
      sym_keyword_default,
    ACTIONS(1063), 1,
      sym_keyword_assert,
    ACTIONS(1066), 1,
      sym_keyword_permissions,
    ACTIONS(1069), 1,
      sym_keyword_comment,
    ACTIONS(1046), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(787), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat1,
  [21828] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    STATE(829), 1,
      sym_split_clause,
    STATE(867), 1,
      sym_group_clause,
    STATE(907), 1,
      sym_order_clause,
    STATE(984), 1,
      sym_limit_clause,
    STATE(997), 1,
      sym_fetch_clause,
    STATE(1120), 1,
      sym_timeout_clause,
    STATE(1239), 1,
      sym_parallel_clause,
    STATE(1331), 1,
      sym_explain_clause,
    ACTIONS(1072), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [21885] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1076), 1,
      sym_keyword_value,
    ACTIONS(1078), 1,
      sym_keyword_flexible,
    ACTIONS(1080), 1,
      sym_keyword_readonly,
    ACTIONS(1082), 1,
      sym_keyword_type,
    ACTIONS(1084), 1,
      sym_keyword_default,
    ACTIONS(1086), 1,
      sym_keyword_assert,
    ACTIONS(1088), 1,
      sym_keyword_permissions,
    ACTIONS(1090), 1,
      sym_keyword_comment,
    ACTIONS(1074), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(795), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat1,
  [21928] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1076), 1,
      sym_keyword_value,
    ACTIONS(1078), 1,
      sym_keyword_flexible,
    ACTIONS(1080), 1,
      sym_keyword_readonly,
    ACTIONS(1082), 1,
      sym_keyword_type,
    ACTIONS(1084), 1,
      sym_keyword_default,
    ACTIONS(1086), 1,
      sym_keyword_assert,
    ACTIONS(1088), 1,
      sym_keyword_permissions,
    ACTIONS(1090), 1,
      sym_keyword_comment,
    ACTIONS(1092), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(791), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat1,
  [21971] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1076), 1,
      sym_keyword_value,
    ACTIONS(1078), 1,
      sym_keyword_flexible,
    ACTIONS(1080), 1,
      sym_keyword_readonly,
    ACTIONS(1082), 1,
      sym_keyword_type,
    ACTIONS(1084), 1,
      sym_keyword_default,
    ACTIONS(1086), 1,
      sym_keyword_assert,
    ACTIONS(1088), 1,
      sym_keyword_permissions,
    ACTIONS(1090), 1,
      sym_keyword_comment,
    ACTIONS(1074), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(787), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat1,
  [22014] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    STATE(818), 1,
      sym_split_clause,
    STATE(858), 1,
      sym_group_clause,
    STATE(879), 1,
      sym_order_clause,
    STATE(961), 1,
      sym_limit_clause,
    STATE(1003), 1,
      sym_fetch_clause,
    STATE(1145), 1,
      sym_timeout_clause,
    STATE(1203), 1,
      sym_parallel_clause,
    STATE(1382), 1,
      sym_explain_clause,
    ACTIONS(329), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [22071] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1094), 1,
      anon_sym_COMMA,
    STATE(793), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1008), 17,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_unique,
      sym_keyword_search,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [22100] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    STATE(820), 1,
      sym_split_clause,
    STATE(862), 1,
      sym_group_clause,
    STATE(892), 1,
      sym_order_clause,
    STATE(974), 1,
      sym_limit_clause,
    STATE(1007), 1,
      sym_fetch_clause,
    STATE(1106), 1,
      sym_timeout_clause,
    STATE(1251), 1,
      sym_parallel_clause,
    STATE(1309), 1,
      sym_explain_clause,
    ACTIONS(289), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [22157] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1076), 1,
      sym_keyword_value,
    ACTIONS(1078), 1,
      sym_keyword_flexible,
    ACTIONS(1080), 1,
      sym_keyword_readonly,
    ACTIONS(1082), 1,
      sym_keyword_type,
    ACTIONS(1084), 1,
      sym_keyword_default,
    ACTIONS(1086), 1,
      sym_keyword_assert,
    ACTIONS(1088), 1,
      sym_keyword_permissions,
    ACTIONS(1090), 1,
      sym_keyword_comment,
    ACTIONS(1097), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(787), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat1,
  [22200] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    STATE(824), 1,
      sym_split_clause,
    STATE(856), 1,
      sym_group_clause,
    STATE(894), 1,
      sym_order_clause,
    STATE(988), 1,
      sym_limit_clause,
    STATE(998), 1,
      sym_fetch_clause,
    STATE(1118), 1,
      sym_timeout_clause,
    STATE(1229), 1,
      sym_parallel_clause,
    STATE(1348), 1,
      sym_explain_clause,
    ACTIONS(1042), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [22257] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    STATE(813), 1,
      sym_split_clause,
    STATE(864), 1,
      sym_group_clause,
    STATE(900), 1,
      sym_order_clause,
    STATE(956), 1,
      sym_limit_clause,
    STATE(1024), 1,
      sym_fetch_clause,
    STATE(1158), 1,
      sym_timeout_clause,
    STATE(1215), 1,
      sym_parallel_clause,
    STATE(1370), 1,
      sym_explain_clause,
    ACTIONS(1006), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [22314] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(333), 1,
      sym_keyword_order,
    STATE(842), 1,
      sym_split_clause,
    STATE(890), 1,
      sym_group_clause,
    STATE(892), 1,
      sym_order_clause,
    STATE(974), 1,
      sym_limit_clause,
    STATE(1007), 1,
      sym_fetch_clause,
    STATE(1106), 1,
      sym_timeout_clause,
    STATE(1251), 1,
      sym_parallel_clause,
    STATE(1309), 1,
      sym_explain_clause,
    ACTIONS(289), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [22370] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(333), 1,
      sym_keyword_order,
    STATE(839), 1,
      sym_split_clause,
    STATE(906), 1,
      sym_group_clause,
    STATE(907), 1,
      sym_order_clause,
    STATE(984), 1,
      sym_limit_clause,
    STATE(997), 1,
      sym_fetch_clause,
    STATE(1120), 1,
      sym_timeout_clause,
    STATE(1239), 1,
      sym_parallel_clause,
    STATE(1331), 1,
      sym_explain_clause,
    ACTIONS(1072), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [22426] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1099), 1,
      anon_sym_EQ,
    STATE(50), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
    ACTIONS(178), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(180), 6,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
      sym_keyword_unset,
  [22464] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1078), 1,
      sym_keyword_flexible,
    ACTIONS(1080), 1,
      sym_keyword_readonly,
    ACTIONS(1082), 1,
      sym_keyword_type,
    ACTIONS(1090), 1,
      sym_keyword_comment,
    ACTIONS(1101), 1,
      sym_keyword_value,
    ACTIONS(1103), 1,
      sym_keyword_default,
    ACTIONS(1105), 1,
      sym_keyword_assert,
    ACTIONS(1107), 1,
      sym_keyword_permissions,
    ACTIONS(1092), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(808), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat1,
  [22506] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1109), 1,
      anon_sym_EQ,
    STATE(48), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
    ACTIONS(367), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(369), 6,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
      sym_keyword_unset,
  [22544] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1051), 1,
      sym_keyword_flexible,
    ACTIONS(1054), 1,
      sym_keyword_readonly,
    ACTIONS(1057), 1,
      sym_keyword_type,
    ACTIONS(1069), 1,
      sym_keyword_comment,
    ACTIONS(1111), 1,
      sym_keyword_value,
    ACTIONS(1114), 1,
      sym_keyword_default,
    ACTIONS(1117), 1,
      sym_keyword_assert,
    ACTIONS(1120), 1,
      sym_keyword_permissions,
    ACTIONS(1046), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(803), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat1,
  [22586] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(333), 1,
      sym_keyword_order,
    STATE(831), 1,
      sym_split_clause,
    STATE(900), 1,
      sym_order_clause,
    STATE(901), 1,
      sym_group_clause,
    STATE(956), 1,
      sym_limit_clause,
    STATE(1024), 1,
      sym_fetch_clause,
    STATE(1158), 1,
      sym_timeout_clause,
    STATE(1215), 1,
      sym_parallel_clause,
    STATE(1370), 1,
      sym_explain_clause,
    ACTIONS(1006), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [22642] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(333), 1,
      sym_keyword_order,
    STATE(854), 1,
      sym_split_clause,
    STATE(879), 1,
      sym_order_clause,
    STATE(880), 1,
      sym_group_clause,
    STATE(961), 1,
      sym_limit_clause,
    STATE(1003), 1,
      sym_fetch_clause,
    STATE(1145), 1,
      sym_timeout_clause,
    STATE(1203), 1,
      sym_parallel_clause,
    STATE(1382), 1,
      sym_explain_clause,
    ACTIONS(329), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [22698] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(307), 1,
      sym_keyword_split,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(333), 1,
      sym_keyword_order,
    STATE(837), 1,
      sym_split_clause,
    STATE(891), 1,
      sym_group_clause,
    STATE(894), 1,
      sym_order_clause,
    STATE(988), 1,
      sym_limit_clause,
    STATE(998), 1,
      sym_fetch_clause,
    STATE(1118), 1,
      sym_timeout_clause,
    STATE(1229), 1,
      sym_parallel_clause,
    STATE(1348), 1,
      sym_explain_clause,
    ACTIONS(1042), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [22754] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_EQ,
    STATE(49), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
    ACTIONS(210), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(212), 6,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
      sym_keyword_unset,
  [22792] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1078), 1,
      sym_keyword_flexible,
    ACTIONS(1080), 1,
      sym_keyword_readonly,
    ACTIONS(1082), 1,
      sym_keyword_type,
    ACTIONS(1090), 1,
      sym_keyword_comment,
    ACTIONS(1101), 1,
      sym_keyword_value,
    ACTIONS(1103), 1,
      sym_keyword_default,
    ACTIONS(1105), 1,
      sym_keyword_assert,
    ACTIONS(1107), 1,
      sym_keyword_permissions,
    ACTIONS(1074), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(803), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat1,
  [22834] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1078), 1,
      sym_keyword_flexible,
    ACTIONS(1080), 1,
      sym_keyword_readonly,
    ACTIONS(1082), 1,
      sym_keyword_type,
    ACTIONS(1090), 1,
      sym_keyword_comment,
    ACTIONS(1101), 1,
      sym_keyword_value,
    ACTIONS(1103), 1,
      sym_keyword_default,
    ACTIONS(1105), 1,
      sym_keyword_assert,
    ACTIONS(1107), 1,
      sym_keyword_permissions,
    ACTIONS(1074), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(812), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat1,
  [22876] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1125), 18,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_when,
      sym_keyword_then,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_fields,
      sym_keyword_columns,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [22900] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1127), 18,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_when,
      sym_keyword_then,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_fields,
      sym_keyword_columns,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [22924] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1078), 1,
      sym_keyword_flexible,
    ACTIONS(1080), 1,
      sym_keyword_readonly,
    ACTIONS(1082), 1,
      sym_keyword_type,
    ACTIONS(1090), 1,
      sym_keyword_comment,
    ACTIONS(1101), 1,
      sym_keyword_value,
    ACTIONS(1103), 1,
      sym_keyword_default,
    ACTIONS(1105), 1,
      sym_keyword_assert,
    ACTIONS(1107), 1,
      sym_keyword_permissions,
    ACTIONS(1097), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(803), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat1,
  [22966] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    ACTIONS(309), 1,
      sym_keyword_group,
    STATE(856), 1,
      sym_group_clause,
    STATE(894), 1,
      sym_order_clause,
    STATE(988), 1,
      sym_limit_clause,
    STATE(998), 1,
      sym_fetch_clause,
    STATE(1118), 1,
      sym_timeout_clause,
    STATE(1229), 1,
      sym_parallel_clause,
    STATE(1348), 1,
      sym_explain_clause,
    ACTIONS(1042), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [23017] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1131), 1,
      sym_keyword_as,
    ACTIONS(1135), 1,
      sym_keyword_changefeed,
    ACTIONS(1137), 1,
      sym_keyword_type,
    ACTIONS(1139), 1,
      sym_keyword_permissions,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1129), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1133), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    STATE(828), 6,
      sym_permissions_for_clause,
      sym_comment_clause,
      sym_table_type_clause,
      sym_table_view_clause,
      sym_changefeed_clause,
      aux_sym_define_table_statement_repeat1,
  [23054] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1131), 1,
      sym_keyword_as,
    ACTIONS(1135), 1,
      sym_keyword_changefeed,
    ACTIONS(1137), 1,
      sym_keyword_type,
    ACTIONS(1139), 1,
      sym_keyword_permissions,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1143), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1145), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    STATE(814), 6,
      sym_permissions_for_clause,
      sym_comment_clause,
      sym_table_type_clause,
      sym_table_view_clause,
      sym_changefeed_clause,
      aux_sym_define_table_statement_repeat1,
  [23091] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1131), 1,
      sym_keyword_as,
    ACTIONS(1135), 1,
      sym_keyword_changefeed,
    ACTIONS(1137), 1,
      sym_keyword_type,
    ACTIONS(1139), 1,
      sym_keyword_permissions,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1147), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1149), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    STATE(825), 6,
      sym_permissions_for_clause,
      sym_comment_clause,
      sym_table_type_clause,
      sym_table_view_clause,
      sym_changefeed_clause,
      aux_sym_define_table_statement_repeat1,
  [23128] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    ACTIONS(309), 1,
      sym_keyword_group,
    STATE(858), 1,
      sym_group_clause,
    STATE(879), 1,
      sym_order_clause,
    STATE(961), 1,
      sym_limit_clause,
    STATE(1003), 1,
      sym_fetch_clause,
    STATE(1145), 1,
      sym_timeout_clause,
    STATE(1203), 1,
      sym_parallel_clause,
    STATE(1382), 1,
      sym_explain_clause,
    ACTIONS(329), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [23179] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    ACTIONS(309), 1,
      sym_keyword_group,
    STATE(862), 1,
      sym_group_clause,
    STATE(892), 1,
      sym_order_clause,
    STATE(974), 1,
      sym_limit_clause,
    STATE(1007), 1,
      sym_fetch_clause,
    STATE(1106), 1,
      sym_timeout_clause,
    STATE(1251), 1,
      sym_parallel_clause,
    STATE(1309), 1,
      sym_explain_clause,
    ACTIONS(289), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [23230] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1109), 1,
      anon_sym_EQ,
    STATE(48), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
    ACTIONS(367), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(369), 5,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
  [23267] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    ACTIONS(309), 1,
      sym_keyword_group,
    STATE(864), 1,
      sym_group_clause,
    STATE(900), 1,
      sym_order_clause,
    STATE(956), 1,
      sym_limit_clause,
    STATE(1024), 1,
      sym_fetch_clause,
    STATE(1158), 1,
      sym_timeout_clause,
    STATE(1215), 1,
      sym_parallel_clause,
    STATE(1370), 1,
      sym_explain_clause,
    ACTIONS(1006), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [23318] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1123), 1,
      anon_sym_EQ,
    STATE(49), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
    ACTIONS(210), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(212), 5,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
  [23355] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1153), 1,
      anon_sym_LPAREN,
    ACTIONS(1151), 16,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [23380] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1099), 1,
      anon_sym_EQ,
    STATE(50), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
    ACTIONS(178), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(180), 5,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
  [23417] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    ACTIONS(309), 1,
      sym_keyword_group,
    STATE(867), 1,
      sym_group_clause,
    STATE(907), 1,
      sym_order_clause,
    STATE(984), 1,
      sym_limit_clause,
    STATE(997), 1,
      sym_fetch_clause,
    STATE(1120), 1,
      sym_timeout_clause,
    STATE(1239), 1,
      sym_parallel_clause,
    STATE(1331), 1,
      sym_explain_clause,
    ACTIONS(1072), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [23468] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1131), 1,
      sym_keyword_as,
    ACTIONS(1135), 1,
      sym_keyword_changefeed,
    ACTIONS(1137), 1,
      sym_keyword_type,
    ACTIONS(1139), 1,
      sym_keyword_permissions,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1133), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    ACTIONS(1143), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(828), 6,
      sym_permissions_for_clause,
      sym_comment_clause,
      sym_table_type_clause,
      sym_table_view_clause,
      sym_changefeed_clause,
      aux_sym_define_table_statement_repeat1,
  [23505] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(492), 1,
      sym_keyword_where,
    ACTIONS(494), 1,
      sym_keyword_group,
    ACTIONS(496), 1,
      anon_sym_COMMA,
    STATE(859), 1,
      aux_sym_update_statement_repeat1,
    STATE(889), 1,
      sym_where_clause,
    STATE(973), 1,
      sym_group_clause,
    ACTIONS(498), 11,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [23540] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(492), 1,
      sym_keyword_where,
    ACTIONS(494), 1,
      sym_keyword_group,
    ACTIONS(496), 1,
      anon_sym_COMMA,
    STATE(859), 1,
      aux_sym_update_statement_repeat1,
    STATE(878), 1,
      sym_where_clause,
    STATE(949), 1,
      sym_group_clause,
    ACTIONS(1155), 11,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [23575] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1159), 1,
      sym_keyword_as,
    ACTIONS(1165), 1,
      sym_keyword_changefeed,
    ACTIONS(1168), 1,
      sym_keyword_type,
    ACTIONS(1171), 1,
      sym_keyword_permissions,
    ACTIONS(1174), 1,
      sym_keyword_comment,
    ACTIONS(1157), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1162), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    STATE(828), 6,
      sym_permissions_for_clause,
      sym_comment_clause,
      sym_table_type_clause,
      sym_table_view_clause,
      sym_changefeed_clause,
      aux_sym_define_table_statement_repeat1,
  [23612] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    ACTIONS(309), 1,
      sym_keyword_group,
    STATE(870), 1,
      sym_group_clause,
    STATE(876), 1,
      sym_order_clause,
    STATE(953), 1,
      sym_limit_clause,
    STATE(1001), 1,
      sym_fetch_clause,
    STATE(1157), 1,
      sym_timeout_clause,
    STATE(1253), 1,
      sym_parallel_clause,
    STATE(1304), 1,
      sym_explain_clause,
    ACTIONS(1177), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [23663] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1179), 1,
      anon_sym_COMMA,
    STATE(830), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1008), 14,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_out,
      sym_keyword_to,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [23689] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(333), 1,
      sym_keyword_order,
    STATE(891), 1,
      sym_group_clause,
    STATE(894), 1,
      sym_order_clause,
    STATE(988), 1,
      sym_limit_clause,
    STATE(998), 1,
      sym_fetch_clause,
    STATE(1118), 1,
      sym_timeout_clause,
    STATE(1229), 1,
      sym_parallel_clause,
    STATE(1348), 1,
      sym_explain_clause,
    ACTIONS(1042), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [23739] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1186), 1,
      anon_sym_COMMA,
    STATE(830), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1184), 2,
      sym_keyword_out,
      sym_keyword_to,
    ACTIONS(1182), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [23767] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1188), 16,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [23789] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1135), 1,
      sym_keyword_changefeed,
    ACTIONS(1137), 1,
      sym_keyword_type,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1190), 1,
      sym_keyword_as,
    ACTIONS(1194), 1,
      sym_keyword_permissions,
    ACTIONS(1143), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(1192), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    STATE(853), 6,
      sym_permissions_for_clause,
      sym_comment_clause,
      sym_table_type_clause,
      sym_table_view_clause,
      sym_changefeed_clause,
      aux_sym_define_table_statement_repeat1,
  [23825] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1135), 1,
      sym_keyword_changefeed,
    ACTIONS(1137), 1,
      sym_keyword_type,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1190), 1,
      sym_keyword_as,
    ACTIONS(1194), 1,
      sym_keyword_permissions,
    ACTIONS(1143), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(1196), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    STATE(841), 6,
      sym_permissions_for_clause,
      sym_comment_clause,
      sym_table_type_clause,
      sym_table_view_clause,
      sym_changefeed_clause,
      aux_sym_define_table_statement_repeat1,
  [23861] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1198), 16,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [23883] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(333), 1,
      sym_keyword_order,
    STATE(906), 1,
      sym_group_clause,
    STATE(907), 1,
      sym_order_clause,
    STATE(984), 1,
      sym_limit_clause,
    STATE(997), 1,
      sym_fetch_clause,
    STATE(1120), 1,
      sym_timeout_clause,
    STATE(1239), 1,
      sym_parallel_clause,
    STATE(1331), 1,
      sym_explain_clause,
    ACTIONS(1072), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [23933] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1186), 1,
      anon_sym_COMMA,
    STATE(832), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1202), 2,
      sym_keyword_out,
      sym_keyword_to,
    ACTIONS(1200), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [23961] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(333), 1,
      sym_keyword_order,
    STATE(876), 1,
      sym_order_clause,
    STATE(893), 1,
      sym_group_clause,
    STATE(953), 1,
      sym_limit_clause,
    STATE(1001), 1,
      sym_fetch_clause,
    STATE(1157), 1,
      sym_timeout_clause,
    STATE(1253), 1,
      sym_parallel_clause,
    STATE(1304), 1,
      sym_explain_clause,
    ACTIONS(1177), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [24011] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1206), 2,
      sym_keyword_from,
      sym_keyword_in,
    ACTIONS(1208), 2,
      sym_keyword_out,
      sym_keyword_to,
    ACTIONS(1204), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [24037] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1135), 1,
      sym_keyword_changefeed,
    ACTIONS(1137), 1,
      sym_keyword_type,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1190), 1,
      sym_keyword_as,
    ACTIONS(1194), 1,
      sym_keyword_permissions,
    ACTIONS(1129), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(1192), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    STATE(853), 6,
      sym_permissions_for_clause,
      sym_comment_clause,
      sym_table_type_clause,
      sym_table_view_clause,
      sym_changefeed_clause,
      aux_sym_define_table_statement_repeat1,
  [24073] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(333), 1,
      sym_keyword_order,
    STATE(900), 1,
      sym_order_clause,
    STATE(901), 1,
      sym_group_clause,
    STATE(956), 1,
      sym_limit_clause,
    STATE(1024), 1,
      sym_fetch_clause,
    STATE(1158), 1,
      sym_timeout_clause,
    STATE(1215), 1,
      sym_parallel_clause,
    STATE(1370), 1,
      sym_explain_clause,
    ACTIONS(1006), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [24123] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(494), 1,
      sym_keyword_group,
    ACTIONS(542), 1,
      sym_keyword_where,
    ACTIONS(544), 1,
      anon_sym_COMMA,
    STATE(878), 1,
      sym_where_clause,
    STATE(888), 1,
      aux_sym_update_statement_repeat1,
    STATE(949), 1,
      sym_group_clause,
    ACTIONS(1155), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
  [24157] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1135), 1,
      sym_keyword_changefeed,
    ACTIONS(1137), 1,
      sym_keyword_type,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1190), 1,
      sym_keyword_as,
    ACTIONS(1194), 1,
      sym_keyword_permissions,
    ACTIONS(1147), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(1210), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    STATE(834), 6,
      sym_permissions_for_clause,
      sym_comment_clause,
      sym_table_type_clause,
      sym_table_view_clause,
      sym_changefeed_clause,
      aux_sym_define_table_statement_repeat1,
  [24193] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1212), 16,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [24215] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1214), 16,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [24237] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1216), 16,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [24259] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1218), 16,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [24281] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1220), 16,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [24303] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(333), 1,
      sym_keyword_order,
    STATE(879), 1,
      sym_order_clause,
    STATE(880), 1,
      sym_group_clause,
    STATE(961), 1,
      sym_limit_clause,
    STATE(1003), 1,
      sym_fetch_clause,
    STATE(1145), 1,
      sym_timeout_clause,
    STATE(1203), 1,
      sym_parallel_clause,
    STATE(1382), 1,
      sym_explain_clause,
    ACTIONS(329), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [24353] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1222), 16,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [24375] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(494), 1,
      sym_keyword_group,
    ACTIONS(542), 1,
      sym_keyword_where,
    ACTIONS(544), 1,
      anon_sym_COMMA,
    STATE(888), 1,
      aux_sym_update_statement_repeat1,
    STATE(889), 1,
      sym_where_clause,
    STATE(973), 1,
      sym_group_clause,
    ACTIONS(498), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
  [24409] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1165), 1,
      sym_keyword_changefeed,
    ACTIONS(1168), 1,
      sym_keyword_type,
    ACTIONS(1174), 1,
      sym_keyword_comment,
    ACTIONS(1224), 1,
      sym_keyword_as,
    ACTIONS(1230), 1,
      sym_keyword_permissions,
    ACTIONS(1157), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(1227), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    STATE(853), 6,
      sym_permissions_for_clause,
      sym_comment_clause,
      sym_table_type_clause,
      sym_table_view_clause,
      sym_changefeed_clause,
      aux_sym_define_table_statement_repeat1,
  [24445] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(309), 1,
      sym_keyword_group,
    ACTIONS(333), 1,
      sym_keyword_order,
    STATE(890), 1,
      sym_group_clause,
    STATE(892), 1,
      sym_order_clause,
    STATE(974), 1,
      sym_limit_clause,
    STATE(1007), 1,
      sym_fetch_clause,
    STATE(1106), 1,
      sym_timeout_clause,
    STATE(1251), 1,
      sym_parallel_clause,
    STATE(1309), 1,
      sym_explain_clause,
    ACTIONS(289), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [24495] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1233), 16,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [24517] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    STATE(907), 1,
      sym_order_clause,
    STATE(984), 1,
      sym_limit_clause,
    STATE(997), 1,
      sym_fetch_clause,
    STATE(1120), 1,
      sym_timeout_clause,
    STATE(1239), 1,
      sym_parallel_clause,
    STATE(1331), 1,
      sym_explain_clause,
    ACTIONS(1072), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [24562] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1235), 15,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_GT,
  [24583] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    STATE(892), 1,
      sym_order_clause,
    STATE(974), 1,
      sym_limit_clause,
    STATE(1007), 1,
      sym_fetch_clause,
    STATE(1106), 1,
      sym_timeout_clause,
    STATE(1251), 1,
      sym_parallel_clause,
    STATE(1309), 1,
      sym_explain_clause,
    ACTIONS(289), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [24628] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1237), 1,
      anon_sym_COMMA,
    STATE(859), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(658), 13,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_where,
      sym_keyword_group,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [24653] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1240), 15,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_GT,
  [24674] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1242), 1,
      anon_sym_COMMA,
    STATE(861), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(658), 13,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_with,
      sym_keyword_where,
      sym_keyword_split,
      sym_keyword_group,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [24699] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    STATE(900), 1,
      sym_order_clause,
    STATE(956), 1,
      sym_limit_clause,
    STATE(1024), 1,
      sym_fetch_clause,
    STATE(1158), 1,
      sym_timeout_clause,
    STATE(1215), 1,
      sym_parallel_clause,
    STATE(1370), 1,
      sym_explain_clause,
    ACTIONS(1006), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [24744] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    ACTIONS(347), 1,
      sym_keyword_content,
    ACTIONS(1247), 1,
      sym_keyword_set,
    ACTIONS(1249), 1,
      sym_keyword_unset,
    STATE(1108), 1,
      sym_return_clause,
    STATE(1210), 1,
      sym_timeout_clause,
    STATE(1296), 1,
      sym_parallel_clause,
    ACTIONS(1245), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1100), 3,
      sym_content_clause,
      sym_set_clause,
      sym_unset_clause,
  [24785] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    STATE(894), 1,
      sym_order_clause,
    STATE(988), 1,
      sym_limit_clause,
    STATE(998), 1,
      sym_fetch_clause,
    STATE(1118), 1,
      sym_timeout_clause,
    STATE(1229), 1,
      sym_parallel_clause,
    STATE(1348), 1,
      sym_explain_clause,
    ACTIONS(1042), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [24830] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 15,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_out,
      sym_keyword_to,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [24851] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    ACTIONS(347), 1,
      sym_keyword_content,
    ACTIONS(1247), 1,
      sym_keyword_set,
    ACTIONS(1249), 1,
      sym_keyword_unset,
    STATE(1116), 1,
      sym_return_clause,
    STATE(1233), 1,
      sym_timeout_clause,
    STATE(1406), 1,
      sym_parallel_clause,
    ACTIONS(1251), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1081), 3,
      sym_content_clause,
      sym_set_clause,
      sym_unset_clause,
  [24892] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    STATE(876), 1,
      sym_order_clause,
    STATE(953), 1,
      sym_limit_clause,
    STATE(1001), 1,
      sym_fetch_clause,
    STATE(1157), 1,
      sym_timeout_clause,
    STATE(1253), 1,
      sym_parallel_clause,
    STATE(1304), 1,
      sym_explain_clause,
    ACTIONS(1177), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [24937] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    STATE(879), 1,
      sym_order_clause,
    STATE(961), 1,
      sym_limit_clause,
    STATE(1003), 1,
      sym_fetch_clause,
    STATE(1145), 1,
      sym_timeout_clause,
    STATE(1203), 1,
      sym_parallel_clause,
    STATE(1382), 1,
      sym_explain_clause,
    ACTIONS(329), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [24982] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1253), 15,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_GT,
  [25003] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(301), 1,
      sym_keyword_order,
    STATE(872), 1,
      sym_order_clause,
    STATE(985), 1,
      sym_limit_clause,
    STATE(999), 1,
      sym_fetch_clause,
    STATE(1159), 1,
      sym_timeout_clause,
    STATE(1206), 1,
      sym_parallel_clause,
    STATE(1287), 1,
      sym_explain_clause,
    ACTIONS(1255), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25048] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    STATE(895), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1200), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25072] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    STATE(952), 1,
      sym_limit_clause,
    STATE(1016), 1,
      sym_fetch_clause,
    STATE(1105), 1,
      sym_timeout_clause,
    STATE(1208), 1,
      sym_parallel_clause,
    STATE(1412), 1,
      sym_explain_clause,
    ACTIONS(1259), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25112] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    STATE(793), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1261), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25136] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(347), 1,
      sym_keyword_content,
    ACTIONS(424), 1,
      sym_keyword_return,
    ACTIONS(1263), 1,
      sym_keyword_set,
    ACTIONS(1265), 1,
      sym_keyword_unset,
    STATE(1116), 1,
      sym_return_clause,
    STATE(1233), 1,
      sym_timeout_clause,
    STATE(1406), 1,
      sym_parallel_clause,
    ACTIONS(1251), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1121), 3,
      sym_content_clause,
      sym_set_clause,
      sym_unset_clause,
  [25176] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(1267), 1,
      sym_keyword_only,
    ACTIONS(1269), 1,
      sym_variable_name,
    STATE(1688), 1,
      sym_object_key,
    STATE(1808), 1,
      sym_relate_subject,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1022), 4,
      sym_function_call,
      sym_identifier,
      sym_array,
      sym_record_id,
  [25212] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    STATE(985), 1,
      sym_limit_clause,
    STATE(999), 1,
      sym_fetch_clause,
    STATE(1159), 1,
      sym_timeout_clause,
    STATE(1206), 1,
      sym_parallel_clause,
    STATE(1287), 1,
      sym_explain_clause,
    ACTIONS(1255), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25252] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    STATE(793), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1271), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25276] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(494), 1,
      sym_keyword_group,
    STATE(972), 1,
      sym_group_clause,
    ACTIONS(1273), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25300] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    STATE(974), 1,
      sym_limit_clause,
    STATE(1007), 1,
      sym_fetch_clause,
    STATE(1106), 1,
      sym_timeout_clause,
    STATE(1251), 1,
      sym_parallel_clause,
    STATE(1309), 1,
      sym_explain_clause,
    ACTIONS(289), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25340] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(333), 1,
      sym_keyword_order,
    STATE(892), 1,
      sym_order_clause,
    STATE(974), 1,
      sym_limit_clause,
    STATE(1007), 1,
      sym_fetch_clause,
    STATE(1106), 1,
      sym_timeout_clause,
    STATE(1251), 1,
      sym_parallel_clause,
    STATE(1309), 1,
      sym_explain_clause,
    ACTIONS(289), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [25384] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(494), 1,
      sym_keyword_group,
    STATE(973), 1,
      sym_group_clause,
    ACTIONS(498), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25408] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(1269), 1,
      sym_variable_name,
    ACTIONS(1275), 1,
      sym_keyword_only,
    STATE(1688), 1,
      sym_object_key,
    STATE(1779), 1,
      sym_relate_subject,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1022), 4,
      sym_function_call,
      sym_identifier,
      sym_array,
      sym_record_id,
  [25444] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    STATE(793), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1277), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25468] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    STATE(877), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1279), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25492] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    STATE(793), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1279), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25516] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    STATE(885), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1281), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25540] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    STATE(873), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1277), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25564] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1283), 1,
      anon_sym_COMMA,
    STATE(888), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(658), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_where,
      sym_keyword_group,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
  [25588] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(494), 1,
      sym_keyword_group,
    STATE(949), 1,
      sym_group_clause,
    ACTIONS(1155), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25612] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(333), 1,
      sym_keyword_order,
    STATE(900), 1,
      sym_order_clause,
    STATE(956), 1,
      sym_limit_clause,
    STATE(1024), 1,
      sym_fetch_clause,
    STATE(1158), 1,
      sym_timeout_clause,
    STATE(1215), 1,
      sym_parallel_clause,
    STATE(1370), 1,
      sym_explain_clause,
    ACTIONS(1006), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [25656] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(333), 1,
      sym_keyword_order,
    STATE(907), 1,
      sym_order_clause,
    STATE(984), 1,
      sym_limit_clause,
    STATE(997), 1,
      sym_fetch_clause,
    STATE(1120), 1,
      sym_timeout_clause,
    STATE(1239), 1,
      sym_parallel_clause,
    STATE(1331), 1,
      sym_explain_clause,
    ACTIONS(1072), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [25700] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    STATE(956), 1,
      sym_limit_clause,
    STATE(1024), 1,
      sym_fetch_clause,
    STATE(1158), 1,
      sym_timeout_clause,
    STATE(1215), 1,
      sym_parallel_clause,
    STATE(1370), 1,
      sym_explain_clause,
    ACTIONS(1006), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25740] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(333), 1,
      sym_keyword_order,
    STATE(872), 1,
      sym_order_clause,
    STATE(985), 1,
      sym_limit_clause,
    STATE(999), 1,
      sym_fetch_clause,
    STATE(1159), 1,
      sym_timeout_clause,
    STATE(1206), 1,
      sym_parallel_clause,
    STATE(1287), 1,
      sym_explain_clause,
    ACTIONS(1255), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [25784] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    STATE(984), 1,
      sym_limit_clause,
    STATE(997), 1,
      sym_fetch_clause,
    STATE(1120), 1,
      sym_timeout_clause,
    STATE(1239), 1,
      sym_parallel_clause,
    STATE(1331), 1,
      sym_explain_clause,
    ACTIONS(1072), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25824] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    STATE(793), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1182), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25848] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 1,
      anon_sym_COMMA,
    STATE(896), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(658), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_with,
      sym_keyword_where,
      sym_keyword_split,
      sym_keyword_group,
  [25872] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(347), 1,
      sym_keyword_content,
    ACTIONS(424), 1,
      sym_keyword_return,
    ACTIONS(1263), 1,
      sym_keyword_set,
    ACTIONS(1265), 1,
      sym_keyword_unset,
    STATE(1108), 1,
      sym_return_clause,
    STATE(1210), 1,
      sym_timeout_clause,
    STATE(1296), 1,
      sym_parallel_clause,
    ACTIONS(1245), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1115), 3,
      sym_content_clause,
      sym_set_clause,
      sym_unset_clause,
  [25912] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1289), 1,
      anon_sym_COMMA,
    STATE(898), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(658), 12,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_where,
      sym_keyword_split,
      sym_keyword_group,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25936] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(666), 1,
      anon_sym_COMMA,
    STATE(898), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(1292), 12,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_where,
      sym_keyword_split,
      sym_keyword_group,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [25960] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    STATE(988), 1,
      sym_limit_clause,
    STATE(998), 1,
      sym_fetch_clause,
    STATE(1118), 1,
      sym_timeout_clause,
    STATE(1229), 1,
      sym_parallel_clause,
    STATE(1348), 1,
      sym_explain_clause,
    ACTIONS(1042), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [26000] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(333), 1,
      sym_keyword_order,
    STATE(894), 1,
      sym_order_clause,
    STATE(988), 1,
      sym_limit_clause,
    STATE(998), 1,
      sym_fetch_clause,
    STATE(1118), 1,
      sym_timeout_clause,
    STATE(1229), 1,
      sym_parallel_clause,
    STATE(1348), 1,
      sym_explain_clause,
    ACTIONS(1042), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [26044] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    STATE(961), 1,
      sym_limit_clause,
    STATE(1003), 1,
      sym_fetch_clause,
    STATE(1145), 1,
      sym_timeout_clause,
    STATE(1203), 1,
      sym_parallel_clause,
    STATE(1382), 1,
      sym_explain_clause,
    ACTIONS(329), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [26084] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(333), 1,
      sym_keyword_order,
    STATE(879), 1,
      sym_order_clause,
    STATE(961), 1,
      sym_limit_clause,
    STATE(1003), 1,
      sym_fetch_clause,
    STATE(1145), 1,
      sym_timeout_clause,
    STATE(1203), 1,
      sym_parallel_clause,
    STATE(1382), 1,
      sym_explain_clause,
    ACTIONS(329), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [26128] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    STATE(883), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1294), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [26152] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1296), 1,
      anon_sym_COMMA,
    STATE(905), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(658), 12,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      sym_keyword_content,
      sym_keyword_merge,
      sym_keyword_patch,
      sym_keyword_set,
      sym_keyword_unset,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [26176] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    ACTIONS(333), 1,
      sym_keyword_order,
    STATE(876), 1,
      sym_order_clause,
    STATE(953), 1,
      sym_limit_clause,
    STATE(1001), 1,
      sym_fetch_clause,
    STATE(1157), 1,
      sym_timeout_clause,
    STATE(1253), 1,
      sym_parallel_clause,
    STATE(1304), 1,
      sym_explain_clause,
    ACTIONS(1177), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [26220] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    ACTIONS(299), 1,
      sym_keyword_limit,
    STATE(953), 1,
      sym_limit_clause,
    STATE(1001), 1,
      sym_fetch_clause,
    STATE(1157), 1,
      sym_timeout_clause,
    STATE(1253), 1,
      sym_parallel_clause,
    STATE(1304), 1,
      sym_explain_clause,
    ACTIONS(1177), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [26260] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1301), 1,
      sym_keyword_session,
    ACTIONS(1303), 1,
      sym_keyword_signin,
    ACTIONS(1305), 1,
      sym_keyword_signup,
    ACTIONS(1299), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(945), 5,
      sym_comment_clause,
      sym_session_clause,
      sym_signin_clause,
      sym_signup_clause,
      aux_sym_define_scope_statement_repeat1,
  [26289] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(1269), 1,
      sym_variable_name,
    STATE(942), 1,
      sym_relate_subject,
    STATE(1739), 1,
      sym_object_key,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1022), 4,
      sym_function_call,
      sym_identifier,
      sym_array,
      sym_record_id,
  [26322] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1309), 1,
      sym_keyword_function,
    ACTIONS(1311), 1,
      sym_keyword_tokenizers,
    ACTIONS(1313), 1,
      sym_keyword_filters,
    ACTIONS(1307), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(948), 5,
      sym_tokenizers_clause,
      sym_filters_clause,
      sym_function_clause,
      sym_comment_clause,
      aux_sym_define_analyzer_statement_repeat1,
  [26351] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1317), 1,
      sym_keyword_for,
    STATE(911), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1315), 11,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [26374] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(1269), 1,
      sym_variable_name,
    STATE(936), 1,
      sym_relate_subject,
    STATE(1739), 1,
      sym_object_key,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1022), 4,
      sym_function_call,
      sym_identifier,
      sym_array,
      sym_record_id,
  [26407] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1320), 13,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_for,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [26426] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1324), 1,
      anon_sym_LT,
    ACTIONS(1322), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [26447] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1328), 1,
      sym_keyword_function,
    ACTIONS(1331), 1,
      sym_keyword_tokenizers,
    ACTIONS(1334), 1,
      sym_keyword_filters,
    ACTIONS(1337), 1,
      sym_keyword_comment,
    ACTIONS(1326), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(915), 5,
      sym_tokenizers_clause,
      sym_filters_clause,
      sym_function_clause,
      sym_comment_clause,
      aux_sym_define_analyzer_statement_repeat1,
  [26476] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(668), 1,
      anon_sym_COMMA,
    STATE(919), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(1292), 11,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_where,
      sym_keyword_split,
      sym_keyword_group,
  [26499] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1342), 1,
      anon_sym_COMMA,
    STATE(934), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1340), 11,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_group,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [26522] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(1269), 1,
      sym_variable_name,
    STATE(1688), 1,
      sym_object_key,
    STATE(1818), 1,
      sym_relate_subject,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1022), 4,
      sym_function_call,
      sym_identifier,
      sym_array,
      sym_record_id,
  [26555] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1344), 1,
      anon_sym_COMMA,
    STATE(919), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(658), 11,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_where,
      sym_keyword_split,
      sym_keyword_group,
  [26578] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1347), 1,
      sym_keyword_for,
    STATE(920), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1315), 11,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [26601] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1352), 1,
      sym_keyword_for,
    STATE(920), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1350), 11,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [26624] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1301), 1,
      sym_keyword_session,
    ACTIONS(1303), 1,
      sym_keyword_signin,
    ACTIONS(1305), 1,
      sym_keyword_signup,
    ACTIONS(1354), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(927), 5,
      sym_comment_clause,
      sym_session_clause,
      sym_signin_clause,
      sym_signup_clause,
      aux_sym_define_scope_statement_repeat1,
  [26653] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1342), 1,
      anon_sym_COMMA,
    STATE(934), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1356), 11,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_group,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [26676] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1358), 13,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_for,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [26695] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1358), 13,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_for,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [26714] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1342), 1,
      anon_sym_COMMA,
    STATE(917), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1356), 11,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_group,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [26737] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1362), 1,
      sym_keyword_comment,
    ACTIONS(1365), 1,
      sym_keyword_session,
    ACTIONS(1368), 1,
      sym_keyword_signin,
    ACTIONS(1371), 1,
      sym_keyword_signup,
    ACTIONS(1360), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(927), 5,
      sym_comment_clause,
      sym_session_clause,
      sym_signin_clause,
      sym_signup_clause,
      aux_sym_define_scope_statement_repeat1,
  [26766] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    ACTIONS(345), 1,
      sym_keyword_where,
    ACTIONS(672), 1,
      anon_sym_COMMA,
    STATE(1029), 1,
      aux_sym_update_statement_repeat1,
    STATE(1097), 1,
      sym_where_clause,
    STATE(1130), 1,
      sym_return_clause,
    STATE(1224), 1,
      sym_timeout_clause,
    STATE(1353), 1,
      sym_parallel_clause,
    ACTIONS(1374), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [26805] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(1269), 1,
      sym_variable_name,
    STATE(960), 1,
      sym_relate_subject,
    STATE(1739), 1,
      sym_object_key,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1022), 4,
      sym_function_call,
      sym_identifier,
      sym_array,
      sym_record_id,
  [26838] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(1269), 1,
      sym_variable_name,
    STATE(1688), 1,
      sym_object_key,
    STATE(1816), 1,
      sym_relate_subject,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1022), 4,
      sym_function_call,
      sym_identifier,
      sym_array,
      sym_record_id,
  [26871] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(1269), 1,
      sym_variable_name,
    STATE(969), 1,
      sym_relate_subject,
    STATE(1739), 1,
      sym_object_key,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1022), 4,
      sym_function_call,
      sym_identifier,
      sym_array,
      sym_record_id,
  [26904] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(1269), 1,
      sym_variable_name,
    STATE(1688), 1,
      sym_object_key,
    STATE(1823), 1,
      sym_relate_subject,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1022), 4,
      sym_function_call,
      sym_identifier,
      sym_array,
      sym_record_id,
  [26937] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1320), 13,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_for,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [26956] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1376), 1,
      anon_sym_COMMA,
    STATE(934), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1008), 11,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_group,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [26979] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(1269), 1,
      sym_variable_name,
    STATE(1688), 1,
      sym_object_key,
    STATE(1844), 1,
      sym_relate_subject,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1022), 4,
      sym_function_call,
      sym_identifier,
      sym_array,
      sym_record_id,
  [27012] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    ACTIONS(347), 1,
      sym_keyword_content,
    ACTIONS(1247), 1,
      sym_keyword_set,
    STATE(1117), 1,
      sym_return_clause,
    STATE(1219), 1,
      sym_timeout_clause,
    STATE(1355), 1,
      sym_parallel_clause,
    STATE(1072), 2,
      sym_content_clause,
      sym_set_clause,
    ACTIONS(1379), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [27049] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1381), 1,
      anon_sym_COMMA,
    STATE(937), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(658), 11,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      sym_keyword_content,
      sym_keyword_merge,
      sym_keyword_patch,
      sym_keyword_set,
      sym_keyword_unset,
  [27072] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1301), 1,
      sym_keyword_session,
    ACTIONS(1303), 1,
      sym_keyword_signin,
    ACTIONS(1305), 1,
      sym_keyword_signup,
    ACTIONS(1384), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(922), 5,
      sym_comment_clause,
      sym_session_clause,
      sym_signin_clause,
      sym_signup_clause,
      aux_sym_define_scope_statement_repeat1,
  [27101] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1386), 13,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_where,
      sym_keyword_split,
      sym_keyword_group,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [27120] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1342), 1,
      anon_sym_COMMA,
    STATE(923), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1388), 11,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_group,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [27143] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(1269), 1,
      sym_variable_name,
    STATE(1688), 1,
      sym_object_key,
    STATE(1815), 1,
      sym_relate_subject,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1022), 4,
      sym_function_call,
      sym_identifier,
      sym_array,
      sym_record_id,
  [27176] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    ACTIONS(347), 1,
      sym_keyword_content,
    ACTIONS(1247), 1,
      sym_keyword_set,
    STATE(1153), 1,
      sym_return_clause,
    STATE(1217), 1,
      sym_timeout_clause,
    STATE(1368), 1,
      sym_parallel_clause,
    STATE(1093), 2,
      sym_content_clause,
      sym_set_clause,
    ACTIONS(1390), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [27213] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1392), 1,
      sym_keyword_for,
    STATE(911), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1350), 11,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [27236] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1324), 1,
      anon_sym_LT,
    ACTIONS(1394), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [27257] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1301), 1,
      sym_keyword_session,
    ACTIONS(1303), 1,
      sym_keyword_signin,
    ACTIONS(1305), 1,
      sym_keyword_signup,
    ACTIONS(1384), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(927), 5,
      sym_comment_clause,
      sym_session_clause,
      sym_signin_clause,
      sym_signup_clause,
      aux_sym_define_scope_statement_repeat1,
  [27286] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(1269), 1,
      sym_variable_name,
    STATE(1688), 1,
      sym_object_key,
    STATE(1812), 1,
      sym_relate_subject,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1022), 4,
      sym_function_call,
      sym_identifier,
      sym_array,
      sym_record_id,
  [27319] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    ACTIONS(345), 1,
      sym_keyword_where,
    ACTIONS(672), 1,
      anon_sym_COMMA,
    STATE(1029), 1,
      aux_sym_update_statement_repeat1,
    STATE(1087), 1,
      sym_where_clause,
    STATE(1109), 1,
      sym_return_clause,
    STATE(1207), 1,
      sym_timeout_clause,
    STATE(1409), 1,
      sym_parallel_clause,
    ACTIONS(674), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [27358] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1309), 1,
      sym_keyword_function,
    ACTIONS(1311), 1,
      sym_keyword_tokenizers,
    ACTIONS(1313), 1,
      sym_keyword_filters,
    ACTIONS(1396), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(915), 5,
      sym_tokenizers_clause,
      sym_filters_clause,
      sym_function_clause,
      sym_comment_clause,
      aux_sym_define_analyzer_statement_repeat1,
  [27387] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1273), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [27405] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1398), 1,
      sym_keyword_index,
    ACTIONS(1400), 1,
      sym_keyword_define,
    ACTIONS(1402), 1,
      sym_keyword_analyzer,
    ACTIONS(1404), 1,
      sym_keyword_event,
    ACTIONS(1406), 1,
      sym_keyword_field,
    ACTIONS(1408), 1,
      sym_keyword_namespace,
    ACTIONS(1410), 1,
      sym_keyword_scope,
    ACTIONS(1412), 1,
      sym_keyword_table,
    ACTIONS(1414), 1,
      sym_keyword_token,
    ACTIONS(1416), 1,
      sym_keyword_user,
    STATE(1430), 1,
      sym_define_function,
    STATE(1558), 1,
      sym_define_param,
  [27445] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1418), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_session,
      sym_keyword_signin,
      sym_keyword_signup,
      sym_keyword_if,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      sym_custom_function_name,
  [27463] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    STATE(1005), 1,
      sym_fetch_clause,
    STATE(1125), 1,
      sym_timeout_clause,
    STATE(1232), 1,
      sym_parallel_clause,
    STATE(1391), 1,
      sym_explain_clause,
    ACTIONS(1420), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [27497] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    STATE(999), 1,
      sym_fetch_clause,
    STATE(1159), 1,
      sym_timeout_clause,
    STATE(1206), 1,
      sym_parallel_clause,
    STATE(1287), 1,
      sym_explain_clause,
    ACTIONS(1255), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [27531] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1398), 1,
      sym_keyword_index,
    ACTIONS(1400), 1,
      sym_keyword_define,
    ACTIONS(1402), 1,
      sym_keyword_analyzer,
    ACTIONS(1404), 1,
      sym_keyword_event,
    ACTIONS(1408), 1,
      sym_keyword_namespace,
    ACTIONS(1410), 1,
      sym_keyword_scope,
    ACTIONS(1414), 1,
      sym_keyword_token,
    ACTIONS(1416), 1,
      sym_keyword_user,
    ACTIONS(1422), 1,
      sym_keyword_field,
    ACTIONS(1424), 1,
      sym_keyword_table,
    STATE(1456), 1,
      sym_define_function,
    STATE(1458), 1,
      sym_define_param,
  [27571] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1342), 1,
      anon_sym_COMMA,
    STATE(978), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1294), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [27593] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    STATE(998), 1,
      sym_fetch_clause,
    STATE(1118), 1,
      sym_timeout_clause,
    STATE(1229), 1,
      sym_parallel_clause,
    STATE(1348), 1,
      sym_explain_clause,
    ACTIONS(1042), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [27627] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(498), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [27645] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1426), 1,
      sym_keyword_for,
    STATE(958), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1315), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
  [27667] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1429), 1,
      sym_keyword_for,
    STATE(959), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1315), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
  [27689] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(347), 1,
      sym_keyword_content,
    ACTIONS(424), 1,
      sym_keyword_return,
    ACTIONS(1263), 1,
      sym_keyword_set,
    STATE(1117), 1,
      sym_return_clause,
    STATE(1219), 1,
      sym_timeout_clause,
    STATE(1355), 1,
      sym_parallel_clause,
    ACTIONS(1379), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1164), 2,
      sym_content_clause,
      sym_set_clause,
  [27725] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    STATE(1007), 1,
      sym_fetch_clause,
    STATE(1106), 1,
      sym_timeout_clause,
    STATE(1251), 1,
      sym_parallel_clause,
    STATE(1309), 1,
      sym_explain_clause,
    ACTIONS(289), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [27759] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1436), 1,
      sym_keyword_function,
    ACTIONS(1438), 1,
      sym_keyword_param,
    ACTIONS(1440), 1,
      sym_keyword_token,
    ACTIONS(1442), 1,
      sym_keyword_user,
    ACTIONS(1432), 3,
      sym_keyword_index,
      sym_keyword_event,
      sym_keyword_field,
    ACTIONS(1434), 5,
      sym_keyword_analyzer,
      sym_keyword_namespace,
      sym_keyword_scope,
      sym_keyword_table,
      sym_keyword_database,
  [27787] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(1444), 1,
      sym_keyword_only,
    ACTIONS(1446), 1,
      sym_variable_name,
    STATE(897), 1,
      sym_create_target,
    STATE(1803), 1,
      sym_object_key,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(996), 3,
      sym_function_call,
      sym_identifier,
      sym_record_id,
  [27819] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(424), 1,
      sym_keyword_return,
    ACTIONS(426), 1,
      sym_keyword_where,
    ACTIONS(676), 1,
      anon_sym_COMMA,
    STATE(1113), 1,
      aux_sym_update_statement_repeat1,
    STATE(1130), 1,
      sym_return_clause,
    STATE(1132), 1,
      sym_where_clause,
    STATE(1224), 1,
      sym_timeout_clause,
    STATE(1353), 1,
      sym_parallel_clause,
    ACTIONS(1374), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [27857] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(1446), 1,
      sym_variable_name,
    ACTIONS(1448), 1,
      sym_keyword_only,
    STATE(863), 1,
      sym_create_target,
    STATE(1803), 1,
      sym_object_key,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(996), 3,
      sym_function_call,
      sym_identifier,
      sym_record_id,
  [27889] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1450), 1,
      sym_keyword_for,
    STATE(958), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1350), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
  [27911] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(424), 1,
      sym_keyword_return,
    ACTIONS(426), 1,
      sym_keyword_where,
    ACTIONS(676), 1,
      anon_sym_COMMA,
    STATE(1109), 1,
      sym_return_clause,
    STATE(1113), 1,
      aux_sym_update_statement_repeat1,
    STATE(1134), 1,
      sym_where_clause,
    STATE(1207), 1,
      sym_timeout_clause,
    STATE(1409), 1,
      sym_parallel_clause,
    ACTIONS(674), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [27949] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [27967] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(347), 1,
      sym_keyword_content,
    ACTIONS(424), 1,
      sym_keyword_return,
    ACTIONS(1263), 1,
      sym_keyword_set,
    STATE(1153), 1,
      sym_return_clause,
    STATE(1217), 1,
      sym_timeout_clause,
    STATE(1368), 1,
      sym_parallel_clause,
    ACTIONS(1390), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1152), 2,
      sym_content_clause,
      sym_set_clause,
  [28003] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1204), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28021] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1452), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28039] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1454), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28057] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1155), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_changefeed,
      sym_keyword_type,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28075] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    STATE(1024), 1,
      sym_fetch_clause,
    STATE(1158), 1,
      sym_timeout_clause,
    STATE(1215), 1,
      sym_parallel_clause,
    STATE(1370), 1,
      sym_explain_clause,
    ACTIONS(1006), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28109] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1458), 2,
      sym_keyword_asc,
      sym_keyword_desc,
    ACTIONS(1456), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28129] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1460), 1,
      anon_sym_GT,
    ACTIONS(1462), 1,
      anon_sym_DOT_DOT,
    ACTIONS(182), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
      sym_keyword_unset,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28151] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1342), 1,
      anon_sym_COMMA,
    STATE(986), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1277), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28173] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1342), 1,
      anon_sym_COMMA,
    STATE(934), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1277), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28195] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1464), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28213] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1466), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_session,
      sym_keyword_signin,
      sym_keyword_signup,
      sym_keyword_if,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      sym_custom_function_name,
  [28231] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    STATE(1003), 1,
      sym_fetch_clause,
    STATE(1145), 1,
      sym_timeout_clause,
    STATE(1203), 1,
      sym_parallel_clause,
    STATE(1382), 1,
      sym_explain_clause,
    ACTIONS(329), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28265] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1044), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28283] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1468), 1,
      sym_keyword_for,
    STATE(959), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1350), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
  [28305] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    STATE(1001), 1,
      sym_fetch_clause,
    STATE(1157), 1,
      sym_timeout_clause,
    STATE(1253), 1,
      sym_parallel_clause,
    STATE(1304), 1,
      sym_explain_clause,
    ACTIONS(1177), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28339] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    STATE(1016), 1,
      sym_fetch_clause,
    STATE(1105), 1,
      sym_timeout_clause,
    STATE(1208), 1,
      sym_parallel_clause,
    STATE(1412), 1,
      sym_explain_clause,
    ACTIONS(1259), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28373] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1342), 1,
      anon_sym_COMMA,
    STATE(934), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1261), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28395] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28413] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(297), 1,
      sym_keyword_fetch,
    STATE(997), 1,
      sym_fetch_clause,
    STATE(1120), 1,
      sym_timeout_clause,
    STATE(1239), 1,
      sym_parallel_clause,
    STATE(1331), 1,
      sym_explain_clause,
    ACTIONS(1072), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28447] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1470), 1,
      anon_sym_GT,
    ACTIONS(1472), 1,
      anon_sym_DOT_DOT,
    ACTIONS(182), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28468] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    ACTIONS(345), 1,
      sym_keyword_where,
    STATE(1043), 1,
      sym_where_clause,
    STATE(1133), 1,
      sym_return_clause,
    STATE(1221), 1,
      sym_timeout_clause,
    STATE(1356), 1,
      sym_parallel_clause,
    ACTIONS(1016), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28501] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(1446), 1,
      sym_variable_name,
    STATE(874), 1,
      sym_create_target,
    STATE(1803), 1,
      sym_object_key,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(996), 3,
      sym_function_call,
      sym_identifier,
      sym_record_id,
  [28530] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    ACTIONS(345), 1,
      sym_keyword_where,
    STATE(1058), 1,
      sym_where_clause,
    STATE(1128), 1,
      sym_return_clause,
    STATE(1242), 1,
      sym_timeout_clause,
    STATE(1350), 1,
      sym_parallel_clause,
    ACTIONS(1474), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28563] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_keyword_count,
    ACTIONS(45), 1,
      aux_sym_type_name_token1,
    ACTIONS(1446), 1,
      sym_variable_name,
    STATE(866), 1,
      sym_create_target,
    STATE(1803), 1,
      sym_object_key,
    ACTIONS(7), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(996), 3,
      sym_function_call,
      sym_identifier,
      sym_record_id,
  [28592] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 11,
      sym_keyword_jwks,
      sym_keyword_eddsa,
      sym_keyword_es256,
      sym_keyword_es384,
      sym_keyword_es512,
      sym_keyword_ps256,
      sym_keyword_ps384,
      sym_keyword_ps512,
      sym_keyword_rs256,
      sym_keyword_rs384,
      sym_keyword_rs512,
  [28609] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    ACTIONS(345), 1,
      sym_keyword_where,
    STATE(1099), 1,
      sym_where_clause,
    STATE(1166), 1,
      sym_return_clause,
    STATE(1256), 1,
      sym_timeout_clause,
    STATE(1395), 1,
      sym_parallel_clause,
    ACTIONS(375), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28642] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1478), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
      sym_keyword_unset,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28658] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1157), 1,
      sym_timeout_clause,
    STATE(1253), 1,
      sym_parallel_clause,
    STATE(1304), 1,
      sym_explain_clause,
    ACTIONS(1177), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28686] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1120), 1,
      sym_timeout_clause,
    STATE(1239), 1,
      sym_parallel_clause,
    STATE(1331), 1,
      sym_explain_clause,
    ACTIONS(1072), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28714] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1105), 1,
      sym_timeout_clause,
    STATE(1208), 1,
      sym_parallel_clause,
    STATE(1412), 1,
      sym_explain_clause,
    ACTIONS(1259), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28742] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1482), 1,
      anon_sym_COMMA,
    STATE(1011), 1,
      aux_sym_tokenizers_clause_repeat1,
    ACTIONS(1480), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_function,
      sym_keyword_tokenizers,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28762] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1159), 1,
      sym_timeout_clause,
    STATE(1206), 1,
      sym_parallel_clause,
    STATE(1287), 1,
      sym_explain_clause,
    ACTIONS(1255), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28790] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(424), 1,
      sym_keyword_return,
    ACTIONS(426), 1,
      sym_keyword_where,
    STATE(1166), 1,
      sym_return_clause,
    STATE(1167), 1,
      sym_where_clause,
    STATE(1256), 1,
      sym_timeout_clause,
    STATE(1395), 1,
      sym_parallel_clause,
    ACTIONS(375), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [28822] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1106), 1,
      sym_timeout_clause,
    STATE(1251), 1,
      sym_parallel_clause,
    STATE(1309), 1,
      sym_explain_clause,
    ACTIONS(289), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28850] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(424), 1,
      sym_keyword_return,
    ACTIONS(426), 1,
      sym_keyword_where,
    STATE(1127), 1,
      sym_where_clause,
    STATE(1128), 1,
      sym_return_clause,
    STATE(1242), 1,
      sym_timeout_clause,
    STATE(1350), 1,
      sym_parallel_clause,
    ACTIONS(1474), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [28882] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1126), 1,
      sym_timeout_clause,
    STATE(1201), 1,
      sym_parallel_clause,
    STATE(1332), 1,
      sym_explain_clause,
    ACTIONS(1484), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28910] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1488), 1,
      anon_sym_COMMA,
    STATE(1010), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(1486), 8,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28930] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1158), 1,
      sym_timeout_clause,
    STATE(1215), 1,
      sym_parallel_clause,
    STATE(1370), 1,
      sym_explain_clause,
    ACTIONS(1006), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28958] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1456), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28974] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1488), 1,
      anon_sym_COMMA,
    STATE(1010), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(1490), 8,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [28994] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1494), 1,
      anon_sym_COMMA,
    STATE(1010), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(1492), 8,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29014] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1499), 1,
      anon_sym_COMMA,
    STATE(1011), 1,
      aux_sym_tokenizers_clause_repeat1,
    ACTIONS(1497), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_function,
      sym_keyword_tokenizers,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29034] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1504), 1,
      anon_sym_COMMA,
    STATE(1012), 1,
      aux_sym_filters_clause_repeat1,
    ACTIONS(1502), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_function,
      sym_keyword_tokenizers,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29054] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1509), 1,
      anon_sym_COMMA,
    STATE(1012), 1,
      aux_sym_filters_clause_repeat1,
    ACTIONS(1507), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_function,
      sym_keyword_tokenizers,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29074] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1145), 1,
      sym_timeout_clause,
    STATE(1203), 1,
      sym_parallel_clause,
    STATE(1382), 1,
      sym_explain_clause,
    ACTIONS(329), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29102] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1511), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29118] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1125), 1,
      sym_timeout_clause,
    STATE(1232), 1,
      sym_parallel_clause,
    STATE(1391), 1,
      sym_explain_clause,
    ACTIONS(1420), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29146] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(424), 1,
      sym_keyword_return,
    ACTIONS(426), 1,
      sym_keyword_where,
    STATE(1133), 1,
      sym_return_clause,
    STATE(1135), 1,
      sym_where_clause,
    STATE(1221), 1,
      sym_timeout_clause,
    STATE(1356), 1,
      sym_parallel_clause,
    ACTIONS(1016), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [29178] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1482), 1,
      anon_sym_COMMA,
    STATE(1000), 1,
      aux_sym_tokenizers_clause_repeat1,
    ACTIONS(1513), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_function,
      sym_keyword_tokenizers,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29198] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1492), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29214] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1488), 1,
      anon_sym_COMMA,
    STATE(1006), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(1515), 8,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29234] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1488), 1,
      anon_sym_COMMA,
    STATE(1009), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(1486), 8,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29254] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1517), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
      anon_sym_DASH_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29270] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1509), 1,
      anon_sym_COMMA,
    STATE(1013), 1,
      aux_sym_filters_clause_repeat1,
    ACTIONS(1519), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_function,
      sym_keyword_tokenizers,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29290] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1118), 1,
      sym_timeout_clause,
    STATE(1229), 1,
      sym_parallel_clause,
    STATE(1348), 1,
      sym_explain_clause,
    ACTIONS(1042), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29318] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(1521), 1,
      anon_sym_DOT_DOT,
    STATE(37), 1,
      sym_record_id_range,
    STATE(327), 1,
      sym_record_id_value,
    ACTIONS(373), 2,
      sym_int,
      sym_record_id_ident,
    STATE(18), 2,
      sym_array,
      sym_object,
  [29345] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1523), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_function,
      sym_keyword_tokenizers,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29360] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(210), 1,
      anon_sym_DASH_GT,
    ACTIONS(1123), 1,
      anon_sym_EQ,
    STATE(49), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
  [29387] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1525), 1,
      anon_sym_DOT_DOT,
    STATE(46), 1,
      sym_record_id_range,
    STATE(989), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
  [29414] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1527), 1,
      anon_sym_COMMA,
    STATE(1029), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(658), 7,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29433] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1530), 1,
      anon_sym_DOT_DOT,
    STATE(46), 1,
      sym_record_id_range,
    STATE(384), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
  [29460] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(442), 1,
      anon_sym_LBRACE,
    ACTIONS(590), 1,
      anon_sym_LBRACK,
    ACTIONS(1532), 1,
      anon_sym_DOT_DOT,
    STATE(305), 1,
      sym_record_id_range,
    STATE(330), 1,
      sym_record_id_value,
    ACTIONS(444), 2,
      sym_int,
      sym_record_id_ident,
    STATE(292), 2,
      sym_array,
      sym_object,
  [29487] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(178), 1,
      anon_sym_DASH_GT,
    ACTIONS(1099), 1,
      anon_sym_EQ,
    STATE(50), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
  [29514] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(359), 1,
      anon_sym_LBRACE,
    ACTIONS(874), 1,
      anon_sym_LBRACK,
    ACTIONS(1534), 1,
      anon_sym_DOT_DOT,
    STATE(116), 1,
      sym_record_id_range,
    STATE(227), 1,
      sym_record_id_value,
    ACTIONS(361), 2,
      sym_int,
      sym_record_id_ident,
    STATE(101), 2,
      sym_array,
      sym_object,
  [29541] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1538), 1,
      sym_keyword_unique,
    ACTIONS(1540), 1,
      sym_keyword_search,
    STATE(1091), 3,
      sym_unique_clause,
      sym_search_analyzer_clause,
      aux_sym_define_index_statement_repeat1,
    ACTIONS(1536), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29562] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1542), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_function,
      sym_keyword_tokenizers,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29577] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_LBRACE,
    ACTIONS(626), 1,
      anon_sym_LBRACK,
    ACTIONS(1544), 1,
      anon_sym_DOT_DOT,
    STATE(289), 1,
      sym_record_id_range,
    STATE(342), 1,
      sym_record_id_value,
    ACTIONS(365), 2,
      sym_int,
      sym_record_id_ident,
    STATE(241), 2,
      sym_array,
      sym_object,
  [29604] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(359), 1,
      anon_sym_LBRACE,
    ACTIONS(874), 1,
      anon_sym_LBRACK,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT,
    STATE(116), 1,
      sym_record_id_range,
    STATE(344), 1,
      sym_record_id_value,
    ACTIONS(361), 2,
      sym_int,
      sym_record_id_ident,
    STATE(101), 2,
      sym_array,
      sym_object,
  [29631] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(398), 1,
      anon_sym_LBRACE,
    ACTIONS(936), 1,
      anon_sym_LBRACK,
    ACTIONS(1548), 1,
      anon_sym_DOT_DOT,
    STATE(252), 1,
      sym_record_id_value,
    STATE(263), 1,
      sym_record_id_range,
    ACTIONS(400), 2,
      sym_int,
      sym_record_id_ident,
    STATE(226), 2,
      sym_array,
      sym_object,
  [29658] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(398), 1,
      anon_sym_LBRACE,
    ACTIONS(936), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_DOT_DOT,
    STATE(263), 1,
      sym_record_id_range,
    STATE(345), 1,
      sym_record_id_value,
    ACTIONS(400), 2,
      sym_int,
      sym_record_id_ident,
    STATE(226), 2,
      sym_array,
      sym_object,
  [29685] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1552), 1,
      anon_sym_COMMA,
    STATE(1040), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(1492), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
  [29704] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1557), 1,
      anon_sym_COMMA,
    STATE(1060), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1555), 7,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29723] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1559), 1,
      anon_sym_COMMA,
    STATE(1040), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(1490), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
  [29742] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    STATE(1128), 1,
      sym_return_clause,
    STATE(1242), 1,
      sym_timeout_clause,
    STATE(1350), 1,
      sym_parallel_clause,
    ACTIONS(1474), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29769] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(1561), 1,
      anon_sym_DOT_DOT,
    STATE(37), 1,
      sym_record_id_range,
    STATE(506), 1,
      sym_record_id_value,
    ACTIONS(373), 2,
      sym_int,
      sym_record_id_ident,
    STATE(18), 2,
      sym_array,
      sym_object,
  [29796] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(1563), 1,
      anon_sym_DOT_DOT,
    STATE(37), 1,
      sym_record_id_range,
    STATE(520), 1,
      sym_record_id_value,
    ACTIONS(373), 2,
      sym_int,
      sym_record_id_ident,
    STATE(18), 2,
      sym_array,
      sym_object,
  [29823] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(367), 1,
      anon_sym_DASH_GT,
    ACTIONS(1109), 1,
      anon_sym_EQ,
    STATE(48), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
  [29850] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1565), 1,
      anon_sym_DOT_DOT,
    STATE(46), 1,
      sym_record_id_range,
    STATE(503), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
  [29877] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1538), 1,
      sym_keyword_unique,
    ACTIONS(1540), 1,
      sym_keyword_search,
    STATE(1094), 3,
      sym_unique_clause,
      sym_search_analyzer_clause,
      aux_sym_define_index_statement_repeat1,
    ACTIONS(1536), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29898] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    STATE(1166), 1,
      sym_return_clause,
    STATE(1256), 1,
      sym_timeout_clause,
    STATE(1395), 1,
      sym_parallel_clause,
    ACTIONS(375), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [29925] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1567), 1,
      anon_sym_DOT_DOT,
    STATE(46), 1,
      sym_record_id_range,
    STATE(1428), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
  [29952] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_LBRACE,
    ACTIONS(626), 1,
      anon_sym_LBRACK,
    ACTIONS(1569), 1,
      anon_sym_DOT_DOT,
    STATE(268), 1,
      sym_record_id_value,
    STATE(289), 1,
      sym_record_id_range,
    ACTIONS(365), 2,
      sym_int,
      sym_record_id_ident,
    STATE(241), 2,
      sym_array,
      sym_object,
  [29979] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(442), 1,
      anon_sym_LBRACE,
    ACTIONS(590), 1,
      anon_sym_LBRACK,
    ACTIONS(1571), 1,
      anon_sym_DOT_DOT,
    STATE(305), 1,
      sym_record_id_range,
    STATE(390), 1,
      sym_record_id_value,
    ACTIONS(444), 2,
      sym_int,
      sym_record_id_ident,
    STATE(292), 2,
      sym_array,
      sym_object,
  [30006] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1559), 1,
      anon_sym_COMMA,
    STATE(1101), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(1515), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
  [30025] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1573), 1,
      anon_sym_DOT_DOT,
    STATE(46), 1,
      sym_record_id_range,
    STATE(291), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
  [30052] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(1575), 1,
      anon_sym_DOT_DOT,
    STATE(37), 1,
      sym_record_id_range,
    STATE(502), 1,
      sym_record_id_value,
    ACTIONS(373), 2,
      sym_int,
      sym_record_id_ident,
    STATE(18), 2,
      sym_array,
      sym_object,
  [30079] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    STATE(1103), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1577), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [30098] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1579), 1,
      anon_sym_DOT_DOT,
    STATE(46), 1,
      sym_record_id_range,
    STATE(331), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
  [30125] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    STATE(1140), 1,
      sym_return_clause,
    STATE(1227), 1,
      sym_timeout_clause,
    STATE(1358), 1,
      sym_parallel_clause,
    ACTIONS(1581), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [30152] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(1583), 1,
      anon_sym_DOT_DOT,
    STATE(37), 1,
      sym_record_id_range,
    STATE(469), 1,
      sym_record_id_value,
    ACTIONS(373), 2,
      sym_int,
      sym_record_id_ident,
    STATE(18), 2,
      sym_array,
      sym_object,
  [30179] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1587), 1,
      anon_sym_COMMA,
    STATE(1060), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1585), 7,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [30198] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1557), 1,
      anon_sym_COMMA,
    STATE(1041), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1590), 7,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [30217] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1557), 1,
      anon_sym_COMMA,
    STATE(1092), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1592), 7,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [30236] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(1594), 1,
      anon_sym_DOT_DOT,
    STATE(37), 1,
      sym_record_id_range,
    STATE(508), 1,
      sym_record_id_value,
    ACTIONS(373), 2,
      sym_int,
      sym_record_id_ident,
    STATE(18), 2,
      sym_array,
      sym_object,
  [30263] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1598), 1,
      sym_keyword_minkowski,
    ACTIONS(1596), 8,
      sym_keyword_chebyshev,
      sym_keyword_cosine,
      sym_keyword_euclidean,
      sym_keyword_hamming,
      sym_keyword_jaccard,
      sym_keyword_manhattan,
      sym_keyword_pearson,
      sym_int,
  [30280] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(1600), 1,
      anon_sym_DOT_DOT,
    STATE(37), 1,
      sym_record_id_range,
    STATE(490), 1,
      sym_record_id_value,
    ACTIONS(373), 2,
      sym_int,
      sym_record_id_ident,
    STATE(18), 2,
      sym_array,
      sym_object,
  [30307] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_LBRACE,
    ACTIONS(626), 1,
      anon_sym_LBRACK,
    ACTIONS(1602), 1,
      anon_sym_DOT_DOT,
    STATE(238), 1,
      sym_record_id_value,
    STATE(289), 1,
      sym_record_id_range,
    ACTIONS(365), 2,
      sym_int,
      sym_record_id_ident,
    STATE(241), 2,
      sym_array,
      sym_object,
  [30334] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1604), 1,
      anon_sym_DOT_DOT,
    STATE(46), 1,
      sym_record_id_range,
    STATE(474), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
  [30361] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(1606), 1,
      anon_sym_DOT_DOT,
    STATE(37), 1,
      sym_record_id_range,
    STATE(492), 1,
      sym_record_id_value,
    ACTIONS(373), 2,
      sym_int,
      sym_record_id_ident,
    STATE(18), 2,
      sym_array,
      sym_object,
  [30388] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1608), 1,
      anon_sym_DOT_DOT,
    STATE(46), 1,
      sym_record_id_range,
    STATE(343), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
  [30415] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1610), 1,
      anon_sym_DOT_DOT,
    STATE(46), 1,
      sym_record_id_range,
    STATE(511), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
  [30442] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(1612), 1,
      anon_sym_DOT_DOT,
    STATE(37), 1,
      sym_record_id_range,
    STATE(228), 1,
      sym_record_id_value,
    ACTIONS(373), 2,
      sym_int,
      sym_record_id_ident,
    STATE(18), 2,
      sym_array,
      sym_object,
  [30469] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    STATE(1146), 1,
      sym_return_clause,
    STATE(1237), 1,
      sym_timeout_clause,
    STATE(1337), 1,
      sym_parallel_clause,
    ACTIONS(1614), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [30496] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1585), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [30511] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1538), 1,
      sym_keyword_unique,
    ACTIONS(1540), 1,
      sym_keyword_search,
    STATE(1034), 3,
      sym_unique_clause,
      sym_search_analyzer_clause,
      aux_sym_define_index_statement_repeat1,
    ACTIONS(1616), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [30532] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(1618), 1,
      anon_sym_DOT_DOT,
    STATE(37), 1,
      sym_record_id_range,
    STATE(513), 1,
      sym_record_id_value,
    ACTIONS(373), 2,
      sym_int,
      sym_record_id_ident,
    STATE(18), 2,
      sym_array,
      sym_object,
  [30559] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    STATE(1109), 1,
      sym_return_clause,
    STATE(1207), 1,
      sym_timeout_clause,
    STATE(1409), 1,
      sym_parallel_clause,
    ACTIONS(674), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [30586] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1620), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_function,
      sym_keyword_tokenizers,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [30601] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1622), 1,
      anon_sym_DOT_DOT,
    STATE(46), 1,
      sym_record_id_range,
    STATE(494), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
  [30628] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1624), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_function,
      sym_keyword_tokenizers,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [30643] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(1626), 1,
      anon_sym_DOT_DOT,
    STATE(37), 1,
      sym_record_id_range,
    STATE(505), 1,
      sym_record_id_value,
    ACTIONS(373), 2,
      sym_int,
      sym_record_id_ident,
    STATE(18), 2,
      sym_array,
      sym_object,
  [30670] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    STATE(1129), 1,
      sym_return_clause,
    STATE(1230), 1,
      sym_timeout_clause,
    STATE(1278), 1,
      sym_parallel_clause,
    ACTIONS(1628), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [30697] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(1630), 1,
      anon_sym_DOT_DOT,
    STATE(37), 1,
      sym_record_id_range,
    STATE(499), 1,
      sym_record_id_value,
    ACTIONS(373), 2,
      sym_int,
      sym_record_id_ident,
    STATE(18), 2,
      sym_array,
      sym_object,
  [30724] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1632), 1,
      anon_sym_DOT_DOT,
    STATE(46), 1,
      sym_record_id_range,
    STATE(498), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
  [30751] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1502), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_function,
      sym_keyword_tokenizers,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [30766] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(442), 1,
      anon_sym_LBRACE,
    ACTIONS(590), 1,
      anon_sym_LBRACK,
    ACTIONS(1634), 1,
      anon_sym_DOT_DOT,
    STATE(296), 1,
      sym_record_id_value,
    STATE(305), 1,
      sym_record_id_range,
    ACTIONS(444), 2,
      sym_int,
      sym_record_id_ident,
    STATE(292), 2,
      sym_array,
      sym_object,
  [30793] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(398), 1,
      anon_sym_LBRACE,
    ACTIONS(936), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_DOT_DOT,
    STATE(263), 1,
      sym_record_id_range,
    STATE(368), 1,
      sym_record_id_value,
    ACTIONS(400), 2,
      sym_int,
      sym_record_id_ident,
    STATE(226), 2,
      sym_array,
      sym_object,
  [30820] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    STATE(1130), 1,
      sym_return_clause,
    STATE(1224), 1,
      sym_timeout_clause,
    STATE(1353), 1,
      sym_parallel_clause,
    ACTIONS(1374), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [30847] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1497), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_function,
      sym_keyword_tokenizers,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [30862] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(359), 1,
      anon_sym_LBRACE,
    ACTIONS(874), 1,
      anon_sym_LBRACK,
    ACTIONS(1638), 1,
      anon_sym_DOT_DOT,
    STATE(116), 1,
      sym_record_id_range,
    STATE(329), 1,
      sym_record_id_value,
    ACTIONS(361), 2,
      sym_int,
      sym_record_id_ident,
    STATE(101), 2,
      sym_array,
      sym_object,
  [30889] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(1640), 1,
      anon_sym_DOT_DOT,
    STATE(37), 1,
      sym_record_id_range,
    STATE(269), 1,
      sym_record_id_value,
    ACTIONS(373), 2,
      sym_int,
      sym_record_id_ident,
    STATE(18), 2,
      sym_array,
      sym_object,
  [30916] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1644), 1,
      sym_keyword_unique,
    ACTIONS(1647), 1,
      sym_keyword_search,
    STATE(1091), 3,
      sym_unique_clause,
      sym_search_analyzer_clause,
      aux_sym_define_index_statement_repeat1,
    ACTIONS(1642), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [30937] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1557), 1,
      anon_sym_COMMA,
    STATE(1060), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1650), 7,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [30956] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    STATE(1117), 1,
      sym_return_clause,
    STATE(1219), 1,
      sym_timeout_clause,
    STATE(1355), 1,
      sym_parallel_clause,
    ACTIONS(1379), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [30983] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1538), 1,
      sym_keyword_unique,
    ACTIONS(1540), 1,
      sym_keyword_search,
    STATE(1091), 3,
      sym_unique_clause,
      sym_search_analyzer_clause,
      aux_sym_define_index_statement_repeat1,
    ACTIONS(1652), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31004] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(1654), 1,
      anon_sym_DOT_DOT,
    STATE(37), 1,
      sym_record_id_range,
    STATE(324), 1,
      sym_record_id_value,
    ACTIONS(373), 2,
      sym_int,
      sym_record_id_ident,
    STATE(18), 2,
      sym_array,
      sym_object,
  [31031] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1656), 1,
      anon_sym_DOT_DOT,
    STATE(46), 1,
      sym_record_id_range,
    STATE(976), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
  [31058] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    STATE(1131), 1,
      sym_return_clause,
    STATE(1222), 1,
      sym_timeout_clause,
    STATE(1281), 1,
      sym_parallel_clause,
    ACTIONS(1658), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31085] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 1,
      anon_sym_LBRACE,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(1660), 1,
      anon_sym_DOT_DOT,
    STATE(37), 1,
      sym_record_id_range,
    STATE(429), 1,
      sym_record_id_value,
    ACTIONS(373), 2,
      sym_int,
      sym_record_id_ident,
    STATE(18), 2,
      sym_array,
      sym_object,
  [31112] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    STATE(1133), 1,
      sym_return_clause,
    STATE(1221), 1,
      sym_timeout_clause,
    STATE(1356), 1,
      sym_parallel_clause,
    ACTIONS(1016), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31139] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(343), 1,
      sym_keyword_return,
    STATE(1116), 1,
      sym_return_clause,
    STATE(1233), 1,
      sym_timeout_clause,
    STATE(1406), 1,
      sym_parallel_clause,
    ACTIONS(1251), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31166] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1559), 1,
      anon_sym_COMMA,
    STATE(1040), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(1486), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
  [31185] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1559), 1,
      anon_sym_COMMA,
    STATE(1042), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(1486), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
  [31204] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    STATE(793), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1662), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31223] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1664), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_if,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      sym_custom_function_name,
  [31237] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1232), 1,
      sym_parallel_clause,
    STATE(1391), 1,
      sym_explain_clause,
    ACTIONS(1420), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31259] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1215), 1,
      sym_parallel_clause,
    STATE(1370), 1,
      sym_explain_clause,
    ACTIONS(1006), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31281] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1666), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31295] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1233), 1,
      sym_timeout_clause,
    STATE(1406), 1,
      sym_parallel_clause,
    ACTIONS(1251), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31317] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1224), 1,
      sym_timeout_clause,
    STATE(1353), 1,
      sym_parallel_clause,
    ACTIONS(1374), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31339] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    STATE(793), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1668), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31357] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1670), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      sym_keyword_session,
      sym_keyword_signin,
      sym_keyword_signup,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31371] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1672), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      sym_keyword_session,
      sym_keyword_signin,
      sym_keyword_signup,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31385] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1674), 1,
      anon_sym_COMMA,
    STATE(1113), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(658), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
  [31403] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1677), 1,
      anon_sym_COMMA,
    STATE(1122), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1555), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
  [31421] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(424), 1,
      sym_keyword_return,
    STATE(1116), 1,
      sym_return_clause,
    STATE(1233), 1,
      sym_timeout_clause,
    STATE(1406), 1,
      sym_parallel_clause,
    ACTIONS(1251), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [31447] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1230), 1,
      sym_timeout_clause,
    STATE(1278), 1,
      sym_parallel_clause,
    ACTIONS(1628), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31469] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1237), 1,
      sym_timeout_clause,
    STATE(1337), 1,
      sym_parallel_clause,
    ACTIONS(1614), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31491] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1239), 1,
      sym_parallel_clause,
    STATE(1331), 1,
      sym_explain_clause,
    ACTIONS(1072), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31513] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1677), 1,
      anon_sym_COMMA,
    STATE(1122), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1650), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
  [31531] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1253), 1,
      sym_parallel_clause,
    STATE(1304), 1,
      sym_explain_clause,
    ACTIONS(1177), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31553] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(424), 1,
      sym_keyword_return,
    STATE(1129), 1,
      sym_return_clause,
    STATE(1230), 1,
      sym_timeout_clause,
    STATE(1278), 1,
      sym_parallel_clause,
    ACTIONS(1628), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [31579] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1679), 1,
      anon_sym_COMMA,
    STATE(1122), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1585), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
  [31597] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1684), 1,
      sym_keyword_permissions,
    ACTIONS(1687), 1,
      sym_keyword_comment,
    ACTIONS(1682), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1123), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [31617] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1690), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_function,
      sym_keyword_tokenizers,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31631] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1201), 1,
      sym_parallel_clause,
    STATE(1332), 1,
      sym_explain_clause,
    ACTIONS(1484), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31653] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1254), 1,
      sym_parallel_clause,
    STATE(1310), 1,
      sym_explain_clause,
    ACTIONS(1692), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31675] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(424), 1,
      sym_keyword_return,
    STATE(1140), 1,
      sym_return_clause,
    STATE(1227), 1,
      sym_timeout_clause,
    STATE(1358), 1,
      sym_parallel_clause,
    ACTIONS(1581), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [31701] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1227), 1,
      sym_timeout_clause,
    STATE(1358), 1,
      sym_parallel_clause,
    ACTIONS(1581), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31723] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1220), 1,
      sym_timeout_clause,
    STATE(1413), 1,
      sym_parallel_clause,
    ACTIONS(1694), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31745] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1222), 1,
      sym_timeout_clause,
    STATE(1281), 1,
      sym_parallel_clause,
    ACTIONS(1658), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31767] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1234), 1,
      sym_timeout_clause,
    STATE(1325), 1,
      sym_parallel_clause,
    ACTIONS(1696), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31789] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(424), 1,
      sym_keyword_return,
    STATE(1131), 1,
      sym_return_clause,
    STATE(1222), 1,
      sym_timeout_clause,
    STATE(1281), 1,
      sym_parallel_clause,
    ACTIONS(1658), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [31815] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1242), 1,
      sym_timeout_clause,
    STATE(1350), 1,
      sym_parallel_clause,
    ACTIONS(1474), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31837] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(424), 1,
      sym_keyword_return,
    STATE(1130), 1,
      sym_return_clause,
    STATE(1224), 1,
      sym_timeout_clause,
    STATE(1353), 1,
      sym_parallel_clause,
    ACTIONS(1374), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [31863] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(424), 1,
      sym_keyword_return,
    STATE(1128), 1,
      sym_return_clause,
    STATE(1242), 1,
      sym_timeout_clause,
    STATE(1350), 1,
      sym_parallel_clause,
    ACTIONS(1474), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [31889] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1698), 1,
      anon_sym_COMMA,
    STATE(1150), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1650), 6,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31907] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1203), 1,
      sym_parallel_clause,
    STATE(1382), 1,
      sym_explain_clause,
    ACTIONS(329), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31929] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1698), 1,
      anon_sym_COMMA,
    STATE(1143), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1590), 6,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31947] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1207), 1,
      sym_timeout_clause,
    STATE(1409), 1,
      sym_parallel_clause,
    ACTIONS(674), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31969] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1202), 1,
      sym_timeout_clause,
    STATE(1361), 1,
      sym_parallel_clause,
    ACTIONS(1700), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [31991] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1698), 1,
      anon_sym_COMMA,
    STATE(1136), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1592), 6,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32009] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    ACTIONS(1702), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1148), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [32029] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1698), 1,
      anon_sym_COMMA,
    STATE(1150), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1555), 6,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32047] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1706), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      sym_keyword_session,
      sym_keyword_signin,
      sym_keyword_signup,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32061] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1251), 1,
      sym_parallel_clause,
    STATE(1309), 1,
      sym_explain_clause,
    ACTIONS(289), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32083] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1252), 1,
      sym_timeout_clause,
    STATE(1313), 1,
      sym_parallel_clause,
    ACTIONS(1708), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32105] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1710), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32119] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    ACTIONS(1712), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1123), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [32139] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    ACTIONS(1712), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1160), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [32159] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1714), 1,
      anon_sym_COMMA,
    STATE(1150), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1585), 6,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32177] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1256), 1,
      sym_timeout_clause,
    STATE(1395), 1,
      sym_parallel_clause,
    ACTIONS(375), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32199] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(424), 1,
      sym_keyword_return,
    STATE(1117), 1,
      sym_return_clause,
    STATE(1219), 1,
      sym_timeout_clause,
    STATE(1355), 1,
      sym_parallel_clause,
    ACTIONS(1379), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [32225] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1219), 1,
      sym_timeout_clause,
    STATE(1355), 1,
      sym_parallel_clause,
    ACTIONS(1379), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32247] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1677), 1,
      anon_sym_COMMA,
    STATE(1119), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1592), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
  [32265] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(424), 1,
      sym_keyword_return,
    STATE(1109), 1,
      sym_return_clause,
    STATE(1207), 1,
      sym_timeout_clause,
    STATE(1409), 1,
      sym_parallel_clause,
    ACTIONS(674), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [32291] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(424), 1,
      sym_keyword_return,
    STATE(1166), 1,
      sym_return_clause,
    STATE(1256), 1,
      sym_timeout_clause,
    STATE(1395), 1,
      sym_parallel_clause,
    ACTIONS(375), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [32317] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1206), 1,
      sym_parallel_clause,
    STATE(1287), 1,
      sym_explain_clause,
    ACTIONS(1255), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32339] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1229), 1,
      sym_parallel_clause,
    STATE(1348), 1,
      sym_explain_clause,
    ACTIONS(1042), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32361] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1208), 1,
      sym_parallel_clause,
    STATE(1412), 1,
      sym_explain_clause,
    ACTIONS(1259), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32383] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    ACTIONS(1717), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1123), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [32403] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1677), 1,
      anon_sym_COMMA,
    STATE(1114), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1590), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
  [32421] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    STATE(1110), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1719), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32439] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1721), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32453] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(424), 1,
      sym_keyword_return,
    STATE(1146), 1,
      sym_return_clause,
    STATE(1237), 1,
      sym_timeout_clause,
    STATE(1337), 1,
      sym_parallel_clause,
    ACTIONS(1614), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [32479] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1723), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32493] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    STATE(1221), 1,
      sym_timeout_clause,
    STATE(1356), 1,
      sym_parallel_clause,
    ACTIONS(1016), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32515] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    ACTIONS(295), 1,
      sym_keyword_timeout,
    ACTIONS(424), 1,
      sym_keyword_return,
    STATE(1133), 1,
      sym_return_clause,
    STATE(1221), 1,
      sym_timeout_clause,
    STATE(1356), 1,
      sym_parallel_clause,
    ACTIONS(1016), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [32541] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1687), 1,
      sym_keyword_comment,
    ACTIONS(1725), 1,
      sym_keyword_permissions,
    ACTIONS(1682), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1168), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [32560] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1730), 1,
      anon_sym_COMMA,
    STATE(1173), 1,
      aux_sym_when_then_clause_repeat1,
    ACTIONS(1728), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32577] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1736), 1,
      anon_sym_snowball,
    STATE(1084), 1,
      sym_analyzer_filters,
    ACTIONS(1734), 2,
      anon_sym_edgengram,
      anon_sym_ngram,
    ACTIONS(1732), 3,
      anon_sym_ascii,
      anon_sym_lowercase,
      anon_sym_uppercase,
  [32596] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1738), 1,
      anon_sym_COMMA,
    STATE(1189), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1590), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
  [32613] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1742), 1,
      anon_sym_COMMA,
    STATE(1172), 1,
      aux_sym_when_then_clause_repeat1,
    ACTIONS(1740), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32630] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1730), 1,
      anon_sym_COMMA,
    STATE(1172), 1,
      aux_sym_when_then_clause_repeat1,
    ACTIONS(1745), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32647] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1730), 1,
      anon_sym_COMMA,
    STATE(1187), 1,
      aux_sym_when_then_clause_repeat1,
    ACTIONS(1745), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32664] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1730), 1,
      anon_sym_COMMA,
    STATE(1182), 1,
      aux_sym_when_then_clause_repeat1,
    ACTIONS(1747), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32681] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    STATE(49), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
  [32702] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1749), 1,
      sym_keyword_permissions,
    ACTIONS(1751), 2,
      sym_keyword_if,
      sym_custom_function_name,
    STATE(1179), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [32721] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1749), 1,
      sym_keyword_permissions,
    ACTIONS(1753), 2,
      sym_keyword_if,
      sym_custom_function_name,
    STATE(1193), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [32740] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1749), 1,
      sym_keyword_permissions,
    ACTIONS(1753), 2,
      sym_keyword_if,
      sym_custom_function_name,
    STATE(1196), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [32759] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1755), 1,
      sym_keyword_permissions,
    ACTIONS(1717), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1168), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [32778] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    STATE(47), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
  [32799] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1730), 1,
      anon_sym_COMMA,
    STATE(1172), 1,
      aux_sym_when_then_clause_repeat1,
    ACTIONS(1728), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32816] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1757), 1,
      anon_sym_COMMA,
    STATE(1183), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(658), 5,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32833] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1755), 1,
      sym_keyword_permissions,
    ACTIONS(1702), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1198), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [32852] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(720), 1,
      anon_sym_COMMA,
    STATE(1183), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(1760), 5,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32869] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1730), 1,
      anon_sym_COMMA,
    STATE(1172), 1,
      aux_sym_when_then_clause_repeat1,
    ACTIONS(1762), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32886] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1730), 1,
      anon_sym_COMMA,
    STATE(1172), 1,
      aux_sym_when_then_clause_repeat1,
    ACTIONS(1764), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [32903] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1738), 1,
      anon_sym_COMMA,
    STATE(1190), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1592), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
  [32920] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1738), 1,
      anon_sym_COMMA,
    STATE(1195), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1555), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
  [32937] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1738), 1,
      anon_sym_COMMA,
    STATE(1195), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1650), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
  [32954] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(746), 1,
      anon_sym_LPAREN,
    ACTIONS(748), 1,
      anon_sym_LBRACE,
    ACTIONS(1766), 1,
      sym_keyword_when,
    ACTIONS(1768), 1,
      sym_keyword_then,
    STATE(1212), 1,
      sym_when_then_clause,
    STATE(1175), 2,
      sym_block,
      sym_sub_query,
  [32977] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    STATE(50), 1,
      sym_record_id_value,
    ACTIONS(446), 2,
      sym_int,
      sym_record_id_ident,
    STATE(29), 2,
      sym_array,
      sym_object,
  [32998] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1749), 1,
      sym_keyword_permissions,
    ACTIONS(1770), 2,
      sym_keyword_if,
      sym_custom_function_name,
    STATE(1196), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [33017] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1730), 1,
      anon_sym_COMMA,
    STATE(1186), 1,
      aux_sym_when_then_clause_repeat1,
    ACTIONS(1764), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33034] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1772), 1,
      anon_sym_COMMA,
    STATE(1195), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1585), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
  [33051] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1687), 1,
      sym_keyword_comment,
    ACTIONS(1775), 1,
      sym_keyword_permissions,
    ACTIONS(1682), 2,
      sym_keyword_if,
      sym_custom_function_name,
    STATE(1196), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [33070] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1736), 1,
      anon_sym_snowball,
    STATE(1023), 1,
      sym_analyzer_filters,
    ACTIONS(1734), 2,
      anon_sym_edgengram,
      anon_sym_ngram,
    ACTIONS(1732), 3,
      anon_sym_ascii,
      anon_sym_lowercase,
      anon_sym_uppercase,
  [33089] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1755), 1,
      sym_keyword_permissions,
    ACTIONS(1712), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1168), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [33108] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    ACTIONS(1755), 1,
      sym_keyword_permissions,
    ACTIONS(1712), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1180), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [33127] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1395), 1,
      sym_parallel_clause,
    ACTIONS(375), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33143] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    STATE(1310), 1,
      sym_explain_clause,
    ACTIONS(1692), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33159] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1338), 1,
      sym_parallel_clause,
    ACTIONS(1778), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33175] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    STATE(1309), 1,
      sym_explain_clause,
    ACTIONS(289), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33191] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    STATE(1382), 1,
      sym_explain_clause,
    ACTIONS(329), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33207] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(718), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33219] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    STATE(1412), 1,
      sym_explain_clause,
    ACTIONS(1259), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33235] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1353), 1,
      sym_parallel_clause,
    ACTIONS(1374), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33251] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    STATE(1391), 1,
      sym_explain_clause,
    ACTIONS(1420), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33267] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1780), 1,
      anon_sym_RBRACE,
    ACTIONS(1782), 1,
      aux_sym_type_name_token1,
    ACTIONS(1784), 1,
      sym_string,
    STATE(1465), 1,
      sym_object_property,
    STATE(1710), 1,
      sym_object_content,
    STATE(1776), 1,
      sym_object_key,
  [33289] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1406), 1,
      sym_parallel_clause,
    ACTIONS(1251), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33305] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    STATE(793), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1786), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33321] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    STATE(1405), 1,
      sym_comment_clause,
    ACTIONS(1788), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33337] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1782), 1,
      aux_sym_type_name_token1,
    ACTIONS(1784), 1,
      sym_string,
    ACTIONS(1790), 1,
      anon_sym_RBRACE,
    STATE(1465), 1,
      sym_object_property,
    STATE(1776), 1,
      sym_object_key,
    STATE(1822), 1,
      sym_object_content,
  [33359] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1782), 1,
      aux_sym_type_name_token1,
    ACTIONS(1784), 1,
      sym_string,
    ACTIONS(1792), 1,
      anon_sym_RBRACE,
    STATE(1465), 1,
      sym_object_property,
    STATE(1776), 1,
      sym_object_key,
    STATE(1798), 1,
      sym_object_content,
  [33381] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    STATE(1348), 1,
      sym_explain_clause,
    ACTIONS(1042), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33397] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1796), 1,
      sym_keyword_where,
    ACTIONS(1798), 1,
      anon_sym_COMMA,
    STATE(925), 1,
      sym_where_clause,
    STATE(1263), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(1794), 2,
      sym_keyword_full,
      sym_keyword_none,
  [33417] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1355), 1,
      sym_parallel_clause,
    ACTIONS(1379), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33433] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1796), 1,
      sym_keyword_where,
    ACTIONS(1798), 1,
      anon_sym_COMMA,
    STATE(933), 1,
      sym_where_clause,
    STATE(1216), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(1800), 2,
      sym_keyword_full,
      sym_keyword_none,
  [33453] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1337), 1,
      sym_parallel_clause,
    ACTIONS(1614), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33469] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1319), 1,
      sym_parallel_clause,
    ACTIONS(1802), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33485] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1350), 1,
      sym_parallel_clause,
    ACTIONS(1474), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33501] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1325), 1,
      sym_parallel_clause,
    ACTIONS(1696), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33517] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1409), 1,
      sym_parallel_clause,
    ACTIONS(674), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33533] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1281), 1,
      sym_parallel_clause,
    ACTIONS(1658), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33549] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1804), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33561] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1740), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33573] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1361), 1,
      sym_parallel_clause,
    ACTIONS(1700), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33589] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(722), 1,
      anon_sym_COMMA,
    STATE(1255), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(1760), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
  [33605] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    STATE(1331), 1,
      sym_explain_clause,
    ACTIONS(1072), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33621] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1413), 1,
      sym_parallel_clause,
    ACTIONS(1694), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33637] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1798), 1,
      anon_sym_COMMA,
    ACTIONS(1808), 1,
      sym_keyword_where,
    STATE(913), 1,
      sym_where_clause,
    STATE(1250), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(1806), 2,
      sym_keyword_full,
      sym_keyword_none,
  [33657] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    STATE(1332), 1,
      sym_explain_clause,
    ACTIONS(1484), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33673] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1278), 1,
      sym_parallel_clause,
    ACTIONS(1628), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33689] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1400), 1,
      sym_parallel_clause,
    ACTIONS(1810), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33705] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    STATE(1244), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1812), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33721] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1814), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33733] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1313), 1,
      sym_parallel_clause,
    ACTIONS(1708), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33749] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      sym_keyword_comment,
    STATE(1363), 1,
      sym_comment_clause,
    ACTIONS(1816), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33765] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    STATE(1304), 1,
      sym_explain_clause,
    ACTIONS(1177), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33781] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1782), 1,
      aux_sym_type_name_token1,
    ACTIONS(1784), 1,
      sym_string,
    ACTIONS(1818), 1,
      anon_sym_RBRACE,
    STATE(1465), 1,
      sym_object_property,
    STATE(1775), 1,
      sym_object_content,
    STATE(1776), 1,
      sym_object_key,
  [33803] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1782), 1,
      aux_sym_type_name_token1,
    ACTIONS(1784), 1,
      sym_string,
    ACTIONS(1820), 1,
      anon_sym_RBRACE,
    STATE(1465), 1,
      sym_object_property,
    STATE(1776), 1,
      sym_object_key,
    STATE(1842), 1,
      sym_object_content,
  [33825] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1358), 1,
      sym_parallel_clause,
    ACTIONS(1581), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33841] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    STATE(1211), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1822), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33857] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    STATE(793), 1,
      aux_sym_define_user_statement_repeat1,
    ACTIONS(1822), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [33873] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1798), 1,
      anon_sym_COMMA,
    ACTIONS(1824), 1,
      sym_keyword_where,
    STATE(913), 1,
      sym_where_clause,
    STATE(1246), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(1806), 2,
      sym_keyword_full,
      sym_keyword_none,
  [33893] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1798), 1,
      anon_sym_COMMA,
    ACTIONS(1824), 1,
      sym_keyword_where,
    STATE(924), 1,
      sym_where_clause,
    STATE(1263), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(1826), 2,
      sym_keyword_full,
      sym_keyword_none,
  [33913] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1798), 1,
      anon_sym_COMMA,
    ACTIONS(1828), 1,
      sym_keyword_where,
    STATE(933), 1,
      sym_where_clause,
    STATE(1249), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(1800), 2,
      sym_keyword_full,
      sym_keyword_none,
  [33933] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1782), 1,
      aux_sym_type_name_token1,
    ACTIONS(1784), 1,
      sym_string,
    ACTIONS(1830), 1,
      anon_sym_RBRACE,
    STATE(1465), 1,
      sym_object_property,
    STATE(1767), 1,
      sym_object_content,
    STATE(1776), 1,
      sym_object_key,
  [33955] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1798), 1,
      anon_sym_COMMA,
    ACTIONS(1828), 1,
      sym_keyword_where,
    STATE(925), 1,
      sym_where_clause,
    STATE(1263), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(1794), 2,
      sym_keyword_full,
      sym_keyword_none,
  [33975] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1798), 1,
      anon_sym_COMMA,
    ACTIONS(1808), 1,
      sym_keyword_where,
    STATE(924), 1,
      sym_where_clause,
    STATE(1263), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(1826), 2,
      sym_keyword_full,
      sym_keyword_none,
  [33995] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    STATE(1370), 1,
      sym_explain_clause,
    ACTIONS(1006), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34011] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1289), 1,
      sym_parallel_clause,
    ACTIONS(1832), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34027] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    STATE(1287), 1,
      sym_explain_clause,
    ACTIONS(1255), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34043] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(291), 1,
      sym_keyword_explain,
    STATE(1303), 1,
      sym_explain_clause,
    ACTIONS(1834), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34059] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1836), 1,
      anon_sym_COMMA,
    STATE(1255), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(658), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
  [34075] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      sym_keyword_parallel,
    STATE(1356), 1,
      sym_parallel_clause,
    ACTIONS(1016), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34091] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1841), 1,
      anon_sym_COMMA,
    STATE(1268), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1839), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34106] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(728), 1,
      sym_keyword_as,
    ACTIONS(730), 1,
      sym_keyword_where,
    STATE(1485), 1,
      sym_where_clause,
    ACTIONS(732), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [34123] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1845), 1,
      sym_keyword_transaction,
    ACTIONS(1843), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34136] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1849), 1,
      sym_keyword_transaction,
    ACTIONS(1847), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34149] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1853), 1,
      sym_keyword_transaction,
    ACTIONS(1851), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34162] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1018), 1,
      sym_analyzer_tokenizers,
    ACTIONS(1855), 4,
      anon_sym_blank,
      anon_sym_camel,
      anon_sym_class,
      anon_sym_punct,
  [34175] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1859), 1,
      anon_sym_COMMA,
    STATE(1263), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(1857), 3,
      sym_keyword_full,
      sym_keyword_where,
      sym_keyword_none,
  [34190] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1841), 1,
      anon_sym_COMMA,
    STATE(1266), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1862), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34205] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1866), 1,
      sym_keyword_full,
    ACTIONS(1864), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34218] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1841), 1,
      anon_sym_COMMA,
    STATE(1267), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1839), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34233] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1868), 1,
      anon_sym_COMMA,
    STATE(1267), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1585), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34248] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1841), 1,
      anon_sym_COMMA,
    STATE(1267), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1871), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34263] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1841), 1,
      anon_sym_COMMA,
    STATE(1271), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1871), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34278] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1088), 1,
      sym_analyzer_tokenizers,
    ACTIONS(1855), 4,
      anon_sym_blank,
      anon_sym_camel,
      anon_sym_class,
      anon_sym_punct,
  [34291] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1841), 1,
      anon_sym_COMMA,
    STATE(1267), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1873), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34306] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34317] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1841), 1,
      anon_sym_COMMA,
    STATE(1274), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1873), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34332] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1841), 1,
      anon_sym_COMMA,
    STATE(1267), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1877), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34347] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1841), 1,
      anon_sym_COMMA,
    STATE(1277), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1877), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34362] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1879), 1,
      aux_sym_type_name_token1,
    ACTIONS(1881), 1,
      sym_int,
    STATE(1641), 1,
      sym_type,
    STATE(869), 2,
      sym_type_name,
      sym_parameterized_type,
  [34379] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1841), 1,
      anon_sym_COMMA,
    STATE(1267), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1883), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34394] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1694), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34404] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34414] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(685), 1,
      sym_assignment_operator,
    ACTIONS(1885), 3,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
  [34426] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1696), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34436] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1352), 1,
      sym_keyword_for,
    STATE(921), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1887), 2,
      sym_keyword_full,
      sym_keyword_none,
  [34450] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1891), 1,
      anon_sym_LT,
    STATE(84), 1,
      sym_argument_list,
    STATE(1600), 1,
      sym_version,
  [34466] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1893), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34476] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 1,
      anon_sym_COMMA,
    STATE(1411), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1862), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [34490] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1897), 4,
      sym_keyword_select,
      sym_keyword_create,
      sym_keyword_delete,
      sym_keyword_update,
  [34500] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1259), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34510] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1899), 1,
      anon_sym_COMMA,
    STATE(1288), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1585), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [34524] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1902), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34534] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1904), 1,
      anon_sym_STAR,
    ACTIONS(1906), 1,
      aux_sym_type_name_token1,
    ACTIONS(1908), 1,
      sym_function_name,
    STATE(32), 1,
      sym_identifier,
  [34550] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1910), 4,
      sym_keyword_select,
      sym_keyword_create,
      sym_keyword_delete,
      sym_keyword_update,
  [34560] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(666), 1,
      sym_assignment_operator,
    ACTIONS(1885), 3,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
  [34572] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1324), 1,
      anon_sym_LT,
    ACTIONS(1912), 1,
      anon_sym_COMMA,
    ACTIONS(1914), 1,
      anon_sym_RPAREN,
    STATE(1432), 1,
      aux_sym_param_list_repeat1,
  [34588] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1916), 1,
      sym_keyword_if,
    ACTIONS(1918), 1,
      aux_sym_type_name_token1,
    STATE(1598), 1,
      sym_identifier,
    STATE(1687), 1,
      sym_if_not_exists_clause,
  [34604] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1920), 1,
      anon_sym_LBRACK,
    ACTIONS(1922), 1,
      anon_sym_LPAREN,
    STATE(1369), 1,
      sym_object,
  [34620] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34630] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      sym_decimal,
    STATE(1147), 1,
      sym_number,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
  [34644] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1891), 1,
      anon_sym_LT,
    ACTIONS(1924), 1,
      anon_sym_LPAREN,
    STATE(88), 1,
      sym_argument_list,
    STATE(1640), 1,
      sym_version,
  [34660] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(746), 1,
      anon_sym_LPAREN,
    ACTIONS(748), 1,
      anon_sym_LBRACE,
    STATE(1194), 2,
      sym_block,
      sym_sub_query,
  [34674] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(674), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34684] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1926), 1,
      anon_sym_LPAREN,
    ACTIONS(1928), 1,
      anon_sym_QMARK,
    ACTIONS(1930), 1,
      aux_sym_type_name_token1,
    STATE(44), 1,
      sym_identifier,
  [34700] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(746), 1,
      anon_sym_LPAREN,
    ACTIONS(748), 1,
      anon_sym_LBRACE,
    STATE(1169), 2,
      sym_block,
      sym_sub_query,
  [34714] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1932), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34724] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1255), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34734] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(329), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34744] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 1,
      anon_sym_COMMA,
    STATE(1347), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1877), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [34758] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 1,
      anon_sym_COMMA,
    STATE(1288), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1877), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [34772] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1879), 1,
      aux_sym_type_name_token1,
    STATE(944), 1,
      sym_type,
    STATE(869), 2,
      sym_type_name,
      sym_parameterized_type,
  [34786] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1006), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34796] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1834), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34806] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1934), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34816] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34826] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1832), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34836] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1936), 4,
      sym_keyword_select,
      sym_keyword_create,
      sym_keyword_delete,
      sym_keyword_update,
  [34846] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(747), 1,
      sym_assignment_operator,
    ACTIONS(1885), 3,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
  [34858] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1938), 1,
      anon_sym_LBRACK,
    ACTIONS(1940), 1,
      anon_sym_LPAREN,
    STATE(1344), 1,
      sym_object,
  [34874] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1918), 1,
      aux_sym_type_name_token1,
    ACTIONS(1942), 1,
      anon_sym_STAR,
    ACTIONS(1944), 1,
      sym_function_name,
    STATE(264), 1,
      sym_identifier,
  [34890] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1946), 4,
      sym_keyword_select,
      sym_keyword_create,
      sym_keyword_delete,
      sym_keyword_update,
  [34900] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1948), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34910] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1918), 1,
      aux_sym_type_name_token1,
    ACTIONS(1950), 1,
      anon_sym_STAR,
    ACTIONS(1952), 1,
      sym_function_name,
    STATE(57), 1,
      sym_identifier,
  [34926] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 1,
      anon_sym_COMMA,
    STATE(1307), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1873), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [34940] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1954), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34950] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1879), 1,
      aux_sym_type_name_token1,
    STATE(1523), 1,
      sym_type,
    STATE(869), 2,
      sym_type_name,
      sym_parameterized_type,
  [34964] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1956), 4,
      sym_keyword_select,
      sym_keyword_create,
      sym_keyword_delete,
      sym_keyword_update,
  [34974] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1810), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [34984] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 1,
      anon_sym_COMMA,
    STATE(1288), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1873), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [34998] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(341), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35008] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(670), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35018] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1782), 1,
      aux_sym_type_name_token1,
    ACTIONS(1784), 1,
      sym_string,
    STATE(1637), 1,
      sym_object_property,
    STATE(1776), 1,
      sym_object_key,
  [35034] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1958), 1,
      anon_sym_COMMA,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(658), 2,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [35048] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1177), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35058] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1692), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35068] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1918), 1,
      aux_sym_type_name_token1,
    ACTIONS(1961), 1,
      sym_keyword_if,
    STATE(1676), 1,
      sym_if_exists_clause,
    STATE(1709), 1,
      sym_identifier,
  [35084] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1918), 1,
      aux_sym_type_name_token1,
    ACTIONS(1961), 1,
      sym_keyword_if,
    STATE(1675), 1,
      sym_if_exists_clause,
    STATE(1712), 1,
      sym_identifier,
  [35100] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1963), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35110] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1920), 1,
      anon_sym_LBRACK,
    ACTIONS(1965), 1,
      anon_sym_LPAREN,
    STATE(1369), 1,
      sym_object,
  [35126] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1708), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35136] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1967), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35146] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1918), 1,
      aux_sym_type_name_token1,
    ACTIONS(1961), 1,
      sym_keyword_if,
    STATE(1284), 1,
      sym_identifier,
    STATE(1671), 1,
      sym_if_exists_clause,
  [35162] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1969), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35172] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1468), 1,
      sym_keyword_for,
    STATE(983), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1887), 2,
      sym_keyword_full,
      sym_keyword_none,
  [35186] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1971), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35196] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(709), 1,
      sym_assignment_operator,
    ACTIONS(1885), 3,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
  [35208] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1973), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35218] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1961), 1,
      sym_keyword_if,
    ACTIONS(1975), 1,
      aux_sym_type_name_token1,
    STATE(1495), 1,
      sym_identifier,
    STATE(1670), 1,
      sym_if_exists_clause,
  [35234] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1916), 1,
      sym_keyword_if,
    ACTIONS(1918), 1,
      aux_sym_type_name_token1,
    STATE(1673), 1,
      sym_if_not_exists_clause,
    STATE(1730), 1,
      sym_identifier,
  [35250] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 1,
      anon_sym_COMMA,
    STATE(1288), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1883), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [35264] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1072), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35274] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1916), 1,
      sym_keyword_if,
    ACTIONS(1918), 1,
      aux_sym_type_name_token1,
    STATE(1664), 1,
      sym_if_not_exists_clause,
    STATE(1732), 1,
      sym_identifier,
  [35290] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1581), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35300] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1916), 1,
      sym_keyword_if,
    ACTIONS(1918), 1,
      aux_sym_type_name_token1,
    STATE(844), 1,
      sym_identifier,
    STATE(1663), 1,
      sym_if_not_exists_clause,
  [35316] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1977), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35326] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1658), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35336] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1916), 1,
      sym_keyword_if,
    ACTIONS(1918), 1,
      aux_sym_type_name_token1,
    STATE(908), 1,
      sym_identifier,
    STATE(1661), 1,
      sym_if_not_exists_clause,
  [35352] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1614), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35362] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1474), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35372] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1979), 1,
      anon_sym_LPAREN,
    ACTIONS(1981), 1,
      anon_sym_QMARK,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(267), 1,
      sym_identifier,
  [35388] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1700), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35398] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1987), 1,
      sym_keyword_where,
    STATE(1104), 1,
      sym_where_clause,
    ACTIONS(1985), 2,
      sym_keyword_full,
      sym_keyword_none,
  [35412] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1916), 1,
      sym_keyword_if,
    ACTIONS(1918), 1,
      aux_sym_type_name_token1,
    STATE(1658), 1,
      sym_if_not_exists_clause,
    STATE(1659), 1,
      sym_identifier,
  [35428] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1778), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35438] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1950), 1,
      anon_sym_STAR,
    ACTIONS(1952), 1,
      sym_function_name,
    ACTIONS(1989), 1,
      aux_sym_type_name_token1,
    STATE(57), 1,
      sym_identifier,
  [35454] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1991), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35464] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1916), 1,
      sym_keyword_if,
    ACTIONS(1918), 1,
      aux_sym_type_name_token1,
    STATE(1568), 1,
      sym_identifier,
    STATE(1653), 1,
      sym_if_not_exists_clause,
  [35480] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(746), 1,
      anon_sym_LPAREN,
    ACTIONS(748), 1,
      anon_sym_LBRACE,
    STATE(1111), 2,
      sym_block,
      sym_sub_query,
  [35494] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 1,
      anon_sym_COMMA,
    STATE(1326), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1871), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [35508] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1392), 1,
      sym_keyword_for,
    STATE(943), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1993), 2,
      sym_keyword_full,
      sym_keyword_none,
  [35522] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1379), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35532] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1995), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35542] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1042), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35552] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(676), 1,
      sym_assignment_operator,
    ACTIONS(1885), 3,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
  [35564] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1997), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35574] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1999), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35584] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(746), 1,
      anon_sym_LPAREN,
    ACTIONS(748), 1,
      anon_sym_LBRACE,
    STATE(1144), 2,
      sym_block,
      sym_sub_query,
  [35598] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2001), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35608] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 1,
      anon_sym_COMMA,
    STATE(1288), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1871), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [35622] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2003), 1,
      anon_sym_STAR,
    ACTIONS(2005), 1,
      aux_sym_type_name_token1,
    ACTIONS(2007), 1,
      sym_function_name,
    STATE(303), 1,
      sym_identifier,
  [35638] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2009), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35648] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2011), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35658] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2013), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35668] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      sym_decimal,
    STATE(1753), 1,
      sym_number,
    ACTIONS(49), 2,
      sym_int,
      sym_float,
  [35682] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(289), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35692] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2015), 1,
      anon_sym_LPAREN,
    ACTIONS(2017), 1,
      anon_sym_QMARK,
    ACTIONS(2019), 1,
      aux_sym_type_name_token1,
    STATE(122), 1,
      sym_identifier,
  [35708] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(806), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35718] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2021), 1,
      sym_keyword_where,
    STATE(1104), 1,
      sym_where_clause,
    ACTIONS(1985), 2,
      sym_keyword_full,
      sym_keyword_none,
  [35732] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1879), 1,
      aux_sym_type_name_token1,
    STATE(1293), 1,
      sym_type,
    STATE(869), 2,
      sym_type_name,
      sym_parameterized_type,
  [35746] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1891), 1,
      anon_sym_LT,
    ACTIONS(2023), 1,
      anon_sym_LPAREN,
    STATE(450), 1,
      sym_argument_list,
    STATE(1669), 1,
      sym_version,
  [35762] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1450), 1,
      sym_keyword_for,
    STATE(966), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1993), 2,
      sym_keyword_full,
      sym_keyword_none,
  [35776] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2025), 1,
      sym_keyword_where,
    STATE(1104), 1,
      sym_where_clause,
    ACTIONS(1985), 2,
      sym_keyword_full,
      sym_keyword_none,
  [35790] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2027), 1,
      anon_sym_STAR,
    ACTIONS(2029), 1,
      aux_sym_type_name_token1,
    ACTIONS(2031), 1,
      sym_function_name,
    STATE(290), 1,
      sym_identifier,
  [35806] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1484), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35816] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2033), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35826] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    ACTIONS(2035), 1,
      anon_sym_LPAREN,
    ACTIONS(2037), 1,
      anon_sym_QMARK,
    STATE(60), 1,
      sym_identifier,
  [35842] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2035), 1,
      anon_sym_LPAREN,
    ACTIONS(2037), 1,
      anon_sym_QMARK,
    ACTIONS(2039), 1,
      aux_sym_type_name_token1,
    STATE(60), 1,
      sym_identifier,
  [35858] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1016), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35868] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1891), 1,
      anon_sym_LT,
    ACTIONS(2041), 1,
      anon_sym_LPAREN,
    STATE(477), 1,
      sym_argument_list,
    STATE(1606), 1,
      sym_version,
  [35884] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 1,
      anon_sym_COMMA,
    STATE(1376), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1839), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [35898] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1891), 1,
      anon_sym_LT,
    ACTIONS(2043), 1,
      anon_sym_LPAREN,
    STATE(193), 1,
      sym_argument_list,
    STATE(1649), 1,
      sym_version,
  [35914] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2045), 1,
      anon_sym_LPAREN,
    ACTIONS(2047), 1,
      anon_sym_QMARK,
    ACTIONS(2049), 1,
      aux_sym_type_name_token1,
    STATE(335), 1,
      sym_identifier,
  [35930] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2051), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [35940] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1879), 1,
      aux_sym_type_name_token1,
    STATE(914), 1,
      sym_type,
    STATE(869), 2,
      sym_type_name,
      sym_parameterized_type,
  [35954] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1857), 4,
      sym_keyword_full,
      sym_keyword_where,
      sym_keyword_none,
      anon_sym_COMMA,
  [35964] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(746), 1,
      anon_sym_LPAREN,
    ACTIONS(748), 1,
      anon_sym_LBRACE,
    STATE(1226), 2,
      sym_block,
      sym_sub_query,
  [35978] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1916), 1,
      sym_keyword_if,
    ACTIONS(1918), 1,
      aux_sym_type_name_token1,
    STATE(816), 1,
      sym_identifier,
    STATE(1583), 1,
      sym_if_not_exists_clause,
  [35994] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2053), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [36004] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1628), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [36014] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2055), 1,
      anon_sym_LPAREN,
    ACTIONS(2057), 1,
      anon_sym_QMARK,
    ACTIONS(2059), 1,
      aux_sym_type_name_token1,
    STATE(293), 1,
      sym_identifier,
  [36030] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2061), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [36040] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1374), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [36050] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1891), 1,
      anon_sym_LT,
    ACTIONS(2063), 1,
      anon_sym_LPAREN,
    STATE(458), 1,
      sym_argument_list,
    STATE(1597), 1,
      sym_version,
  [36066] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 1,
      anon_sym_COMMA,
    STATE(1288), 1,
      aux_sym_insert_statement_repeat3,
    ACTIONS(1839), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [36080] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1420), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [36090] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1802), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [36100] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    ACTIONS(1938), 1,
      anon_sym_LBRACK,
    ACTIONS(2065), 1,
      anon_sym_LPAREN,
    STATE(1344), 1,
      sym_object,
  [36116] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2067), 1,
      anon_sym_STAR,
    ACTIONS(2069), 1,
      aux_sym_type_name_token1,
    ACTIONS(2071), 1,
      sym_function_name,
    STATE(107), 1,
      sym_identifier,
  [36132] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(716), 1,
      sym_assignment_operator,
    ACTIONS(1885), 3,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
  [36144] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2073), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [36157] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2075), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [36170] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    ACTIONS(2077), 1,
      anon_sym_RPAREN,
    STATE(793), 1,
      aux_sym_define_user_statement_repeat1,
  [36183] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    ACTIONS(2079), 1,
      anon_sym_RPAREN,
    STATE(1419), 1,
      aux_sym_define_user_statement_repeat1,
  [36196] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2081), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [36209] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2083), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [36222] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2085), 1,
      anon_sym_COMMA,
    ACTIONS(2087), 1,
      anon_sym_RPAREN,
    STATE(1438), 1,
      aux_sym_graph_path_repeat1,
  [36235] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    ACTIONS(2079), 1,
      anon_sym_RPAREN,
    STATE(793), 1,
      aux_sym_define_user_statement_repeat1,
  [36248] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    ACTIONS(2089), 1,
      anon_sym_RPAREN,
    STATE(1424), 1,
      aux_sym_define_user_statement_repeat1,
  [36261] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1154), 1,
      sym_field_assignment,
    STATE(1371), 1,
      sym_identifier,
  [36274] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1161), 1,
      sym_field_assignment,
    STATE(1371), 1,
      sym_identifier,
  [36287] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(182), 1,
      anon_sym_DASH_GT,
    ACTIONS(2091), 1,
      anon_sym_GT,
    ACTIONS(2093), 1,
      anon_sym_DOT_DOT,
  [36300] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2095), 1,
      anon_sym_RBRACK,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [36313] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2097), 1,
      sym_keyword_if,
    ACTIONS(2099), 1,
      sym_custom_function_name,
    STATE(1811), 1,
      sym_if_not_exists_clause,
  [36326] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2085), 1,
      anon_sym_COMMA,
    ACTIONS(2101), 1,
      anon_sym_RPAREN,
    STATE(1423), 1,
      aux_sym_graph_path_repeat1,
  [36339] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1912), 1,
      anon_sym_COMMA,
    ACTIONS(2103), 1,
      anon_sym_RPAREN,
    STATE(1552), 1,
      aux_sym_param_list_repeat1,
  [36352] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2105), 1,
      sym_keyword_from,
    ACTIONS(2107), 1,
      anon_sym_COMMA,
    STATE(1491), 1,
      aux_sym_select_statement_repeat1,
  [36365] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1292), 1,
      sym_identifier,
    STATE(1366), 1,
      sym_field_assignment,
  [36378] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2109), 1,
      sym_keyword_on_duplicate_key_update,
    ACTIONS(2111), 1,
      anon_sym_COMMA,
    STATE(1566), 1,
      aux_sym_insert_statement_repeat2,
  [36391] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2109), 1,
      sym_keyword_on_duplicate_key_update,
    ACTIONS(2111), 1,
      anon_sym_COMMA,
    STATE(1461), 1,
      aux_sym_insert_statement_repeat2,
  [36404] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2113), 1,
      ts_builtin_sym_end,
    ACTIONS(2115), 1,
      sym_semi_colon,
    STATE(1466), 1,
      aux_sym_expressions_repeat1,
  [36417] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2117), 1,
      anon_sym_COMMA,
    ACTIONS(2120), 1,
      anon_sym_RPAREN,
    STATE(1438), 1,
      aux_sym_graph_path_repeat1,
  [36430] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2122), 3,
      sym_keyword_namespace,
      sym_keyword_root,
      sym_keyword_database,
  [36439] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2107), 1,
      anon_sym_COMMA,
    ACTIONS(2124), 1,
      sym_keyword_from,
    STATE(1473), 1,
      aux_sym_select_statement_repeat1,
  [36452] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2126), 3,
      sym_keyword_namespace,
      sym_keyword_root,
      sym_keyword_database,
  [36461] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2128), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [36474] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1073), 1,
      sym_field_assignment,
    STATE(1371), 1,
      sym_identifier,
  [36487] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2122), 3,
      sym_keyword_namespace,
      sym_keyword_scope,
      sym_keyword_root,
  [36496] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    ACTIONS(2130), 1,
      anon_sym_RPAREN,
    STATE(1467), 1,
      aux_sym_define_user_statement_repeat1,
  [36509] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1292), 1,
      sym_identifier,
    STATE(1321), 1,
      sym_field_assignment,
  [36522] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2085), 1,
      anon_sym_COMMA,
    ACTIONS(2132), 1,
      anon_sym_RPAREN,
    STATE(1455), 1,
      aux_sym_graph_path_repeat1,
  [36535] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2134), 1,
      anon_sym_RBRACK,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [36548] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2136), 1,
      anon_sym_COMMA,
    ACTIONS(2138), 1,
      anon_sym_RBRACK,
    STATE(1464), 1,
      aux_sym_insert_statement_repeat1,
  [36561] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1073), 1,
      sym_field_assignment,
    STATE(1416), 1,
      sym_identifier,
  [36574] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2140), 3,
      sym_keyword_namespace,
      sym_keyword_root,
      sym_keyword_database,
  [36583] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2140), 3,
      sym_keyword_namespace,
      sym_keyword_scope,
      sym_keyword_root,
  [36592] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2142), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [36605] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2144), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [36618] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2085), 1,
      anon_sym_COMMA,
    ACTIONS(2146), 1,
      anon_sym_RPAREN,
    STATE(1438), 1,
      aux_sym_graph_path_repeat1,
  [36631] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2097), 1,
      sym_keyword_if,
    ACTIONS(2148), 1,
      sym_custom_function_name,
    STATE(1728), 1,
      sym_if_not_exists_clause,
  [36644] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1918), 1,
      aux_sym_type_name_token1,
    ACTIONS(2150), 1,
      sym_keyword_on,
    STATE(1340), 1,
      sym_identifier,
  [36657] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2152), 1,
      sym_keyword_if,
    ACTIONS(2154), 1,
      sym_variable_name,
    STATE(1725), 1,
      sym_if_not_exists_clause,
  [36670] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2156), 1,
      sym_keyword_if,
    ACTIONS(2158), 1,
      sym_custom_function_name,
    STATE(1835), 1,
      sym_if_exists_clause,
  [36683] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2158), 1,
      sym_variable_name,
    ACTIONS(2160), 1,
      sym_keyword_if,
    STATE(1716), 1,
      sym_if_exists_clause,
  [36696] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2111), 1,
      anon_sym_COMMA,
    ACTIONS(2162), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(1566), 1,
      aux_sym_insert_statement_repeat2,
  [36709] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2164), 3,
      sym_keyword_namespace,
      sym_keyword_scope,
      sym_keyword_root,
  [36718] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2166), 1,
      anon_sym_RBRACK,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [36731] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2136), 1,
      anon_sym_COMMA,
    ACTIONS(2168), 1,
      anon_sym_RBRACK,
    STATE(1522), 1,
      aux_sym_insert_statement_repeat1,
  [36744] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2170), 1,
      anon_sym_COMMA,
    ACTIONS(2172), 1,
      anon_sym_RBRACE,
    STATE(1551), 1,
      aux_sym_object_content_repeat1,
  [36757] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(540), 1,
      ts_builtin_sym_end,
    ACTIONS(2174), 1,
      sym_semi_colon,
    STATE(1556), 1,
      aux_sym_expressions_repeat1,
  [36770] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    ACTIONS(2176), 1,
      anon_sym_RPAREN,
    STATE(793), 1,
      aux_sym_define_user_statement_repeat1,
  [36783] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2178), 3,
      sym_keyword_namespace,
      sym_keyword_root,
      sym_keyword_database,
  [36792] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1292), 1,
      sym_identifier,
    STATE(1306), 1,
      sym_field_assignment,
  [36805] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2136), 1,
      anon_sym_COMMA,
    ACTIONS(2168), 1,
      anon_sym_RBRACK,
    STATE(1545), 1,
      aux_sym_insert_statement_repeat1,
  [36818] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1073), 1,
      sym_field_assignment,
    STATE(1315), 1,
      sym_identifier,
  [36831] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    ACTIONS(2176), 1,
      anon_sym_RPAREN,
    STATE(1516), 1,
      aux_sym_define_user_statement_repeat1,
  [36844] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2107), 1,
      anon_sym_COMMA,
    ACTIONS(2180), 1,
      sym_keyword_from,
    STATE(1541), 1,
      aux_sym_select_statement_repeat1,
  [36857] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2182), 3,
      sym_keyword_namespace,
      sym_keyword_scope,
      sym_keyword_root,
  [36866] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2085), 1,
      anon_sym_COMMA,
    ACTIONS(2184), 1,
      anon_sym_RPAREN,
    STATE(1483), 1,
      aux_sym_graph_path_repeat1,
  [36879] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2186), 1,
      anon_sym_RBRACK,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [36892] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2097), 1,
      sym_keyword_if,
    ACTIONS(2188), 1,
      sym_custom_function_name,
    STATE(1801), 1,
      sym_if_not_exists_clause,
  [36905] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2152), 1,
      sym_keyword_if,
    ACTIONS(2190), 1,
      sym_variable_name,
    STATE(1786), 1,
      sym_if_not_exists_clause,
  [36918] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1062), 1,
      sym_field_assignment,
    STATE(1280), 1,
      sym_identifier,
  [36931] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1061), 1,
      sym_field_assignment,
    STATE(1280), 1,
      sym_identifier,
  [36944] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2192), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [36957] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2194), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [36970] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2085), 1,
      anon_sym_COMMA,
    ACTIONS(2196), 1,
      anon_sym_RPAREN,
    STATE(1438), 1,
      aux_sym_graph_path_repeat1,
  [36983] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2198), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [36996] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2200), 1,
      sym_keyword_as,
    ACTIONS(2202), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [37007] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2206), 1,
      sym_keyword_relation,
    ACTIONS(2204), 2,
      sym_keyword_any,
      sym_keyword_normal,
  [37018] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2111), 1,
      anon_sym_COMMA,
    ACTIONS(2208), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(1435), 1,
      aux_sym_insert_statement_repeat2,
  [37031] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(971), 1,
      sym_duration,
  [37044] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2111), 1,
      anon_sym_COMMA,
    ACTIONS(2208), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(1566), 1,
      aux_sym_insert_statement_repeat2,
  [37057] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1073), 1,
      sym_field_assignment,
    STATE(1280), 1,
      sym_identifier,
  [37070] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2107), 1,
      anon_sym_COMMA,
    ACTIONS(2210), 1,
      sym_keyword_from,
    STATE(1541), 1,
      aux_sym_select_statement_repeat1,
  [37083] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1275), 1,
      sym_field_assignment,
    STATE(1315), 1,
      sym_identifier,
  [37096] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1273), 1,
      sym_field_assignment,
    STATE(1315), 1,
      sym_identifier,
  [37109] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1292), 1,
      sym_identifier,
    STATE(1397), 1,
      sym_field_assignment,
  [37122] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1918), 1,
      aux_sym_type_name_token1,
    ACTIONS(2212), 1,
      sym_keyword_on,
    STATE(1335), 1,
      sym_identifier,
  [37135] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1269), 1,
      sym_field_assignment,
    STATE(1315), 1,
      sym_identifier,
  [37148] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2214), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [37161] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(820), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [37174] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1257), 1,
      sym_field_assignment,
    STATE(1315), 1,
      sym_identifier,
  [37187] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1264), 1,
      sym_field_assignment,
    STATE(1315), 1,
      sym_identifier,
  [37200] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1048), 1,
      sym_fields_columns_clause,
    ACTIONS(2216), 2,
      sym_keyword_fields,
      sym_keyword_columns,
  [37211] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(1112), 1,
      sym_duration,
  [37224] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2085), 1,
      anon_sym_COMMA,
    ACTIONS(2218), 1,
      anon_sym_RPAREN,
    STATE(1511), 1,
      aux_sym_graph_path_repeat1,
  [37237] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2220), 1,
      anon_sym_RBRACK,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [37250] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(822), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [37263] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_duration_part,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(1225), 1,
      sym_duration,
  [37276] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1073), 1,
      sym_field_assignment,
    STATE(1292), 1,
      sym_identifier,
  [37289] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2107), 1,
      anon_sym_COMMA,
    ACTIONS(2222), 1,
      sym_keyword_from,
    STATE(1541), 1,
      aux_sym_select_statement_repeat1,
  [37302] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2224), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [37315] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2226), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [37328] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2085), 1,
      anon_sym_COMMA,
    ACTIONS(2228), 1,
      anon_sym_RPAREN,
    STATE(1438), 1,
      aux_sym_graph_path_repeat1,
  [37341] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(774), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [37354] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2111), 1,
      anon_sym_COMMA,
    ACTIONS(2230), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(1489), 1,
      aux_sym_insert_statement_repeat2,
  [37367] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2111), 1,
      anon_sym_COMMA,
    ACTIONS(2230), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(1566), 1,
      aux_sym_insert_statement_repeat2,
  [37380] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2005), 1,
      aux_sym_type_name_token1,
    ACTIONS(2232), 1,
      sym_keyword_by,
    STATE(955), 1,
      sym_identifier,
  [37393] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      anon_sym_COMMA,
    ACTIONS(2234), 1,
      anon_sym_RPAREN,
    STATE(793), 1,
      aux_sym_define_user_statement_repeat1,
  [37406] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1285), 1,
      sym_field_assignment,
    STATE(1292), 1,
      sym_identifier,
  [37419] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2107), 1,
      anon_sym_COMMA,
    ACTIONS(2236), 1,
      sym_keyword_from,
    STATE(1508), 1,
      aux_sym_select_statement_repeat1,
  [37432] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1171), 1,
      sym_field_assignment,
    STATE(1416), 1,
      sym_identifier,
  [37445] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2005), 1,
      aux_sym_type_name_token1,
    ACTIONS(2238), 1,
      sym_keyword_at,
    STATE(940), 1,
      sym_identifier,
  [37458] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1188), 1,
      sym_field_assignment,
    STATE(1416), 1,
      sym_identifier,
  [37471] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2240), 1,
      anon_sym_COMMA,
    ACTIONS(2243), 1,
      anon_sym_RBRACK,
    STATE(1522), 1,
      aux_sym_insert_statement_repeat1,
  [37484] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1324), 1,
      anon_sym_LT,
    ACTIONS(2245), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [37495] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2113), 1,
      anon_sym_RBRACE,
    ACTIONS(2247), 1,
      sym_semi_colon,
    STATE(1527), 1,
      aux_sym_expressions_repeat1,
  [37508] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2107), 1,
      anon_sym_COMMA,
    ACTIONS(2249), 1,
      sym_keyword_from,
    STATE(1536), 1,
      aux_sym_select_statement_repeat1,
  [37521] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2251), 1,
      anon_sym_COMMA,
    ACTIONS(2254), 1,
      anon_sym_RBRACE,
    STATE(1526), 1,
      aux_sym_object_content_repeat1,
  [37534] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(540), 1,
      anon_sym_RBRACE,
    ACTIONS(2256), 1,
      sym_semi_colon,
    STATE(1555), 1,
      aux_sym_expressions_repeat1,
  [37547] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2258), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [37560] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(760), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [37573] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2111), 1,
      anon_sym_COMMA,
    ACTIONS(2260), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(1514), 1,
      aux_sym_insert_statement_repeat2,
  [37586] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1073), 1,
      sym_field_assignment,
    STATE(1343), 1,
      sym_identifier,
  [37599] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1074), 1,
      sym_fields_columns_clause,
    ACTIONS(2216), 2,
      sym_keyword_fields,
      sym_keyword_columns,
  [37610] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1918), 1,
      aux_sym_type_name_token1,
    ACTIONS(2262), 1,
      sym_keyword_table,
    STATE(811), 1,
      sym_identifier,
  [37623] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2264), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [37636] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2085), 1,
      anon_sym_COMMA,
    ACTIONS(2266), 1,
      anon_sym_RPAREN,
    STATE(1438), 1,
      aux_sym_graph_path_repeat1,
  [37649] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2107), 1,
      anon_sym_COMMA,
    ACTIONS(2268), 1,
      sym_keyword_from,
    STATE(1541), 1,
      aux_sym_select_statement_repeat1,
  [37662] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2111), 1,
      anon_sym_COMMA,
    ACTIONS(2270), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(1566), 1,
      aux_sym_insert_statement_repeat2,
  [37675] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2111), 1,
      anon_sym_COMMA,
    ACTIONS(2272), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(1537), 1,
      aux_sym_insert_statement_repeat2,
  [37688] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2274), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [37701] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2276), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [37714] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2278), 1,
      sym_keyword_from,
    ACTIONS(2280), 1,
      anon_sym_COMMA,
    STATE(1541), 1,
      aux_sym_select_statement_repeat1,
  [37727] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2111), 1,
      anon_sym_COMMA,
    ACTIONS(2272), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(1566), 1,
      aux_sym_insert_statement_repeat2,
  [37740] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2111), 1,
      anon_sym_COMMA,
    ACTIONS(2283), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(1542), 1,
      aux_sym_insert_statement_repeat2,
  [37753] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2285), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [37766] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2136), 1,
      anon_sym_COMMA,
    ACTIONS(2287), 1,
      anon_sym_RBRACK,
    STATE(1522), 1,
      aux_sym_insert_statement_repeat1,
  [37779] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2111), 1,
      anon_sym_COMMA,
    ACTIONS(2283), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(1566), 1,
      aux_sym_insert_statement_repeat2,
  [37792] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2111), 1,
      anon_sym_COMMA,
    ACTIONS(2289), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(1546), 1,
      aux_sym_insert_statement_repeat2,
  [37805] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2111), 1,
      anon_sym_COMMA,
    ACTIONS(2289), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(1566), 1,
      aux_sym_insert_statement_repeat2,
  [37818] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2291), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [37831] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2111), 1,
      anon_sym_COMMA,
    ACTIONS(2293), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(1548), 1,
      aux_sym_insert_statement_repeat2,
  [37844] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2170), 1,
      anon_sym_COMMA,
    ACTIONS(2295), 1,
      anon_sym_RBRACE,
    STATE(1526), 1,
      aux_sym_object_content_repeat1,
  [37857] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2297), 1,
      anon_sym_COMMA,
    ACTIONS(2300), 1,
      anon_sym_RPAREN,
    STATE(1552), 1,
      aux_sym_param_list_repeat1,
  [37870] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2302), 1,
      anon_sym_RBRACK,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [37883] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2005), 1,
      aux_sym_type_name_token1,
    ACTIONS(2304), 1,
      sym_keyword_table,
    STATE(811), 1,
      sym_identifier,
  [37896] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2306), 1,
      sym_semi_colon,
    ACTIONS(2309), 1,
      anon_sym_RBRACE,
    STATE(1555), 1,
      aux_sym_expressions_repeat1,
  [37909] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2309), 1,
      ts_builtin_sym_end,
    ACTIONS(2311), 1,
      sym_semi_colon,
    STATE(1556), 1,
      aux_sym_expressions_repeat1,
  [37922] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2314), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [37935] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2152), 1,
      sym_keyword_if,
    ACTIONS(2316), 1,
      sym_variable_name,
    STATE(1830), 1,
      sym_if_not_exists_clause,
  [37948] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2085), 1,
      anon_sym_COMMA,
    ACTIONS(2318), 1,
      anon_sym_RPAREN,
    STATE(1561), 1,
      aux_sym_graph_path_repeat1,
  [37961] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1138), 1,
      sym_field_assignment,
    STATE(1343), 1,
      sym_identifier,
  [37974] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2085), 1,
      anon_sym_COMMA,
    ACTIONS(2320), 1,
      anon_sym_RPAREN,
    STATE(1438), 1,
      aux_sym_graph_path_repeat1,
  [37987] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1141), 1,
      sym_field_assignment,
    STATE(1343), 1,
      sym_identifier,
  [38000] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1918), 1,
      aux_sym_type_name_token1,
    ACTIONS(2322), 1,
      sym_keyword_by,
    STATE(904), 1,
      sym_identifier,
  [38013] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(750), 1,
      anon_sym_COMMA,
    ACTIONS(2324), 1,
      anon_sym_RPAREN,
    STATE(1330), 1,
      aux_sym_update_statement_repeat1,
  [38026] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2085), 1,
      anon_sym_COMMA,
    ACTIONS(2326), 1,
      anon_sym_RPAREN,
    STATE(1535), 1,
      aux_sym_graph_path_repeat1,
  [38039] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2328), 1,
      sym_keyword_on_duplicate_key_update,
    ACTIONS(2330), 1,
      anon_sym_COMMA,
    STATE(1566), 1,
      aux_sym_insert_statement_repeat2,
  [38052] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2309), 3,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RBRACE,
  [38061] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2333), 1,
      sym_keyword_on,
    STATE(1532), 1,
      sym_on_table_clause,
  [38071] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    STATE(1107), 1,
      sym_object,
  [38081] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2335), 1,
      anon_sym_COMMA,
    ACTIONS(2337), 1,
      anon_sym_PIPE_GT,
  [38091] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2339), 1,
      sym_keyword_into,
    ACTIONS(2341), 1,
      sym_keyword_ignore,
  [38101] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1295), 1,
      sym_identifier,
  [38111] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1414), 1,
      sym_identifier,
  [38121] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1420), 1,
      sym_identifier,
  [38131] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1425), 1,
      sym_identifier,
  [38141] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2049), 1,
      aux_sym_type_name_token1,
    STATE(762), 1,
      sym_identifier,
  [38151] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2343), 1,
      anon_sym_LPAREN,
    STATE(311), 1,
      sym_argument_list,
  [38161] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(887), 1,
      sym_identifier,
  [38171] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(884), 1,
      sym_identifier,
  [38181] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1235), 1,
      sym_identifier,
  [38191] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1243), 1,
      sym_identifier,
  [38201] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(748), 1,
      anon_sym_LBRACE,
    STATE(1178), 1,
      sym_block,
  [38211] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(815), 1,
      sym_identifier,
  [38221] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2345), 1,
      anon_sym_LPAREN,
    STATE(458), 1,
      sym_argument_list_count,
  [38231] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2049), 1,
      aux_sym_type_name_token1,
    STATE(977), 1,
      sym_identifier,
  [38241] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2347), 1,
      aux_sym_type_name_token1,
    STATE(838), 1,
      sym_identifier,
  [38251] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2349), 1,
      anon_sym_LPAREN,
    STATE(20), 1,
      sym_argument_list,
  [38261] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2049), 1,
      aux_sym_type_name_token1,
    STATE(810), 1,
      sym_identifier,
  [38271] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2049), 1,
      aux_sym_type_name_token1,
    STATE(926), 1,
      sym_identifier,
  [38281] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(871), 1,
      sym_identifier,
  [38291] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(854), 1,
      anon_sym_RBRACK,
    ACTIONS(2351), 1,
      anon_sym_QMARK,
  [38301] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2353), 1,
      sym_keyword_into,
    ACTIONS(2355), 1,
      sym_keyword_ignore,
  [38311] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2357), 1,
      sym_keyword_type,
    STATE(1704), 1,
      sym_token_type_clause,
  [38321] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2359), 1,
      anon_sym_LPAREN,
    STATE(84), 1,
      sym_argument_list_count,
  [38331] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2361), 2,
      sym_keyword_password,
      sym_keyword_password_hash,
  [38339] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1311), 1,
      sym_identifier,
  [38349] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2063), 1,
      anon_sym_LPAREN,
    STATE(459), 1,
      sym_argument_list,
  [38359] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2363), 1,
      sym_keyword_on,
    STATE(790), 1,
      sym_on_table_clause,
  [38369] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2365), 2,
      sym_keyword_from,
      anon_sym_COMMA,
  [38377] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    STATE(77), 1,
      sym_argument_list,
  [38387] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2363), 1,
      sym_keyword_on,
    STATE(789), 1,
      sym_on_table_clause,
  [38397] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1656), 1,
      sym_identifier,
  [38407] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2367), 2,
      sym_keyword_on_duplicate_key_update,
      anon_sym_COMMA,
  [38415] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2369), 1,
      sym_keyword_index,
    ACTIONS(2371), 1,
      sym_keyword_no_index,
  [38425] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1607), 1,
      sym_identifier,
  [38435] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2041), 1,
      anon_sym_LPAREN,
    STATE(476), 1,
      sym_argument_list,
  [38445] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2373), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [38453] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(748), 1,
      anon_sym_LBRACE,
    STATE(1149), 1,
      sym_block,
  [38463] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1472), 1,
      sym_identifier,
  [38473] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    STATE(1470), 1,
      sym_object,
  [38483] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2375), 1,
      anon_sym_LPAREN,
    STATE(1686), 1,
      sym_param_list,
  [38493] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1336), 1,
      sym_identifier,
  [38503] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1056), 1,
      sym_identifier,
  [38513] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(850), 1,
      anon_sym_RBRACK,
    ACTIONS(2377), 1,
      anon_sym_QMARK,
  [38523] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(840), 1,
      anon_sym_RBRACK,
    ACTIONS(2379), 1,
      anon_sym_QMARK,
  [38533] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2381), 1,
      anon_sym_LPAREN,
    STATE(65), 1,
      sym_argument_list,
  [38543] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2383), 1,
      anon_sym_LPAREN,
    STATE(450), 1,
      sym_argument_list_count,
  [38553] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2385), 2,
      sym_keyword_from,
      anon_sym_COMMA,
  [38561] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2278), 2,
      sym_keyword_from,
      anon_sym_COMMA,
  [38569] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2375), 1,
      anon_sym_LPAREN,
    STATE(1632), 1,
      sym_param_list,
  [38579] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2387), 1,
      sym_keyword_function,
    ACTIONS(2389), 1,
      sym_keyword_param,
  [38589] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(910), 1,
      sym_identifier,
  [38599] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1657), 1,
      sym_identifier,
  [38609] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2120), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [38617] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1238), 1,
      sym_identifier,
  [38627] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2333), 1,
      sym_keyword_on,
    STATE(1501), 1,
      sym_on_table_clause,
  [38637] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2375), 1,
      anon_sym_LPAREN,
    STATE(1667), 1,
      sym_param_list,
  [38647] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2391), 1,
      anon_sym_LPAREN,
    STATE(242), 1,
      sym_argument_list,
  [38657] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1373), 1,
      sym_identifier,
  [38667] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2393), 2,
      aux_sym_type_name_token1,
      sym_variable_name,
  [38675] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(886), 1,
      sym_identifier,
  [38685] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(748), 1,
      anon_sym_LBRACE,
    STATE(1199), 1,
      sym_block,
  [38695] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_LBRACK,
    STATE(1163), 1,
      sym_array,
  [38705] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    STATE(1165), 1,
      sym_object,
  [38715] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2395), 1,
      anon_sym_LPAREN,
    STATE(193), 1,
      sym_argument_list_count,
  [38725] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2397), 1,
      anon_sym_LPAREN,
    STATE(477), 1,
      sym_argument_list_count,
  [38735] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2254), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [38743] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2399), 2,
      sym_keyword_password,
      sym_keyword_password_hash,
  [38751] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2357), 1,
      sym_keyword_type,
    STATE(1836), 1,
      sym_token_type_clause,
  [38761] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1924), 1,
      anon_sym_LPAREN,
    STATE(74), 1,
      sym_argument_list,
  [38771] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1324), 1,
      anon_sym_LT,
    ACTIONS(2401), 1,
      anon_sym_GT,
  [38781] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    STATE(1643), 1,
      sym_object,
  [38791] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [38799] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1316), 1,
      sym_identifier,
  [38809] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2403), 2,
      sym_keyword_on_duplicate_key_update,
      anon_sym_COMMA,
  [38817] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2405), 1,
      anon_sym_LPAREN,
    STATE(88), 1,
      sym_argument_list_count,
  [38827] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(748), 1,
      anon_sym_LBRACE,
    STATE(1184), 1,
      sym_block,
  [38837] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(762), 1,
      sym_identifier,
  [38847] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2043), 1,
      anon_sym_LPAREN,
    STATE(194), 1,
      sym_argument_list,
  [38857] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2407), 1,
      anon_sym_RPAREN,
    ACTIONS(2409), 1,
      sym_variable_name,
  [38867] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1618), 1,
      sym_identifier,
  [38877] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(838), 1,
      anon_sym_RBRACK,
    ACTIONS(2411), 1,
      anon_sym_QMARK,
  [38887] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1626), 1,
      sym_identifier,
  [38897] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(836), 1,
      anon_sym_RBRACK,
    ACTIONS(2413), 1,
      anon_sym_QMARK,
  [38907] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2415), 1,
      anon_sym_LPAREN,
    STATE(120), 1,
      sym_argument_list,
  [38917] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2417), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [38925] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2333), 1,
      sym_keyword_on,
    STATE(1191), 1,
      sym_on_table_clause,
  [38935] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1683), 1,
      sym_identifier,
  [38945] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2363), 1,
      sym_keyword_on,
    STATE(801), 1,
      sym_on_table_clause,
  [38955] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(756), 1,
      sym_identifier,
  [38965] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(938), 1,
      sym_identifier,
  [38975] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1745), 1,
      sym_identifier,
  [38985] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(835), 1,
      sym_identifier,
  [38995] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1756), 1,
      sym_identifier,
  [39005] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2347), 1,
      aux_sym_type_name_token1,
    STATE(762), 1,
      sym_identifier,
  [39015] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2375), 1,
      anon_sym_LPAREN,
    STATE(1582), 1,
      sym_param_list,
  [39025] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(748), 1,
      anon_sym_LBRACE,
    STATE(1177), 1,
      sym_block,
  [39035] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2375), 1,
      anon_sym_LPAREN,
    STATE(1647), 1,
      sym_param_list,
  [39045] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2023), 1,
      anon_sym_LPAREN,
    STATE(425), 1,
      sym_argument_list,
  [39055] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2419), 1,
      aux_sym_type_name_token1,
    STATE(1457), 1,
      sym_identifier,
  [39065] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1335), 1,
      sym_identifier,
  [39075] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1162), 1,
      sym_identifier,
  [39085] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1765), 1,
      sym_identifier,
  [39095] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(810), 1,
      sym_identifier,
  [39105] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1813), 1,
      sym_identifier,
  [39115] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1828), 1,
      sym_identifier,
  [39125] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(842), 1,
      anon_sym_RBRACK,
    ACTIONS(2421), 1,
      anon_sym_QMARK,
  [39135] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2423), 2,
      aux_sym_type_name_token1,
      sym_variable_name,
  [39143] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_LPAREN,
    STATE(260), 1,
      sym_argument_list,
  [39153] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2375), 1,
      anon_sym_LPAREN,
    STATE(1608), 1,
      sym_param_list,
  [39163] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 2,
      sym_keyword_on,
      aux_sym_type_name_token1,
  [39171] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2371), 1,
      sym_keyword_no_index,
    ACTIONS(2427), 1,
      sym_keyword_index,
  [39181] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2363), 1,
      sym_keyword_on,
    STATE(809), 1,
      sym_on_table_clause,
  [39191] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1445), 1,
      sym_identifier,
  [39201] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_LBRACE,
    STATE(1449), 1,
      sym_object,
  [39211] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(748), 1,
      anon_sym_LBRACE,
    STATE(1142), 1,
      sym_block,
  [39221] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_type_name_token1,
    STATE(1601), 1,
      sym_identifier,
  [39231] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2429), 1,
      anon_sym_COLON,
  [39238] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2431), 1,
      anon_sym_LPAREN,
  [39245] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2433), 1,
      anon_sym_COLON,
  [39252] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2435), 1,
      sym_custom_function_name,
  [39259] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2437), 1,
      sym_string,
  [39266] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2439), 1,
      anon_sym_LPAREN,
  [39273] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2441), 1,
      sym_keyword_select,
  [39280] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
  [39287] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2445), 1,
      sym_keyword_values,
  [39294] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2447), 1,
      anon_sym_DOT_DOT,
  [39301] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2449), 1,
      sym_keyword_roles,
  [39308] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2451), 1,
      sym_string,
  [39315] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2453), 1,
      sym_string,
  [39322] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2455), 1,
      anon_sym_RPAREN,
  [39329] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2457), 1,
      anon_sym_COLON,
  [39336] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2459), 1,
      sym_keyword_value,
  [39343] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2461), 1,
      sym_keyword_value,
  [39350] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2463), 1,
      anon_sym_COLON,
  [39357] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2465), 1,
      sym_keyword_values,
  [39364] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2467), 1,
      anon_sym_COLON,
  [39371] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(798), 1,
      anon_sym_RPAREN,
  [39378] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2469), 1,
      sym_keyword_on,
  [39385] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2471), 1,
      anon_sym_RBRACE,
  [39392] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2473), 1,
      anon_sym_COLON,
  [39399] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2475), 1,
      sym_keyword_on,
  [39406] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2477), 1,
      anon_sym_COLON,
  [39413] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2479), 1,
      sym_int,
  [39420] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2481), 1,
      sym_float,
  [39427] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2483), 1,
      sym_variable_name,
  [39434] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2485), 1,
      anon_sym_COLON,
  [39441] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2487), 1,
      anon_sym_COLON,
  [39448] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2489), 1,
      anon_sym_COLON,
  [39455] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2491), 1,
      anon_sym_COLON,
  [39462] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2493), 1,
      anon_sym_RPAREN,
  [39469] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2495), 1,
      anon_sym_LPAREN,
  [39476] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2497), 1,
      anon_sym_COLON,
  [39483] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2499), 1,
      sym_keyword_exists,
  [39490] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2501), 1,
      sym_variable_name,
  [39497] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2503), 1,
      sym_keyword_value,
  [39504] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2505), 1,
      anon_sym_COLON,
  [39511] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2507), 1,
      sym_custom_function_name,
  [39518] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2509), 1,
      anon_sym_COLON,
  [39525] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2511), 1,
      sym_keyword_on,
  [39532] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2513), 1,
      anon_sym_COLON,
  [39539] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2515), 1,
      sym_keyword_on,
  [39546] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2517), 1,
      anon_sym_COLON,
  [39553] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2519), 1,
      sym_keyword_value,
  [39560] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2521), 1,
      sym_keyword_select,
  [39567] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2523), 1,
      sym_int,
  [39574] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2525), 1,
      sym_keyword_roles,
  [39581] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2527), 1,
      anon_sym_COLON,
  [39588] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2529), 1,
      anon_sym_COLON,
  [39595] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2531), 1,
      anon_sym_LPAREN,
  [39602] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2533), 1,
      anon_sym_RPAREN,
  [39609] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2401), 1,
      anon_sym_GT,
  [39616] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2535), 1,
      anon_sym_COLON,
  [39623] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2537), 1,
      sym_int,
  [39630] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2539), 1,
      anon_sym_RPAREN,
  [39637] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2541), 1,
      sym_keyword_type,
  [39644] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2543), 1,
      anon_sym_COLON,
  [39651] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2545), 1,
      anon_sym_COMMA,
  [39658] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2547), 1,
      anon_sym_COLON,
  [39665] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2549), 1,
      anon_sym_COLON,
  [39672] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2551), 1,
      anon_sym_COLON,
  [39679] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2553), 1,
      anon_sym_COLON,
  [39686] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2555), 1,
      anon_sym_PIPE_GT,
  [39693] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2557), 1,
      anon_sym_COLON,
  [39700] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2559), 1,
      anon_sym_COLON,
  [39707] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2561), 1,
      sym_keyword_on,
  [39714] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2563), 1,
      anon_sym_COLON,
  [39721] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2565), 1,
      anon_sym_COLON,
  [39728] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2567), 1,
      sym_keyword_not,
  [39735] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2569), 1,
      anon_sym_GT,
  [39742] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2571), 1,
      anon_sym_COLON,
  [39749] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2573), 1,
      anon_sym_COLON,
  [39756] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2180), 1,
      sym_keyword_from,
  [39763] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(752), 1,
      anon_sym_RPAREN,
  [39770] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2575), 1,
      sym_keyword_on,
  [39777] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2577), 1,
      anon_sym_LPAREN,
  [39784] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2579), 1,
      anon_sym_RBRACE,
  [39791] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2581), 1,
      anon_sym_RPAREN,
  [39798] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2583), 1,
      sym_int,
  [39805] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2585), 1,
      sym_int,
  [39812] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2587), 1,
      sym_keyword_in,
  [39819] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2589), 1,
      anon_sym_COLON,
  [39826] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2591), 1,
      sym_keyword_values,
  [39833] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2593), 1,
      anon_sym_COLON,
  [39840] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2595), 1,
      anon_sym_RBRACE,
  [39847] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2597), 1,
      anon_sym_COLON,
  [39854] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(120), 1,
      anon_sym_COLON,
  [39861] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2599), 1,
      anon_sym_RPAREN,
  [39868] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2601), 1,
      anon_sym_DASH_GT,
  [39875] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2603), 1,
      anon_sym_COLON,
  [39882] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2605), 1,
      anon_sym_COLON,
  [39889] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2607), 1,
      sym_decimal,
  [39896] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2609), 1,
      sym_keyword_into,
  [39903] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2611), 1,
      anon_sym_COMMA,
  [39910] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2613), 1,
      anon_sym_RPAREN,
  [39917] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2615), 1,
      sym_variable_name,
  [39924] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2617), 1,
      sym_decimal,
  [39931] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2619), 1,
      sym_keyword_value,
  [39938] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2621), 1,
      anon_sym_COLON,
  [39945] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2623), 1,
      anon_sym_LBRACE,
  [39952] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2625), 1,
      anon_sym_COLON,
  [39959] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2627), 1,
      anon_sym_RPAREN,
  [39966] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2629), 1,
      sym_keyword_value,
  [39973] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2631), 1,
      sym_decimal,
  [39980] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2633), 1,
      sym_keyword_table,
  [39987] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2635), 1,
      anon_sym_COLON,
  [39994] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2637), 1,
      anon_sym_RPAREN,
  [40001] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2639), 1,
      anon_sym_RBRACE,
  [40008] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2641), 1,
      anon_sym_RPAREN,
  [40015] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2643), 1,
      sym_keyword_table,
  [40022] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2645), 1,
      sym_custom_function_name,
  [40029] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2647), 1,
      sym_decimal,
  [40036] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2649), 1,
      anon_sym_COLON,
  [40043] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2651), 1,
      sym_keyword_exists,
  [40050] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2268), 1,
      sym_keyword_from,
  [40057] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2653), 1,
      sym_int,
  [40064] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2655), 1,
      anon_sym_LPAREN,
  [40071] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2657), 1,
      anon_sym_DASH_GT,
  [40078] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2659), 1,
      sym_int,
  [40085] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2661), 1,
      sym_int,
  [40092] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2663), 1,
      sym_custom_function_name,
  [40099] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2665), 1,
      anon_sym_DASH_GT,
  [40106] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2667), 1,
      sym_keyword_on,
  [40113] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2669), 1,
      sym_keyword_value,
  [40120] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2671), 1,
      anon_sym_DASH_GT,
  [40127] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2673), 1,
      anon_sym_DASH_GT,
  [40134] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(756), 1,
      anon_sym_RPAREN,
  [40141] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2675), 1,
      anon_sym_DASH_GT,
  [40148] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2677), 1,
      sym_keyword_exists,
  [40155] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(766), 1,
      anon_sym_RPAREN,
  [40162] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(782), 1,
      anon_sym_RPAREN,
  [40169] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2679), 1,
      anon_sym_RBRACE,
  [40176] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2681), 1,
      anon_sym_DASH_GT,
  [40183] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2683), 1,
      sym_version_number,
  [40190] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2685), 1,
      anon_sym_RPAREN,
  [40197] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2687), 1,
      sym_decimal,
  [40204] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2689), 1,
      anon_sym_COLON,
  [40211] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2691), 1,
      sym_keyword_on,
  [40218] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2693), 1,
      anon_sym_PIPE_GT,
  [40225] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2695), 1,
      sym_variable_name,
  [40232] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2697), 1,
      sym_keyword_not,
  [40239] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2699), 1,
      sym_string,
  [40246] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2701), 1,
      ts_builtin_sym_end,
  [40253] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2703), 1,
      ts_builtin_sym_end,
  [40260] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2483), 1,
      sym_custom_function_name,
  [40267] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2705), 1,
      sym_keyword_value,
  [40274] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2707), 1,
      sym_decimal,
  [40281] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2393), 1,
      sym_custom_function_name,
  [40288] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2709), 1,
      anon_sym_COLON,
  [40295] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2711), 1,
      sym_string,
  [40302] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2713), 1,
      anon_sym_RPAREN,
  [40309] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2715), 1,
      anon_sym_RBRACE,
  [40316] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2717), 1,
      sym_float,
  [40323] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2719), 1,
      anon_sym_DASH_GT,
  [40330] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2423), 1,
      sym_custom_function_name,
  [40337] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2721), 1,
      sym_keyword_exists,
  [40344] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(812), 1,
      anon_sym_RPAREN,
  [40351] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2723), 1,
      sym_string,
  [40358] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2725), 1,
      sym_keyword_analyzer,
  [40365] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2727), 1,
      anon_sym_LBRACE,
  [40372] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2729), 1,
      anon_sym_LBRACE,
  [40379] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2731), 1,
      sym_variable_name,
  [40386] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2733), 1,
      anon_sym_RPAREN,
  [40393] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2735), 1,
      anon_sym_COLON,
  [40400] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2737), 1,
      anon_sym_LPAREN,
  [40407] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2739), 1,
      anon_sym_LPAREN,
  [40414] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2741), 1,
      anon_sym_LPAREN,
  [40421] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2743), 1,
      sym_keyword_values,
  [40428] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2745), 1,
      sym_keyword_values,
  [40435] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2747), 1,
      sym_keyword_values,
  [40442] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2749), 1,
      sym_keyword_value,
  [40449] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2751), 1,
      anon_sym_DOT_DOT,
  [40456] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2753), 1,
      anon_sym_RPAREN,
  [40463] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2755), 1,
      anon_sym_DOT_DOT,
  [40470] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2757), 1,
      anon_sym_RPAREN,
  [40477] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2759), 1,
      sym_int,
  [40484] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2761), 1,
      anon_sym_RBRACE,
  [40491] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2763), 1,
      sym_int,
  [40498] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2765), 1,
      sym_int,
  [40505] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2767), 1,
      sym_int,
  [40512] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2337), 1,
      anon_sym_AT,
  [40519] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2769), 1,
      sym_keyword_into,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(516)] = 0,
  [SMALL_STATE(517)] = 75,
  [SMALL_STATE(518)] = 164,
  [SMALL_STATE(519)] = 239,
  [SMALL_STATE(520)] = 332,
  [SMALL_STATE(521)] = 405,
  [SMALL_STATE(522)] = 494,
  [SMALL_STATE(523)] = 569,
  [SMALL_STATE(524)] = 658,
  [SMALL_STATE(525)] = 732,
  [SMALL_STATE(526)] = 806,
  [SMALL_STATE(527)] = 894,
  [SMALL_STATE(528)] = 966,
  [SMALL_STATE(529)] = 1060,
  [SMALL_STATE(530)] = 1132,
  [SMALL_STATE(531)] = 1204,
  [SMALL_STATE(532)] = 1276,
  [SMALL_STATE(533)] = 1348,
  [SMALL_STATE(534)] = 1420,
  [SMALL_STATE(535)] = 1508,
  [SMALL_STATE(536)] = 1596,
  [SMALL_STATE(537)] = 1690,
  [SMALL_STATE(538)] = 1777,
  [SMALL_STATE(539)] = 1864,
  [SMALL_STATE(540)] = 1937,
  [SMALL_STATE(541)] = 2010,
  [SMALL_STATE(542)] = 2097,
  [SMALL_STATE(543)] = 2170,
  [SMALL_STATE(544)] = 2242,
  [SMALL_STATE(545)] = 2332,
  [SMALL_STATE(546)] = 2422,
  [SMALL_STATE(547)] = 2508,
  [SMALL_STATE(548)] = 2598,
  [SMALL_STATE(549)] = 2670,
  [SMALL_STATE(550)] = 2760,
  [SMALL_STATE(551)] = 2850,
  [SMALL_STATE(552)] = 2936,
  [SMALL_STATE(553)] = 3026,
  [SMALL_STATE(554)] = 3116,
  [SMALL_STATE(555)] = 3206,
  [SMALL_STATE(556)] = 3296,
  [SMALL_STATE(557)] = 3386,
  [SMALL_STATE(558)] = 3476,
  [SMALL_STATE(559)] = 3566,
  [SMALL_STATE(560)] = 3656,
  [SMALL_STATE(561)] = 3746,
  [SMALL_STATE(562)] = 3836,
  [SMALL_STATE(563)] = 3908,
  [SMALL_STATE(564)] = 3998,
  [SMALL_STATE(565)] = 4084,
  [SMALL_STATE(566)] = 4170,
  [SMALL_STATE(567)] = 4260,
  [SMALL_STATE(568)] = 4350,
  [SMALL_STATE(569)] = 4438,
  [SMALL_STATE(570)] = 4524,
  [SMALL_STATE(571)] = 4614,
  [SMALL_STATE(572)] = 4704,
  [SMALL_STATE(573)] = 4794,
  [SMALL_STATE(574)] = 4866,
  [SMALL_STATE(575)] = 4956,
  [SMALL_STATE(576)] = 5046,
  [SMALL_STATE(577)] = 5132,
  [SMALL_STATE(578)] = 5222,
  [SMALL_STATE(579)] = 5312,
  [SMALL_STATE(580)] = 5402,
  [SMALL_STATE(581)] = 5492,
  [SMALL_STATE(582)] = 5582,
  [SMALL_STATE(583)] = 5672,
  [SMALL_STATE(584)] = 5762,
  [SMALL_STATE(585)] = 5852,
  [SMALL_STATE(586)] = 5937,
  [SMALL_STATE(587)] = 6024,
  [SMALL_STATE(588)] = 6109,
  [SMALL_STATE(589)] = 6194,
  [SMALL_STATE(590)] = 6279,
  [SMALL_STATE(591)] = 6350,
  [SMALL_STATE(592)] = 6435,
  [SMALL_STATE(593)] = 6520,
  [SMALL_STATE(594)] = 6604,
  [SMALL_STATE(595)] = 6688,
  [SMALL_STATE(596)] = 6772,
  [SMALL_STATE(597)] = 6856,
  [SMALL_STATE(598)] = 6940,
  [SMALL_STATE(599)] = 7024,
  [SMALL_STATE(600)] = 7108,
  [SMALL_STATE(601)] = 7192,
  [SMALL_STATE(602)] = 7276,
  [SMALL_STATE(603)] = 7360,
  [SMALL_STATE(604)] = 7444,
  [SMALL_STATE(605)] = 7528,
  [SMALL_STATE(606)] = 7612,
  [SMALL_STATE(607)] = 7706,
  [SMALL_STATE(608)] = 7800,
  [SMALL_STATE(609)] = 7891,
  [SMALL_STATE(610)] = 7982,
  [SMALL_STATE(611)] = 8069,
  [SMALL_STATE(612)] = 8156,
  [SMALL_STATE(613)] = 8247,
  [SMALL_STATE(614)] = 8335,
  [SMALL_STATE(615)] = 8423,
  [SMALL_STATE(616)] = 8511,
  [SMALL_STATE(617)] = 8599,
  [SMALL_STATE(618)] = 8687,
  [SMALL_STATE(619)] = 8775,
  [SMALL_STATE(620)] = 8863,
  [SMALL_STATE(621)] = 8951,
  [SMALL_STATE(622)] = 9039,
  [SMALL_STATE(623)] = 9127,
  [SMALL_STATE(624)] = 9215,
  [SMALL_STATE(625)] = 9303,
  [SMALL_STATE(626)] = 9391,
  [SMALL_STATE(627)] = 9479,
  [SMALL_STATE(628)] = 9567,
  [SMALL_STATE(629)] = 9652,
  [SMALL_STATE(630)] = 9737,
  [SMALL_STATE(631)] = 9822,
  [SMALL_STATE(632)] = 9907,
  [SMALL_STATE(633)] = 9992,
  [SMALL_STATE(634)] = 10077,
  [SMALL_STATE(635)] = 10162,
  [SMALL_STATE(636)] = 10247,
  [SMALL_STATE(637)] = 10332,
  [SMALL_STATE(638)] = 10417,
  [SMALL_STATE(639)] = 10502,
  [SMALL_STATE(640)] = 10587,
  [SMALL_STATE(641)] = 10672,
  [SMALL_STATE(642)] = 10757,
  [SMALL_STATE(643)] = 10842,
  [SMALL_STATE(644)] = 10927,
  [SMALL_STATE(645)] = 11012,
  [SMALL_STATE(646)] = 11097,
  [SMALL_STATE(647)] = 11182,
  [SMALL_STATE(648)] = 11267,
  [SMALL_STATE(649)] = 11352,
  [SMALL_STATE(650)] = 11437,
  [SMALL_STATE(651)] = 11522,
  [SMALL_STATE(652)] = 11607,
  [SMALL_STATE(653)] = 11689,
  [SMALL_STATE(654)] = 11771,
  [SMALL_STATE(655)] = 11853,
  [SMALL_STATE(656)] = 11935,
  [SMALL_STATE(657)] = 12017,
  [SMALL_STATE(658)] = 12099,
  [SMALL_STATE(659)] = 12181,
  [SMALL_STATE(660)] = 12263,
  [SMALL_STATE(661)] = 12345,
  [SMALL_STATE(662)] = 12427,
  [SMALL_STATE(663)] = 12509,
  [SMALL_STATE(664)] = 12591,
  [SMALL_STATE(665)] = 12673,
  [SMALL_STATE(666)] = 12755,
  [SMALL_STATE(667)] = 12837,
  [SMALL_STATE(668)] = 12919,
  [SMALL_STATE(669)] = 13001,
  [SMALL_STATE(670)] = 13083,
  [SMALL_STATE(671)] = 13165,
  [SMALL_STATE(672)] = 13247,
  [SMALL_STATE(673)] = 13329,
  [SMALL_STATE(674)] = 13411,
  [SMALL_STATE(675)] = 13493,
  [SMALL_STATE(676)] = 13575,
  [SMALL_STATE(677)] = 13657,
  [SMALL_STATE(678)] = 13739,
  [SMALL_STATE(679)] = 13821,
  [SMALL_STATE(680)] = 13903,
  [SMALL_STATE(681)] = 13985,
  [SMALL_STATE(682)] = 14067,
  [SMALL_STATE(683)] = 14149,
  [SMALL_STATE(684)] = 14231,
  [SMALL_STATE(685)] = 14313,
  [SMALL_STATE(686)] = 14395,
  [SMALL_STATE(687)] = 14477,
  [SMALL_STATE(688)] = 14559,
  [SMALL_STATE(689)] = 14641,
  [SMALL_STATE(690)] = 14723,
  [SMALL_STATE(691)] = 14805,
  [SMALL_STATE(692)] = 14887,
  [SMALL_STATE(693)] = 14969,
  [SMALL_STATE(694)] = 15051,
  [SMALL_STATE(695)] = 15133,
  [SMALL_STATE(696)] = 15215,
  [SMALL_STATE(697)] = 15297,
  [SMALL_STATE(698)] = 15379,
  [SMALL_STATE(699)] = 15461,
  [SMALL_STATE(700)] = 15543,
  [SMALL_STATE(701)] = 15625,
  [SMALL_STATE(702)] = 15707,
  [SMALL_STATE(703)] = 15789,
  [SMALL_STATE(704)] = 15871,
  [SMALL_STATE(705)] = 15953,
  [SMALL_STATE(706)] = 16035,
  [SMALL_STATE(707)] = 16117,
  [SMALL_STATE(708)] = 16199,
  [SMALL_STATE(709)] = 16281,
  [SMALL_STATE(710)] = 16363,
  [SMALL_STATE(711)] = 16445,
  [SMALL_STATE(712)] = 16527,
  [SMALL_STATE(713)] = 16609,
  [SMALL_STATE(714)] = 16691,
  [SMALL_STATE(715)] = 16773,
  [SMALL_STATE(716)] = 16855,
  [SMALL_STATE(717)] = 16937,
  [SMALL_STATE(718)] = 17019,
  [SMALL_STATE(719)] = 17101,
  [SMALL_STATE(720)] = 17183,
  [SMALL_STATE(721)] = 17265,
  [SMALL_STATE(722)] = 17347,
  [SMALL_STATE(723)] = 17429,
  [SMALL_STATE(724)] = 17511,
  [SMALL_STATE(725)] = 17593,
  [SMALL_STATE(726)] = 17675,
  [SMALL_STATE(727)] = 17757,
  [SMALL_STATE(728)] = 17839,
  [SMALL_STATE(729)] = 17921,
  [SMALL_STATE(730)] = 18003,
  [SMALL_STATE(731)] = 18085,
  [SMALL_STATE(732)] = 18167,
  [SMALL_STATE(733)] = 18249,
  [SMALL_STATE(734)] = 18331,
  [SMALL_STATE(735)] = 18413,
  [SMALL_STATE(736)] = 18495,
  [SMALL_STATE(737)] = 18577,
  [SMALL_STATE(738)] = 18659,
  [SMALL_STATE(739)] = 18741,
  [SMALL_STATE(740)] = 18823,
  [SMALL_STATE(741)] = 18905,
  [SMALL_STATE(742)] = 18987,
  [SMALL_STATE(743)] = 19069,
  [SMALL_STATE(744)] = 19151,
  [SMALL_STATE(745)] = 19233,
  [SMALL_STATE(746)] = 19315,
  [SMALL_STATE(747)] = 19397,
  [SMALL_STATE(748)] = 19479,
  [SMALL_STATE(749)] = 19561,
  [SMALL_STATE(750)] = 19643,
  [SMALL_STATE(751)] = 19725,
  [SMALL_STATE(752)] = 19807,
  [SMALL_STATE(753)] = 19889,
  [SMALL_STATE(754)] = 19971,
  [SMALL_STATE(755)] = 20053,
  [SMALL_STATE(756)] = 20135,
  [SMALL_STATE(757)] = 20189,
  [SMALL_STATE(758)] = 20243,
  [SMALL_STATE(759)] = 20297,
  [SMALL_STATE(760)] = 20372,
  [SMALL_STATE(761)] = 20447,
  [SMALL_STATE(762)] = 20522,
  [SMALL_STATE(763)] = 20552,
  [SMALL_STATE(764)] = 20626,
  [SMALL_STATE(765)] = 20700,
  [SMALL_STATE(766)] = 20774,
  [SMALL_STATE(767)] = 20807,
  [SMALL_STATE(768)] = 20868,
  [SMALL_STATE(769)] = 20929,
  [SMALL_STATE(770)] = 20959,
  [SMALL_STATE(771)] = 20989,
  [SMALL_STATE(772)] = 21019,
  [SMALL_STATE(773)] = 21079,
  [SMALL_STATE(774)] = 21109,
  [SMALL_STATE(775)] = 21139,
  [SMALL_STATE(776)] = 21169,
  [SMALL_STATE(777)] = 21229,
  [SMALL_STATE(778)] = 21259,
  [SMALL_STATE(779)] = 21322,
  [SMALL_STATE(780)] = 21385,
  [SMALL_STATE(781)] = 21448,
  [SMALL_STATE(782)] = 21511,
  [SMALL_STATE(783)] = 21573,
  [SMALL_STATE(784)] = 21635,
  [SMALL_STATE(785)] = 21661,
  [SMALL_STATE(786)] = 21723,
  [SMALL_STATE(787)] = 21785,
  [SMALL_STATE(788)] = 21828,
  [SMALL_STATE(789)] = 21885,
  [SMALL_STATE(790)] = 21928,
  [SMALL_STATE(791)] = 21971,
  [SMALL_STATE(792)] = 22014,
  [SMALL_STATE(793)] = 22071,
  [SMALL_STATE(794)] = 22100,
  [SMALL_STATE(795)] = 22157,
  [SMALL_STATE(796)] = 22200,
  [SMALL_STATE(797)] = 22257,
  [SMALL_STATE(798)] = 22314,
  [SMALL_STATE(799)] = 22370,
  [SMALL_STATE(800)] = 22426,
  [SMALL_STATE(801)] = 22464,
  [SMALL_STATE(802)] = 22506,
  [SMALL_STATE(803)] = 22544,
  [SMALL_STATE(804)] = 22586,
  [SMALL_STATE(805)] = 22642,
  [SMALL_STATE(806)] = 22698,
  [SMALL_STATE(807)] = 22754,
  [SMALL_STATE(808)] = 22792,
  [SMALL_STATE(809)] = 22834,
  [SMALL_STATE(810)] = 22876,
  [SMALL_STATE(811)] = 22900,
  [SMALL_STATE(812)] = 22924,
  [SMALL_STATE(813)] = 22966,
  [SMALL_STATE(814)] = 23017,
  [SMALL_STATE(815)] = 23054,
  [SMALL_STATE(816)] = 23091,
  [SMALL_STATE(817)] = 23128,
  [SMALL_STATE(818)] = 23179,
  [SMALL_STATE(819)] = 23230,
  [SMALL_STATE(820)] = 23267,
  [SMALL_STATE(821)] = 23318,
  [SMALL_STATE(822)] = 23355,
  [SMALL_STATE(823)] = 23380,
  [SMALL_STATE(824)] = 23417,
  [SMALL_STATE(825)] = 23468,
  [SMALL_STATE(826)] = 23505,
  [SMALL_STATE(827)] = 23540,
  [SMALL_STATE(828)] = 23575,
  [SMALL_STATE(829)] = 23612,
  [SMALL_STATE(830)] = 23663,
  [SMALL_STATE(831)] = 23689,
  [SMALL_STATE(832)] = 23739,
  [SMALL_STATE(833)] = 23767,
  [SMALL_STATE(834)] = 23789,
  [SMALL_STATE(835)] = 23825,
  [SMALL_STATE(836)] = 23861,
  [SMALL_STATE(837)] = 23883,
  [SMALL_STATE(838)] = 23933,
  [SMALL_STATE(839)] = 23961,
  [SMALL_STATE(840)] = 24011,
  [SMALL_STATE(841)] = 24037,
  [SMALL_STATE(842)] = 24073,
  [SMALL_STATE(843)] = 24123,
  [SMALL_STATE(844)] = 24157,
  [SMALL_STATE(845)] = 24193,
  [SMALL_STATE(846)] = 24215,
  [SMALL_STATE(847)] = 24237,
  [SMALL_STATE(848)] = 24259,
  [SMALL_STATE(849)] = 24281,
  [SMALL_STATE(850)] = 24303,
  [SMALL_STATE(851)] = 24353,
  [SMALL_STATE(852)] = 24375,
  [SMALL_STATE(853)] = 24409,
  [SMALL_STATE(854)] = 24445,
  [SMALL_STATE(855)] = 24495,
  [SMALL_STATE(856)] = 24517,
  [SMALL_STATE(857)] = 24562,
  [SMALL_STATE(858)] = 24583,
  [SMALL_STATE(859)] = 24628,
  [SMALL_STATE(860)] = 24653,
  [SMALL_STATE(861)] = 24674,
  [SMALL_STATE(862)] = 24699,
  [SMALL_STATE(863)] = 24744,
  [SMALL_STATE(864)] = 24785,
  [SMALL_STATE(865)] = 24830,
  [SMALL_STATE(866)] = 24851,
  [SMALL_STATE(867)] = 24892,
  [SMALL_STATE(868)] = 24937,
  [SMALL_STATE(869)] = 24982,
  [SMALL_STATE(870)] = 25003,
  [SMALL_STATE(871)] = 25048,
  [SMALL_STATE(872)] = 25072,
  [SMALL_STATE(873)] = 25112,
  [SMALL_STATE(874)] = 25136,
  [SMALL_STATE(875)] = 25176,
  [SMALL_STATE(876)] = 25212,
  [SMALL_STATE(877)] = 25252,
  [SMALL_STATE(878)] = 25276,
  [SMALL_STATE(879)] = 25300,
  [SMALL_STATE(880)] = 25340,
  [SMALL_STATE(881)] = 25384,
  [SMALL_STATE(882)] = 25408,
  [SMALL_STATE(883)] = 25444,
  [SMALL_STATE(884)] = 25468,
  [SMALL_STATE(885)] = 25492,
  [SMALL_STATE(886)] = 25516,
  [SMALL_STATE(887)] = 25540,
  [SMALL_STATE(888)] = 25564,
  [SMALL_STATE(889)] = 25588,
  [SMALL_STATE(890)] = 25612,
  [SMALL_STATE(891)] = 25656,
  [SMALL_STATE(892)] = 25700,
  [SMALL_STATE(893)] = 25740,
  [SMALL_STATE(894)] = 25784,
  [SMALL_STATE(895)] = 25824,
  [SMALL_STATE(896)] = 25848,
  [SMALL_STATE(897)] = 25872,
  [SMALL_STATE(898)] = 25912,
  [SMALL_STATE(899)] = 25936,
  [SMALL_STATE(900)] = 25960,
  [SMALL_STATE(901)] = 26000,
  [SMALL_STATE(902)] = 26044,
  [SMALL_STATE(903)] = 26084,
  [SMALL_STATE(904)] = 26128,
  [SMALL_STATE(905)] = 26152,
  [SMALL_STATE(906)] = 26176,
  [SMALL_STATE(907)] = 26220,
  [SMALL_STATE(908)] = 26260,
  [SMALL_STATE(909)] = 26289,
  [SMALL_STATE(910)] = 26322,
  [SMALL_STATE(911)] = 26351,
  [SMALL_STATE(912)] = 26374,
  [SMALL_STATE(913)] = 26407,
  [SMALL_STATE(914)] = 26426,
  [SMALL_STATE(915)] = 26447,
  [SMALL_STATE(916)] = 26476,
  [SMALL_STATE(917)] = 26499,
  [SMALL_STATE(918)] = 26522,
  [SMALL_STATE(919)] = 26555,
  [SMALL_STATE(920)] = 26578,
  [SMALL_STATE(921)] = 26601,
  [SMALL_STATE(922)] = 26624,
  [SMALL_STATE(923)] = 26653,
  [SMALL_STATE(924)] = 26676,
  [SMALL_STATE(925)] = 26695,
  [SMALL_STATE(926)] = 26714,
  [SMALL_STATE(927)] = 26737,
  [SMALL_STATE(928)] = 26766,
  [SMALL_STATE(929)] = 26805,
  [SMALL_STATE(930)] = 26838,
  [SMALL_STATE(931)] = 26871,
  [SMALL_STATE(932)] = 26904,
  [SMALL_STATE(933)] = 26937,
  [SMALL_STATE(934)] = 26956,
  [SMALL_STATE(935)] = 26979,
  [SMALL_STATE(936)] = 27012,
  [SMALL_STATE(937)] = 27049,
  [SMALL_STATE(938)] = 27072,
  [SMALL_STATE(939)] = 27101,
  [SMALL_STATE(940)] = 27120,
  [SMALL_STATE(941)] = 27143,
  [SMALL_STATE(942)] = 27176,
  [SMALL_STATE(943)] = 27213,
  [SMALL_STATE(944)] = 27236,
  [SMALL_STATE(945)] = 27257,
  [SMALL_STATE(946)] = 27286,
  [SMALL_STATE(947)] = 27319,
  [SMALL_STATE(948)] = 27358,
  [SMALL_STATE(949)] = 27387,
  [SMALL_STATE(950)] = 27405,
  [SMALL_STATE(951)] = 27445,
  [SMALL_STATE(952)] = 27463,
  [SMALL_STATE(953)] = 27497,
  [SMALL_STATE(954)] = 27531,
  [SMALL_STATE(955)] = 27571,
  [SMALL_STATE(956)] = 27593,
  [SMALL_STATE(957)] = 27627,
  [SMALL_STATE(958)] = 27645,
  [SMALL_STATE(959)] = 27667,
  [SMALL_STATE(960)] = 27689,
  [SMALL_STATE(961)] = 27725,
  [SMALL_STATE(962)] = 27759,
  [SMALL_STATE(963)] = 27787,
  [SMALL_STATE(964)] = 27819,
  [SMALL_STATE(965)] = 27857,
  [SMALL_STATE(966)] = 27889,
  [SMALL_STATE(967)] = 27911,
  [SMALL_STATE(968)] = 27949,
  [SMALL_STATE(969)] = 27967,
  [SMALL_STATE(970)] = 28003,
  [SMALL_STATE(971)] = 28021,
  [SMALL_STATE(972)] = 28039,
  [SMALL_STATE(973)] = 28057,
  [SMALL_STATE(974)] = 28075,
  [SMALL_STATE(975)] = 28109,
  [SMALL_STATE(976)] = 28129,
  [SMALL_STATE(977)] = 28151,
  [SMALL_STATE(978)] = 28173,
  [SMALL_STATE(979)] = 28195,
  [SMALL_STATE(980)] = 28213,
  [SMALL_STATE(981)] = 28231,
  [SMALL_STATE(982)] = 28265,
  [SMALL_STATE(983)] = 28283,
  [SMALL_STATE(984)] = 28305,
  [SMALL_STATE(985)] = 28339,
  [SMALL_STATE(986)] = 28373,
  [SMALL_STATE(987)] = 28395,
  [SMALL_STATE(988)] = 28413,
  [SMALL_STATE(989)] = 28447,
  [SMALL_STATE(990)] = 28468,
  [SMALL_STATE(991)] = 28501,
  [SMALL_STATE(992)] = 28530,
  [SMALL_STATE(993)] = 28563,
  [SMALL_STATE(994)] = 28592,
  [SMALL_STATE(995)] = 28609,
  [SMALL_STATE(996)] = 28642,
  [SMALL_STATE(997)] = 28658,
  [SMALL_STATE(998)] = 28686,
  [SMALL_STATE(999)] = 28714,
  [SMALL_STATE(1000)] = 28742,
  [SMALL_STATE(1001)] = 28762,
  [SMALL_STATE(1002)] = 28790,
  [SMALL_STATE(1003)] = 28822,
  [SMALL_STATE(1004)] = 28850,
  [SMALL_STATE(1005)] = 28882,
  [SMALL_STATE(1006)] = 28910,
  [SMALL_STATE(1007)] = 28930,
  [SMALL_STATE(1008)] = 28958,
  [SMALL_STATE(1009)] = 28974,
  [SMALL_STATE(1010)] = 28994,
  [SMALL_STATE(1011)] = 29014,
  [SMALL_STATE(1012)] = 29034,
  [SMALL_STATE(1013)] = 29054,
  [SMALL_STATE(1014)] = 29074,
  [SMALL_STATE(1015)] = 29102,
  [SMALL_STATE(1016)] = 29118,
  [SMALL_STATE(1017)] = 29146,
  [SMALL_STATE(1018)] = 29178,
  [SMALL_STATE(1019)] = 29198,
  [SMALL_STATE(1020)] = 29214,
  [SMALL_STATE(1021)] = 29234,
  [SMALL_STATE(1022)] = 29254,
  [SMALL_STATE(1023)] = 29270,
  [SMALL_STATE(1024)] = 29290,
  [SMALL_STATE(1025)] = 29318,
  [SMALL_STATE(1026)] = 29345,
  [SMALL_STATE(1027)] = 29360,
  [SMALL_STATE(1028)] = 29387,
  [SMALL_STATE(1029)] = 29414,
  [SMALL_STATE(1030)] = 29433,
  [SMALL_STATE(1031)] = 29460,
  [SMALL_STATE(1032)] = 29487,
  [SMALL_STATE(1033)] = 29514,
  [SMALL_STATE(1034)] = 29541,
  [SMALL_STATE(1035)] = 29562,
  [SMALL_STATE(1036)] = 29577,
  [SMALL_STATE(1037)] = 29604,
  [SMALL_STATE(1038)] = 29631,
  [SMALL_STATE(1039)] = 29658,
  [SMALL_STATE(1040)] = 29685,
  [SMALL_STATE(1041)] = 29704,
  [SMALL_STATE(1042)] = 29723,
  [SMALL_STATE(1043)] = 29742,
  [SMALL_STATE(1044)] = 29769,
  [SMALL_STATE(1045)] = 29796,
  [SMALL_STATE(1046)] = 29823,
  [SMALL_STATE(1047)] = 29850,
  [SMALL_STATE(1048)] = 29877,
  [SMALL_STATE(1049)] = 29898,
  [SMALL_STATE(1050)] = 29925,
  [SMALL_STATE(1051)] = 29952,
  [SMALL_STATE(1052)] = 29979,
  [SMALL_STATE(1053)] = 30006,
  [SMALL_STATE(1054)] = 30025,
  [SMALL_STATE(1055)] = 30052,
  [SMALL_STATE(1056)] = 30079,
  [SMALL_STATE(1057)] = 30098,
  [SMALL_STATE(1058)] = 30125,
  [SMALL_STATE(1059)] = 30152,
  [SMALL_STATE(1060)] = 30179,
  [SMALL_STATE(1061)] = 30198,
  [SMALL_STATE(1062)] = 30217,
  [SMALL_STATE(1063)] = 30236,
  [SMALL_STATE(1064)] = 30263,
  [SMALL_STATE(1065)] = 30280,
  [SMALL_STATE(1066)] = 30307,
  [SMALL_STATE(1067)] = 30334,
  [SMALL_STATE(1068)] = 30361,
  [SMALL_STATE(1069)] = 30388,
  [SMALL_STATE(1070)] = 30415,
  [SMALL_STATE(1071)] = 30442,
  [SMALL_STATE(1072)] = 30469,
  [SMALL_STATE(1073)] = 30496,
  [SMALL_STATE(1074)] = 30511,
  [SMALL_STATE(1075)] = 30532,
  [SMALL_STATE(1076)] = 30559,
  [SMALL_STATE(1077)] = 30586,
  [SMALL_STATE(1078)] = 30601,
  [SMALL_STATE(1079)] = 30628,
  [SMALL_STATE(1080)] = 30643,
  [SMALL_STATE(1081)] = 30670,
  [SMALL_STATE(1082)] = 30697,
  [SMALL_STATE(1083)] = 30724,
  [SMALL_STATE(1084)] = 30751,
  [SMALL_STATE(1085)] = 30766,
  [SMALL_STATE(1086)] = 30793,
  [SMALL_STATE(1087)] = 30820,
  [SMALL_STATE(1088)] = 30847,
  [SMALL_STATE(1089)] = 30862,
  [SMALL_STATE(1090)] = 30889,
  [SMALL_STATE(1091)] = 30916,
  [SMALL_STATE(1092)] = 30937,
  [SMALL_STATE(1093)] = 30956,
  [SMALL_STATE(1094)] = 30983,
  [SMALL_STATE(1095)] = 31004,
  [SMALL_STATE(1096)] = 31031,
  [SMALL_STATE(1097)] = 31058,
  [SMALL_STATE(1098)] = 31085,
  [SMALL_STATE(1099)] = 31112,
  [SMALL_STATE(1100)] = 31139,
  [SMALL_STATE(1101)] = 31166,
  [SMALL_STATE(1102)] = 31185,
  [SMALL_STATE(1103)] = 31204,
  [SMALL_STATE(1104)] = 31223,
  [SMALL_STATE(1105)] = 31237,
  [SMALL_STATE(1106)] = 31259,
  [SMALL_STATE(1107)] = 31281,
  [SMALL_STATE(1108)] = 31295,
  [SMALL_STATE(1109)] = 31317,
  [SMALL_STATE(1110)] = 31339,
  [SMALL_STATE(1111)] = 31357,
  [SMALL_STATE(1112)] = 31371,
  [SMALL_STATE(1113)] = 31385,
  [SMALL_STATE(1114)] = 31403,
  [SMALL_STATE(1115)] = 31421,
  [SMALL_STATE(1116)] = 31447,
  [SMALL_STATE(1117)] = 31469,
  [SMALL_STATE(1118)] = 31491,
  [SMALL_STATE(1119)] = 31513,
  [SMALL_STATE(1120)] = 31531,
  [SMALL_STATE(1121)] = 31553,
  [SMALL_STATE(1122)] = 31579,
  [SMALL_STATE(1123)] = 31597,
  [SMALL_STATE(1124)] = 31617,
  [SMALL_STATE(1125)] = 31631,
  [SMALL_STATE(1126)] = 31653,
  [SMALL_STATE(1127)] = 31675,
  [SMALL_STATE(1128)] = 31701,
  [SMALL_STATE(1129)] = 31723,
  [SMALL_STATE(1130)] = 31745,
  [SMALL_STATE(1131)] = 31767,
  [SMALL_STATE(1132)] = 31789,
  [SMALL_STATE(1133)] = 31815,
  [SMALL_STATE(1134)] = 31837,
  [SMALL_STATE(1135)] = 31863,
  [SMALL_STATE(1136)] = 31889,
  [SMALL_STATE(1137)] = 31907,
  [SMALL_STATE(1138)] = 31929,
  [SMALL_STATE(1139)] = 31947,
  [SMALL_STATE(1140)] = 31969,
  [SMALL_STATE(1141)] = 31991,
  [SMALL_STATE(1142)] = 32009,
  [SMALL_STATE(1143)] = 32029,
  [SMALL_STATE(1144)] = 32047,
  [SMALL_STATE(1145)] = 32061,
  [SMALL_STATE(1146)] = 32083,
  [SMALL_STATE(1147)] = 32105,
  [SMALL_STATE(1148)] = 32119,
  [SMALL_STATE(1149)] = 32139,
  [SMALL_STATE(1150)] = 32159,
  [SMALL_STATE(1151)] = 32177,
  [SMALL_STATE(1152)] = 32199,
  [SMALL_STATE(1153)] = 32225,
  [SMALL_STATE(1154)] = 32247,
  [SMALL_STATE(1155)] = 32265,
  [SMALL_STATE(1156)] = 32291,
  [SMALL_STATE(1157)] = 32317,
  [SMALL_STATE(1158)] = 32339,
  [SMALL_STATE(1159)] = 32361,
  [SMALL_STATE(1160)] = 32383,
  [SMALL_STATE(1161)] = 32403,
  [SMALL_STATE(1162)] = 32421,
  [SMALL_STATE(1163)] = 32439,
  [SMALL_STATE(1164)] = 32453,
  [SMALL_STATE(1165)] = 32479,
  [SMALL_STATE(1166)] = 32493,
  [SMALL_STATE(1167)] = 32515,
  [SMALL_STATE(1168)] = 32541,
  [SMALL_STATE(1169)] = 32560,
  [SMALL_STATE(1170)] = 32577,
  [SMALL_STATE(1171)] = 32596,
  [SMALL_STATE(1172)] = 32613,
  [SMALL_STATE(1173)] = 32630,
  [SMALL_STATE(1174)] = 32647,
  [SMALL_STATE(1175)] = 32664,
  [SMALL_STATE(1176)] = 32681,
  [SMALL_STATE(1177)] = 32702,
  [SMALL_STATE(1178)] = 32721,
  [SMALL_STATE(1179)] = 32740,
  [SMALL_STATE(1180)] = 32759,
  [SMALL_STATE(1181)] = 32778,
  [SMALL_STATE(1182)] = 32799,
  [SMALL_STATE(1183)] = 32816,
  [SMALL_STATE(1184)] = 32833,
  [SMALL_STATE(1185)] = 32852,
  [SMALL_STATE(1186)] = 32869,
  [SMALL_STATE(1187)] = 32886,
  [SMALL_STATE(1188)] = 32903,
  [SMALL_STATE(1189)] = 32920,
  [SMALL_STATE(1190)] = 32937,
  [SMALL_STATE(1191)] = 32954,
  [SMALL_STATE(1192)] = 32977,
  [SMALL_STATE(1193)] = 32998,
  [SMALL_STATE(1194)] = 33017,
  [SMALL_STATE(1195)] = 33034,
  [SMALL_STATE(1196)] = 33051,
  [SMALL_STATE(1197)] = 33070,
  [SMALL_STATE(1198)] = 33089,
  [SMALL_STATE(1199)] = 33108,
  [SMALL_STATE(1200)] = 33127,
  [SMALL_STATE(1201)] = 33143,
  [SMALL_STATE(1202)] = 33159,
  [SMALL_STATE(1203)] = 33175,
  [SMALL_STATE(1204)] = 33191,
  [SMALL_STATE(1205)] = 33207,
  [SMALL_STATE(1206)] = 33219,
  [SMALL_STATE(1207)] = 33235,
  [SMALL_STATE(1208)] = 33251,
  [SMALL_STATE(1209)] = 33267,
  [SMALL_STATE(1210)] = 33289,
  [SMALL_STATE(1211)] = 33305,
  [SMALL_STATE(1212)] = 33321,
  [SMALL_STATE(1213)] = 33337,
  [SMALL_STATE(1214)] = 33359,
  [SMALL_STATE(1215)] = 33381,
  [SMALL_STATE(1216)] = 33397,
  [SMALL_STATE(1217)] = 33417,
  [SMALL_STATE(1218)] = 33433,
  [SMALL_STATE(1219)] = 33453,
  [SMALL_STATE(1220)] = 33469,
  [SMALL_STATE(1221)] = 33485,
  [SMALL_STATE(1222)] = 33501,
  [SMALL_STATE(1223)] = 33517,
  [SMALL_STATE(1224)] = 33533,
  [SMALL_STATE(1225)] = 33549,
  [SMALL_STATE(1226)] = 33561,
  [SMALL_STATE(1227)] = 33573,
  [SMALL_STATE(1228)] = 33589,
  [SMALL_STATE(1229)] = 33605,
  [SMALL_STATE(1230)] = 33621,
  [SMALL_STATE(1231)] = 33637,
  [SMALL_STATE(1232)] = 33657,
  [SMALL_STATE(1233)] = 33673,
  [SMALL_STATE(1234)] = 33689,
  [SMALL_STATE(1235)] = 33705,
  [SMALL_STATE(1236)] = 33721,
  [SMALL_STATE(1237)] = 33733,
  [SMALL_STATE(1238)] = 33749,
  [SMALL_STATE(1239)] = 33765,
  [SMALL_STATE(1240)] = 33781,
  [SMALL_STATE(1241)] = 33803,
  [SMALL_STATE(1242)] = 33825,
  [SMALL_STATE(1243)] = 33841,
  [SMALL_STATE(1244)] = 33857,
  [SMALL_STATE(1245)] = 33873,
  [SMALL_STATE(1246)] = 33893,
  [SMALL_STATE(1247)] = 33913,
  [SMALL_STATE(1248)] = 33933,
  [SMALL_STATE(1249)] = 33955,
  [SMALL_STATE(1250)] = 33975,
  [SMALL_STATE(1251)] = 33995,
  [SMALL_STATE(1252)] = 34011,
  [SMALL_STATE(1253)] = 34027,
  [SMALL_STATE(1254)] = 34043,
  [SMALL_STATE(1255)] = 34059,
  [SMALL_STATE(1256)] = 34075,
  [SMALL_STATE(1257)] = 34091,
  [SMALL_STATE(1258)] = 34106,
  [SMALL_STATE(1259)] = 34123,
  [SMALL_STATE(1260)] = 34136,
  [SMALL_STATE(1261)] = 34149,
  [SMALL_STATE(1262)] = 34162,
  [SMALL_STATE(1263)] = 34175,
  [SMALL_STATE(1264)] = 34190,
  [SMALL_STATE(1265)] = 34205,
  [SMALL_STATE(1266)] = 34218,
  [SMALL_STATE(1267)] = 34233,
  [SMALL_STATE(1268)] = 34248,
  [SMALL_STATE(1269)] = 34263,
  [SMALL_STATE(1270)] = 34278,
  [SMALL_STATE(1271)] = 34291,
  [SMALL_STATE(1272)] = 34306,
  [SMALL_STATE(1273)] = 34317,
  [SMALL_STATE(1274)] = 34332,
  [SMALL_STATE(1275)] = 34347,
  [SMALL_STATE(1276)] = 34362,
  [SMALL_STATE(1277)] = 34379,
  [SMALL_STATE(1278)] = 34394,
  [SMALL_STATE(1279)] = 34404,
  [SMALL_STATE(1280)] = 34414,
  [SMALL_STATE(1281)] = 34426,
  [SMALL_STATE(1282)] = 34436,
  [SMALL_STATE(1283)] = 34450,
  [SMALL_STATE(1284)] = 34466,
  [SMALL_STATE(1285)] = 34476,
  [SMALL_STATE(1286)] = 34490,
  [SMALL_STATE(1287)] = 34500,
  [SMALL_STATE(1288)] = 34510,
  [SMALL_STATE(1289)] = 34524,
  [SMALL_STATE(1290)] = 34534,
  [SMALL_STATE(1291)] = 34550,
  [SMALL_STATE(1292)] = 34560,
  [SMALL_STATE(1293)] = 34572,
  [SMALL_STATE(1294)] = 34588,
  [SMALL_STATE(1295)] = 34604,
  [SMALL_STATE(1296)] = 34620,
  [SMALL_STATE(1297)] = 34630,
  [SMALL_STATE(1298)] = 34644,
  [SMALL_STATE(1299)] = 34660,
  [SMALL_STATE(1300)] = 34674,
  [SMALL_STATE(1301)] = 34684,
  [SMALL_STATE(1302)] = 34700,
  [SMALL_STATE(1303)] = 34714,
  [SMALL_STATE(1304)] = 34724,
  [SMALL_STATE(1305)] = 34734,
  [SMALL_STATE(1306)] = 34744,
  [SMALL_STATE(1307)] = 34758,
  [SMALL_STATE(1308)] = 34772,
  [SMALL_STATE(1309)] = 34786,
  [SMALL_STATE(1310)] = 34796,
  [SMALL_STATE(1311)] = 34806,
  [SMALL_STATE(1312)] = 34816,
  [SMALL_STATE(1313)] = 34826,
  [SMALL_STATE(1314)] = 34836,
  [SMALL_STATE(1315)] = 34846,
  [SMALL_STATE(1316)] = 34858,
  [SMALL_STATE(1317)] = 34874,
  [SMALL_STATE(1318)] = 34890,
  [SMALL_STATE(1319)] = 34900,
  [SMALL_STATE(1320)] = 34910,
  [SMALL_STATE(1321)] = 34926,
  [SMALL_STATE(1322)] = 34940,
  [SMALL_STATE(1323)] = 34950,
  [SMALL_STATE(1324)] = 34964,
  [SMALL_STATE(1325)] = 34974,
  [SMALL_STATE(1326)] = 34984,
  [SMALL_STATE(1327)] = 34998,
  [SMALL_STATE(1328)] = 35008,
  [SMALL_STATE(1329)] = 35018,
  [SMALL_STATE(1330)] = 35034,
  [SMALL_STATE(1331)] = 35048,
  [SMALL_STATE(1332)] = 35058,
  [SMALL_STATE(1333)] = 35068,
  [SMALL_STATE(1334)] = 35084,
  [SMALL_STATE(1335)] = 35100,
  [SMALL_STATE(1336)] = 35110,
  [SMALL_STATE(1337)] = 35126,
  [SMALL_STATE(1338)] = 35136,
  [SMALL_STATE(1339)] = 35146,
  [SMALL_STATE(1340)] = 35162,
  [SMALL_STATE(1341)] = 35172,
  [SMALL_STATE(1342)] = 35186,
  [SMALL_STATE(1343)] = 35196,
  [SMALL_STATE(1344)] = 35208,
  [SMALL_STATE(1345)] = 35218,
  [SMALL_STATE(1346)] = 35234,
  [SMALL_STATE(1347)] = 35250,
  [SMALL_STATE(1348)] = 35264,
  [SMALL_STATE(1349)] = 35274,
  [SMALL_STATE(1350)] = 35290,
  [SMALL_STATE(1351)] = 35300,
  [SMALL_STATE(1352)] = 35316,
  [SMALL_STATE(1353)] = 35326,
  [SMALL_STATE(1354)] = 35336,
  [SMALL_STATE(1355)] = 35352,
  [SMALL_STATE(1356)] = 35362,
  [SMALL_STATE(1357)] = 35372,
  [SMALL_STATE(1358)] = 35388,
  [SMALL_STATE(1359)] = 35398,
  [SMALL_STATE(1360)] = 35412,
  [SMALL_STATE(1361)] = 35428,
  [SMALL_STATE(1362)] = 35438,
  [SMALL_STATE(1363)] = 35454,
  [SMALL_STATE(1364)] = 35464,
  [SMALL_STATE(1365)] = 35480,
  [SMALL_STATE(1366)] = 35494,
  [SMALL_STATE(1367)] = 35508,
  [SMALL_STATE(1368)] = 35522,
  [SMALL_STATE(1369)] = 35532,
  [SMALL_STATE(1370)] = 35542,
  [SMALL_STATE(1371)] = 35552,
  [SMALL_STATE(1372)] = 35564,
  [SMALL_STATE(1373)] = 35574,
  [SMALL_STATE(1374)] = 35584,
  [SMALL_STATE(1375)] = 35598,
  [SMALL_STATE(1376)] = 35608,
  [SMALL_STATE(1377)] = 35622,
  [SMALL_STATE(1378)] = 35638,
  [SMALL_STATE(1379)] = 35648,
  [SMALL_STATE(1380)] = 35658,
  [SMALL_STATE(1381)] = 35668,
  [SMALL_STATE(1382)] = 35682,
  [SMALL_STATE(1383)] = 35692,
  [SMALL_STATE(1384)] = 35708,
  [SMALL_STATE(1385)] = 35718,
  [SMALL_STATE(1386)] = 35732,
  [SMALL_STATE(1387)] = 35746,
  [SMALL_STATE(1388)] = 35762,
  [SMALL_STATE(1389)] = 35776,
  [SMALL_STATE(1390)] = 35790,
  [SMALL_STATE(1391)] = 35806,
  [SMALL_STATE(1392)] = 35816,
  [SMALL_STATE(1393)] = 35826,
  [SMALL_STATE(1394)] = 35842,
  [SMALL_STATE(1395)] = 35858,
  [SMALL_STATE(1396)] = 35868,
  [SMALL_STATE(1397)] = 35884,
  [SMALL_STATE(1398)] = 35898,
  [SMALL_STATE(1399)] = 35914,
  [SMALL_STATE(1400)] = 35930,
  [SMALL_STATE(1401)] = 35940,
  [SMALL_STATE(1402)] = 35954,
  [SMALL_STATE(1403)] = 35964,
  [SMALL_STATE(1404)] = 35978,
  [SMALL_STATE(1405)] = 35994,
  [SMALL_STATE(1406)] = 36004,
  [SMALL_STATE(1407)] = 36014,
  [SMALL_STATE(1408)] = 36030,
  [SMALL_STATE(1409)] = 36040,
  [SMALL_STATE(1410)] = 36050,
  [SMALL_STATE(1411)] = 36066,
  [SMALL_STATE(1412)] = 36080,
  [SMALL_STATE(1413)] = 36090,
  [SMALL_STATE(1414)] = 36100,
  [SMALL_STATE(1415)] = 36116,
  [SMALL_STATE(1416)] = 36132,
  [SMALL_STATE(1417)] = 36144,
  [SMALL_STATE(1418)] = 36157,
  [SMALL_STATE(1419)] = 36170,
  [SMALL_STATE(1420)] = 36183,
  [SMALL_STATE(1421)] = 36196,
  [SMALL_STATE(1422)] = 36209,
  [SMALL_STATE(1423)] = 36222,
  [SMALL_STATE(1424)] = 36235,
  [SMALL_STATE(1425)] = 36248,
  [SMALL_STATE(1426)] = 36261,
  [SMALL_STATE(1427)] = 36274,
  [SMALL_STATE(1428)] = 36287,
  [SMALL_STATE(1429)] = 36300,
  [SMALL_STATE(1430)] = 36313,
  [SMALL_STATE(1431)] = 36326,
  [SMALL_STATE(1432)] = 36339,
  [SMALL_STATE(1433)] = 36352,
  [SMALL_STATE(1434)] = 36365,
  [SMALL_STATE(1435)] = 36378,
  [SMALL_STATE(1436)] = 36391,
  [SMALL_STATE(1437)] = 36404,
  [SMALL_STATE(1438)] = 36417,
  [SMALL_STATE(1439)] = 36430,
  [SMALL_STATE(1440)] = 36439,
  [SMALL_STATE(1441)] = 36452,
  [SMALL_STATE(1442)] = 36461,
  [SMALL_STATE(1443)] = 36474,
  [SMALL_STATE(1444)] = 36487,
  [SMALL_STATE(1445)] = 36496,
  [SMALL_STATE(1446)] = 36509,
  [SMALL_STATE(1447)] = 36522,
  [SMALL_STATE(1448)] = 36535,
  [SMALL_STATE(1449)] = 36548,
  [SMALL_STATE(1450)] = 36561,
  [SMALL_STATE(1451)] = 36574,
  [SMALL_STATE(1452)] = 36583,
  [SMALL_STATE(1453)] = 36592,
  [SMALL_STATE(1454)] = 36605,
  [SMALL_STATE(1455)] = 36618,
  [SMALL_STATE(1456)] = 36631,
  [SMALL_STATE(1457)] = 36644,
  [SMALL_STATE(1458)] = 36657,
  [SMALL_STATE(1459)] = 36670,
  [SMALL_STATE(1460)] = 36683,
  [SMALL_STATE(1461)] = 36696,
  [SMALL_STATE(1462)] = 36709,
  [SMALL_STATE(1463)] = 36718,
  [SMALL_STATE(1464)] = 36731,
  [SMALL_STATE(1465)] = 36744,
  [SMALL_STATE(1466)] = 36757,
  [SMALL_STATE(1467)] = 36770,
  [SMALL_STATE(1468)] = 36783,
  [SMALL_STATE(1469)] = 36792,
  [SMALL_STATE(1470)] = 36805,
  [SMALL_STATE(1471)] = 36818,
  [SMALL_STATE(1472)] = 36831,
  [SMALL_STATE(1473)] = 36844,
  [SMALL_STATE(1474)] = 36857,
  [SMALL_STATE(1475)] = 36866,
  [SMALL_STATE(1476)] = 36879,
  [SMALL_STATE(1477)] = 36892,
  [SMALL_STATE(1478)] = 36905,
  [SMALL_STATE(1479)] = 36918,
  [SMALL_STATE(1480)] = 36931,
  [SMALL_STATE(1481)] = 36944,
  [SMALL_STATE(1482)] = 36957,
  [SMALL_STATE(1483)] = 36970,
  [SMALL_STATE(1484)] = 36983,
  [SMALL_STATE(1485)] = 36996,
  [SMALL_STATE(1486)] = 37007,
  [SMALL_STATE(1487)] = 37018,
  [SMALL_STATE(1488)] = 37031,
  [SMALL_STATE(1489)] = 37044,
  [SMALL_STATE(1490)] = 37057,
  [SMALL_STATE(1491)] = 37070,
  [SMALL_STATE(1492)] = 37083,
  [SMALL_STATE(1493)] = 37096,
  [SMALL_STATE(1494)] = 37109,
  [SMALL_STATE(1495)] = 37122,
  [SMALL_STATE(1496)] = 37135,
  [SMALL_STATE(1497)] = 37148,
  [SMALL_STATE(1498)] = 37161,
  [SMALL_STATE(1499)] = 37174,
  [SMALL_STATE(1500)] = 37187,
  [SMALL_STATE(1501)] = 37200,
  [SMALL_STATE(1502)] = 37211,
  [SMALL_STATE(1503)] = 37224,
  [SMALL_STATE(1504)] = 37237,
  [SMALL_STATE(1505)] = 37250,
  [SMALL_STATE(1506)] = 37263,
  [SMALL_STATE(1507)] = 37276,
  [SMALL_STATE(1508)] = 37289,
  [SMALL_STATE(1509)] = 37302,
  [SMALL_STATE(1510)] = 37315,
  [SMALL_STATE(1511)] = 37328,
  [SMALL_STATE(1512)] = 37341,
  [SMALL_STATE(1513)] = 37354,
  [SMALL_STATE(1514)] = 37367,
  [SMALL_STATE(1515)] = 37380,
  [SMALL_STATE(1516)] = 37393,
  [SMALL_STATE(1517)] = 37406,
  [SMALL_STATE(1518)] = 37419,
  [SMALL_STATE(1519)] = 37432,
  [SMALL_STATE(1520)] = 37445,
  [SMALL_STATE(1521)] = 37458,
  [SMALL_STATE(1522)] = 37471,
  [SMALL_STATE(1523)] = 37484,
  [SMALL_STATE(1524)] = 37495,
  [SMALL_STATE(1525)] = 37508,
  [SMALL_STATE(1526)] = 37521,
  [SMALL_STATE(1527)] = 37534,
  [SMALL_STATE(1528)] = 37547,
  [SMALL_STATE(1529)] = 37560,
  [SMALL_STATE(1530)] = 37573,
  [SMALL_STATE(1531)] = 37586,
  [SMALL_STATE(1532)] = 37599,
  [SMALL_STATE(1533)] = 37610,
  [SMALL_STATE(1534)] = 37623,
  [SMALL_STATE(1535)] = 37636,
  [SMALL_STATE(1536)] = 37649,
  [SMALL_STATE(1537)] = 37662,
  [SMALL_STATE(1538)] = 37675,
  [SMALL_STATE(1539)] = 37688,
  [SMALL_STATE(1540)] = 37701,
  [SMALL_STATE(1541)] = 37714,
  [SMALL_STATE(1542)] = 37727,
  [SMALL_STATE(1543)] = 37740,
  [SMALL_STATE(1544)] = 37753,
  [SMALL_STATE(1545)] = 37766,
  [SMALL_STATE(1546)] = 37779,
  [SMALL_STATE(1547)] = 37792,
  [SMALL_STATE(1548)] = 37805,
  [SMALL_STATE(1549)] = 37818,
  [SMALL_STATE(1550)] = 37831,
  [SMALL_STATE(1551)] = 37844,
  [SMALL_STATE(1552)] = 37857,
  [SMALL_STATE(1553)] = 37870,
  [SMALL_STATE(1554)] = 37883,
  [SMALL_STATE(1555)] = 37896,
  [SMALL_STATE(1556)] = 37909,
  [SMALL_STATE(1557)] = 37922,
  [SMALL_STATE(1558)] = 37935,
  [SMALL_STATE(1559)] = 37948,
  [SMALL_STATE(1560)] = 37961,
  [SMALL_STATE(1561)] = 37974,
  [SMALL_STATE(1562)] = 37987,
  [SMALL_STATE(1563)] = 38000,
  [SMALL_STATE(1564)] = 38013,
  [SMALL_STATE(1565)] = 38026,
  [SMALL_STATE(1566)] = 38039,
  [SMALL_STATE(1567)] = 38052,
  [SMALL_STATE(1568)] = 38061,
  [SMALL_STATE(1569)] = 38071,
  [SMALL_STATE(1570)] = 38081,
  [SMALL_STATE(1571)] = 38091,
  [SMALL_STATE(1572)] = 38101,
  [SMALL_STATE(1573)] = 38111,
  [SMALL_STATE(1574)] = 38121,
  [SMALL_STATE(1575)] = 38131,
  [SMALL_STATE(1576)] = 38141,
  [SMALL_STATE(1577)] = 38151,
  [SMALL_STATE(1578)] = 38161,
  [SMALL_STATE(1579)] = 38171,
  [SMALL_STATE(1580)] = 38181,
  [SMALL_STATE(1581)] = 38191,
  [SMALL_STATE(1582)] = 38201,
  [SMALL_STATE(1583)] = 38211,
  [SMALL_STATE(1584)] = 38221,
  [SMALL_STATE(1585)] = 38231,
  [SMALL_STATE(1586)] = 38241,
  [SMALL_STATE(1587)] = 38251,
  [SMALL_STATE(1588)] = 38261,
  [SMALL_STATE(1589)] = 38271,
  [SMALL_STATE(1590)] = 38281,
  [SMALL_STATE(1591)] = 38291,
  [SMALL_STATE(1592)] = 38301,
  [SMALL_STATE(1593)] = 38311,
  [SMALL_STATE(1594)] = 38321,
  [SMALL_STATE(1595)] = 38331,
  [SMALL_STATE(1596)] = 38339,
  [SMALL_STATE(1597)] = 38349,
  [SMALL_STATE(1598)] = 38359,
  [SMALL_STATE(1599)] = 38369,
  [SMALL_STATE(1600)] = 38377,
  [SMALL_STATE(1601)] = 38387,
  [SMALL_STATE(1602)] = 38397,
  [SMALL_STATE(1603)] = 38407,
  [SMALL_STATE(1604)] = 38415,
  [SMALL_STATE(1605)] = 38425,
  [SMALL_STATE(1606)] = 38435,
  [SMALL_STATE(1607)] = 38445,
  [SMALL_STATE(1608)] = 38453,
  [SMALL_STATE(1609)] = 38463,
  [SMALL_STATE(1610)] = 38473,
  [SMALL_STATE(1611)] = 38483,
  [SMALL_STATE(1612)] = 38493,
  [SMALL_STATE(1613)] = 38503,
  [SMALL_STATE(1614)] = 38513,
  [SMALL_STATE(1615)] = 38523,
  [SMALL_STATE(1616)] = 38533,
  [SMALL_STATE(1617)] = 38543,
  [SMALL_STATE(1618)] = 38553,
  [SMALL_STATE(1619)] = 38561,
  [SMALL_STATE(1620)] = 38569,
  [SMALL_STATE(1621)] = 38579,
  [SMALL_STATE(1622)] = 38589,
  [SMALL_STATE(1623)] = 38599,
  [SMALL_STATE(1624)] = 38609,
  [SMALL_STATE(1625)] = 38617,
  [SMALL_STATE(1626)] = 38627,
  [SMALL_STATE(1627)] = 38637,
  [SMALL_STATE(1628)] = 38647,
  [SMALL_STATE(1629)] = 38657,
  [SMALL_STATE(1630)] = 38667,
  [SMALL_STATE(1631)] = 38675,
  [SMALL_STATE(1632)] = 38685,
  [SMALL_STATE(1633)] = 38695,
  [SMALL_STATE(1634)] = 38705,
  [SMALL_STATE(1635)] = 38715,
  [SMALL_STATE(1636)] = 38725,
  [SMALL_STATE(1637)] = 38735,
  [SMALL_STATE(1638)] = 38743,
  [SMALL_STATE(1639)] = 38751,
  [SMALL_STATE(1640)] = 38761,
  [SMALL_STATE(1641)] = 38771,
  [SMALL_STATE(1642)] = 38781,
  [SMALL_STATE(1643)] = 38791,
  [SMALL_STATE(1644)] = 38799,
  [SMALL_STATE(1645)] = 38809,
  [SMALL_STATE(1646)] = 38817,
  [SMALL_STATE(1647)] = 38827,
  [SMALL_STATE(1648)] = 38837,
  [SMALL_STATE(1649)] = 38847,
  [SMALL_STATE(1650)] = 38857,
  [SMALL_STATE(1651)] = 38867,
  [SMALL_STATE(1652)] = 38877,
  [SMALL_STATE(1653)] = 38887,
  [SMALL_STATE(1654)] = 38897,
  [SMALL_STATE(1655)] = 38907,
  [SMALL_STATE(1656)] = 38917,
  [SMALL_STATE(1657)] = 38925,
  [SMALL_STATE(1658)] = 38935,
  [SMALL_STATE(1659)] = 38945,
  [SMALL_STATE(1660)] = 38955,
  [SMALL_STATE(1661)] = 38965,
  [SMALL_STATE(1662)] = 38975,
  [SMALL_STATE(1663)] = 38985,
  [SMALL_STATE(1664)] = 38995,
  [SMALL_STATE(1665)] = 39005,
  [SMALL_STATE(1666)] = 39015,
  [SMALL_STATE(1667)] = 39025,
  [SMALL_STATE(1668)] = 39035,
  [SMALL_STATE(1669)] = 39045,
  [SMALL_STATE(1670)] = 39055,
  [SMALL_STATE(1671)] = 39065,
  [SMALL_STATE(1672)] = 39075,
  [SMALL_STATE(1673)] = 39085,
  [SMALL_STATE(1674)] = 39095,
  [SMALL_STATE(1675)] = 39105,
  [SMALL_STATE(1676)] = 39115,
  [SMALL_STATE(1677)] = 39125,
  [SMALL_STATE(1678)] = 39135,
  [SMALL_STATE(1679)] = 39143,
  [SMALL_STATE(1680)] = 39153,
  [SMALL_STATE(1681)] = 39163,
  [SMALL_STATE(1682)] = 39171,
  [SMALL_STATE(1683)] = 39181,
  [SMALL_STATE(1684)] = 39191,
  [SMALL_STATE(1685)] = 39201,
  [SMALL_STATE(1686)] = 39211,
  [SMALL_STATE(1687)] = 39221,
  [SMALL_STATE(1688)] = 39231,
  [SMALL_STATE(1689)] = 39238,
  [SMALL_STATE(1690)] = 39245,
  [SMALL_STATE(1691)] = 39252,
  [SMALL_STATE(1692)] = 39259,
  [SMALL_STATE(1693)] = 39266,
  [SMALL_STATE(1694)] = 39273,
  [SMALL_STATE(1695)] = 39280,
  [SMALL_STATE(1696)] = 39287,
  [SMALL_STATE(1697)] = 39294,
  [SMALL_STATE(1698)] = 39301,
  [SMALL_STATE(1699)] = 39308,
  [SMALL_STATE(1700)] = 39315,
  [SMALL_STATE(1701)] = 39322,
  [SMALL_STATE(1702)] = 39329,
  [SMALL_STATE(1703)] = 39336,
  [SMALL_STATE(1704)] = 39343,
  [SMALL_STATE(1705)] = 39350,
  [SMALL_STATE(1706)] = 39357,
  [SMALL_STATE(1707)] = 39364,
  [SMALL_STATE(1708)] = 39371,
  [SMALL_STATE(1709)] = 39378,
  [SMALL_STATE(1710)] = 39385,
  [SMALL_STATE(1711)] = 39392,
  [SMALL_STATE(1712)] = 39399,
  [SMALL_STATE(1713)] = 39406,
  [SMALL_STATE(1714)] = 39413,
  [SMALL_STATE(1715)] = 39420,
  [SMALL_STATE(1716)] = 39427,
  [SMALL_STATE(1717)] = 39434,
  [SMALL_STATE(1718)] = 39441,
  [SMALL_STATE(1719)] = 39448,
  [SMALL_STATE(1720)] = 39455,
  [SMALL_STATE(1721)] = 39462,
  [SMALL_STATE(1722)] = 39469,
  [SMALL_STATE(1723)] = 39476,
  [SMALL_STATE(1724)] = 39483,
  [SMALL_STATE(1725)] = 39490,
  [SMALL_STATE(1726)] = 39497,
  [SMALL_STATE(1727)] = 39504,
  [SMALL_STATE(1728)] = 39511,
  [SMALL_STATE(1729)] = 39518,
  [SMALL_STATE(1730)] = 39525,
  [SMALL_STATE(1731)] = 39532,
  [SMALL_STATE(1732)] = 39539,
  [SMALL_STATE(1733)] = 39546,
  [SMALL_STATE(1734)] = 39553,
  [SMALL_STATE(1735)] = 39560,
  [SMALL_STATE(1736)] = 39567,
  [SMALL_STATE(1737)] = 39574,
  [SMALL_STATE(1738)] = 39581,
  [SMALL_STATE(1739)] = 39588,
  [SMALL_STATE(1740)] = 39595,
  [SMALL_STATE(1741)] = 39602,
  [SMALL_STATE(1742)] = 39609,
  [SMALL_STATE(1743)] = 39616,
  [SMALL_STATE(1744)] = 39623,
  [SMALL_STATE(1745)] = 39630,
  [SMALL_STATE(1746)] = 39637,
  [SMALL_STATE(1747)] = 39644,
  [SMALL_STATE(1748)] = 39651,
  [SMALL_STATE(1749)] = 39658,
  [SMALL_STATE(1750)] = 39665,
  [SMALL_STATE(1751)] = 39672,
  [SMALL_STATE(1752)] = 39679,
  [SMALL_STATE(1753)] = 39686,
  [SMALL_STATE(1754)] = 39693,
  [SMALL_STATE(1755)] = 39700,
  [SMALL_STATE(1756)] = 39707,
  [SMALL_STATE(1757)] = 39714,
  [SMALL_STATE(1758)] = 39721,
  [SMALL_STATE(1759)] = 39728,
  [SMALL_STATE(1760)] = 39735,
  [SMALL_STATE(1761)] = 39742,
  [SMALL_STATE(1762)] = 39749,
  [SMALL_STATE(1763)] = 39756,
  [SMALL_STATE(1764)] = 39763,
  [SMALL_STATE(1765)] = 39770,
  [SMALL_STATE(1766)] = 39777,
  [SMALL_STATE(1767)] = 39784,
  [SMALL_STATE(1768)] = 39791,
  [SMALL_STATE(1769)] = 39798,
  [SMALL_STATE(1770)] = 39805,
  [SMALL_STATE(1771)] = 39812,
  [SMALL_STATE(1772)] = 39819,
  [SMALL_STATE(1773)] = 39826,
  [SMALL_STATE(1774)] = 39833,
  [SMALL_STATE(1775)] = 39840,
  [SMALL_STATE(1776)] = 39847,
  [SMALL_STATE(1777)] = 39854,
  [SMALL_STATE(1778)] = 39861,
  [SMALL_STATE(1779)] = 39868,
  [SMALL_STATE(1780)] = 39875,
  [SMALL_STATE(1781)] = 39882,
  [SMALL_STATE(1782)] = 39889,
  [SMALL_STATE(1783)] = 39896,
  [SMALL_STATE(1784)] = 39903,
  [SMALL_STATE(1785)] = 39910,
  [SMALL_STATE(1786)] = 39917,
  [SMALL_STATE(1787)] = 39924,
  [SMALL_STATE(1788)] = 39931,
  [SMALL_STATE(1789)] = 39938,
  [SMALL_STATE(1790)] = 39945,
  [SMALL_STATE(1791)] = 39952,
  [SMALL_STATE(1792)] = 39959,
  [SMALL_STATE(1793)] = 39966,
  [SMALL_STATE(1794)] = 39973,
  [SMALL_STATE(1795)] = 39980,
  [SMALL_STATE(1796)] = 39987,
  [SMALL_STATE(1797)] = 39994,
  [SMALL_STATE(1798)] = 40001,
  [SMALL_STATE(1799)] = 40008,
  [SMALL_STATE(1800)] = 40015,
  [SMALL_STATE(1801)] = 40022,
  [SMALL_STATE(1802)] = 40029,
  [SMALL_STATE(1803)] = 40036,
  [SMALL_STATE(1804)] = 40043,
  [SMALL_STATE(1805)] = 40050,
  [SMALL_STATE(1806)] = 40057,
  [SMALL_STATE(1807)] = 40064,
  [SMALL_STATE(1808)] = 40071,
  [SMALL_STATE(1809)] = 40078,
  [SMALL_STATE(1810)] = 40085,
  [SMALL_STATE(1811)] = 40092,
  [SMALL_STATE(1812)] = 40099,
  [SMALL_STATE(1813)] = 40106,
  [SMALL_STATE(1814)] = 40113,
  [SMALL_STATE(1815)] = 40120,
  [SMALL_STATE(1816)] = 40127,
  [SMALL_STATE(1817)] = 40134,
  [SMALL_STATE(1818)] = 40141,
  [SMALL_STATE(1819)] = 40148,
  [SMALL_STATE(1820)] = 40155,
  [SMALL_STATE(1821)] = 40162,
  [SMALL_STATE(1822)] = 40169,
  [SMALL_STATE(1823)] = 40176,
  [SMALL_STATE(1824)] = 40183,
  [SMALL_STATE(1825)] = 40190,
  [SMALL_STATE(1826)] = 40197,
  [SMALL_STATE(1827)] = 40204,
  [SMALL_STATE(1828)] = 40211,
  [SMALL_STATE(1829)] = 40218,
  [SMALL_STATE(1830)] = 40225,
  [SMALL_STATE(1831)] = 40232,
  [SMALL_STATE(1832)] = 40239,
  [SMALL_STATE(1833)] = 40246,
  [SMALL_STATE(1834)] = 40253,
  [SMALL_STATE(1835)] = 40260,
  [SMALL_STATE(1836)] = 40267,
  [SMALL_STATE(1837)] = 40274,
  [SMALL_STATE(1838)] = 40281,
  [SMALL_STATE(1839)] = 40288,
  [SMALL_STATE(1840)] = 40295,
  [SMALL_STATE(1841)] = 40302,
  [SMALL_STATE(1842)] = 40309,
  [SMALL_STATE(1843)] = 40316,
  [SMALL_STATE(1844)] = 40323,
  [SMALL_STATE(1845)] = 40330,
  [SMALL_STATE(1846)] = 40337,
  [SMALL_STATE(1847)] = 40344,
  [SMALL_STATE(1848)] = 40351,
  [SMALL_STATE(1849)] = 40358,
  [SMALL_STATE(1850)] = 40365,
  [SMALL_STATE(1851)] = 40372,
  [SMALL_STATE(1852)] = 40379,
  [SMALL_STATE(1853)] = 40386,
  [SMALL_STATE(1854)] = 40393,
  [SMALL_STATE(1855)] = 40400,
  [SMALL_STATE(1856)] = 40407,
  [SMALL_STATE(1857)] = 40414,
  [SMALL_STATE(1858)] = 40421,
  [SMALL_STATE(1859)] = 40428,
  [SMALL_STATE(1860)] = 40435,
  [SMALL_STATE(1861)] = 40442,
  [SMALL_STATE(1862)] = 40449,
  [SMALL_STATE(1863)] = 40456,
  [SMALL_STATE(1864)] = 40463,
  [SMALL_STATE(1865)] = 40470,
  [SMALL_STATE(1866)] = 40477,
  [SMALL_STATE(1867)] = 40484,
  [SMALL_STATE(1868)] = 40491,
  [SMALL_STATE(1869)] = 40498,
  [SMALL_STATE(1870)] = 40505,
  [SMALL_STATE(1871)] = 40512,
  [SMALL_STATE(1872)] = 40519,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = false}}, SHIFT(607),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1283),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(664),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(58),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1259),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1260),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1261),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(954),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(962),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(963),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(349),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(360),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1592),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(882),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1594),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1393),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1240),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1393),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(27),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [55] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identifier, 1, 0, 0),
  [57] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_identifier, 1, 0, 0),
  [59] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value, 1, 0, 0),
  [61] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value, 1, 0, 0),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1301),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(621),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1301),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1290),
  [71] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_path, 1, 0, 0),
  [73] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_path, 1, 0, 0),
  [75] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0),
  [77] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0),
  [79] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1301),
  [82] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(621),
  [85] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1301),
  [88] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1290),
  [91] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_path, 2, 0, 0),
  [93] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_path, 2, 0, 0),
  [95] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sub_query, 3, 0, 0),
  [97] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sub_query, 3, 0, 0),
  [99] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_duration, 1, 0, 0),
  [101] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_duration, 1, 0, 0),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [105] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_duration_repeat1, 2, 0, 0),
  [107] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_duration_repeat1, 2, 0, 0),
  [109] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_duration_repeat1, 2, 0, 0), SHIFT_REPEAT(9),
  [112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 3, 0, 0),
  [114] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 3, 0, 0),
  [116] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 3, 0, 0),
  [118] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 3, 0, 0),
  [120] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_key, 1, 0, 0),
  [122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 2, 0, 0),
  [124] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 2, 0, 0),
  [126] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 4, 0, 0),
  [128] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 4, 0, 0),
  [130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 2, 0, 0),
  [132] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 2, 0, 0),
  [134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_id_value, 1, 0, 0),
  [136] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_id_value, 1, 0, 0),
  [138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 4, 0, 0),
  [140] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 4, 0, 0),
  [142] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 3, 0, 0),
  [144] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 3, 0, 0),
  [146] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_path_element, 1, 0, 0),
  [148] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_path_element, 1, 0, 0),
  [150] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 2, 0, 0),
  [152] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 2, 0, 0),
  [154] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_value, 1, 0, 0),
  [156] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_base_value, 1, 0, 0),
  [158] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_number, 1, 0, 0),
  [160] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_number, 1, 0, 0),
  [162] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_id_range, 5, 0, 0),
  [164] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_id_range, 5, 0, 0),
  [166] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 2, 0, 0),
  [168] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 2, 0, 0),
  [170] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_id_range, 4, 0, 0),
  [172] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_id_range, 4, 0, 0),
  [174] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_filter, 5, 0, 0),
  [176] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_filter, 5, 0, 0),
  [178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_id_range, 3, 0, 0),
  [180] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_id_range, 3, 0, 0),
  [182] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_id, 3, 0, 0),
  [184] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_id, 3, 0, 0),
  [186] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_point, 5, 0, 0),
  [188] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_point, 5, 0, 0),
  [190] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_path, 5, 0, 0),
  [192] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_graph_path, 5, 0, 0),
  [194] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_path, 4, 0, 0),
  [196] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_graph_path, 4, 0, 0),
  [198] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 3, 0, 0),
  [200] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 3, 0, 0),
  [202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_filter, 3, 0, 0),
  [204] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_filter, 3, 0, 0),
  [206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_path, 2, 0, 0),
  [208] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_graph_path, 2, 0, 0),
  [210] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_id_range, 2, 0, 0),
  [212] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_id_range, 2, 0, 0),
  [214] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_duration_repeat1, 2, 0, 0), SHIFT_REPEAT(51),
  [217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1383),
  [221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1383),
  [225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1415),
  [227] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1383),
  [230] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(617),
  [233] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1383),
  [236] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1415),
  [239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list_count, 3, 0, 0),
  [241] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list_count, 3, 0, 0),
  [243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1394),
  [245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1394),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1362),
  [251] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 3, 0, 0),
  [253] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 3, 0, 0),
  [255] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list_count, 2, 0, 0),
  [257] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list_count, 2, 0, 0),
  [259] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list_count, 4, 0, 0),
  [261] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list_count, 4, 0, 0),
  [263] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1394),
  [266] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(626),
  [269] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1394),
  [272] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1362),
  [275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 2, 0, 0),
  [277] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 2, 0, 0),
  [279] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_duration_repeat1, 2, 0, 0), SHIFT_REPEAT(91),
  [282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [284] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_duration_repeat1, 2, 0, 0), SHIFT_REPEAT(97),
  [287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_statement, 6, 0, 0),
  [291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1265),
  [293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1272),
  [295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1506),
  [297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1613),
  [299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1297),
  [301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(614),
  [303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1604),
  [305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(699),
  [307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1520),
  [309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1515),
  [311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(771),
  [315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(766),
  [317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1771),
  [319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(675),
  [321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(769),
  [323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1770),
  [325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1769),
  [327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_statement, 5, 0, 0),
  [331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_statement, 4, 0, 0),
  [333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1682),
  [337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(667),
  [341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 2, 0, 0),
  [343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1569),
  [349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1634),
  [351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1633),
  [353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1480),
  [355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1479),
  [357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(748),
  [359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(101),
  [363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1213),
  [365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(241),
  [367] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_id_range, 1, 0, 0),
  [369] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_id_range, 1, 0, 0),
  [371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1214),
  [373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18),
  [375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 3, 0, 0),
  [377] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1393),
  [380] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1393),
  [383] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1320),
  [386] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1357),
  [389] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(613),
  [392] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1357),
  [395] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1317),
  [398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1209),
  [400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(226),
  [402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1320),
  [404] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1407),
  [407] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(623),
  [410] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1407),
  [413] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1390),
  [416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1407),
  [418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(623),
  [420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1407),
  [422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1390),
  [424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(668),
  [428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1427),
  [430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1426),
  [432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(707),
  [434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1357),
  [436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1357),
  [440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1317),
  [442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1241),
  [444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(292),
  [446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(29),
  [448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1399),
  [450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1399),
  [454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1377),
  [456] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1399),
  [459] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(618),
  [462] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1399),
  [465] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1377),
  [468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [470] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_duration_repeat1, 2, 0, 0), SHIFT_REPEAT(221),
  [473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [479] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_duration_repeat1, 2, 0, 0), SHIFT_REPEAT(239),
  [482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_view_clause, 5, 0, 0),
  [492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(670),
  [494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1563),
  [496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(662),
  [498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_view_clause, 6, 0, 0),
  [500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(606),
  [502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1298),
  [504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(25),
  [506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(950),
  [508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(965),
  [510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(364),
  [512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(340),
  [514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1571),
  [516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(875),
  [518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1646),
  [520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12),
  [528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(40),
  [532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expressions, 2, 0, 0),
  [542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [546] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expressions, 3, 0, 0),
  [548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(391),
  [562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(387),
  [580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(381),
  [584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1396),
  [586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(332),
  [588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1636),
  [590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(645),
  [592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(275),
  [596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(333),
  [600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(394),
  [606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(385),
  [610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(383),
  [614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(379),
  [620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1410),
  [622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(300),
  [624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1584),
  [626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(237),
  [632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(243),
  [636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(377),
  [642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [648] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, 0, 0),
  [650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 0),
  [652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_criteria, 1, 0, 0),
  [654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [658] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0),
  [660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_clause, 3, 0, 0),
  [666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(724),
  [668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(700),
  [670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 2, 0, 0),
  [672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(681),
  [674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 3, 0, 0),
  [676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(751),
  [678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_where_clause, 2, 0, 0),
  [680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assert_clause, 2, 0, 0),
  [688] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_clause, 2, 0, 0),
  [690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_clause, 2, 0, 0),
  [692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [706] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_assignment, 3, 0, 0),
  [708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_clause, 2, 0, 0),
  [720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(696),
  [722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1802),
  [728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1605),
  [730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [732] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_predicate, 1, 0, 0),
  [734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1782),
  [736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1826),
  [738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1837),
  [740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1794),
  [742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1787),
  [744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1299),
  [746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1513),
  [762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1487),
  [776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_param_statement, 5, 0, 0),
  [786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1530),
  [788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_predicate, 1, 0, 0),
  [792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1651),
  [794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_param_statement, 6, 0, 0),
  [796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1550),
  [798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [806] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0),
  [808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1603),
  [810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1543),
  [822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1547),
  [824] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_param, 5, 0, 0),
  [826] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_where_clause, 2, 0, 0),
  [828] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_param, 6, 0, 0),
  [830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_property, 3, 0, 0),
  [832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(630),
  [858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1599),
  [860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(636),
  [862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1205),
  [864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(661),
  [866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(646),
  [868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1398),
  [870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(110),
  [872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1635),
  [874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(95),
  [880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(111),
  [884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1258),
  [890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(643),
  [892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1387),
  [932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(273),
  [934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1617),
  [936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(230),
  [942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(270),
  [946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [948] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_search_analyzer_clause, 3, 0, 0),
  [950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(822),
  [952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1806),
  [954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1809),
  [956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1810),
  [958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1714),
  [960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1744),
  [962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1870),
  [964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1869),
  [966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1866),
  [968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [970] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0),
  [972] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(822),
  [975] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1806),
  [978] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1809),
  [981] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1810),
  [984] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1714),
  [987] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1744),
  [990] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1870),
  [993] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1869),
  [996] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1866),
  [999] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(757),
  [1002] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_search_analyzer_clause, 4, 0, 0),
  [1004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [1006] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_statement, 7, 0, 0),
  [1008] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_define_user_statement_repeat1, 2, 0, 0),
  [1010] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator, 1, 0, 0),
  [1012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(775),
  [1014] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator, 1, 0, 0),
  [1016] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 4, 0, 0),
  [1018] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_operator, 1, 0, 0),
  [1020] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_operator, 1, 0, 0),
  [1022] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator, 5, 0, 0),
  [1024] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator, 5, 0, 0),
  [1026] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator, 6, 0, 0),
  [1028] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator, 6, 0, 0),
  [1030] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_operator, 1, 0, 0),
  [1032] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_operator, 1, 0, 0),
  [1034] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator, 2, 0, 0),
  [1036] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator, 2, 0, 0),
  [1038] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator, 3, 0, 0),
  [1040] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator, 3, 0, 0),
  [1042] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_statement, 8, 0, 0),
  [1044] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comment_clause, 2, 0, 0),
  [1046] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat1, 2, 0, 0),
  [1048] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(714),
  [1051] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1746),
  [1054] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(979),
  [1057] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1308),
  [1060] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(713),
  [1063] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(712),
  [1066] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1282),
  [1069] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1848),
  [1072] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_statement, 9, 0, 0),
  [1074] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_field_statement, 5, 0, 0),
  [1076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [1078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1746),
  [1080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(979),
  [1082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1308),
  [1084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(713),
  [1086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [1088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1282),
  [1090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1848),
  [1092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_field_statement, 4, 0, 0),
  [1094] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_user_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1648),
  [1097] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_field_statement, 6, 0, 0),
  [1099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1181),
  [1101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [1103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(689),
  [1105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [1107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1341),
  [1109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1176),
  [1111] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(717),
  [1114] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(689),
  [1117] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(680),
  [1120] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1341),
  [1123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1192),
  [1125] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_on_table_clause, 3, 0, 0),
  [1127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_on_table_clause, 2, 0, 0),
  [1129] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_table_statement, 5, 0, 0),
  [1131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1694),
  [1133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [1135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1488),
  [1137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1486),
  [1139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1367),
  [1141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1692),
  [1143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_table_statement, 4, 0, 0),
  [1145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [1147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_table_statement, 3, 0, 0),
  [1149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [1151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bm25_clause, 1, 0, 0),
  [1153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1843),
  [1155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_view_clause, 7, 0, 0),
  [1157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_define_table_statement_repeat1, 2, 0, 0),
  [1159] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_table_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1694),
  [1162] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_table_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(828),
  [1165] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_table_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1488),
  [1168] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_table_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1486),
  [1171] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_table_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1367),
  [1174] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_table_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1692),
  [1177] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_statement, 10, 0, 0),
  [1179] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_user_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1665),
  [1182] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_type_clause, 5, 0, 0),
  [1184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1579),
  [1186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1665),
  [1188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_terms_order_clause, 2, 0, 0),
  [1190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1735),
  [1192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(853),
  [1194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1388),
  [1196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(841),
  [1198] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bm25_clause, 6, 0, 0),
  [1200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_type_clause, 4, 0, 0),
  [1202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1631),
  [1204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_type_clause, 2, 0, 0),
  [1206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1586),
  [1208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [1210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(834),
  [1212] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_ids_cache_clause, 2, 0, 0),
  [1214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_ids_order_clause, 2, 0, 0),
  [1216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_terms_cache_clause, 2, 0, 0),
  [1218] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_lengths_cache_clause, 2, 0, 0),
  [1220] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_lengths_order_clause, 2, 0, 0),
  [1222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_postings_cache_clause, 2, 0, 0),
  [1224] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_table_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1735),
  [1227] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_table_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(853),
  [1230] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_table_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1388),
  [1233] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_postings_order_clause, 2, 0, 0),
  [1235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameterized_type, 4, 0, 0),
  [1237] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(662),
  [1240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_name, 1, 0, 0),
  [1242] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(675),
  [1245] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_create_statement, 2, 0, 0),
  [1247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1560),
  [1249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1562),
  [1251] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_create_statement, 3, 0, 0),
  [1253] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 1, 0, 0),
  [1255] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_statement, 11, 0, 0),
  [1257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1648),
  [1259] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_statement, 12, 0, 0),
  [1261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_clause, 4, 0, 0),
  [1263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1519),
  [1265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1521),
  [1267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(946),
  [1269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [1271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_type_clause, 8, 0, 0),
  [1273] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_view_clause, 8, 0, 0),
  [1275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(918),
  [1277] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_clause, 3, 0, 0),
  [1279] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_type_clause, 7, 0, 0),
  [1281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_type_clause, 6, 0, 0),
  [1283] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(726),
  [1286] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(667),
  [1289] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(724),
  [1292] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_clause, 4, 0, 0),
  [1294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_clause, 2, 0, 0),
  [1296] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(748),
  [1299] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_scope_statement, 3, 0, 0),
  [1301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1502),
  [1303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1365),
  [1305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1374),
  [1307] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_analyzer_statement, 3, 0, 0),
  [1309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1691),
  [1311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1262),
  [1313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1197),
  [1315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat2, 2, 0, 0),
  [1317] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat2, 2, 0, 0), SHIFT_REPEAT(1291),
  [1320] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat2, 3, 0, 0),
  [1322] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_clause, 3, 0, 0),
  [1324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1276),
  [1326] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_define_analyzer_statement_repeat1, 2, 0, 0),
  [1328] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_analyzer_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1691),
  [1331] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_analyzer_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1262),
  [1334] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_analyzer_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1197),
  [1337] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_analyzer_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1692),
  [1340] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_split_clause, 4, 0, 0),
  [1342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1576),
  [1344] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(700),
  [1347] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat2, 2, 0, 0), SHIFT_REPEAT(1314),
  [1350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_permissions_for_clause, 2, 0, 0),
  [1352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1314),
  [1354] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_scope_statement, 5, 0, 0),
  [1356] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_split_clause, 3, 0, 0),
  [1358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat2, 4, 0, 0),
  [1360] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_define_scope_statement_repeat1, 2, 0, 0),
  [1362] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_scope_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1692),
  [1365] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_scope_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1502),
  [1368] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_scope_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1365),
  [1371] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_scope_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1374),
  [1374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 4, 0, 0),
  [1376] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_user_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1576),
  [1379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relate_statement, 7, 0, 0),
  [1381] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(707),
  [1384] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_scope_statement, 4, 0, 0),
  [1386] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_clause, 2, 0, 0),
  [1388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_split_clause, 2, 0, 0),
  [1390] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relate_statement, 6, 0, 0),
  [1392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1291),
  [1394] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_clause, 2, 0, 0),
  [1396] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_analyzer_statement, 4, 0, 0),
  [1398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1364),
  [1400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1621),
  [1402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1622),
  [1404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1623),
  [1406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1294),
  [1408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1625),
  [1410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1354),
  [1412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1404),
  [1414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1349),
  [1416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1346),
  [1418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2, 0, 0),
  [1420] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_statement, 13, 0, 0),
  [1422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1360),
  [1424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1351),
  [1426] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat2, 2, 0, 0), SHIFT_REPEAT(1318),
  [1429] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat2, 2, 0, 0), SHIFT_REPEAT(1324),
  [1432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1345),
  [1434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1339),
  [1436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1459),
  [1438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1460),
  [1440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1334),
  [1442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1333),
  [1444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(991),
  [1446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(996),
  [1448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(993),
  [1450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1318),
  [1452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_changefeed_clause, 2, 0, 0),
  [1454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_view_clause, 9, 0, 0),
  [1456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_criteria, 2, 0, 0),
  [1458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [1460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1862),
  [1462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [1464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_readonly_clause, 1, 0, 0),
  [1466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3, 0, 0),
  [1468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [1470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1864),
  [1472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [1474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 5, 0, 0),
  [1476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1703),
  [1478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_create_target, 1, 0, 0),
  [1480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tokenizers_clause, 3, 0, 0),
  [1482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1270),
  [1484] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_statement, 14, 0, 0),
  [1486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_clause, 3, 0, 0),
  [1488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(651),
  [1490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_clause, 4, 0, 0),
  [1492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0),
  [1494] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(651),
  [1497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tokenizers_clause_repeat1, 2, 0, 0),
  [1499] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tokenizers_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1270),
  [1502] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_filters_clause_repeat1, 2, 0, 0),
  [1504] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filters_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1170),
  [1507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_filters_clause, 3, 0, 0),
  [1509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1170),
  [1511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_criteria, 3, 0, 0),
  [1513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tokenizers_clause, 2, 0, 0),
  [1515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_clause, 2, 0, 0),
  [1517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relate_subject, 1, 0, 0),
  [1519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_filters_clause, 2, 0, 0),
  [1521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [1523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_analyzer_filters, 6, 0, 0),
  [1525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [1527] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(681),
  [1530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [1532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [1534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [1536] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_index_statement, 6, 0, 0),
  [1538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [1540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1849),
  [1542] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_analyzer_filters, 4, 0, 0),
  [1544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [1546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [1548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [1550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [1552] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(638),
  [1555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_clause, 3, 0, 0),
  [1557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1490),
  [1559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [1561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [1563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [1565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [1567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1046),
  [1569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [1571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [1573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [1575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [1577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fetch_clause, 2, 0, 0),
  [1579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [1581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 6, 0, 0),
  [1583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [1585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat3, 2, 0, 0),
  [1587] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat3, 2, 0, 0), SHIFT_REPEAT(1490),
  [1590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_clause, 2, 0, 0),
  [1592] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unset_clause, 2, 0, 0),
  [1594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [1596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1829),
  [1598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1381),
  [1600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [1602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [1604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [1606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [1608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [1610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [1612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [1614] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relate_statement, 8, 0, 0),
  [1616] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_index_statement, 5, 0, 0),
  [1618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [1620] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_analyzer_tokenizers, 1, 0, 0),
  [1622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [1624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_analyzer_filters, 1, 0, 0),
  [1626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [1628] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_create_statement, 4, 0, 0),
  [1630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [1632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [1634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [1636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [1638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [1640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [1642] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_define_index_statement_repeat1, 2, 0, 0),
  [1644] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_index_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1236),
  [1647] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_index_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1849),
  [1650] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unset_clause, 3, 0, 0),
  [1652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_index_statement, 7, 0, 0),
  [1654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [1656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [1658] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 5, 0, 0),
  [1660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [1662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fetch_clause, 3, 0, 0),
  [1664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_permissions_basic_clause, 2, 0, 0),
  [1666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_content_clause, 2, 0, 0),
  [1668] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fields_columns_clause, 3, 0, 0),
  [1670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_signin_clause, 2, 0, 0),
  [1672] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_session_clause, 2, 0, 0),
  [1674] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(751),
  [1677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1443),
  [1679] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat3, 2, 0, 0), SHIFT_REPEAT(1443),
  [1682] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_define_function_statement_repeat1, 2, 0, 0),
  [1684] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_function_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1389),
  [1687] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_function_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1692),
  [1690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_clause, 2, 0, 0),
  [1692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_statement, 15, 0, 0),
  [1694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_create_statement, 5, 0, 0),
  [1696] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 6, 0, 0),
  [1698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1531),
  [1700] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 7, 0, 0),
  [1702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_function_statement, 5, 0, 0),
  [1704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1389),
  [1706] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_signup_clause, 2, 0, 0),
  [1708] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relate_statement, 9, 0, 0),
  [1710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_limit_clause, 2, 0, 0),
  [1712] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_function_statement, 6, 0, 0),
  [1714] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat3, 2, 0, 0), SHIFT_REPEAT(1531),
  [1717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_function_statement, 7, 0, 0),
  [1719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fields_columns_clause, 2, 0, 0),
  [1721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_patch_clause, 2, 0, 0),
  [1723] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_merge_clause, 2, 0, 0),
  [1725] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_function_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1385),
  [1728] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_when_then_clause, 2, 0, 0),
  [1730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1403),
  [1732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [1734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1740),
  [1736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1689),
  [1738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1450),
  [1740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_when_then_clause_repeat1, 2, 0, 0),
  [1742] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_when_then_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1403),
  [1745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_when_then_clause, 3, 0, 0),
  [1747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_when_then_clause, 1, 0, 0),
  [1749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1359),
  [1751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_function, 5, 0, 0),
  [1753] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_function, 6, 0, 0),
  [1755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1385),
  [1757] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(696),
  [1760] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_clause, 3, 0, 0),
  [1762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_when_then_clause, 5, 0, 0),
  [1764] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_when_then_clause, 4, 0, 0),
  [1766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [1768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1302),
  [1770] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_function, 7, 0, 0),
  [1772] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat3, 2, 0, 0), SHIFT_REPEAT(1450),
  [1775] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_function_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1359),
  [1778] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 8, 0, 0),
  [1780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [1782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1777),
  [1784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1776),
  [1786] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_user_statement, 11, 0, 0),
  [1788] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_event_statement, 5, 0, 0),
  [1790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [1792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [1794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [1796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(656),
  [1798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1286),
  [1800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(933),
  [1802] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_create_statement, 6, 0, 0),
  [1804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_timeout_clause, 2, 0, 0),
  [1806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [1808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [1810] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 7, 0, 0),
  [1812] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_user_statement, 9, 0, 0),
  [1814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unique_clause, 1, 0, 0),
  [1816] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_namespace_statement, 3, 0, 0),
  [1818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [1820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [1822] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_user_statement, 10, 0, 0),
  [1824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(658),
  [1826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [1828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(678),
  [1830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [1832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relate_statement, 10, 0, 0),
  [1834] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_statement, 16, 0, 0),
  [1836] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(753),
  [1839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 13, 0, 0),
  [1841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1471),
  [1843] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_begin_statement, 1, 0, 0),
  [1845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1379),
  [1847] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cancel_statement, 1, 0, 0),
  [1849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1378),
  [1851] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_commit_statement, 1, 0, 0),
  [1853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1375),
  [1855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1077),
  [1857] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat1, 2, 0, 0),
  [1859] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1286),
  [1862] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 12, 0, 0),
  [1864] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_explain_clause, 1, 0, 0),
  [1866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1392),
  [1868] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat3, 2, 0, 0), SHIFT_REPEAT(1471),
  [1871] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 14, 0, 0),
  [1873] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 15, 0, 0),
  [1875] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parallel_clause, 1, 0, 0),
  [1877] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 16, 0, 0),
  [1879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(860),
  [1881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1742),
  [1883] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 17, 0, 0),
  [1885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(774),
  [1887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(987),
  [1889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(637),
  [1891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1824),
  [1893] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_remove_statement, 3, 0, 0),
  [1895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1507),
  [1897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1402),
  [1899] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat3, 2, 0, 0), SHIFT_REPEAT(1507),
  [1902] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relate_statement, 11, 0, 0),
  [1904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [1906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21),
  [1908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1587),
  [1910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1245),
  [1912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1852),
  [1914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1851),
  [1916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1759),
  [1918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2),
  [1920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1610),
  [1922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1574),
  [1924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(632),
  [1926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [1928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [1930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [1932] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_statement, 17, 0, 0),
  [1934] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_remove_statement, 7, 0, 0),
  [1936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1247),
  [1938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1685),
  [1940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1684),
  [1942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [1944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1679),
  [1946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1231),
  [1948] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_create_statement, 7, 0, 0),
  [1950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [1952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1616),
  [1954] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 6, 0, 0),
  [1956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1218),
  [1958] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(754),
  [1961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1724),
  [1963] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_remove_statement, 4, 0, 0),
  [1965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1609),
  [1967] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 9, 0, 0),
  [1969] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_remove_statement, 5, 0, 0),
  [1971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_token_statement, 9, 0, 0),
  [1973] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 4, 0, 0),
  [1975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1681),
  [1977] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 7, 0, 0),
  [1979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [1981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [1983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [1985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [1987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(693),
  [1989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(126),
  [1991] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_namespace_statement, 4, 0, 0),
  [1993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(968),
  [1995] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 5, 0, 0),
  [1997] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 8, 0, 0),
  [1999] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_remove_statement, 6, 0, 0),
  [2001] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_commit_statement, 2, 0, 0),
  [2003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [2005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(118),
  [2007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1577),
  [2009] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cancel_statement, 2, 0, 0),
  [2011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_begin_statement, 2, 0, 0),
  [2013] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 1, 0, 0),
  [2015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(620),
  [2017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [2019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [2021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(755),
  [2023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(649),
  [2025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(655),
  [2027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [2029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(276),
  [2031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1628),
  [2033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_explain_clause, 2, 0, 0),
  [2035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [2037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [2039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [2041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [2043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [2045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(615),
  [2047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [2049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [2051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 8, 0, 0),
  [2053] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_event_statement, 6, 0, 0),
  [2055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [2057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [2059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [2061] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_token_statement, 8, 0, 0),
  [2063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(628),
  [2065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1575),
  [2067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [2069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(108),
  [2071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1655),
  [2073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [2075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [2077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1860),
  [2079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1859),
  [2081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [2083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [2085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [2087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [2089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1858),
  [2091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1697),
  [2093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [2095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [2097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1831),
  [2099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1611),
  [2101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [2103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1850),
  [2105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(688),
  [2107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [2109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1446),
  [2111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1695),
  [2113] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expressions, 1, 0, 0),
  [2115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [2117] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_graph_path_repeat1, 2, 0, 0), SHIFT_REPEAT(616),
  [2120] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_graph_path_repeat1, 2, 0, 0),
  [2122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1340),
  [2124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [2126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1595),
  [2128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1645),
  [2130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1773),
  [2132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [2134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [2136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1642),
  [2138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1322),
  [2140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1373),
  [2142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [2144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [2146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [2148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1668),
  [2150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1795),
  [2152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1759),
  [2154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1726),
  [2156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1819),
  [2158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1284),
  [2160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1724),
  [2162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1469),
  [2164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1593),
  [2166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [2168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1352),
  [2170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1329),
  [2172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_content, 1, 0, 0),
  [2174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [2176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1696),
  [2178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1638),
  [2180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [2182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1639),
  [2184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [2186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [2188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1627),
  [2190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1788),
  [2192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [2194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [2196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [2198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1436),
  [2200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1602),
  [2202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_predicate, 2, 0, 0),
  [2204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [2206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [2208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1434),
  [2210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [2212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1800),
  [2214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1538),
  [2216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1672),
  [2218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [2220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [2222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(683),
  [2224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [2226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [2228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [2230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1494),
  [2232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1585),
  [2234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1706),
  [2236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [2238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1589),
  [2240] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1642),
  [2243] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat1, 2, 0, 0),
  [2245] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_param_list_repeat1, 4, 0, 0),
  [2247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [2249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [2251] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_content_repeat1, 2, 0, 0), SHIFT_REPEAT(1329),
  [2254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_content_repeat1, 2, 0, 0),
  [2256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [2258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [2260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1517),
  [2262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1674),
  [2264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [2266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [2268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [2270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1492),
  [2272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1493),
  [2274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [2276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [2278] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_select_statement_repeat1, 2, 0, 0),
  [2280] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_select_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(608),
  [2283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1496),
  [2285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [2287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1372),
  [2289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1499),
  [2291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [2293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1500),
  [2295] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_content, 2, 0, 0),
  [2297] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_param_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1852),
  [2300] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_param_list_repeat1, 2, 0, 0),
  [2302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [2304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1588),
  [2306] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expressions_repeat1, 2, 0, 0), SHIFT_REPEAT(371),
  [2309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_expressions_repeat1, 2, 0, 0),
  [2311] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expressions_repeat1, 2, 0, 0), SHIFT_REPEAT(365),
  [2314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [2316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1814),
  [2318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [2320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [2322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1578),
  [2324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [2326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [2328] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat2, 2, 0, 0),
  [2330] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(1695),
  [2333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1533),
  [2335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [2337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [2339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1573),
  [2341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1872),
  [2343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [2345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [2347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [2349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(639),
  [2351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [2353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1644),
  [2355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1783),
  [2357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(994),
  [2359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [2361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1699),
  [2363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1554),
  [2365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inclusive_predicate, 1, 0, 0),
  [2367] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat2, 4, 0, 0),
  [2369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [2371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [2373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_predicate, 3, 0, 0),
  [2375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1650),
  [2377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [2379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [2381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(647),
  [2383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [2385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_predicate, 3, 0, 0),
  [2387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1477),
  [2389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1478),
  [2391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [2393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_exists_clause, 2, 0, 0),
  [2395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [2397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [2399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1832),
  [2401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(857),
  [2403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat2, 5, 0, 0),
  [2405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [2407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1790),
  [2409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1791),
  [2411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(740),
  [2413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(697),
  [2415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [2417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_predicate, 4, 0, 0),
  [2419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1681),
  [2421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [2423] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_not_exists_clause, 3, 0, 0),
  [2425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [2427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(708),
  [2429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1050),
  [2431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1662),
  [2433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1095),
  [2435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1124),
  [2437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [2439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(674),
  [2441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [2443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(695),
  [2445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1722),
  [2447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [2449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1580),
  [2451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1737),
  [2453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1408),
  [2455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [2457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1044),
  [2459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_token_type_clause, 2, 0, 0),
  [2461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1840),
  [2463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1086),
  [2465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1766),
  [2467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [2469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1439),
  [2471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [2473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1025),
  [2475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1444),
  [2477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1071),
  [2479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(849),
  [2481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1853),
  [2483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1335),
  [2485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [2487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1055),
  [2489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1051),
  [2491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1047),
  [2493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [2495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(652),
  [2497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1039),
  [2499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1630),
  [2501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1793),
  [2503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [2505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1038),
  [2507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1620),
  [2509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1037),
  [2511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1468),
  [2513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [2515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1474),
  [2517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1033),
  [2519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(684),
  [2521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(609),
  [2523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1865),
  [2525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1581),
  [2527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [2529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1028),
  [2531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1868),
  [2533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [2535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1030),
  [2537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(851),
  [2539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [2541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1401),
  [2543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1045),
  [2545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1736),
  [2547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1052),
  [2549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [2551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [2553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1065),
  [2555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(773),
  [2557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [2559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [2561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1462),
  [2563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [2565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1083),
  [2567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1804),
  [2569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1807),
  [2571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [2573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1090),
  [2575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1441),
  [2577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(743),
  [2579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [2581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [2583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1570),
  [2585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1871),
  [2587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(775),
  [2589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1098),
  [2591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1693),
  [2593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1080),
  [2595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [2597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(665),
  [2599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [2601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [2603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1068),
  [2605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [2607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1701),
  [2609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1612),
  [2611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1715),
  [2613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [2615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1734),
  [2617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1741),
  [2619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(694),
  [2621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [2623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_param_list, 2, 0, 0),
  [2625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1386),
  [2627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [2629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(730),
  [2631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1799),
  [2633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1596),
  [2635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [2637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [2639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [2641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [2643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1629),
  [2645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1666),
  [2647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1863),
  [2649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1096),
  [2651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1678),
  [2653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [2655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_version, 3, 0, 0),
  [2657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [2659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [2661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(848),
  [2663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1680),
  [2665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [2667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1452),
  [2669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(733),
  [2671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [2673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [2675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [2677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1838),
  [2679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [2681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [2683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1760),
  [2685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [2687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1785),
  [2689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1070),
  [2691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1451),
  [2693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [2695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1861),
  [2697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1846),
  [2699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1698),
  [2701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [2703] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [2705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1700),
  [2707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1792),
  [2709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1063),
  [2711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1342),
  [2713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [2715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [2717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1784),
  [2719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(931),
  [2721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1845),
  [2723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [2725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1660),
  [2727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_param_list, 6, 0, 0),
  [2729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_param_list, 5, 0, 0),
  [2731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1854),
  [2733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(836),
  [2735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1323),
  [2737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [2739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [2741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [2743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1855),
  [2745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1856),
  [2747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1857),
  [2749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [2751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [2753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [2755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(823),
  [2757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [2759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [2761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(980),
  [2763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1748),
  [2765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [2767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(855),
  [2769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1572),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_surrealql(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
